$emoji-map: (
"2049": "interrobang",
"2122": "tm",
"2139": "information_source",
"2194": "left_right_arrow",
"2195": "arrow_up_down",
"2196": "arrow_upper_left",
"2197": "arrow_upper_right",
"2198": "arrow_lower_right",
"2199": "arrow_lower_left",
"2328": "keyboard",
"2600": "sunny",
"2601": "cloud",
"2602": "umbrella2",
"2603": "snowman2",
"2604": "comet",
"2611": "ballot_box_with_check",
"2614": "umbrella",
"2615": "coffee",
"2618": "shamrock",
"2620": "skull_crossbones",
"2622": "radioactive",
"2623": "biohazard",
"2626": "orthodox_cross",
"2638": "wheel_of_dharma",
"2639": "frowning2",
"2640": "female_sign",
"2642": "male_sign",
"2648": "aries",
"2649": "taurus",
"2650": "sagittarius",
"2651": "capricorn",
"2652": "aquarius",
"2653": "pisces",
"2660": "spades",
"2663": "clubs",
"2665": "hearts",
"2666": "diamonds",
"2668": "hotsprings",
"2692": "hammer_pick",
"2693": "anchor",
"2694": "crossed_swords",
"2695": "medical_symbol",
"2696": "scales",
"2697": "alembic",
"2699": "gear",
"2702": "scissors",
"2705": "white_check_mark",
"2708": "airplane",
"2709": "envelope",
"2712": "black_nib",
"2714": "heavy_check_mark",
"2716": "heavy_multiplication_x",
"2721": "star_of_david",
"2728": "sparkles",
"2733": "eight_spoked_asterisk",
"2734": "eight_pointed_black_star",
"2744": "snowflake",
"2747": "sparkle",
"2753": "question",
"2754": "grey_question",
"2755": "grey_exclamation",
"2757": "exclamation",
"2763": "heart_exclamation",
"2764": "heart",
"2795": "heavy_plus_sign",
"2796": "heavy_minus_sign",
"2797": "heavy_division_sign",
"2934": "arrow_heading_up",
"2935": "arrow_heading_down",
"3030": "wavy_dash",
"3297": "congratulations",
"3299": "secret",
"1f9e1": "orange_heart",
"1f49b": "yellow_heart",
"1f49a": "green_heart",
"1f499": "blue_heart",
"1f49c": "purple_heart",
"1f5a4": "black_heart",
"1f494": "broken_heart",
"1f495": "two_hearts",
"1f49e": "revolving_hearts",
"1f493": "heartbeat",
"1f497": "heartpulse",
"1f496": "sparkling_heart",
"1f498": "cupid",
"1f49d": "gift_heart",
"1f49f": "heart_decoration",
"262e": "peace",
"271d": "cross",
"262a": "star_and_crescent",
"1f549": "om_symbol",
"1f52f": "six_pointed_star",
"1f54e": "menorah",
"262f": "yin_yang",
"1f6d0": "place_of_worship",
"26ce": "ophiuchus",
"264a": "gemini",
"264b": "cancer",
"264c": "leo",
"264d": "virgo",
"264e": "libra",
"264f": "scorpius",
"1f194": "id",
"269b": "atom",
"267e": "infinity",
"1f251": "accept",
"1f4f4": "mobile_phone_off",
"1f4f3": "vibration_mode",
"1f236": "u6709",
"1f21a": "u7121",
"1f238": "u7533",
"1f23a": "u55b6",
"1f237": "u6708",
"1f19a": "vs",
"1f4ae": "white_flower",
"1f250": "ideograph_advantage",
"1f234": "u5408",
"1f235": "u6e80",
"1f239": "u5272",
"1f232": "u7981",
"1f170": "a",
"1f171": "b",
"1f18e": "ab",
"1f191": "cl",
"1f17e": "o2",
"1f198": "sos",
"274c": "x",
"2b55": "o",
"1f6d1": "octagonal_sign",
"26d4": "no_entry",
"1f4db": "name_badge",
"1f6ab": "no_entry_sign",
"1f4af": "100",
"1f4a2": "anger",
"1f6b7": "no_pedestrians",
"1f6af": "do_not_litter",
"1f6b3": "no_bicycles",
"1f6b1": "non-potable_water",
"1f51e": "underage",
"1f4f5": "no_mobile_phones",
"1f6ad": "no_smoking",
"203c": "bangbang",
"1f505": "low_brightness",
"1f506": "high_brightness",
"303d": "part_alternation_mark",
"26a0": "warning",
"1f6b8": "children_crossing",
"1f531": "trident",
"269c": "fleur-de-lis",
"1f530": "beginner",
"267b": "recycle",
"1f22f": "u6307",
"1f4b9": "chart",
"274e": "negative_squared_cross_mark",
"1f310": "globe_with_meridians",
"1f4a0": "diamond_shape_with_a_dot_inside",
"24c2": "m",
"1f300": "cyclone",
"1f4a4": "zzz",
"1f3e7": "atm",
"1f6be": "wc",
"267f": "wheelchair",
"1f17f": "parking",
"1f233": "u7a7a",
"1f202": "sa",
"1f6c2": "passport_control",
"1f6c3": "customs",
"1f6c4": "baggage_claim",
"1f6c5": "left_luggage",
"1f6b9": "mens",
"1f6ba": "womens",
"1f6bc": "baby_symbol",
"1f6bb": "restroom",
"1f6ae": "put_litter_in_its_place",
"1f3a6": "cinema",
"1f4f6": "signal_strength",
"1f201": "koko",
"1f523": "symbols",
"1f524": "abc",
"1f521": "abcd",
"1f520": "capital_abcd",
"1f196": "ng",
"1f197": "ok",
"1f199": "up",
"1f192": "cool",
"1f195": "new",
"1f193": "free",
"0030-20e3": "zero",
"0031-20e3": "one",
"0032-20e3": "two",
"0033-20e3": "three",
"0034-20e3": "four",
"0035-20e3": "five",
"0036-20e3": "six",
"0037-20e3": "seven",
"0038-20e3": "eight",
"0039-20e3": "nine",
"1f51f": "keycap_ten",
"1f522": "1234",
"0023-20e3": "hash",
"002a-20e3": "asterisk",
"23cf": "eject",
"25b6": "arrow_forward",
"23f8": "pause_button",
"23ef": "play_pause",
"23f9": "stop_button",
"23fa": "record_button",
"23ed": "track_next",
"23ee": "track_previous",
"23e9": "fast_forward",
"23ea": "rewind",
"23eb": "arrow_double_up",
"23ec": "arrow_double_down",
"25c0": "arrow_backward",
"1f53c": "arrow_up_small",
"1f53d": "arrow_down_small",
"27a1": "arrow_right",
"2b05": "arrow_left",
"2b06": "arrow_up",
"2b07": "arrow_down",
"21aa": "arrow_right_hook",
"21a9": "leftwards_arrow_with_hook",
"1f500": "twisted_rightwards_arrows",
"1f501": "repeat",
"1f502": "repeat_one",
"1f504": "arrows_counterclockwise",
"1f503": "arrows_clockwise",
"1f3b5": "musical_note",
"1f3b6": "notes",
"1f4b2": "heavy_dollar_sign",
"1f4b1": "currency_exchange",
"00a9": "copyright",
"00ae": "registered",
"27b0": "curly_loop",
"27bf": "loop",
"1f51a": "end",
"1f519": "back",
"1f51b": "on",
"1f51d": "top",
"1f51c": "soon",
"1f518": "radio_button",
"26aa": "white_circle",
"26ab": "black_circle",
"1f534": "red_circle",
"1f535": "blue_circle",
"1f53a": "small_red_triangle",
"1f53b": "small_red_triangle_down",
"1f538": "small_orange_diamond",
"1f539": "small_blue_diamond",
"1f536": "large_orange_diamond",
"1f537": "large_blue_diamond",
"1f533": "white_square_button",
"1f532": "black_square_button",
"25aa": "black_small_square",
"25ab": "white_small_square",
"25fe": "black_medium_small_square",
"25fd": "white_medium_small_square",
"25fc": "black_medium_square",
"25fb": "white_medium_square",
"2b1b": "black_large_square",
"2b1c": "white_large_square",
"1f508": "speaker",
"1f507": "mute",
"1f509": "sound",
"1f50a": "loud_sound",
"1f514": "bell",
"1f515": "no_bell",
"1f4e3": "mega",
"1f4e2": "loudspeaker",
"1f5e8": "speech_left",
"1f441-1f5e8": "eye_in_speech_bubble",
"1f4ac": "speech_balloon",
"1f4ad": "thought_balloon",
"1f5ef": "anger_right",
"1f0cf": "black_joker",
"1f3b4": "flower_playing_cards",
"1f004": "mahjong",
"1f550": "clock1",
"1f551": "clock2",
"1f552": "clock3",
"1f553": "clock4",
"1f554": "clock5",
"1f555": "clock6",
"1f556": "clock7",
"1f557": "clock8",
"1f558": "clock9",
"1f559": "clock10",
"1f55a": "clock11",
"1f55b": "clock12",
"1f55c": "clock130",
"1f55d": "clock230",
"1f55e": "clock330",
"1f55f": "clock430",
"1f560": "clock530",
"1f561": "clock630",
"1f562": "clock730",
"1f563": "clock830",
"1f564": "clock930",
"1f565": "clock1030",
"1f566": "clock1130",
"1f567": "clock1230",
"0030": "digit_zero",
"0031": "digit_one",
"0032": "digit_two",
"0033": "digit_three",
"0034": "digit_four",
"0035": "digit_five",
"0036": "digit_six",
"0037": "digit_seven",
"0038": "digit_eight",
"0039": "digit_nine",
"0023": "pound_symbol",
"002a": "asterisk_symbol",
"26bd": "soccer",
"1f3c0": "basketball",
"1f3c8": "football",
"26be": "baseball",
"1f94e": "softball",
"1f3be": "tennis",
"1f3d0": "volleyball",
"1f3c9": "rugby_football",
"1f3b1": "8ball",
"1f3d3": "ping_pong",
"1f3f8": "badminton",
"1f945": "goal",
"1f3d2": "hockey",
"1f3d1": "field_hockey",
"1f3cf": "cricket_game",
"1f94d": "lacrosse",
"26f3": "golf",
"1f94f": "flying_disc",
"1f3f9": "bow_and_arrow",
"1f3a3": "fishing_pole_and_fish",
"1f94a": "boxing_glove",
"1f94b": "martial_arts_uniform",
"1f3bd": "running_shirt_with_sash",
"1f6f9": "skateboard",
"26f8": "ice_skate",
"1f94c": "curling_stone",
"1f6f7": "sled",
"1f3bf": "ski",
"26f7": "skier",
"1f3c2": "snowboarder",
"1f3c2-1f3fb": "snowboarder_tone1",
"1f3c2-1f3fc": "snowboarder_tone2",
"1f3c2-1f3fd": "snowboarder_tone3",
"1f3c2-1f3fe": "snowboarder_tone4",
"1f3c2-1f3ff": "snowboarder_tone5",
"1f3cb": "person_lifting_weights",
"1f3cb-1f3fb": "person_lifting_weights_tone1",
"1f3cb-1f3fc": "person_lifting_weights_tone2",
"1f3cb-1f3fd": "person_lifting_weights_tone3",
"1f3cb-1f3fe": "person_lifting_weights_tone4",
"1f3cb-1f3ff": "person_lifting_weights_tone5",
"1f3cb-2640": "woman_lifting_weights",
"1f3cb-1f3fb-2640": "woman_lifting_weights_tone1",
"1f3cb-1f3fc-2640": "woman_lifting_weights_tone2",
"1f3cb-1f3fd-2640": "woman_lifting_weights_tone3",
"1f3cb-1f3fe-2640": "woman_lifting_weights_tone4",
"1f3cb-1f3ff-2640": "woman_lifting_weights_tone5",
"1f3cb-2642": "man_lifting_weights",
"1f3cb-1f3fb-2642": "man_lifting_weights_tone1",
"1f3cb-1f3fc-2642": "man_lifting_weights_tone2",
"1f3cb-1f3fd-2642": "man_lifting_weights_tone3",
"1f3cb-1f3fe-2642": "man_lifting_weights_tone4",
"1f3cb-1f3ff-2642": "man_lifting_weights_tone5",
"1f93c": "people_wrestling",
"1f93c-2640": "women_wrestling",
"1f93c-2642": "men_wrestling",
"1f938": "person_doing_cartwheel",
"1f938-1f3fb": "person_doing_cartwheel_tone1",
"1f938-1f3fc": "person_doing_cartwheel_tone2",
"1f938-1f3fd": "person_doing_cartwheel_tone3",
"1f938-1f3fe": "person_doing_cartwheel_tone4",
"1f938-1f3ff": "person_doing_cartwheel_tone5",
"1f938-2640": "woman_cartwheeling",
"1f938-1f3fb-2640": "woman_cartwheeling_tone1",
"1f938-1f3fc-2640": "woman_cartwheeling_tone2",
"1f938-1f3fd-2640": "woman_cartwheeling_tone3",
"1f938-1f3fe-2640": "woman_cartwheeling_tone4",
"1f938-1f3ff-2640": "woman_cartwheeling_tone5",
"1f938-2642": "man_cartwheeling",
"1f938-1f3fb-2642": "man_cartwheeling_tone1",
"1f938-1f3fc-2642": "man_cartwheeling_tone2",
"1f938-1f3fd-2642": "man_cartwheeling_tone3",
"1f938-1f3fe-2642": "man_cartwheeling_tone4",
"1f938-1f3ff-2642": "man_cartwheeling_tone5",
"26f9": "person_bouncing_ball",
"26f9-1f3fb": "person_bouncing_ball_tone1",
"26f9-1f3fc": "person_bouncing_ball_tone2",
"26f9-1f3fd": "person_bouncing_ball_tone3",
"26f9-1f3fe": "person_bouncing_ball_tone4",
"26f9-1f3ff": "person_bouncing_ball_tone5",
"26f9-2640": "woman_bouncing_ball",
"26f9-1f3fb-2640": "woman_bouncing_ball_tone1",
"26f9-1f3fc-2640": "woman_bouncing_ball_tone2",
"26f9-1f3fd-2640": "woman_bouncing_ball_tone3",
"26f9-1f3fe-2640": "woman_bouncing_ball_tone4",
"26f9-1f3ff-2640": "woman_bouncing_ball_tone5",
"26f9-2642": "man_bouncing_ball",
"26f9-1f3fb-2642": "man_bouncing_ball_tone1",
"26f9-1f3fc-2642": "man_bouncing_ball_tone2",
"26f9-1f3fd-2642": "man_bouncing_ball_tone3",
"26f9-1f3fe-2642": "man_bouncing_ball_tone4",
"26f9-1f3ff-2642": "man_bouncing_ball_tone5",
"1f93a": "person_fencing",
"1f93e": "person_playing_handball",
"1f93e-1f3fb": "person_playing_handball_tone1",
"1f93e-1f3fc": "person_playing_handball_tone2",
"1f93e-1f3fd": "person_playing_handball_tone3",
"1f93e-1f3fe": "person_playing_handball_tone4",
"1f93e-1f3ff": "person_playing_handball_tone5",
"1f93e-2640": "woman_playing_handball",
"1f93e-1f3fb-2640": "woman_playing_handball_tone1",
"1f93e-1f3fc-2640": "woman_playing_handball_tone2",
"1f93e-1f3fd-2640": "woman_playing_handball_tone3",
"1f93e-1f3fe-2640": "woman_playing_handball_tone4",
"1f93e-1f3ff-2640": "woman_playing_handball_tone5",
"1f93e-2642": "man_playing_handball",
"1f93e-1f3fb-2642": "man_playing_handball_tone1",
"1f93e-1f3fc-2642": "man_playing_handball_tone2",
"1f93e-1f3fd-2642": "man_playing_handball_tone3",
"1f93e-1f3fe-2642": "man_playing_handball_tone4",
"1f93e-1f3ff-2642": "man_playing_handball_tone5",
"1f3cc": "person_golfing",
"1f3cc-1f3fb": "person_golfing_tone1",
"1f3cc-1f3fc": "person_golfing_tone2",
"1f3cc-1f3fd": "person_golfing_tone3",
"1f3cc-1f3fe": "person_golfing_tone4",
"1f3cc-1f3ff": "person_golfing_tone5",
"1f3cc-2640": "woman_golfing",
"1f3cc-1f3fb-2640": "woman_golfing_tone1",
"1f3cc-1f3fc-2640": "woman_golfing_tone2",
"1f3cc-1f3fd-2640": "woman_golfing_tone3",
"1f3cc-1f3fe-2640": "woman_golfing_tone4",
"1f3cc-1f3ff-2640": "woman_golfing_tone5",
"1f3cc-2642": "man_golfing",
"1f3cc-1f3fb-2642": "man_golfing_tone1",
"1f3cc-1f3fc-2642": "man_golfing_tone2",
"1f3cc-1f3fd-2642": "man_golfing_tone3",
"1f3cc-1f3fe-2642": "man_golfing_tone4",
"1f3cc-1f3ff-2642": "man_golfing_tone5",
"1f3c7": "horse_racing",
"1f3c7-1f3fb": "horse_racing_tone1",
"1f3c7-1f3fc": "horse_racing_tone2",
"1f3c7-1f3fd": "horse_racing_tone3",
"1f3c7-1f3fe": "horse_racing_tone4",
"1f3c7-1f3ff": "horse_racing_tone5",
"1f9d8": "person_in_lotus_position",
"1f9d8-1f3fb": "person_in_lotus_position_tone1",
"1f9d8-1f3fc": "person_in_lotus_position_tone2",
"1f9d8-1f3fd": "person_in_lotus_position_tone3",
"1f9d8-1f3fe": "person_in_lotus_position_tone4",
"1f9d8-1f3ff": "person_in_lotus_position_tone5",
"1f9d8-2640": "woman_in_lotus_position",
"1f9d8-1f3fb-2640": "woman_in_lotus_position_tone1",
"1f9d8-1f3fc-2640": "woman_in_lotus_position_tone2",
"1f9d8-1f3fd-2640": "woman_in_lotus_position_tone3",
"1f9d8-1f3fe-2640": "woman_in_lotus_position_tone4",
"1f9d8-1f3ff-2640": "woman_in_lotus_position_tone5",
"1f9d8-2642": "man_in_lotus_position",
"1f9d8-1f3fb-2642": "man_in_lotus_position_tone1",
"1f9d8-1f3fc-2642": "man_in_lotus_position_tone2",
"1f9d8-1f3fd-2642": "man_in_lotus_position_tone3",
"1f9d8-1f3fe-2642": "man_in_lotus_position_tone4",
"1f9d8-1f3ff-2642": "man_in_lotus_position_tone5",
"1f3c4": "person_surfing",
"1f3c4-1f3fb": "person_surfing_tone1",
"1f3c4-1f3fc": "person_surfing_tone2",
"1f3c4-1f3fd": "person_surfing_tone3",
"1f3c4-1f3fe": "person_surfing_tone4",
"1f3c4-1f3ff": "person_surfing_tone5",
"1f3c4-2640": "woman_surfing",
"1f3c4-1f3fb-2640": "woman_surfing_tone1",
"1f3c4-1f3fc-2640": "woman_surfing_tone2",
"1f3c4-1f3fd-2640": "woman_surfing_tone3",
"1f3c4-1f3fe-2640": "woman_surfing_tone4",
"1f3c4-1f3ff-2640": "woman_surfing_tone5",
"1f3c4-2642": "man_surfing",
"1f3c4-1f3fb-2642": "man_surfing_tone1",
"1f3c4-1f3fc-2642": "man_surfing_tone2",
"1f3c4-1f3fd-2642": "man_surfing_tone3",
"1f3c4-1f3fe-2642": "man_surfing_tone4",
"1f3c4-1f3ff-2642": "man_surfing_tone5",
"1f3ca": "person_swimming",
"1f3ca-1f3fb": "person_swimming_tone1",
"1f3ca-1f3fc": "person_swimming_tone2",
"1f3ca-1f3fd": "person_swimming_tone3",
"1f3ca-1f3fe": "person_swimming_tone4",
"1f3ca-1f3ff": "person_swimming_tone5",
"1f3ca-2640": "woman_swimming",
"1f3ca-1f3fb-2640": "woman_swimming_tone1",
"1f3ca-1f3fc-2640": "woman_swimming_tone2",
"1f3ca-1f3fd-2640": "woman_swimming_tone3",
"1f3ca-1f3fe-2640": "woman_swimming_tone4",
"1f3ca-1f3ff-2640": "woman_swimming_tone5",
"1f3ca-2642": "man_swimming",
"1f3ca-1f3fb-2642": "man_swimming_tone1",
"1f3ca-1f3fc-2642": "man_swimming_tone2",
"1f3ca-1f3fd-2642": "man_swimming_tone3",
"1f3ca-1f3fe-2642": "man_swimming_tone4",
"1f3ca-1f3ff-2642": "man_swimming_tone5",
"1f93d": "person_playing_water_polo",
"1f93d-1f3fb": "person_playing_water_polo_tone1",
"1f93d-1f3fc": "person_playing_water_polo_tone2",
"1f93d-1f3fd": "person_playing_water_polo_tone3",
"1f93d-1f3fe": "person_playing_water_polo_tone4",
"1f93d-1f3ff": "person_playing_water_polo_tone5",
"1f93d-2640": "woman_playing_water_polo",
"1f93d-1f3fb-2640": "woman_playing_water_polo_tone1",
"1f93d-1f3fc-2640": "woman_playing_water_polo_tone2",
"1f93d-1f3fd-2640": "woman_playing_water_polo_tone3",
"1f93d-1f3fe-2640": "woman_playing_water_polo_tone4",
"1f93d-1f3ff-2640": "woman_playing_water_polo_tone5",
"1f93d-2642": "man_playing_water_polo",
"1f93d-1f3fb-2642": "man_playing_water_polo_tone1",
"1f93d-1f3fc-2642": "man_playing_water_polo_tone2",
"1f93d-1f3fd-2642": "man_playing_water_polo_tone3",
"1f93d-1f3fe-2642": "man_playing_water_polo_tone4",
"1f93d-1f3ff-2642": "man_playing_water_polo_tone5",
"1f6a3": "person_rowing_boat",
"1f6a3-1f3fb": "person_rowing_boat_tone1",
"1f6a3-1f3fc": "person_rowing_boat_tone2",
"1f6a3-1f3fd": "person_rowing_boat_tone3",
"1f6a3-1f3fe": "person_rowing_boat_tone4",
"1f6a3-1f3ff": "person_rowing_boat_tone5",
"1f6a3-2640": "woman_rowing_boat",
"1f6a3-1f3fb-2640": "woman_rowing_boat_tone1",
"1f6a3-1f3fc-2640": "woman_rowing_boat_tone2",
"1f6a3-1f3fd-2640": "woman_rowing_boat_tone3",
"1f6a3-1f3fe-2640": "woman_rowing_boat_tone4",
"1f6a3-1f3ff-2640": "woman_rowing_boat_tone5",
"1f6a3-2642": "man_rowing_boat",
"1f6a3-1f3fb-2642": "man_rowing_boat_tone1",
"1f6a3-1f3fc-2642": "man_rowing_boat_tone2",
"1f6a3-1f3fd-2642": "man_rowing_boat_tone3",
"1f6a3-1f3fe-2642": "man_rowing_boat_tone4",
"1f6a3-1f3ff-2642": "man_rowing_boat_tone5",
"1f9d7": "person_climbing",
"1f9d7-1f3fb": "person_climbing_tone1",
"1f9d7-1f3fc": "person_climbing_tone2",
"1f9d7-1f3fd": "person_climbing_tone3",
"1f9d7-1f3fe": "person_climbing_tone4",
"1f9d7-1f3ff": "person_climbing_tone5",
"1f9d7-2640": "woman_climbing",
"1f9d7-1f3fb-2640": "woman_climbing_tone1",
"1f9d7-1f3fc-2640": "woman_climbing_tone2",
"1f9d7-1f3fd-2640": "woman_climbing_tone3",
"1f9d7-1f3fe-2640": "woman_climbing_tone4",
"1f9d7-1f3ff-2640": "woman_climbing_tone5",
"1f9d7-2642": "man_climbing",
"1f9d7-1f3fb-2642": "man_climbing_tone1",
"1f9d7-1f3fc-2642": "man_climbing_tone2",
"1f9d7-1f3fd-2642": "man_climbing_tone3",
"1f9d7-1f3fe-2642": "man_climbing_tone4",
"1f9d7-1f3ff-2642": "man_climbing_tone5",
"1f6b5": "person_mountain_biking",
"1f6b5-1f3fb": "person_mountain_biking_tone1",
"1f6b5-1f3fc": "person_mountain_biking_tone2",
"1f6b5-1f3fd": "person_mountain_biking_tone3",
"1f6b5-1f3fe": "person_mountain_biking_tone4",
"1f6b5-1f3ff": "person_mountain_biking_tone5",
"1f6b5-2640": "woman_mountain_biking",
"1f6b5-1f3fb-2640": "woman_mountain_biking_tone1",
"1f6b5-1f3fc-2640": "woman_mountain_biking_tone2",
"1f6b5-1f3fd-2640": "woman_mountain_biking_tone3",
"1f6b5-1f3fe-2640": "woman_mountain_biking_tone4",
"1f6b5-1f3ff-2640": "woman_mountain_biking_tone5",
"1f6b5-2642": "man_mountain_biking",
"1f6b5-1f3fb-2642": "man_mountain_biking_tone1",
"1f6b5-1f3fc-2642": "man_mountain_biking_tone2",
"1f6b5-1f3fd-2642": "man_mountain_biking_tone3",
"1f6b5-1f3fe-2642": "man_mountain_biking_tone4",
"1f6b5-1f3ff-2642": "man_mountain_biking_tone5",
"1f6b4": "person_biking",
"1f6b4-1f3fb": "person_biking_tone1",
"1f6b4-1f3fc": "person_biking_tone2",
"1f6b4-1f3fd": "person_biking_tone3",
"1f6b4-1f3fe": "person_biking_tone4",
"1f6b4-1f3ff": "person_biking_tone5",
"1f6b4-2640": "woman_biking",
"1f6b4-1f3fb-2640": "woman_biking_tone1",
"1f6b4-1f3fc-2640": "woman_biking_tone2",
"1f6b4-1f3fd-2640": "woman_biking_tone3",
"1f6b4-1f3fe-2640": "woman_biking_tone4",
"1f6b4-1f3ff-2640": "woman_biking_tone5",
"1f6b4-2642": "man_biking",
"1f6b4-1f3fb-2642": "man_biking_tone1",
"1f6b4-1f3fc-2642": "man_biking_tone2",
"1f6b4-1f3fd-2642": "man_biking_tone3",
"1f6b4-1f3fe-2642": "man_biking_tone4",
"1f6b4-1f3ff-2642": "man_biking_tone5",
"1f3c6": "trophy",
"1f947": "first_place",
"1f948": "second_place",
"1f949": "third_place",
"1f3c5": "medal",
"1f396": "military_medal",
"1f3f5": "rosette",
"1f397": "reminder_ribbon",
"1f3ab": "ticket",
"1f39f": "tickets",
"1f3aa": "circus_tent",
"1f939": "person_juggling",
"1f939-1f3fb": "person_juggling_tone1",
"1f939-1f3fc": "person_juggling_tone2",
"1f939-1f3fd": "person_juggling_tone3",
"1f939-1f3fe": "person_juggling_tone4",
"1f939-1f3ff": "person_juggling_tone5",
"1f939-2640": "woman_juggling",
"1f939-1f3fb-2640": "woman_juggling_tone1",
"1f939-1f3fc-2640": "woman_juggling_tone2",
"1f939-1f3fd-2640": "woman_juggling_tone3",
"1f939-1f3fe-2640": "woman_juggling_tone4",
"1f939-1f3ff-2640": "woman_juggling_tone5",
"1f939-2642": "man_juggling",
"1f939-1f3fb-2642": "man_juggling_tone1",
"1f939-1f3fc-2642": "man_juggling_tone2",
"1f939-1f3fd-2642": "man_juggling_tone3",
"1f939-1f3fe-2642": "man_juggling_tone4",
"1f939-1f3ff-2642": "man_juggling_tone5",
"1f3ad": "performing_arts",
"1f3a8": "art",
"1f3ac": "clapper",
"1f3a4": "microphone",
"1f3a7": "headphones",
"1f3bc": "musical_score",
"1f3b9": "musical_keyboard",
"1f941": "drum",
"1f3b7": "saxophone",
"1f3ba": "trumpet",
"1f3b8": "guitar",
"1f3bb": "violin",
"1f3b2": "game_die",
"1f3af": "dart",
"1f3b3": "bowling",
"1f3ae": "video_game",
"1f3b0": "slot_machine",
"231a": "watch",
"1f4f1": "iphone",
"1f4f2": "calling",
"1f4bb": "computer",
"1f5a5": "desktop",
"1f5a8": "printer",
"1f5b1": "mouse_three_button",
"1f5b2": "trackball",
"1f579": "joystick",
"265f": "chess_pawn",
"1f9e9": "jigsaw",
"1f5dc": "compression",
"1f4bd": "minidisc",
"1f4be": "floppy_disk",
"1f4bf": "cd",
"1f4c0": "dvd",
"1f4fc": "vhs",
"1f4f7": "camera",
"1f4f8": "camera_with_flash",
"1f4f9": "video_camera",
"1f3a5": "movie_camera",
"1f4fd": "projector",
"1f39e": "film_frames",
"1f4de": "telephone_receiver",
"260e": "telephone",
"1f4df": "pager",
"1f4e0": "fax",
"1f4fa": "tv",
"1f4fb": "radio",
"1f399": "microphone2",
"1f39a": "level_slider",
"1f39b": "control_knobs",
"23f1": "stopwatch",
"23f2": "timer",
"23f0": "alarm_clock",
"1f570": "clock",
"231b": "hourglass",
"23f3": "hourglass_flowing_sand",
"1f4e1": "satellite",
"1f9ed": "compass",
"1f50b": "battery",
"1f50c": "electric_plug",
"1f9f2": "magnet",
"1f4a1": "bulb",
"1f526": "flashlight",
"1f56f": "candle",
"1f9ef": "fire_extinguisher",
"1f5d1": "wastebasket",
"1f6e2": "oil",
"1f4b8": "money_with_wings",
"1f4b5": "dollar",
"1f4b4": "yen",
"1f4b6": "euro",
"1f4b7": "pound",
"1f4b0": "moneybag",
"1f4b3": "credit_card",
"1f48e": "gem",
"1f9ff": "nazar_amulet",
"1f9f1": "bricks",
"1f9f0": "toolbox",
"1f527": "wrench",
"1f528": "hammer",
"1f6e0": "tools",
"26cf": "pick",
"1f529": "nut_and_bolt",
"26d3": "chains",
"1f52b": "gun",
"1f4a3": "bomb",
"1f52a": "knife",
"1f5e1": "dagger",
"1f6e1": "shield",
"1f6ac": "smoking",
"26b0": "coffin",
"26b1": "urn",
"1f3fa": "amphora",
"1f52e": "crystal_ball",
"1f4ff": "prayer_beads",
"1f488": "barber",
"1f9ea": "test_tube",
"1f9eb": "petri_dish",
"1f9ec": "dna",
"1f9ee": "abacus",
"1f52d": "telescope",
"1f52c": "microscope",
"1f573": "hole",
"1f48a": "pill",
"1f489": "syringe",
"1f321": "thermometer",
"1f6bd": "toilet",
"1f6b0": "potable_water",
"1f6bf": "shower",
"1f6c1": "bathtub",
"1f6c0": "bath",
"1f6c0-1f3fb": "bath_tone1",
"1f6c0-1f3fc": "bath_tone2",
"1f6c0-1f3fd": "bath_tone3",
"1f6c0-1f3fe": "bath_tone4",
"1f6c0-1f3ff": "bath_tone5",
"1f9f9": "broom",
"1f9fa": "basket",
"1f9fb": "roll_of_paper",
"1f9fc": "soap",
"1f9fd": "sponge",
"1f9f4": "squeeze_bottle",
"1f9f5": "thread",
"1f9f6": "yarn",
"1f6ce": "bellhop",
"1f511": "key",
"1f5dd": "key2",
"1f6aa": "door",
"1f6cb": "couch",
"1f6cf": "bed",
"1f6cc": "sleeping_accommodation",
"1f6cc-1f3fb": "person_in_bed_tone1",
"1f6cc-1f3fc": "person_in_bed_tone2",
"1f6cc-1f3fd": "person_in_bed_tone3",
"1f6cc-1f3fe": "person_in_bed_tone4",
"1f6cc-1f3ff": "person_in_bed_tone5",
"1f9f8": "teddy_bear",
"1f5bc": "frame_photo",
"1f6cd": "shopping_bags",
"1f6d2": "shopping_cart",
"1f381": "gift",
"1f388": "balloon",
"1f38f": "flags",
"1f380": "ribbon",
"1f38a": "confetti_ball",
"1f389": "tada",
"1f38e": "dolls",
"1f3ee": "izakaya_lantern",
"1f390": "wind_chime",
"1f9e7": "red_envelope",
"1f4e9": "envelope_with_arrow",
"1f4e8": "incoming_envelope",
"1f4e7": "e-mail",
"1f48c": "love_letter",
"1f4e5": "inbox_tray",
"1f4e4": "outbox_tray",
"1f4e6": "package",
"1f3f7": "label",
"1f4ea": "mailbox_closed",
"1f4eb": "mailbox",
"1f4ec": "mailbox_with_mail",
"1f4ed": "mailbox_with_no_mail",
"1f4ee": "postbox",
"1f4ef": "postal_horn",
"1f4dc": "scroll",
"1f4c3": "page_with_curl",
"1f4c4": "page_facing_up",
"1f9fe": "receipt",
"1f4d1": "bookmark_tabs",
"1f4ca": "bar_chart",
"1f4c8": "chart_with_upwards_trend",
"1f4c9": "chart_with_downwards_trend",
"1f5d2": "notepad_spiral",
"1f5d3": "calendar_spiral",
"1f4c6": "calendar",
"1f4c5": "date",
"1f4c7": "card_index",
"1f5c3": "card_box",
"1f5f3": "ballot_box",
"1f5c4": "file_cabinet",
"1f4cb": "clipboard",
"1f4c1": "file_folder",
"1f4c2": "open_file_folder",
"1f5c2": "dividers",
"1f5de": "newspaper2",
"1f4f0": "newspaper",
"1f4d3": "notebook",
"1f4d4": "notebook_with_decorative_cover",
"1f4d2": "ledger",
"1f4d5": "closed_book",
"1f4d7": "green_book",
"1f4d8": "blue_book",
"1f4d9": "orange_book",
"1f4da": "books",
"1f4d6": "book",
"1f516": "bookmark",
"1f517": "link",
"1f4ce": "paperclip",
"1f587": "paperclips",
"1f4d0": "triangular_ruler",
"1f4cf": "straight_ruler",
"1f9f7": "safety_pin",
"1f4cc": "pushpin",
"1f4cd": "round_pushpin",
"1f58a": "pen_ballpoint",
"1f58b": "pen_fountain",
"1f58c": "paintbrush",
"1f58d": "crayon",
"1f4dd": "pencil",
"270f": "pencil2",
"1f50d": "mag",
"1f50e": "mag_right",
"1f50f": "lock_with_ink_pen",
"1f510": "closed_lock_with_key",
"1f436": "dog",
"1f431": "cat",
"1f42d": "mouse",
"1f439": "hamster",
"1f430": "rabbit",
"1f98a": "fox",
"1f99d": "raccoon",
"1f43b": "bear",
"1f43c": "panda_face",
"1f998": "kangaroo",
"1f9a1": "badger",
"1f428": "koala",
"1f42f": "tiger",
"1f981": "lion_face",
"1f42e": "cow",
"1f437": "pig",
"1f43d": "pig_nose",
"1f438": "frog",
"1f435": "monkey_face",
"1f648": "see_no_evil",
"1f649": "hear_no_evil",
"1f64a": "speak_no_evil",
"1f412": "monkey",
"1f414": "chicken",
"1f427": "penguin",
"1f426": "bird",
"1f424": "baby_chick",
"1f423": "hatching_chick",
"1f425": "hatched_chick",
"1f986": "duck",
"1f9a2": "swan",
"1f985": "eagle",
"1f989": "owl",
"1f99c": "parrot",
"1f99a": "peacock",
"1f987": "bat",
"1f43a": "wolf",
"1f417": "boar",
"1f434": "horse",
"1f984": "unicorn",
"1f41d": "bee",
"1f41b": "bug",
"1f98b": "butterfly",
"1f40c": "snail",
"1f41a": "shell",
"1f41e": "beetle",
"1f41c": "ant",
"1f997": "cricket",
"1f577": "spider",
"1f578": "spider_web",
"1f982": "scorpion",
"1f99f": "mosquito",
"1f9a0": "microbe",
"1f422": "turtle",
"1f40d": "snake",
"1f98e": "lizard",
"1f996": "t_rex",
"1f995": "sauropod",
"1f419": "octopus",
"1f991": "squid",
"1f990": "shrimp",
"1f980": "crab",
"1f99e": "lobster",
"1f421": "blowfish",
"1f420": "tropical_fish",
"1f41f": "fish",
"1f42c": "dolphin",
"1f433": "whale",
"1f40b": "whale2",
"1f988": "shark",
"1f40a": "crocodile",
"1f405": "tiger2",
"1f406": "leopard",
"1f993": "zebra",
"1f98d": "gorilla",
"1f418": "elephant",
"1f98f": "rhino",
"1f99b": "hippopotamus",
"1f42a": "dromedary_camel",
"1f42b": "camel",
"1f992": "giraffe",
"1f999": "llama",
"1f403": "water_buffalo",
"1f402": "ox",
"1f404": "cow2",
"1f40e": "racehorse",
"1f416": "pig2",
"1f40f": "ram",
"1f411": "sheep",
"1f410": "goat",
"1f98c": "deer",
"1f415": "dog2",
"1f429": "poodle",
"1f408": "cat2",
"1f413": "rooster",
"1f983": "turkey",
"1f54a": "dove",
"1f407": "rabbit2",
"1f401": "mouse2",
"1f400": "rat",
"1f43f": "chipmunk",
"1f994": "hedgehog",
"1f43e": "feet",
"1f409": "dragon",
"1f432": "dragon_face",
"1f335": "cactus",
"1f384": "christmas_tree",
"1f332": "evergreen_tree",
"1f333": "deciduous_tree",
"1f334": "palm_tree",
"1f331": "seedling",
"1f33f": "herb",
"1f340": "four_leaf_clover",
"1f38d": "bamboo",
"1f38b": "tanabata_tree",
"1f343": "leaves",
"1f342": "fallen_leaf",
"1f341": "maple_leaf",
"1f344": "mushroom",
"1f33e": "ear_of_rice",
"1f490": "bouquet",
"1f337": "tulip",
"1f339": "rose",
"1f940": "wilted_rose",
"1f33a": "hibiscus",
"1f338": "cherry_blossom",
"1f33c": "blossom",
"1f33b": "sunflower",
"1f31e": "sun_with_face",
"1f31d": "full_moon_with_face",
"1f31b": "first_quarter_moon_with_face",
"1f31c": "last_quarter_moon_with_face",
"1f31a": "new_moon_with_face",
"1f315": "full_moon",
"1f316": "waning_gibbous_moon",
"1f317": "last_quarter_moon",
"1f318": "waning_crescent_moon",
"1f311": "new_moon",
"1f312": "waxing_crescent_moon",
"1f313": "first_quarter_moon",
"1f314": "waxing_gibbous_moon",
"1f319": "crescent_moon",
"1f30e": "earth_americas",
"1f30d": "earth_africa",
"1f30f": "earth_asia",
"1f4ab": "dizzy",
"2b50": "star",
"1f31f": "star2",
"26a1": "zap",
"1f4a5": "boom",
"1f525": "fire",
"1f32a": "cloud_tornado",
"1f308": "rainbow",
"1f324": "white_sun_small_cloud",
"26c5": "partly_sunny",
"1f325": "white_sun_cloud",
"1f326": "white_sun_rain_cloud",
"1f327": "cloud_rain",
"26c8": "thunder_cloud_rain",
"1f329": "cloud_lightning",
"1f328": "cloud_snow",
"26c4": "snowman",
"1f32c": "wind_blowing_face",
"1f4a8": "dash",
"1f4a7": "droplet",
"1f4a6": "sweat_drops",
"1f30a": "ocean",
"1f32b": "fog",
"1f34f": "green_apple",
"1f34e": "apple",
"1f350": "pear",
"1f34a": "tangerine",
"1f34b": "lemon",
"1f34c": "banana",
"1f349": "watermelon",
"1f347": "grapes",
"1f353": "strawberry",
"1f348": "melon",
"1f352": "cherries",
"1f351": "peach",
"1f96d": "mango",
"1f34d": "pineapple",
"1f965": "coconut",
"1f95d": "kiwi",
"1f345": "tomato",
"1f346": "eggplant",
"1f951": "avocado",
"1f966": "broccoli",
"1f96c": "leafy_green",
"1f952": "cucumber",
"1f336": "hot_pepper",
"1f33d": "corn",
"1f955": "carrot",
"1f954": "potato",
"1f360": "sweet_potato",
"1f950": "croissant",
"1f35e": "bread",
"1f956": "french_bread",
"1f968": "pretzel",
"1f96f": "bagel",
"1f9c0": "cheese",
"1f95a": "egg",
"1f373": "cooking",
"1f95e": "pancakes",
"1f953": "bacon",
"1f969": "cut_of_meat",
"1f357": "poultry_leg",
"1f356": "meat_on_bone",
"1f32d": "hotdog",
"1f354": "hamburger",
"1f35f": "fries",
"1f355": "pizza",
"1f96a": "sandwich",
"1f959": "stuffed_flatbread",
"1f32e": "taco",
"1f32f": "burrito",
"1f957": "salad",
"1f958": "shallow_pan_of_food",
"1f96b": "canned_food",
"1f35d": "spaghetti",
"1f35c": "ramen",
"1f372": "stew",
"1f35b": "curry",
"1f363": "sushi",
"1f371": "bento",
"1f364": "fried_shrimp",
"1f359": "rice_ball",
"1f35a": "rice",
"1f358": "rice_cracker",
"1f365": "fish_cake",
"1f960": "fortune_cookie",
"1f362": "oden",
"1f361": "dango",
"1f367": "shaved_ice",
"1f368": "ice_cream",
"1f366": "icecream",
"1f967": "pie",
"1f370": "cake",
"1f382": "birthday",
"1f96e": "moon_cake",
"1f9c1": "cupcake",
"1f36e": "custard",
"1f36d": "lollipop",
"1f36c": "candy",
"1f36b": "chocolate_bar",
"1f37f": "popcorn",
"1f9c2": "salt",
"1f369": "doughnut",
"1f95f": "dumpling",
"1f36a": "cookie",
"1f330": "chestnut",
"1f95c": "peanuts",
"1f36f": "honey_pot",
"1f95b": "milk",
"1f37c": "baby_bottle",
"1f375": "tea",
"1f964": "cup_with_straw",
"1f376": "sake",
"1f37a": "beer",
"1f37b": "beers",
"1f942": "champagne_glass",
"1f377": "wine_glass",
"1f943": "tumbler_glass",
"1f378": "cocktail",
"1f379": "tropical_drink",
"1f37e": "champagne",
"1f944": "spoon",
"1f374": "fork_and_knife",
"1f37d": "fork_knife_plate",
"1f963": "bowl_with_spoon",
"1f961": "takeout_box",
"1f962": "chopsticks",
"1f600": "grinning",
"1f603": "smiley",
"1f604": "smile",
"1f601": "grin",
"1f606": "laughing",
"1f605": "sweat_smile",
"1f602": "joy",
"1f923": "rofl",
"263a": "relaxed",
"1f60a": "blush",
"1f607": "innocent",
"1f642": "slight_smile",
"1f643": "upside_down",
"1f609": "wink",
"1f60c": "relieved",
"1f60d": "heart_eyes",
"1f618": "kissing_heart",
"1f970": "smiling_face_with_3_hearts",
"1f617": "kissing",
"1f619": "kissing_smiling_eyes",
"1f61a": "kissing_closed_eyes",
"1f60b": "yum",
"1f61b": "stuck_out_tongue",
"1f61d": "stuck_out_tongue_closed_eyes",
"1f61c": "stuck_out_tongue_winking_eye",
"1f92a": "zany_face",
"1f928": "face_with_raised_eyebrow",
"1f9d0": "face_with_monocle",
"1f913": "nerd",
"1f60e": "sunglasses",
"1f929": "star_struck",
"1f973": "partying_face",
"1f60f": "smirk",
"1f612": "unamused",
"1f61e": "disappointed",
"1f614": "pensive",
"1f61f": "worried",
"1f615": "confused",
"1f641": "slight_frown",
"1f623": "persevere",
"1f616": "confounded",
"1f62b": "tired_face",
"1f629": "weary",
"1f622": "cry",
"1f62d": "sob",
"1f624": "triumph",
"1f620": "angry",
"1f621": "rage",
"1f92c": "face_with_symbols_over_mouth",
"1f92f": "exploding_head",
"1f633": "flushed",
"1f631": "scream",
"1f628": "fearful",
"1f630": "cold_sweat",
"1f975": "hot_face",
"1f976": "cold_face",
"1f97a": "pleading_face",
"1f625": "disappointed_relieved",
"1f613": "sweat",
"1f917": "hugging",
"1f914": "thinking",
"1f92d": "face_with_hand_over_mouth",
"1f92b": "shushing_face",
"1f925": "lying_face",
"1f636": "no_mouth",
"1f610": "neutral_face",
"1f611": "expressionless",
"1f62c": "grimacing",
"1f644": "rolling_eyes",
"1f62f": "hushed",
"1f626": "frowning",
"1f627": "anguished",
"1f62e": "open_mouth",
"1f632": "astonished",
"1f634": "sleeping",
"1f924": "drooling_face",
"1f62a": "sleepy",
"1f635": "dizzy_face",
"1f910": "zipper_mouth",
"1f974": "woozy_face",
"1f922": "nauseated_face",
"1f92e": "face_vomiting",
"1f927": "sneezing_face",
"1f637": "mask",
"1f912": "thermometer_face",
"1f915": "head_bandage",
"1f911": "money_mouth",
"1f920": "cowboy",
"1f608": "smiling_imp",
"1f47f": "imp",
"1f479": "japanese_ogre",
"1f47a": "japanese_goblin",
"1f921": "clown",
"1f4a9": "poop",
"1f47b": "ghost",
"1f480": "skull",
"1f47d": "alien",
"1f47e": "space_invader",
"1f916": "robot",
"1f383": "jack_o_lantern",
"1f63a": "smiley_cat",
"1f638": "smile_cat",
"1f639": "joy_cat",
"1f63b": "heart_eyes_cat",
"1f63c": "smirk_cat",
"1f63d": "kissing_cat",
"1f640": "scream_cat",
"1f63f": "crying_cat_face",
"1f63e": "pouting_cat",
"1f932": "palms_up_together",
"1f932-1f3fb": "palms_up_together_tone1",
"1f932-1f3fc": "palms_up_together_tone2",
"1f932-1f3fd": "palms_up_together_tone3",
"1f932-1f3fe": "palms_up_together_tone4",
"1f932-1f3ff": "palms_up_together_tone5",
"1f450": "open_hands",
"1f450-1f3fb": "open_hands_tone1",
"1f450-1f3fc": "open_hands_tone2",
"1f450-1f3fd": "open_hands_tone3",
"1f450-1f3fe": "open_hands_tone4",
"1f450-1f3ff": "open_hands_tone5",
"1f64c": "raised_hands",
"1f64c-1f3fb": "raised_hands_tone1",
"1f64c-1f3fc": "raised_hands_tone2",
"1f64c-1f3fd": "raised_hands_tone3",
"1f64c-1f3fe": "raised_hands_tone4",
"1f64c-1f3ff": "raised_hands_tone5",
"1f44f": "clap",
"1f44f-1f3fb": "clap_tone1",
"1f44f-1f3fc": "clap_tone2",
"1f44f-1f3fd": "clap_tone3",
"1f44f-1f3fe": "clap_tone4",
"1f44f-1f3ff": "clap_tone5",
"1f91d": "handshake",
"1f44d": "thumbsup",
"1f44d-1f3fb": "thumbsup_tone1",
"1f44d-1f3fc": "thumbsup_tone2",
"1f44d-1f3fd": "thumbsup_tone3",
"1f44d-1f3fe": "thumbsup_tone4",
"1f44d-1f3ff": "thumbsup_tone5",
"1f44e": "thumbsdown",
"1f44e-1f3fb": "thumbsdown_tone1",
"1f44e-1f3fc": "thumbsdown_tone2",
"1f44e-1f3fd": "thumbsdown_tone3",
"1f44e-1f3fe": "thumbsdown_tone4",
"1f44e-1f3ff": "thumbsdown_tone5",
"1f44a": "punch",
"1f44a-1f3fb": "punch_tone1",
"1f44a-1f3fc": "punch_tone2",
"1f44a-1f3fd": "punch_tone3",
"1f44a-1f3fe": "punch_tone4",
"1f44a-1f3ff": "punch_tone5",
"270a": "fist",
"270a-1f3fb": "fist_tone1",
"270a-1f3fc": "fist_tone2",
"270a-1f3fd": "fist_tone3",
"270a-1f3fe": "fist_tone4",
"270a-1f3ff": "fist_tone5",
"1f91b": "left_facing_fist",
"1f91b-1f3fb": "left_facing_fist_tone1",
"1f91b-1f3fc": "left_facing_fist_tone2",
"1f91b-1f3fd": "left_facing_fist_tone3",
"1f91b-1f3fe": "left_facing_fist_tone4",
"1f91b-1f3ff": "left_facing_fist_tone5",
"1f91c": "right_facing_fist",
"1f91c-1f3fb": "right_facing_fist_tone1",
"1f91c-1f3fc": "right_facing_fist_tone2",
"1f91c-1f3fd": "right_facing_fist_tone3",
"1f91c-1f3fe": "right_facing_fist_tone4",
"1f91c-1f3ff": "right_facing_fist_tone5",
"1f91e": "fingers_crossed",
"1f91e-1f3fb": "fingers_crossed_tone1",
"1f91e-1f3fc": "fingers_crossed_tone2",
"1f91e-1f3fd": "fingers_crossed_tone3",
"1f91e-1f3fe": "fingers_crossed_tone4",
"1f91e-1f3ff": "fingers_crossed_tone5",
"270c": "v",
"270c-1f3fb": "v_tone1",
"270c-1f3fc": "v_tone2",
"270c-1f3fd": "v_tone3",
"270c-1f3fe": "v_tone4",
"270c-1f3ff": "v_tone5",
"1f91f": "love_you_gesture",
"1f91f-1f3fb": "love_you_gesture_tone1",
"1f91f-1f3fc": "love_you_gesture_tone2",
"1f91f-1f3fd": "love_you_gesture_tone3",
"1f91f-1f3fe": "love_you_gesture_tone4",
"1f91f-1f3ff": "love_you_gesture_tone5",
"1f918": "metal",
"1f918-1f3fb": "metal_tone1",
"1f918-1f3fc": "metal_tone2",
"1f918-1f3fd": "metal_tone3",
"1f918-1f3fe": "metal_tone4",
"1f918-1f3ff": "metal_tone5",
"1f44c": "ok_hand",
"1f44c-1f3fb": "ok_hand_tone1",
"1f44c-1f3fc": "ok_hand_tone2",
"1f44c-1f3fd": "ok_hand_tone3",
"1f44c-1f3fe": "ok_hand_tone4",
"1f44c-1f3ff": "ok_hand_tone5",
"1f448": "point_left",
"1f448-1f3fb": "point_left_tone1",
"1f448-1f3fc": "point_left_tone2",
"1f448-1f3fd": "point_left_tone3",
"1f448-1f3fe": "point_left_tone4",
"1f448-1f3ff": "point_left_tone5",
"1f449": "point_right",
"1f449-1f3fb": "point_right_tone1",
"1f449-1f3fc": "point_right_tone2",
"1f449-1f3fd": "point_right_tone3",
"1f449-1f3fe": "point_right_tone4",
"1f449-1f3ff": "point_right_tone5",
"1f446": "point_up_2",
"1f446-1f3fb": "point_up_2_tone1",
"1f446-1f3fc": "point_up_2_tone2",
"1f446-1f3fd": "point_up_2_tone3",
"1f446-1f3fe": "point_up_2_tone4",
"1f446-1f3ff": "point_up_2_tone5",
"1f447": "point_down",
"1f447-1f3fb": "point_down_tone1",
"1f447-1f3fc": "point_down_tone2",
"1f447-1f3fd": "point_down_tone3",
"1f447-1f3fe": "point_down_tone4",
"1f447-1f3ff": "point_down_tone5",
"261d": "point_up",
"261d-1f3fb": "point_up_tone1",
"261d-1f3fc": "point_up_tone2",
"261d-1f3fd": "point_up_tone3",
"261d-1f3fe": "point_up_tone4",
"261d-1f3ff": "point_up_tone5",
"270b": "raised_hand",
"270b-1f3fb": "raised_hand_tone1",
"270b-1f3fc": "raised_hand_tone2",
"270b-1f3fd": "raised_hand_tone3",
"270b-1f3fe": "raised_hand_tone4",
"270b-1f3ff": "raised_hand_tone5",
"1f91a": "raised_back_of_hand",
"1f91a-1f3fb": "raised_back_of_hand_tone1",
"1f91a-1f3fc": "raised_back_of_hand_tone2",
"1f91a-1f3fd": "raised_back_of_hand_tone3",
"1f91a-1f3fe": "raised_back_of_hand_tone4",
"1f91a-1f3ff": "raised_back_of_hand_tone5",
"1f590": "hand_splayed",
"1f590-1f3fb": "hand_splayed_tone1",
"1f590-1f3fc": "hand_splayed_tone2",
"1f590-1f3fd": "hand_splayed_tone3",
"1f590-1f3fe": "hand_splayed_tone4",
"1f590-1f3ff": "hand_splayed_tone5",
"1f596": "vulcan",
"1f596-1f3fb": "vulcan_tone1",
"1f596-1f3fc": "vulcan_tone2",
"1f596-1f3fd": "vulcan_tone3",
"1f596-1f3fe": "vulcan_tone4",
"1f596-1f3ff": "vulcan_tone5",
"1f44b": "wave",
"1f44b-1f3fb": "wave_tone1",
"1f44b-1f3fc": "wave_tone2",
"1f44b-1f3fd": "wave_tone3",
"1f44b-1f3fe": "wave_tone4",
"1f44b-1f3ff": "wave_tone5",
"1f919": "call_me",
"1f919-1f3fb": "call_me_tone1",
"1f919-1f3fc": "call_me_tone2",
"1f919-1f3fd": "call_me_tone3",
"1f919-1f3fe": "call_me_tone4",
"1f919-1f3ff": "call_me_tone5",
"1f4aa": "muscle",
"1f4aa-1f3fb": "muscle_tone1",
"1f4aa-1f3fc": "muscle_tone2",
"1f4aa-1f3fd": "muscle_tone3",
"1f4aa-1f3fe": "muscle_tone4",
"1f4aa-1f3ff": "muscle_tone5",
"1f9b5": "leg",
"1f9b5-1f3fb": "leg_tone1",
"1f9b5-1f3fc": "leg_tone2",
"1f9b5-1f3fd": "leg_tone3",
"1f9b5-1f3fe": "leg_tone4",
"1f9b5-1f3ff": "leg_tone5",
"1f9b6": "foot",
"1f9b6-1f3fb": "foot_tone1",
"1f9b6-1f3fc": "foot_tone2",
"1f9b6-1f3fd": "foot_tone3",
"1f9b6-1f3fe": "foot_tone4",
"1f9b6-1f3ff": "foot_tone5",
"1f595": "middle_finger",
"1f595-1f3fb": "middle_finger_tone1",
"1f595-1f3fc": "middle_finger_tone2",
"1f595-1f3fd": "middle_finger_tone3",
"1f595-1f3fe": "middle_finger_tone4",
"1f595-1f3ff": "middle_finger_tone5",
"270d": "writing_hand",
"270d-1f3fb": "writing_hand_tone1",
"270d-1f3fc": "writing_hand_tone2",
"270d-1f3fd": "writing_hand_tone3",
"270d-1f3fe": "writing_hand_tone4",
"270d-1f3ff": "writing_hand_tone5",
"1f64f": "pray",
"1f64f-1f3fb": "pray_tone1",
"1f64f-1f3fc": "pray_tone2",
"1f64f-1f3fd": "pray_tone3",
"1f64f-1f3fe": "pray_tone4",
"1f64f-1f3ff": "pray_tone5",
"1f48d": "ring",
"1f484": "lipstick",
"1f48b": "kiss",
"1f444": "lips",
"1f445": "tongue",
"1f442": "ear",
"1f442-1f3fb": "ear_tone1",
"1f442-1f3fc": "ear_tone2",
"1f442-1f3fd": "ear_tone3",
"1f442-1f3fe": "ear_tone4",
"1f442-1f3ff": "ear_tone5",
"1f443": "nose",
"1f443-1f3fb": "nose_tone1",
"1f443-1f3fc": "nose_tone2",
"1f443-1f3fd": "nose_tone3",
"1f443-1f3fe": "nose_tone4",
"1f443-1f3ff": "nose_tone5",
"1f463": "footprints",
"1f441": "eye",
"1f440": "eyes",
"1f9e0": "brain",
"1f9b4": "bone",
"1f9b7": "tooth",
"1f5e3": "speaking_head",
"1f464": "bust_in_silhouette",
"1f465": "busts_in_silhouette",
"1f476": "baby",
"1f476-1f3fb": "baby_tone1",
"1f476-1f3fc": "baby_tone2",
"1f476-1f3fd": "baby_tone3",
"1f476-1f3fe": "baby_tone4",
"1f476-1f3ff": "baby_tone5",
"1f467": "girl",
"1f467-1f3fb": "girl_tone1",
"1f467-1f3fc": "girl_tone2",
"1f467-1f3fd": "girl_tone3",
"1f467-1f3fe": "girl_tone4",
"1f467-1f3ff": "girl_tone5",
"1f9d2": "child",
"1f9d2-1f3fb": "child_tone1",
"1f9d2-1f3fc": "child_tone2",
"1f9d2-1f3fd": "child_tone3",
"1f9d2-1f3fe": "child_tone4",
"1f9d2-1f3ff": "child_tone5",
"1f466": "boy",
"1f466-1f3fb": "boy_tone1",
"1f466-1f3fc": "boy_tone2",
"1f466-1f3fd": "boy_tone3",
"1f466-1f3fe": "boy_tone4",
"1f466-1f3ff": "boy_tone5",
"1f469": "woman",
"1f469-1f3fb": "woman_tone1",
"1f469-1f3fc": "woman_tone2",
"1f469-1f3fd": "woman_tone3",
"1f469-1f3fe": "woman_tone4",
"1f469-1f3ff": "woman_tone5",
"1f9d1": "adult",
"1f9d1-1f3fb": "adult_tone1",
"1f9d1-1f3fc": "adult_tone2",
"1f9d1-1f3fd": "adult_tone3",
"1f9d1-1f3fe": "adult_tone4",
"1f9d1-1f3ff": "adult_tone5",
"1f468": "man",
"1f468-1f3fb": "man_tone1",
"1f468-1f3fc": "man_tone2",
"1f468-1f3fd": "man_tone3",
"1f468-1f3fe": "man_tone4",
"1f468-1f3ff": "man_tone5",
"1f471": "blond_haired_person",
"1f471-1f3fb": "blond_haired_person_tone1",
"1f471-1f3fc": "blond_haired_person_tone2",
"1f471-1f3fd": "blond_haired_person_tone3",
"1f471-1f3fe": "blond_haired_person_tone4",
"1f471-1f3ff": "blond_haired_person_tone5",
"1f471-2640": "blond-haired_woman",
"1f471-1f3fb-2640": "blond-haired_woman_tone1",
"1f471-1f3fc-2640": "blond-haired_woman_tone2",
"1f471-1f3fd-2640": "blond-haired_woman_tone3",
"1f471-1f3fe-2640": "blond-haired_woman_tone4",
"1f471-1f3ff-2640": "blond-haired_woman_tone5",
"1f471-2642": "blond-haired_man",
"1f471-1f3fb-2642": "blond-haired_man_tone1",
"1f471-1f3fc-2642": "blond-haired_man_tone2",
"1f471-1f3fd-2642": "blond-haired_man_tone3",
"1f471-1f3fe-2642": "blond-haired_man_tone4",
"1f471-1f3ff-2642": "blond-haired_man_tone5",
"1f469-1f9b0": "woman_red_haired",
"1f469-1f3fb-1f9b0": "woman_red_haired_tone1",
"1f469-1f3fc-1f9b0": "woman_red_haired_tone2",
"1f469-1f3fd-1f9b0": "woman_red_haired_tone3",
"1f469-1f3fe-1f9b0": "woman_red_haired_tone4",
"1f469-1f3ff-1f9b0": "woman_red_haired_tone5",
"1f468-1f9b0": "man_red_haired",
"1f468-1f3fb-1f9b0": "man_red_haired_tone1",
"1f468-1f3fc-1f9b0": "man_red_haired_tone2",
"1f468-1f3fd-1f9b0": "man_red_haired_tone3",
"1f468-1f3fe-1f9b0": "man_red_haired_tone4",
"1f468-1f3ff-1f9b0": "man_red_haired_tone5",
"1f469-1f9b1": "woman_curly_haired",
"1f469-1f3fb-1f9b1": "woman_curly_haired_tone1",
"1f469-1f3fc-1f9b1": "woman_curly_haired_tone2",
"1f469-1f3fd-1f9b1": "woman_curly_haired_tone3",
"1f469-1f3fe-1f9b1": "woman_curly_haired_tone4",
"1f469-1f3ff-1f9b1": "woman_curly_haired_tone5",
"1f468-1f9b1": "man_curly_haired",
"1f468-1f3fb-1f9b1": "man_curly_haired_tone1",
"1f468-1f3fc-1f9b1": "man_curly_haired_tone2",
"1f468-1f3fd-1f9b1": "man_curly_haired_tone3",
"1f468-1f3fe-1f9b1": "man_curly_haired_tone4",
"1f468-1f3ff-1f9b1": "man_curly_haired_tone5",
"1f469-1f9b3": "woman_white_haired",
"1f469-1f3fb-1f9b3": "woman_white_haired_tone1",
"1f469-1f3fc-1f9b3": "woman_white_haired_tone2",
"1f469-1f3fd-1f9b3": "woman_white_haired_tone3",
"1f469-1f3fe-1f9b3": "woman_white_haired_tone4",
"1f469-1f3ff-1f9b3": "woman_white_haired_tone5",
"1f468-1f9b3": "man_white_haired",
"1f468-1f3fb-1f9b3": "man_white_haired_tone1",
"1f468-1f3fc-1f9b3": "man_white_haired_tone2",
"1f468-1f3fd-1f9b3": "man_white_haired_tone3",
"1f468-1f3fe-1f9b3": "man_white_haired_tone4",
"1f468-1f3ff-1f9b3": "man_white_haired_tone5",
"1f469-1f9b2": "woman_bald",
"1f469-1f3fb-1f9b2": "woman_bald_tone1",
"1f469-1f3fc-1f9b2": "woman_bald_tone2",
"1f469-1f3fd-1f9b2": "woman_bald_tone3",
"1f469-1f3fe-1f9b2": "woman_bald_tone4",
"1f469-1f3ff-1f9b2": "woman_bald_tone5",
"1f468-1f9b2": "man_bald",
"1f468-1f3fb-1f9b2": "man_bald_tone1",
"1f468-1f3fc-1f9b2": "man_bald_tone2",
"1f468-1f3fd-1f9b2": "man_bald_tone3",
"1f468-1f3fe-1f9b2": "man_bald_tone4",
"1f468-1f3ff-1f9b2": "man_bald_tone5",
"1f9d4": "bearded_person",
"1f9d4-1f3fb": "bearded_person_tone1",
"1f9d4-1f3fc": "bearded_person_tone2",
"1f9d4-1f3fd": "bearded_person_tone3",
"1f9d4-1f3fe": "bearded_person_tone4",
"1f9d4-1f3ff": "bearded_person_tone5",
"1f475": "older_woman",
"1f475-1f3fb": "older_woman_tone1",
"1f475-1f3fc": "older_woman_tone2",
"1f475-1f3fd": "older_woman_tone3",
"1f475-1f3fe": "older_woman_tone4",
"1f475-1f3ff": "older_woman_tone5",
"1f9d3": "older_adult",
"1f9d3-1f3fb": "older_adult_tone1",
"1f9d3-1f3fc": "older_adult_tone2",
"1f9d3-1f3fd": "older_adult_tone3",
"1f9d3-1f3fe": "older_adult_tone4",
"1f9d3-1f3ff": "older_adult_tone5",
"1f474": "older_man",
"1f474-1f3fb": "older_man_tone1",
"1f474-1f3fc": "older_man_tone2",
"1f474-1f3fd": "older_man_tone3",
"1f474-1f3fe": "older_man_tone4",
"1f474-1f3ff": "older_man_tone5",
"1f472": "man_with_chinese_cap",
"1f472-1f3fb": "man_with_chinese_cap_tone1",
"1f472-1f3fc": "man_with_chinese_cap_tone2",
"1f472-1f3fd": "man_with_chinese_cap_tone3",
"1f472-1f3fe": "man_with_chinese_cap_tone4",
"1f472-1f3ff": "man_with_chinese_cap_tone5",
"1f473": "person_wearing_turban",
"1f473-1f3fb": "person_wearing_turban_tone1",
"1f473-1f3fc": "person_wearing_turban_tone2",
"1f473-1f3fd": "person_wearing_turban_tone3",
"1f473-1f3fe": "person_wearing_turban_tone4",
"1f473-1f3ff": "person_wearing_turban_tone5",
"1f473-2640": "woman_wearing_turban",
"1f473-1f3fb-2640": "woman_wearing_turban_tone1",
"1f473-1f3fc-2640": "woman_wearing_turban_tone2",
"1f473-1f3fd-2640": "woman_wearing_turban_tone3",
"1f473-1f3fe-2640": "woman_wearing_turban_tone4",
"1f473-1f3ff-2640": "woman_wearing_turban_tone5",
"1f473-2642": "man_wearing_turban",
"1f473-1f3fb-2642": "man_wearing_turban_tone1",
"1f473-1f3fc-2642": "man_wearing_turban_tone2",
"1f473-1f3fd-2642": "man_wearing_turban_tone3",
"1f473-1f3fe-2642": "man_wearing_turban_tone4",
"1f473-1f3ff-2642": "man_wearing_turban_tone5",
"1f9d5": "woman_with_headscarf",
"1f9d5-1f3fb": "woman_with_headscarf_tone1",
"1f9d5-1f3fc": "woman_with_headscarf_tone2",
"1f9d5-1f3fd": "woman_with_headscarf_tone3",
"1f9d5-1f3fe": "woman_with_headscarf_tone4",
"1f9d5-1f3ff": "woman_with_headscarf_tone5",
"1f46e": "police_officer",
"1f46e-1f3fb": "police_officer_tone1",
"1f46e-1f3fc": "police_officer_tone2",
"1f46e-1f3fd": "police_officer_tone3",
"1f46e-1f3fe": "police_officer_tone4",
"1f46e-1f3ff": "police_officer_tone5",
"1f46e-2640": "woman_police_officer",
"1f46e-1f3fb-2640": "woman_police_officer_tone1",
"1f46e-1f3fc-2640": "woman_police_officer_tone2",
"1f46e-1f3fd-2640": "woman_police_officer_tone3",
"1f46e-1f3fe-2640": "woman_police_officer_tone4",
"1f46e-1f3ff-2640": "woman_police_officer_tone5",
"1f46e-2642": "man_police_officer",
"1f46e-1f3fb-2642": "man_police_officer_tone1",
"1f46e-1f3fc-2642": "man_police_officer_tone2",
"1f46e-1f3fd-2642": "man_police_officer_tone3",
"1f46e-1f3fe-2642": "man_police_officer_tone4",
"1f46e-1f3ff-2642": "man_police_officer_tone5",
"1f477": "construction_worker",
"1f477-1f3fb": "construction_worker_tone1",
"1f477-1f3fc": "construction_worker_tone2",
"1f477-1f3fd": "construction_worker_tone3",
"1f477-1f3fe": "construction_worker_tone4",
"1f477-1f3ff": "construction_worker_tone5",
"1f477-2640": "woman_construction_worker",
"1f477-1f3fb-2640": "woman_construction_worker_tone1",
"1f477-1f3fc-2640": "woman_construction_worker_tone2",
"1f477-1f3fd-2640": "woman_construction_worker_tone3",
"1f477-1f3fe-2640": "woman_construction_worker_tone4",
"1f477-1f3ff-2640": "woman_construction_worker_tone5",
"1f477-2642": "man_construction_worker",
"1f477-1f3fb-2642": "man_construction_worker_tone1",
"1f477-1f3fc-2642": "man_construction_worker_tone2",
"1f477-1f3fd-2642": "man_construction_worker_tone3",
"1f477-1f3fe-2642": "man_construction_worker_tone4",
"1f477-1f3ff-2642": "man_construction_worker_tone5",
"1f482": "guard",
"1f482-1f3fb": "guard_tone1",
"1f482-1f3fc": "guard_tone2",
"1f482-1f3fd": "guard_tone3",
"1f482-1f3fe": "guard_tone4",
"1f482-1f3ff": "guard_tone5",
"1f482-2640": "woman_guard",
"1f482-1f3fb-2640": "woman_guard_tone1",
"1f482-1f3fc-2640": "woman_guard_tone2",
"1f482-1f3fd-2640": "woman_guard_tone3",
"1f482-1f3fe-2640": "woman_guard_tone4",
"1f482-1f3ff-2640": "woman_guard_tone5",
"1f482-2642": "man_guard",
"1f482-1f3fb-2642": "man_guard_tone1",
"1f482-1f3fc-2642": "man_guard_tone2",
"1f482-1f3fd-2642": "man_guard_tone3",
"1f482-1f3fe-2642": "man_guard_tone4",
"1f482-1f3ff-2642": "man_guard_tone5",
"1f575": "detective",
"1f575-1f3fb": "detective_tone1",
"1f575-1f3fc": "detective_tone2",
"1f575-1f3fd": "detective_tone3",
"1f575-1f3fe": "detective_tone4",
"1f575-1f3ff": "detective_tone5",
"1f575-2640": "woman_detective",
"1f575-1f3fb-2640": "woman_detective_tone1",
"1f575-1f3fc-2640": "woman_detective_tone2",
"1f575-1f3fd-2640": "woman_detective_tone3",
"1f575-1f3fe-2640": "woman_detective_tone4",
"1f575-1f3ff-2640": "woman_detective_tone5",
"1f575-2642": "man_detective",
"1f575-1f3fb-2642": "man_detective_tone1",
"1f575-1f3fc-2642": "man_detective_tone2",
"1f575-1f3fd-2642": "man_detective_tone3",
"1f575-1f3fe-2642": "man_detective_tone4",
"1f575-1f3ff-2642": "man_detective_tone5",
"1f469-2695": "woman_health_worker",
"1f469-1f3fb-2695": "woman_health_worker_tone1",
"1f469-1f3fc-2695": "woman_health_worker_tone2",
"1f469-1f3fd-2695": "woman_health_worker_tone3",
"1f469-1f3fe-2695": "woman_health_worker_tone4",
"1f469-1f3ff-2695": "woman_health_worker_tone5",
"1f468-2695": "man_health_worker",
"1f468-1f3fb-2695": "man_health_worker_tone1",
"1f468-1f3fc-2695": "man_health_worker_tone2",
"1f468-1f3fd-2695": "man_health_worker_tone3",
"1f468-1f3fe-2695": "man_health_worker_tone4",
"1f468-1f3ff-2695": "man_health_worker_tone5",
"1f469-1f33e": "woman_farmer",
"1f469-1f3fb-1f33e": "woman_farmer_tone1",
"1f469-1f3fc-1f33e": "woman_farmer_tone2",
"1f469-1f3fd-1f33e": "woman_farmer_tone3",
"1f469-1f3fe-1f33e": "woman_farmer_tone4",
"1f469-1f3ff-1f33e": "woman_farmer_tone5",
"1f468-1f33e": "man_farmer",
"1f468-1f3fb-1f33e": "man_farmer_tone1",
"1f468-1f3fc-1f33e": "man_farmer_tone2",
"1f468-1f3fd-1f33e": "man_farmer_tone3",
"1f468-1f3fe-1f33e": "man_farmer_tone4",
"1f468-1f3ff-1f33e": "man_farmer_tone5",
"1f469-1f373": "woman_cook",
"1f469-1f3fb-1f373": "woman_cook_tone1",
"1f469-1f3fc-1f373": "woman_cook_tone2",
"1f469-1f3fd-1f373": "woman_cook_tone3",
"1f469-1f3fe-1f373": "woman_cook_tone4",
"1f469-1f3ff-1f373": "woman_cook_tone5",
"1f468-1f373": "man_cook",
"1f468-1f3fb-1f373": "man_cook_tone1",
"1f468-1f3fc-1f373": "man_cook_tone2",
"1f468-1f3fd-1f373": "man_cook_tone3",
"1f468-1f3fe-1f373": "man_cook_tone4",
"1f468-1f3ff-1f373": "man_cook_tone5",
"1f469-1f393": "woman_student",
"1f469-1f3fb-1f393": "woman_student_tone1",
"1f469-1f3fc-1f393": "woman_student_tone2",
"1f469-1f3fd-1f393": "woman_student_tone3",
"1f469-1f3fe-1f393": "woman_student_tone4",
"1f469-1f3ff-1f393": "woman_student_tone5",
"1f468-1f393": "man_student",
"1f468-1f3fb-1f393": "man_student_tone1",
"1f468-1f3fc-1f393": "man_student_tone2",
"1f468-1f3fd-1f393": "man_student_tone3",
"1f468-1f3fe-1f393": "man_student_tone4",
"1f468-1f3ff-1f393": "man_student_tone5",
"1f469-1f3a4": "woman_singer",
"1f469-1f3fb-1f3a4": "woman_singer_tone1",
"1f469-1f3fc-1f3a4": "woman_singer_tone2",
"1f469-1f3fd-1f3a4": "woman_singer_tone3",
"1f469-1f3fe-1f3a4": "woman_singer_tone4",
"1f469-1f3ff-1f3a4": "woman_singer_tone5",
"1f468-1f3a4": "man_singer",
"1f468-1f3fb-1f3a4": "man_singer_tone1",
"1f468-1f3fc-1f3a4": "man_singer_tone2",
"1f468-1f3fd-1f3a4": "man_singer_tone3",
"1f468-1f3fe-1f3a4": "man_singer_tone4",
"1f468-1f3ff-1f3a4": "man_singer_tone5",
"1f469-1f3eb": "woman_teacher",
"1f469-1f3fb-1f3eb": "woman_teacher_tone1",
"1f469-1f3fc-1f3eb": "woman_teacher_tone2",
"1f469-1f3fd-1f3eb": "woman_teacher_tone3",
"1f469-1f3fe-1f3eb": "woman_teacher_tone4",
"1f469-1f3ff-1f3eb": "woman_teacher_tone5",
"1f468-1f3eb": "man_teacher",
"1f468-1f3fb-1f3eb": "man_teacher_tone1",
"1f468-1f3fc-1f3eb": "man_teacher_tone2",
"1f468-1f3fd-1f3eb": "man_teacher_tone3",
"1f468-1f3fe-1f3eb": "man_teacher_tone4",
"1f468-1f3ff-1f3eb": "man_teacher_tone5",
"1f469-1f3ed": "woman_factory_worker",
"1f469-1f3fb-1f3ed": "woman_factory_worker_tone1",
"1f469-1f3fc-1f3ed": "woman_factory_worker_tone2",
"1f469-1f3fd-1f3ed": "woman_factory_worker_tone3",
"1f469-1f3fe-1f3ed": "woman_factory_worker_tone4",
"1f469-1f3ff-1f3ed": "woman_factory_worker_tone5",
"1f468-1f3ed": "man_factory_worker",
"1f468-1f3fb-1f3ed": "man_factory_worker_tone1",
"1f468-1f3fc-1f3ed": "man_factory_worker_tone2",
"1f468-1f3fd-1f3ed": "man_factory_worker_tone3",
"1f468-1f3fe-1f3ed": "man_factory_worker_tone4",
"1f468-1f3ff-1f3ed": "man_factory_worker_tone5",
"1f469-1f4bb": "woman_technologist",
"1f469-1f3fb-1f4bb": "woman_technologist_tone1",
"1f469-1f3fc-1f4bb": "woman_technologist_tone2",
"1f469-1f3fd-1f4bb": "woman_technologist_tone3",
"1f469-1f3fe-1f4bb": "woman_technologist_tone4",
"1f469-1f3ff-1f4bb": "woman_technologist_tone5",
"1f468-1f4bb": "man_technologist",
"1f468-1f3fb-1f4bb": "man_technologist_tone1",
"1f468-1f3fc-1f4bb": "man_technologist_tone2",
"1f468-1f3fd-1f4bb": "man_technologist_tone3",
"1f468-1f3fe-1f4bb": "man_technologist_tone4",
"1f468-1f3ff-1f4bb": "man_technologist_tone5",
"1f469-1f4bc": "woman_office_worker",
"1f469-1f3fb-1f4bc": "woman_office_worker_tone1",
"1f469-1f3fc-1f4bc": "woman_office_worker_tone2",
"1f469-1f3fd-1f4bc": "woman_office_worker_tone3",
"1f469-1f3fe-1f4bc": "woman_office_worker_tone4",
"1f469-1f3ff-1f4bc": "woman_office_worker_tone5",
"1f468-1f4bc": "man_office_worker",
"1f468-1f3fb-1f4bc": "man_office_worker_tone1",
"1f468-1f3fc-1f4bc": "man_office_worker_tone2",
"1f468-1f3fd-1f4bc": "man_office_worker_tone3",
"1f468-1f3fe-1f4bc": "man_office_worker_tone4",
"1f468-1f3ff-1f4bc": "man_office_worker_tone5",
"1f469-1f527": "woman_mechanic",
"1f469-1f3fb-1f527": "woman_mechanic_tone1",
"1f469-1f3fc-1f527": "woman_mechanic_tone2",
"1f469-1f3fd-1f527": "woman_mechanic_tone3",
"1f469-1f3fe-1f527": "woman_mechanic_tone4",
"1f469-1f3ff-1f527": "woman_mechanic_tone5",
"1f468-1f527": "man_mechanic",
"1f468-1f3fb-1f527": "man_mechanic_tone1",
"1f468-1f3fc-1f527": "man_mechanic_tone2",
"1f468-1f3fd-1f527": "man_mechanic_tone3",
"1f468-1f3fe-1f527": "man_mechanic_tone4",
"1f468-1f3ff-1f527": "man_mechanic_tone5",
"1f469-1f52c": "woman_scientist",
"1f469-1f3fb-1f52c": "woman_scientist_tone1",
"1f469-1f3fc-1f52c": "woman_scientist_tone2",
"1f469-1f3fd-1f52c": "woman_scientist_tone3",
"1f469-1f3fe-1f52c": "woman_scientist_tone4",
"1f469-1f3ff-1f52c": "woman_scientist_tone5",
"1f468-1f52c": "man_scientist",
"1f468-1f3fb-1f52c": "man_scientist_tone1",
"1f468-1f3fc-1f52c": "man_scientist_tone2",
"1f468-1f3fd-1f52c": "man_scientist_tone3",
"1f468-1f3fe-1f52c": "man_scientist_tone4",
"1f468-1f3ff-1f52c": "man_scientist_tone5",
"1f469-1f3a8": "woman_artist",
"1f469-1f3fb-1f3a8": "woman_artist_tone1",
"1f469-1f3fc-1f3a8": "woman_artist_tone2",
"1f469-1f3fd-1f3a8": "woman_artist_tone3",
"1f469-1f3fe-1f3a8": "woman_artist_tone4",
"1f469-1f3ff-1f3a8": "woman_artist_tone5",
"1f468-1f3a8": "man_artist",
"1f468-1f3fb-1f3a8": "man_artist_tone1",
"1f468-1f3fc-1f3a8": "man_artist_tone2",
"1f468-1f3fd-1f3a8": "man_artist_tone3",
"1f468-1f3fe-1f3a8": "man_artist_tone4",
"1f468-1f3ff-1f3a8": "man_artist_tone5",
"1f469-1f692": "woman_firefighter",
"1f469-1f3fb-1f692": "woman_firefighter_tone1",
"1f469-1f3fc-1f692": "woman_firefighter_tone2",
"1f469-1f3fd-1f692": "woman_firefighter_tone3",
"1f469-1f3fe-1f692": "woman_firefighter_tone4",
"1f469-1f3ff-1f692": "woman_firefighter_tone5",
"1f468-1f692": "man_firefighter",
"1f468-1f3fb-1f692": "man_firefighter_tone1",
"1f468-1f3fc-1f692": "man_firefighter_tone2",
"1f468-1f3fd-1f692": "man_firefighter_tone3",
"1f468-1f3fe-1f692": "man_firefighter_tone4",
"1f468-1f3ff-1f692": "man_firefighter_tone5",
"1f469-2708": "woman_pilot",
"1f469-1f3fb-2708": "woman_pilot_tone1",
"1f469-1f3fc-2708": "woman_pilot_tone2",
"1f469-1f3fd-2708": "woman_pilot_tone3",
"1f469-1f3fe-2708": "woman_pilot_tone4",
"1f469-1f3ff-2708": "woman_pilot_tone5",
"1f468-2708": "man_pilot",
"1f468-1f3fb-2708": "man_pilot_tone1",
"1f468-1f3fc-2708": "man_pilot_tone2",
"1f468-1f3fd-2708": "man_pilot_tone3",
"1f468-1f3fe-2708": "man_pilot_tone4",
"1f468-1f3ff-2708": "man_pilot_tone5",
"1f469-1f680": "woman_astronaut",
"1f469-1f3fb-1f680": "woman_astronaut_tone1",
"1f469-1f3fc-1f680": "woman_astronaut_tone2",
"1f469-1f3fd-1f680": "woman_astronaut_tone3",
"1f469-1f3fe-1f680": "woman_astronaut_tone4",
"1f469-1f3ff-1f680": "woman_astronaut_tone5",
"1f468-1f680": "man_astronaut",
"1f468-1f3fb-1f680": "man_astronaut_tone1",
"1f468-1f3fc-1f680": "man_astronaut_tone2",
"1f468-1f3fd-1f680": "man_astronaut_tone3",
"1f468-1f3fe-1f680": "man_astronaut_tone4",
"1f468-1f3ff-1f680": "man_astronaut_tone5",
"1f469-2696": "woman_judge",
"1f469-1f3fb-2696": "woman_judge_tone1",
"1f469-1f3fc-2696": "woman_judge_tone2",
"1f469-1f3fd-2696": "woman_judge_tone3",
"1f469-1f3fe-2696": "woman_judge_tone4",
"1f469-1f3ff-2696": "woman_judge_tone5",
"1f468-2696": "man_judge",
"1f468-1f3fb-2696": "man_judge_tone1",
"1f468-1f3fc-2696": "man_judge_tone2",
"1f468-1f3fd-2696": "man_judge_tone3",
"1f468-1f3fe-2696": "man_judge_tone4",
"1f468-1f3ff-2696": "man_judge_tone5",
"1f470": "bride_with_veil",
"1f470-1f3fb": "bride_with_veil_tone1",
"1f470-1f3fc": "bride_with_veil_tone2",
"1f470-1f3fd": "bride_with_veil_tone3",
"1f470-1f3fe": "bride_with_veil_tone4",
"1f470-1f3ff": "bride_with_veil_tone5",
"1f935": "man_in_tuxedo",
"1f935-1f3fb": "man_in_tuxedo_tone1",
"1f935-1f3fc": "man_in_tuxedo_tone2",
"1f935-1f3fd": "man_in_tuxedo_tone3",
"1f935-1f3fe": "man_in_tuxedo_tone4",
"1f935-1f3ff": "man_in_tuxedo_tone5",
"1f478": "princess",
"1f478-1f3fb": "princess_tone1",
"1f478-1f3fc": "princess_tone2",
"1f478-1f3fd": "princess_tone3",
"1f478-1f3fe": "princess_tone4",
"1f478-1f3ff": "princess_tone5",
"1f934": "prince",
"1f934-1f3fb": "prince_tone1",
"1f934-1f3fc": "prince_tone2",
"1f934-1f3fd": "prince_tone3",
"1f934-1f3fe": "prince_tone4",
"1f934-1f3ff": "prince_tone5",
"1f936": "mrs_claus",
"1f936-1f3fb": "mrs_claus_tone1",
"1f936-1f3fd": "mrs_claus_tone3",
"1f936-1f3fc": "mrs_claus_tone2",
"1f936-1f3fe": "mrs_claus_tone4",
"1f936-1f3ff": "mrs_claus_tone5",
"1f385": "santa",
"1f385-1f3fb": "santa_tone1",
"1f385-1f3fc": "santa_tone2",
"1f385-1f3fd": "santa_tone3",
"1f385-1f3fe": "santa_tone4",
"1f385-1f3ff": "santa_tone5",
"1f9b8": "superhero",
"1f9b8-1f3fb": "superhero_tone1",
"1f9b8-1f3fc": "superhero_tone2",
"1f9b8-1f3fd": "superhero_tone3",
"1f9b8-1f3fe": "superhero_tone4",
"1f9b8-1f3ff": "superhero_tone5",
"1f9b8-2640": "woman_superhero",
"1f9b8-1f3fb-2640": "woman_superhero_tone1",
"1f9b8-1f3fc-2640": "woman_superhero_tone2",
"1f9b8-1f3fd-2640": "woman_superhero_tone3",
"1f9b8-1f3fe-2640": "woman_superhero_tone4",
"1f9b8-1f3ff-2640": "woman_superhero_tone5",
"1f9b8-2642": "man_superhero",
"1f9b8-1f3fb-2642": "man_superhero_tone1",
"1f9b8-1f3fc-2642": "man_superhero_tone2",
"1f9b8-1f3fd-2642": "man_superhero_tone3",
"1f9b8-1f3fe-2642": "man_superhero_tone4",
"1f9b8-1f3ff-2642": "man_superhero_tone5",
"1f9b9": "supervillain",
"1f9b9-1f3fb": "supervillain_tone1",
"1f9b9-1f3fc": "supervillain_tone2",
"1f9b9-1f3fd": "supervillain_tone3",
"1f9b9-1f3fe": "supervillain_tone4",
"1f9b9-1f3ff": "supervillain_tone5",
"1f9b9-1f3fb-2640": "woman_supervillain_tone1",
"1f9b9-2640": "woman_supervillain",
"1f9b9-1f3fc-2640": "woman_supervillain_tone2",
"1f9b9-1f3fd-2640": "woman_supervillain_tone3",
"1f9b9-1f3fe-2640": "woman_supervillain_tone4",
"1f9b9-1f3ff-2640": "woman_supervillain_tone5",
"1f9b9-2642": "man_supervillain",
"1f9b9-1f3fb-2642": "man_supervillain_tone1",
"1f9b9-1f3fc-2642": "man_supervillain_tone2",
"1f9b9-1f3fd-2642": "man_supervillain_tone3",
"1f9b9-1f3fe-2642": "man_supervillain_tone4",
"1f9b9-1f3ff-2642": "man_supervillain_tone5",
"1f9d9": "mage",
"1f9d9-1f3fb": "mage_tone1",
"1f9d9-1f3fc": "mage_tone2",
"1f9d9-1f3fd": "mage_tone3",
"1f9d9-1f3fe": "mage_tone4",
"1f9d9-1f3ff": "mage_tone5",
"1f9d9-2640": "woman_mage",
"1f9d9-1f3fb-2640": "woman_mage_tone1",
"1f9d9-1f3fc-2640": "woman_mage_tone2",
"1f9d9-1f3fd-2640": "woman_mage_tone3",
"1f9d9-1f3fe-2640": "woman_mage_tone4",
"1f9d9-1f3ff-2640": "woman_mage_tone5",
"1f9d9-2642": "man_mage",
"1f9d9-1f3fb-2642": "man_mage_tone1",
"1f9d9-1f3fc-2642": "man_mage_tone2",
"1f9d9-1f3fd-2642": "man_mage_tone3",
"1f9d9-1f3fe-2642": "man_mage_tone4",
"1f9d9-1f3ff-2642": "man_mage_tone5",
"1f9dd": "elf",
"1f9dd-1f3fb": "elf_tone1",
"1f9dd-1f3fc": "elf_tone2",
"1f9dd-1f3fd": "elf_tone3",
"1f9dd-1f3fe": "elf_tone4",
"1f9dd-1f3ff": "elf_tone5",
"1f9dd-2640": "woman_elf",
"1f9dd-1f3fb-2640": "woman_elf_tone1",
"1f9dd-1f3fc-2640": "woman_elf_tone2",
"1f9dd-1f3fd-2640": "woman_elf_tone3",
"1f9dd-1f3fe-2640": "woman_elf_tone4",
"1f9dd-1f3ff-2640": "woman_elf_tone5",
"1f9dd-2642": "man_elf",
"1f9dd-1f3fb-2642": "man_elf_tone1",
"1f9dd-1f3fc-2642": "man_elf_tone2",
"1f9dd-1f3fd-2642": "man_elf_tone3",
"1f9dd-1f3fe-2642": "man_elf_tone4",
"1f9dd-1f3ff-2642": "man_elf_tone5",
"1f9db": "vampire",
"1f9db-1f3fb": "vampire_tone1",
"1f9db-1f3fc": "vampire_tone2",
"1f9db-1f3fd": "vampire_tone3",
"1f9db-1f3fe": "vampire_tone4",
"1f9db-1f3ff": "vampire_tone5",
"1f9db-2640": "woman_vampire",
"1f9db-1f3fb-2640": "woman_vampire_tone1",
"1f9db-1f3fc-2640": "woman_vampire_tone2",
"1f9db-1f3fd-2640": "woman_vampire_tone3",
"1f9db-1f3fe-2640": "woman_vampire_tone4",
"1f9db-1f3ff-2640": "woman_vampire_tone5",
"1f9db-2642": "man_vampire",
"1f9db-1f3fb-2642": "man_vampire_tone1",
"1f9db-1f3fc-2642": "man_vampire_tone2",
"1f9db-1f3fd-2642": "man_vampire_tone3",
"1f9db-1f3fe-2642": "man_vampire_tone4",
"1f9db-1f3ff-2642": "man_vampire_tone5",
"1f9df": "zombie",
"1f9df-2640": "woman_zombie",
"1f9df-2642": "man_zombie",
"1f9de": "genie",
"1f9de-2640": "woman_genie",
"1f9de-2642": "man_genie",
"1f9dc": "merperson",
"1f9dc-1f3fb": "merperson_tone1",
"1f9dc-1f3fc": "merperson_tone2",
"1f9dc-1f3fd": "merperson_tone3",
"1f9dc-1f3fe": "merperson_tone4",
"1f9dc-1f3ff": "merperson_tone5",
"1f9dc-2640": "mermaid",
"1f9dc-1f3fb-2640": "mermaid_tone1",
"1f9dc-1f3fc-2640": "mermaid_tone2",
"1f9dc-1f3fd-2640": "mermaid_tone3",
"1f9dc-1f3fe-2640": "mermaid_tone4",
"1f9dc-1f3ff-2640": "mermaid_tone5",
"1f9dc-2642": "merman",
"1f9dc-1f3fb-2642": "merman_tone1",
"1f9dc-1f3fc-2642": "merman_tone2",
"1f9dc-1f3fd-2642": "merman_tone3",
"1f9dc-1f3fe-2642": "merman_tone4",
"1f9dc-1f3ff-2642": "merman_tone5",
"1f9da": "fairy",
"1f9da-1f3fb": "fairy_tone1",
"1f9da-1f3fc": "fairy_tone2",
"1f9da-1f3fd": "fairy_tone3",
"1f9da-1f3fe": "fairy_tone4",
"1f9da-1f3ff": "fairy_tone5",
"1f9da-2640": "woman_fairy",
"1f9da-1f3fb-2640": "woman_fairy_tone1",
"1f9da-1f3fc-2640": "woman_fairy_tone2",
"1f9da-1f3fd-2640": "woman_fairy_tone3",
"1f9da-1f3fe-2640": "woman_fairy_tone4",
"1f9da-1f3ff-2640": "woman_fairy_tone5",
"1f9da-2642": "man_fairy",
"1f9da-1f3fb-2642": "man_fairy_tone1",
"1f9da-1f3fc-2642": "man_fairy_tone2",
"1f9da-1f3fd-2642": "man_fairy_tone3",
"1f9da-1f3fe-2642": "man_fairy_tone4",
"1f9da-1f3ff-2642": "man_fairy_tone5",
"1f47c": "angel",
"1f47c-1f3fb": "angel_tone1",
"1f47c-1f3fc": "angel_tone2",
"1f47c-1f3fd": "angel_tone3",
"1f47c-1f3fe": "angel_tone4",
"1f47c-1f3ff": "angel_tone5",
"1f930": "pregnant_woman",
"1f930-1f3fb": "pregnant_woman_tone1",
"1f930-1f3fc": "pregnant_woman_tone2",
"1f930-1f3fd": "pregnant_woman_tone3",
"1f930-1f3fe": "pregnant_woman_tone4",
"1f930-1f3ff": "pregnant_woman_tone5",
"1f931": "breast_feeding",
"1f931-1f3fb": "breast_feeding_tone1",
"1f931-1f3fc": "breast_feeding_tone2",
"1f931-1f3fd": "breast_feeding_tone3",
"1f931-1f3fe": "breast_feeding_tone4",
"1f931-1f3ff": "breast_feeding_tone5",
"1f647": "person_bowing",
"1f647-1f3fb": "person_bowing_tone1",
"1f647-1f3fc": "person_bowing_tone2",
"1f647-1f3fd": "person_bowing_tone3",
"1f647-1f3fe": "person_bowing_tone4",
"1f647-1f3ff": "person_bowing_tone5",
"1f647-2640": "woman_bowing",
"1f647-1f3fb-2640": "woman_bowing_tone1",
"1f647-1f3fc-2640": "woman_bowing_tone2",
"1f647-1f3fd-2640": "woman_bowing_tone3",
"1f647-1f3fe-2640": "woman_bowing_tone4",
"1f647-1f3ff-2640": "woman_bowing_tone5",
"1f647-2642": "man_bowing",
"1f647-1f3fb-2642": "man_bowing_tone1",
"1f647-1f3fc-2642": "man_bowing_tone2",
"1f647-1f3fd-2642": "man_bowing_tone3",
"1f647-1f3fe-2642": "man_bowing_tone4",
"1f647-1f3ff-2642": "man_bowing_tone5",
"1f481": "person_tipping_hand",
"1f481-1f3fb": "person_tipping_hand_tone1",
"1f481-1f3fc": "person_tipping_hand_tone2",
"1f481-1f3fd": "person_tipping_hand_tone3",
"1f481-1f3fe": "person_tipping_hand_tone4",
"1f481-1f3ff": "person_tipping_hand_tone5",
"1f481-2640": "woman_tipping_hand",
"1f481-1f3fb-2640": "woman_tipping_hand_tone1",
"1f481-1f3fc-2640": "woman_tipping_hand_tone2",
"1f481-1f3fd-2640": "woman_tipping_hand_tone3",
"1f481-1f3fe-2640": "woman_tipping_hand_tone4",
"1f481-1f3ff-2640": "woman_tipping_hand_tone5",
"1f481-2642": "man_tipping_hand",
"1f481-1f3fb-2642": "man_tipping_hand_tone1",
"1f481-1f3fc-2642": "man_tipping_hand_tone2",
"1f481-1f3fd-2642": "man_tipping_hand_tone3",
"1f481-1f3fe-2642": "man_tipping_hand_tone4",
"1f481-1f3ff-2642": "man_tipping_hand_tone5",
"1f645": "person_gesturing_no",
"1f645-1f3fb": "person_gesturing_no_tone1",
"1f645-1f3fc": "person_gesturing_no_tone2",
"1f645-1f3fd": "person_gesturing_no_tone3",
"1f645-1f3fe": "person_gesturing_no_tone4",
"1f645-1f3ff": "person_gesturing_no_tone5",
"1f645-2640": "woman_gesturing_no",
"1f645-1f3fb-2640": "woman_gesturing_no_tone1",
"1f645-1f3fc-2640": "woman_gesturing_no_tone2",
"1f645-1f3fd-2640": "woman_gesturing_no_tone3",
"1f645-1f3fe-2640": "woman_gesturing_no_tone4",
"1f645-1f3ff-2640": "woman_gesturing_no_tone5",
"1f645-2642": "man_gesturing_no",
"1f645-1f3fb-2642": "man_gesturing_no_tone1",
"1f645-1f3fc-2642": "man_gesturing_no_tone2",
"1f645-1f3fd-2642": "man_gesturing_no_tone3",
"1f645-1f3fe-2642": "man_gesturing_no_tone4",
"1f645-1f3ff-2642": "man_gesturing_no_tone5",
"1f646": "person_gesturing_ok",
"1f646-1f3fb": "person_gesturing_ok_tone1",
"1f646-1f3fc": "person_gesturing_ok_tone2",
"1f646-1f3fd": "person_gesturing_ok_tone3",
"1f646-1f3fe": "person_gesturing_ok_tone4",
"1f646-1f3ff": "person_gesturing_ok_tone5",
"1f646-2640": "woman_gesturing_ok",
"1f646-1f3fb-2640": "woman_gesturing_ok_tone1",
"1f646-1f3fc-2640": "woman_gesturing_ok_tone2",
"1f646-1f3fd-2640": "woman_gesturing_ok_tone3",
"1f646-1f3fe-2640": "woman_gesturing_ok_tone4",
"1f646-1f3ff-2640": "woman_gesturing_ok_tone5",
"1f646-2642": "man_gesturing_ok",
"1f646-1f3fb-2642": "man_gesturing_ok_tone1",
"1f646-1f3fc-2642": "man_gesturing_ok_tone2",
"1f646-1f3fd-2642": "man_gesturing_ok_tone3",
"1f646-1f3fe-2642": "man_gesturing_ok_tone4",
"1f646-1f3ff-2642": "man_gesturing_ok_tone5",
"1f64b": "person_raising_hand",
"1f64b-1f3fb": "person_raising_hand_tone1",
"1f64b-1f3fc": "person_raising_hand_tone2",
"1f64b-1f3fd": "person_raising_hand_tone3",
"1f64b-1f3fe": "person_raising_hand_tone4",
"1f64b-1f3ff": "person_raising_hand_tone5",
"1f64b-2640": "woman_raising_hand",
"1f64b-1f3fb-2640": "woman_raising_hand_tone1",
"1f64b-1f3fc-2640": "woman_raising_hand_tone2",
"1f64b-1f3fd-2640": "woman_raising_hand_tone3",
"1f64b-1f3fe-2640": "woman_raising_hand_tone4",
"1f64b-1f3ff-2640": "woman_raising_hand_tone5",
"1f64b-2642": "man_raising_hand",
"1f64b-1f3fb-2642": "man_raising_hand_tone1",
"1f64b-1f3fc-2642": "man_raising_hand_tone2",
"1f64b-1f3fd-2642": "man_raising_hand_tone3",
"1f64b-1f3fe-2642": "man_raising_hand_tone4",
"1f64b-1f3ff-2642": "man_raising_hand_tone5",
"1f926": "person_facepalming",
"1f926-1f3fb": "person_facepalming_tone1",
"1f926-1f3fc": "person_facepalming_tone2",
"1f926-1f3fd": "person_facepalming_tone3",
"1f926-1f3fe": "person_facepalming_tone4",
"1f926-1f3ff": "person_facepalming_tone5",
"1f926-2640": "woman_facepalming",
"1f926-1f3fb-2640": "woman_facepalming_tone1",
"1f926-1f3fc-2640": "woman_facepalming_tone2",
"1f926-1f3fd-2640": "woman_facepalming_tone3",
"1f926-1f3fe-2640": "woman_facepalming_tone4",
"1f926-1f3ff-2640": "woman_facepalming_tone5",
"1f926-2642": "man_facepalming",
"1f926-1f3fb-2642": "man_facepalming_tone1",
"1f926-1f3fc-2642": "man_facepalming_tone2",
"1f926-1f3fd-2642": "man_facepalming_tone3",
"1f926-1f3fe-2642": "man_facepalming_tone4",
"1f926-1f3ff-2642": "man_facepalming_tone5",
"1f937": "person_shrugging",
"1f937-1f3fb": "person_shrugging_tone1",
"1f937-1f3fc": "person_shrugging_tone2",
"1f937-1f3fd": "person_shrugging_tone3",
"1f937-1f3fe": "person_shrugging_tone4",
"1f937-1f3ff": "person_shrugging_tone5",
"1f937-2640": "woman_shrugging",
"1f937-1f3fb-2640": "woman_shrugging_tone1",
"1f937-1f3fc-2640": "woman_shrugging_tone2",
"1f937-1f3fd-2640": "woman_shrugging_tone3",
"1f937-1f3fe-2640": "woman_shrugging_tone4",
"1f937-1f3ff-2640": "woman_shrugging_tone5",
"1f937-2642": "man_shrugging",
"1f937-1f3fb-2642": "man_shrugging_tone1",
"1f937-1f3fc-2642": "man_shrugging_tone2",
"1f937-1f3fd-2642": "man_shrugging_tone3",
"1f937-1f3fe-2642": "man_shrugging_tone4",
"1f937-1f3ff-2642": "man_shrugging_tone5",
"1f64e": "person_pouting",
"1f64e-1f3fb": "person_pouting_tone1",
"1f64e-1f3fc": "person_pouting_tone2",
"1f64e-1f3fd": "person_pouting_tone3",
"1f64e-1f3fe": "person_pouting_tone4",
"1f64e-1f3ff": "person_pouting_tone5",
"1f64e-2640": "woman_pouting",
"1f64e-1f3fb-2640": "woman_pouting_tone1",
"1f64e-1f3fc-2640": "woman_pouting_tone2",
"1f64e-1f3fd-2640": "woman_pouting_tone3",
"1f64e-1f3fe-2640": "woman_pouting_tone4",
"1f64e-1f3ff-2640": "woman_pouting_tone5",
"1f64e-2642": "man_pouting",
"1f64e-1f3fb-2642": "man_pouting_tone1",
"1f64e-1f3fc-2642": "man_pouting_tone2",
"1f64e-1f3fd-2642": "man_pouting_tone3",
"1f64e-1f3fe-2642": "man_pouting_tone4",
"1f64e-1f3ff-2642": "man_pouting_tone5",
"1f64d": "person_frowning",
"1f64d-1f3fb": "person_frowning_tone1",
"1f64d-1f3fc": "person_frowning_tone2",
"1f64d-1f3fd": "person_frowning_tone3",
"1f64d-1f3fe": "person_frowning_tone4",
"1f64d-1f3ff": "person_frowning_tone5",
"1f64d-2640": "woman_frowning",
"1f64d-1f3fb-2640": "woman_frowning_tone1",
"1f64d-1f3fc-2640": "woman_frowning_tone2",
"1f64d-1f3fd-2640": "woman_frowning_tone3",
"1f64d-1f3fe-2640": "woman_frowning_tone4",
"1f64d-1f3ff-2640": "woman_frowning_tone5",
"1f64d-2642": "man_frowning",
"1f64d-1f3fb-2642": "man_frowning_tone1",
"1f64d-1f3fc-2642": "man_frowning_tone2",
"1f64d-1f3fd-2642": "man_frowning_tone3",
"1f64d-1f3fe-2642": "man_frowning_tone4",
"1f64d-1f3ff-2642": "man_frowning_tone5",
"1f487": "person_getting_haircut",
"1f487-1f3fb": "person_getting_haircut_tone1",
"1f487-1f3fc": "person_getting_haircut_tone2",
"1f487-1f3fd": "person_getting_haircut_tone3",
"1f487-1f3fe": "person_getting_haircut_tone4",
"1f487-1f3ff": "person_getting_haircut_tone5",
"1f487-2640": "woman_getting_haircut",
"1f487-1f3fb-2640": "woman_getting_haircut_tone1",
"1f487-1f3fc-2640": "woman_getting_haircut_tone2",
"1f487-1f3fd-2640": "woman_getting_haircut_tone3",
"1f487-1f3fe-2640": "woman_getting_haircut_tone4",
"1f487-1f3ff-2640": "woman_getting_haircut_tone5",
"1f487-2642": "man_getting_haircut",
"1f487-1f3fb-2642": "man_getting_haircut_tone1",
"1f487-1f3fc-2642": "man_getting_haircut_tone2",
"1f487-1f3fd-2642": "man_getting_haircut_tone3",
"1f487-1f3fe-2642": "man_getting_haircut_tone4",
"1f487-1f3ff-2642": "man_getting_haircut_tone5",
"1f486": "person_getting_massage",
"1f486-1f3fb": "person_getting_massage_tone1",
"1f486-1f3fc": "person_getting_massage_tone2",
"1f486-1f3fd": "person_getting_massage_tone3",
"1f486-1f3fe": "person_getting_massage_tone4",
"1f486-1f3ff": "person_getting_massage_tone5",
"1f486-2640": "woman_getting_face_massage",
"1f486-1f3fb-2640": "woman_getting_face_massage_tone1",
"1f486-1f3fc-2640": "woman_getting_face_massage_tone2",
"1f486-1f3fd-2640": "woman_getting_face_massage_tone3",
"1f486-1f3fe-2640": "woman_getting_face_massage_tone4",
"1f486-1f3ff-2640": "woman_getting_face_massage_tone5",
"1f486-2642": "man_getting_face_massage",
"1f486-1f3fb-2642": "man_getting_face_massage_tone1",
"1f486-1f3fc-2642": "man_getting_face_massage_tone2",
"1f486-1f3fd-2642": "man_getting_face_massage_tone3",
"1f486-1f3fe-2642": "man_getting_face_massage_tone4",
"1f486-1f3ff-2642": "man_getting_face_massage_tone5",
"1f9d6": "person_in_steamy_room",
"1f9d6-1f3fb": "person_in_steamy_room_tone1",
"1f9d6-1f3fc": "person_in_steamy_room_tone2",
"1f9d6-1f3fd": "person_in_steamy_room_tone3",
"1f9d6-1f3fe": "person_in_steamy_room_tone4",
"1f9d6-1f3ff": "person_in_steamy_room_tone5",
"1f9d6-2640": "woman_in_steamy_room",
"1f9d6-1f3fb-2640": "woman_in_steamy_room_tone1",
"1f9d6-1f3fc-2640": "woman_in_steamy_room_tone2",
"1f9d6-1f3fd-2640": "woman_in_steamy_room_tone3",
"1f9d6-1f3fe-2640": "woman_in_steamy_room_tone4",
"1f9d6-1f3ff-2640": "woman_in_steamy_room_tone5",
"1f9d6-2642": "man_in_steamy_room",
"1f9d6-1f3fb-2642": "man_in_steamy_room_tone1",
"1f9d6-1f3fc-2642": "man_in_steamy_room_tone2",
"1f9d6-1f3fd-2642": "man_in_steamy_room_tone3",
"1f9d6-1f3fe-2642": "man_in_steamy_room_tone4",
"1f9d6-1f3ff-2642": "man_in_steamy_room_tone5",
"1f485": "nail_care",
"1f485-1f3fb": "nail_care_tone1",
"1f485-1f3fc": "nail_care_tone2",
"1f485-1f3fd": "nail_care_tone3",
"1f485-1f3fe": "nail_care_tone4",
"1f485-1f3ff": "nail_care_tone5",
"1f933": "selfie",
"1f933-1f3fb": "selfie_tone1",
"1f933-1f3fc": "selfie_tone2",
"1f933-1f3fd": "selfie_tone3",
"1f933-1f3fe": "selfie_tone4",
"1f933-1f3ff": "selfie_tone5",
"1f483": "dancer",
"1f483-1f3fb": "dancer_tone1",
"1f483-1f3fc": "dancer_tone2",
"1f483-1f3fd": "dancer_tone3",
"1f483-1f3fe": "dancer_tone4",
"1f483-1f3ff": "dancer_tone5",
"1f57a": "man_dancing",
"1f57a-1f3fb": "man_dancing_tone1",
"1f57a-1f3fc": "man_dancing_tone2",
"1f57a-1f3fd": "man_dancing_tone3",
"1f57a-1f3ff": "man_dancing_tone5",
"1f57a-1f3fe": "man_dancing_tone4",
"1f46f": "people_with_bunny_ears_partying",
"1f46f-2640": "women_with_bunny_ears_partying",
"1f46f-2642": "men_with_bunny_ears_partying",
"1f574": "levitate",
"1f574-1f3fb": "levitate_tone1",
"1f574-1f3fc": "levitate_tone2",
"1f574-1f3fd": "levitate_tone3",
"1f574-1f3fe": "levitate_tone4",
"1f574-1f3ff": "levitate_tone5",
"1f6b6": "person_walking",
"1f6b6-1f3fb": "person_walking_tone1",
"1f6b6-1f3fc": "person_walking_tone2",
"1f6b6-1f3fd": "person_walking_tone3",
"1f6b6-1f3fe": "person_walking_tone4",
"1f6b6-1f3ff": "person_walking_tone5",
"1f6b6-2640": "woman_walking",
"1f6b6-1f3fb-2640": "woman_walking_tone1",
"1f6b6-1f3fc-2640": "woman_walking_tone2",
"1f6b6-1f3fd-2640": "woman_walking_tone3",
"1f6b6-1f3fe-2640": "woman_walking_tone4",
"1f6b6-1f3ff-2640": "woman_walking_tone5",
"1f6b6-2642": "man_walking",
"1f6b6-1f3fb-2642": "man_walking_tone1",
"1f6b6-1f3fc-2642": "man_walking_tone2",
"1f6b6-1f3fd-2642": "man_walking_tone3",
"1f6b6-1f3fe-2642": "man_walking_tone4",
"1f6b6-1f3ff-2642": "man_walking_tone5",
"1f3c3": "person_running",
"1f3c3-1f3fb": "person_running_tone1",
"1f3c3-1f3fc": "person_running_tone2",
"1f3c3-1f3fd": "person_running_tone3",
"1f3c3-1f3fe": "person_running_tone4",
"1f3c3-1f3ff": "person_running_tone5",
"1f3c3-2640": "woman_running",
"1f3c3-1f3fb-2640": "woman_running_tone1",
"1f3c3-1f3fc-2640": "woman_running_tone2",
"1f3c3-1f3fd-2640": "woman_running_tone3",
"1f3c3-1f3fe-2640": "woman_running_tone4",
"1f3c3-1f3ff-2640": "woman_running_tone5",
"1f3c3-2642": "man_running",
"1f3c3-1f3fb-2642": "man_running_tone1",
"1f3c3-1f3fc-2642": "man_running_tone2",
"1f3c3-1f3fd-2642": "man_running_tone3",
"1f3c3-1f3fe-2642": "man_running_tone4",
"1f3c3-1f3ff-2642": "man_running_tone5",
"1f46b": "couple",
"1f46d": "two_women_holding_hands",
"1f46c": "two_men_holding_hands",
"1f491": "couple_with_heart",
"1f469-2764-1f468": "couple_with_heart_woman_man",
"1f469-2764-1f469": "couple_ww",
"1f468-2764-1f468": "couple_mm",
"1f48f": "couplekiss",
"1f469-2764-1f48b-1f468": "kiss_woman_man",
"1f469-2764-1f48b-1f469": "kiss_ww",
"1f468-2764-1f48b-1f468": "kiss_mm",
"1f46a": "family",
"1f468-1f469-1f466": "family_man_woman_boy",
"1f468-1f469-1f467": "family_mwg",
"1f468-1f469-1f467-1f466": "family_mwgb",
"1f468-1f469-1f466-1f466": "family_mwbb",
"1f468-1f469-1f467-1f467": "family_mwgg",
"1f469-1f469-1f466": "family_wwb",
"1f469-1f469-1f467": "family_wwg",
"1f469-1f469-1f467-1f466": "family_wwgb",
"1f469-1f469-1f466-1f466": "family_wwbb",
"1f469-1f469-1f467-1f467": "family_wwgg",
"1f468-1f468-1f466": "family_mmb",
"1f468-1f468-1f467": "family_mmg",
"1f468-1f468-1f467-1f466": "family_mmgb",
"1f468-1f468-1f466-1f466": "family_mmbb",
"1f468-1f468-1f467-1f467": "family_mmgg",
"1f469-1f466": "family_woman_boy",
"1f469-1f467": "family_woman_girl",
"1f469-1f467-1f466": "family_woman_girl_boy",
"1f469-1f466-1f466": "family_woman_boy_boy",
"1f469-1f467-1f467": "family_woman_girl_girl",
"1f468-1f466": "family_man_boy",
"1f468-1f467": "family_man_girl",
"1f468-1f467-1f466": "family_man_girl_boy",
"1f468-1f466-1f466": "family_man_boy_boy",
"1f468-1f467-1f467": "family_man_girl_girl",
"1f9e5": "coat",
"1f45a": "womans_clothes",
"1f455": "shirt",
"1f456": "jeans",
"1f454": "necktie",
"1f457": "dress",
"1f459": "bikini",
"1f458": "kimono",
"1f97c": "lab_coat",
"1f460": "high_heel",
"1f461": "sandal",
"1f462": "boot",
"1f45e": "mans_shoe",
"1f45f": "athletic_shoe",
"1f97e": "hiking_boot",
"1f97f": "womans_flat_shoe",
"1f9e6": "socks",
"1f9e4": "gloves",
"1f9e3": "scarf",
"1f3a9": "tophat",
"1f9e2": "billed_cap",
"1f452": "womans_hat",
"1f393": "mortar_board",
"26d1": "helmet_with_cross",
"1f451": "crown",
"1f45d": "pouch",
"1f45b": "purse",
"1f45c": "handbag",
"1f4bc": "briefcase",
"1f392": "school_satchel",
"1f453": "eyeglasses",
"1f576": "dark_sunglasses",
"1f97d": "goggles",
"1f302": "closed_umbrella",
"1f9b0": "red_haired",
"1f9b1": "curly_haired",
"1f9b3": "white_haired",
"1f9b2": "bald",
"1f1ff": "regional_indicator_z",
"1f1fe": "regional_indicator_y",
"1f1fd": "regional_indicator_x",
"1f1fc": "regional_indicator_w",
"1f1fb": "regional_indicator_v",
"1f1fa": "regional_indicator_u",
"1f1f9": "regional_indicator_t",
"1f1f8": "regional_indicator_s",
"1f1f7": "regional_indicator_r",
"1f1f6": "regional_indicator_q",
"1f1f5": "regional_indicator_p",
"1f1f4": "regional_indicator_o",
"1f1f3": "regional_indicator_n",
"1f1f2": "regional_indicator_m",
"1f1f1": "regional_indicator_l",
"1f1f0": "regional_indicator_k",
"1f1ef": "regional_indicator_j",
"1f1ee": "regional_indicator_i",
"1f1ed": "regional_indicator_h",
"1f1ec": "regional_indicator_g",
"1f1eb": "regional_indicator_f",
"1f1ea": "regional_indicator_e",
"1f1e9": "regional_indicator_d",
"1f1e8": "regional_indicator_c",
"1f1e7": "regional_indicator_b",
"1f1e6": "regional_indicator_a",
"1f697": "red_car",
"1f695": "taxi",
"1f699": "blue_car",
"1f68c": "bus",
"1f68e": "trolleybus",
"1f3ce": "race_car",
"1f693": "police_car",
"1f691": "ambulance",
"1f692": "fire_engine",
"1f690": "minibus",
"1f69a": "truck",
"1f69b": "articulated_lorry",
"1f69c": "tractor",
"1f6f4": "scooter",
"1f6b2": "bike",
"1f6f5": "motor_scooter",
"1f3cd": "motorcycle",
"1f6a8": "rotating_light",
"1f694": "oncoming_police_car",
"1f68d": "oncoming_bus",
"1f698": "oncoming_automobile",
"1f696": "oncoming_taxi",
"1f6a1": "aerial_tramway",
"1f6a0": "mountain_cableway",
"1f69f": "suspension_railway",
"1f683": "railway_car",
"1f68b": "train",
"1f69e": "mountain_railway",
"1f69d": "monorail",
"1f684": "bullettrain_side",
"1f685": "bullettrain_front",
"1f688": "light_rail",
"1f682": "steam_locomotive",
"1f686": "train2",
"1f687": "metro",
"1f68a": "tram",
"1f689": "station",
"1f6eb": "airplane_departure",
"1f6ec": "airplane_arriving",
"1f6e9": "airplane_small",
"1f4ba": "seat",
"1f9f3": "luggage",
"1f6f0": "satellite_orbital",
"1f680": "rocket",
"1f6f8": "flying_saucer",
"1f681": "helicopter",
"1f6f6": "canoe",
"26f5": "sailboat",
"1f6a4": "speedboat",
"1f6e5": "motorboat",
"1f6f3": "cruise_ship",
"26f4": "ferry",
"1f6a2": "ship",
"26fd": "fuelpump",
"1f6a7": "construction",
"1f6a6": "vertical_traffic_light",
"1f6a5": "traffic_light",
"1f68f": "busstop",
"1f5fa": "map",
"1f5ff": "moyai",
"1f5fd": "statue_of_liberty",
"1f5fc": "tokyo_tower",
"1f3f0": "european_castle",
"1f3ef": "japanese_castle",
"1f3df": "stadium",
"1f3a1": "ferris_wheel",
"1f3a2": "roller_coaster",
"1f3a0": "carousel_horse",
"26f2": "fountain",
"26f1": "beach_umbrella",
"1f3d6": "beach",
"1f3dd": "island",
"1f3dc": "desert",
"1f30b": "volcano",
"26f0": "mountain",
"1f3d4": "mountain_snow",
"1f5fb": "mount_fuji",
"1f3d5": "camping",
"26fa": "tent",
"1f3e0": "house",
"1f3e1": "house_with_garden",
"1f3d8": "homes",
"1f3da": "house_abandoned",
"1f3d7": "construction_site",
"1f3ed": "factory",
"1f3e2": "office",
"1f3ec": "department_store",
"1f3e3": "post_office",
"1f3e4": "european_post_office",
"1f3e5": "hospital",
"1f3e6": "bank",
"1f3e8": "hotel",
"1f3ea": "convenience_store",
"1f3eb": "school",
"1f3e9": "love_hotel",
"1f492": "wedding",
"1f3db": "classical_building",
"26ea": "church",
"1f54c": "mosque",
"1f54d": "synagogue",
"1f54b": "kaaba",
"26e9": "shinto_shrine",
"1f6e4": "railway_track",
"1f6e3": "motorway",
"1f5fe": "japan",
"1f391": "rice_scene",
"1f3de": "park",
"1f305": "sunrise",
"1f304": "sunrise_over_mountains",
"1f320": "stars",
"1f387": "sparkler",
"1f386": "fireworks",
"1f9e8": "firecracker",
"1f307": "city_sunset",
"1f306": "city_dusk",
"1f3d9": "cityscape",
"1f303": "night_with_stars",
"1f30c": "milky_way",
"1f309": "bridge_at_night",
"1f512": "lock",
"1f513": "unlock",
"1f301": "foggy",
"1f3f3": "flag_white",
"1f3f4": "flag_black",
"1f3c1": "checkered_flag",
"1f6a9": "triangular_flag_on_post",
"1f3f3-1f308": "rainbow_flag",
"1f3f4-2620": "pirate_flag",
"1f1e6-1f1eb": "flag_af",
"1f1e6-1f1fd": "flag_ax",
"1f1e6-1f1f1": "flag_al",
"1f1e9-1f1ff": "flag_dz",
"1f1e6-1f1f8": "flag_as",
"1f1e6-1f1e9": "flag_ad",
"1f1e6-1f1f4": "flag_ao",
"1f1e6-1f1ee": "flag_ai",
"1f1e6-1f1f6": "flag_aq",
"1f1e6-1f1ec": "flag_ag",
"1f1e6-1f1f7": "flag_ar",
"1f1e6-1f1f2": "flag_am",
"1f1e6-1f1fc": "flag_aw",
"1f1e6-1f1fa": "flag_au",
"1f1e6-1f1f9": "flag_at",
"1f1e6-1f1ff": "flag_az",
"1f1e7-1f1f8": "flag_bs",
"1f1e7-1f1ed": "flag_bh",
"1f1e7-1f1e9": "flag_bd",
"1f1e7-1f1e7": "flag_bb",
"1f1e7-1f1fe": "flag_by",
"1f1e7-1f1ea": "flag_be",
"1f1e7-1f1ff": "flag_bz",
"1f1e7-1f1ef": "flag_bj",
"1f1e7-1f1f2": "flag_bm",
"1f1e7-1f1f9": "flag_bt",
"1f1e7-1f1f4": "flag_bo",
"1f1e7-1f1e6": "flag_ba",
"1f1e7-1f1fc": "flag_bw",
"1f1e7-1f1f7": "flag_br",
"1f1ee-1f1f4": "flag_io",
"1f1fb-1f1ec": "flag_vg",
"1f1e7-1f1f3": "flag_bn",
"1f1e7-1f1ec": "flag_bg",
"1f1e7-1f1eb": "flag_bf",
"1f1e7-1f1ee": "flag_bi",
"1f1f0-1f1ed": "flag_kh",
"1f1e8-1f1f2": "flag_cm",
"1f1e8-1f1e6": "flag_ca",
"1f1ee-1f1e8": "flag_ic",
"1f1e8-1f1fb": "flag_cv",
"1f1e7-1f1f6": "flag_bq",
"1f1f0-1f1fe": "flag_ky",
"1f1e8-1f1eb": "flag_cf",
"1f1f9-1f1e9": "flag_td",
"1f1e8-1f1f1": "flag_cl",
"1f1e8-1f1f3": "flag_cn",
"1f1e8-1f1fd": "flag_cx",
"1f1e8-1f1e8": "flag_cc",
"1f1e8-1f1f4": "flag_co",
"1f1f0-1f1f2": "flag_km",
"1f1e8-1f1ec": "flag_cg",
"1f1e8-1f1e9": "flag_cd",
"1f1e8-1f1f0": "flag_ck",
"1f1e8-1f1f7": "flag_cr",
"1f1e8-1f1ee": "flag_ci",
"1f1ed-1f1f7": "flag_hr",
"1f1e8-1f1fa": "flag_cu",
"1f1e8-1f1fc": "flag_cw",
"1f1e8-1f1fe": "flag_cy",
"1f1e8-1f1ff": "flag_cz",
"1f1e9-1f1f0": "flag_dk",
"1f1e9-1f1ef": "flag_dj",
"1f1e9-1f1f2": "flag_dm",
"1f1e9-1f1f4": "flag_do",
"1f1ea-1f1e8": "flag_ec",
"1f1ea-1f1ec": "flag_eg",
"1f1f8-1f1fb": "flag_sv",
"1f1ec-1f1f6": "flag_gq",
"1f1ea-1f1f7": "flag_er",
"1f1ea-1f1ea": "flag_ee",
"1f1ea-1f1f9": "flag_et",
"1f1ea-1f1fa": "flag_eu",
"1f1eb-1f1f0": "flag_fk",
"1f1eb-1f1f4": "flag_fo",
"1f1eb-1f1ef": "flag_fj",
"1f1eb-1f1ee": "flag_fi",
"1f1eb-1f1f7": "flag_fr",
"1f1ec-1f1eb": "flag_gf",
"1f1f5-1f1eb": "flag_pf",
"1f1f9-1f1eb": "flag_tf",
"1f1ec-1f1e6": "flag_ga",
"1f1ec-1f1f2": "flag_gm",
"1f1ec-1f1ea": "flag_ge",
"1f1e9-1f1ea": "flag_de",
"1f1ec-1f1ed": "flag_gh",
"1f1ec-1f1ee": "flag_gi",
"1f1ec-1f1f7": "flag_gr",
"1f1ec-1f1f1": "flag_gl",
"1f1ec-1f1e9": "flag_gd",
"1f1ec-1f1f5": "flag_gp",
"1f1ec-1f1fa": "flag_gu",
"1f1ec-1f1f9": "flag_gt",
"1f1ec-1f1ec": "flag_gg",
"1f1ec-1f1f3": "flag_gn",
"1f1ec-1f1fc": "flag_gw",
"1f1ec-1f1fe": "flag_gy",
"1f1ed-1f1f9": "flag_ht",
"1f1ed-1f1f3": "flag_hn",
"1f1ed-1f1f0": "flag_hk",
"1f1ed-1f1fa": "flag_hu",
"1f1ee-1f1f8": "flag_is",
"1f1ee-1f1f3": "flag_in",
"1f1ee-1f1e9": "flag_id",
"1f1ee-1f1f7": "flag_ir",
"1f1ee-1f1f6": "flag_iq",
"1f1ee-1f1ea": "flag_ie",
"1f1ee-1f1f2": "flag_im",
"1f1ee-1f1f1": "flag_il",
"1f1ee-1f1f9": "flag_it",
"1f1ef-1f1f2": "flag_jm",
"1f1ef-1f1f5": "flag_jp",
"1f38c": "crossed_flags",
"1f1ef-1f1ea": "flag_je",
"1f1ef-1f1f4": "flag_jo",
"1f1f0-1f1ff": "flag_kz",
"1f1f0-1f1ea": "flag_ke",
"1f1f0-1f1ee": "flag_ki",
"1f1fd-1f1f0": "flag_xk",
"1f1f0-1f1fc": "flag_kw",
"1f1f0-1f1ec": "flag_kg",
"1f1f1-1f1e6": "flag_la",
"1f1f1-1f1fb": "flag_lv",
"1f1f1-1f1e7": "flag_lb",
"1f1f1-1f1f8": "flag_ls",
"1f1f1-1f1f7": "flag_lr",
"1f1f1-1f1fe": "flag_ly",
"1f1f1-1f1ee": "flag_li",
"1f1f1-1f1f9": "flag_lt",
"1f1f1-1f1fa": "flag_lu",
"1f1f2-1f1f4": "flag_mo",
"1f1f2-1f1f0": "flag_mk",
"1f1f2-1f1ec": "flag_mg",
"1f1f2-1f1fc": "flag_mw",
"1f1f2-1f1fe": "flag_my",
"1f1f2-1f1fb": "flag_mv",
"1f1f2-1f1f1": "flag_ml",
"1f1f2-1f1f9": "flag_mt",
"1f1f2-1f1ed": "flag_mh",
"1f1f2-1f1f6": "flag_mq",
"1f1f2-1f1f7": "flag_mr",
"1f1f2-1f1fa": "flag_mu",
"1f1fe-1f1f9": "flag_yt",
"1f1f2-1f1fd": "flag_mx",
"1f1eb-1f1f2": "flag_fm",
"1f1f2-1f1e9": "flag_md",
"1f1f2-1f1e8": "flag_mc",
"1f1f2-1f1f3": "flag_mn",
"1f1f2-1f1ea": "flag_me",
"1f1f2-1f1f8": "flag_ms",
"1f1f2-1f1e6": "flag_ma",
"1f1f2-1f1ff": "flag_mz",
"1f1f2-1f1f2": "flag_mm",
"1f1f3-1f1e6": "flag_na",
"1f1f3-1f1f7": "flag_nr",
"1f1f3-1f1f5": "flag_np",
"1f1f3-1f1f1": "flag_nl",
"1f1f3-1f1e8": "flag_nc",
"1f1f3-1f1ff": "flag_nz",
"1f1f3-1f1ee": "flag_ni",
"1f1f3-1f1ea": "flag_ne",
"1f1f3-1f1ec": "flag_ng",
"1f1f3-1f1fa": "flag_nu",
"1f1f3-1f1eb": "flag_nf",
"1f1f0-1f1f5": "flag_kp",
"1f1f2-1f1f5": "flag_mp",
"1f1f3-1f1f4": "flag_no",
"1f1f4-1f1f2": "flag_om",
"1f1f5-1f1f0": "flag_pk",
"1f1f5-1f1fc": "flag_pw",
"1f1f5-1f1f8": "flag_ps",
"1f1f5-1f1e6": "flag_pa",
"1f1f5-1f1ec": "flag_pg",
"1f1f5-1f1fe": "flag_py",
"1f1f5-1f1ea": "flag_pe",
"1f1f5-1f1ed": "flag_ph",
"1f1f5-1f1f3": "flag_pn",
"1f1f5-1f1f1": "flag_pl",
"1f1f5-1f1f9": "flag_pt",
"1f1f5-1f1f7": "flag_pr",
"1f1f6-1f1e6": "flag_qa",
"1f1f7-1f1ea": "flag_re",
"1f1f7-1f1f4": "flag_ro",
"1f1f7-1f1fa": "flag_ru",
"1f1f7-1f1fc": "flag_rw",
"1f1fc-1f1f8": "flag_ws",
"1f1f8-1f1f2": "flag_sm",
"1f1f8-1f1f9": "flag_st",
"1f1f8-1f1e6": "flag_sa",
"1f1f8-1f1f3": "flag_sn",
"1f1f7-1f1f8": "flag_rs",
"1f1f8-1f1e8": "flag_sc",
"1f1f8-1f1f1": "flag_sl",
"1f1f8-1f1ec": "flag_sg",
"1f1f8-1f1fd": "flag_sx",
"1f1f8-1f1f0": "flag_sk",
"1f1f8-1f1ee": "flag_si",
"1f1ec-1f1f8": "flag_gs",
"1f1f8-1f1e7": "flag_sb",
"1f1f8-1f1f4": "flag_so",
"1f1ff-1f1e6": "flag_za",
"1f1f0-1f1f7": "flag_kr",
"1f1f8-1f1f8": "flag_ss",
"1f1ea-1f1f8": "flag_es",
"1f1f1-1f1f0": "flag_lk",
"1f1e7-1f1f1": "flag_bl",
"1f1f8-1f1ed": "flag_sh",
"1f1f0-1f1f3": "flag_kn",
"1f1f1-1f1e8": "flag_lc",
"1f1f5-1f1f2": "flag_pm",
"1f1fb-1f1e8": "flag_vc",
"1f1f8-1f1e9": "flag_sd",
"1f1f8-1f1f7": "flag_sr",
"1f1f8-1f1ff": "flag_sz",
"1f1f8-1f1ea": "flag_se",
"1f1e8-1f1ed": "flag_ch",
"1f1f8-1f1fe": "flag_sy",
"1f1f9-1f1fc": "flag_tw",
"1f1f9-1f1ef": "flag_tj",
"1f1f9-1f1ff": "flag_tz",
"1f1f9-1f1ed": "flag_th",
"1f1f9-1f1f1": "flag_tl",
"1f1f9-1f1ec": "flag_tg",
"1f1f9-1f1f0": "flag_tk",
"1f1f9-1f1f4": "flag_to",
"1f1f9-1f1f9": "flag_tt",
"1f1f9-1f1f3": "flag_tn",
"1f1f9-1f1f7": "flag_tr",
"1f1f9-1f1f2": "flag_tm",
"1f1f9-1f1e8": "flag_tc",
"1f1fb-1f1ee": "flag_vi",
"1f1f9-1f1fb": "flag_tv",
"1f1fa-1f1ec": "flag_ug",
"1f1fa-1f1e6": "flag_ua",
"1f1e6-1f1ea": "flag_ae",
"1f1ec-1f1e7": "flag_gb",
"1f3f4-e0067-e0062-e0065-e006e-e0067-e007f": "england",
"1f3f4-e0067-e0062-e0073-e0063-e0074-e007f": "scotland",
"1f3f4-e0067-e0062-e0077-e006c-e0073-e007f": "wales",
"1f1fa-1f1f8": "flag_us",
"1f1fa-1f1fe": "flag_uy",
"1f1fa-1f1ff": "flag_uz",
"1f1fb-1f1fa": "flag_vu",
"1f1fb-1f1e6": "flag_va",
"1f1fb-1f1ea": "flag_ve",
"1f1fb-1f1f3": "flag_vn",
"1f1fc-1f1eb": "flag_wf",
"1f1ea-1f1ed": "flag_eh",
"1f1fe-1f1ea": "flag_ye",
"1f1ff-1f1f2": "flag_zm",
"1f1ff-1f1fc": "flag_zw",
"1f1e6-1f1e8": "flag_ac",
"1f1e7-1f1fb": "flag_bv",
"1f1e8-1f1f5": "flag_cp",
"1f1ea-1f1e6": "flag_ea",
"1f1e9-1f1ec": "flag_dg",
"1f1ed-1f1f2": "flag_hm",
"1f1f2-1f1eb": "flag_mf",
"1f1f8-1f1ef": "flag_sj",
"1f1f9-1f1e6": "flag_ta",
"1f1fa-1f1f2": "flag_um",
"1f1fa-1f1f3": "united_nations",
"1f3fb": "tone1",
"1f3fc": "tone2",
"1f3fd": "tone3",
"1f3fe": "tone4",
"1f3ff": "tone5"
);