[class*=e1a-] {
	display: inline-block;
	width: 1em;
	height: 1em;
	margin: -.2ex .05em 0 .1em;
	line-height: normal;
	vertical-align: middle;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: 1em 1em;
}

$size-map: (
	"sm": 1,
	"med": 2,
	"lg": 4
);

@each $name, $size in $size-map {
	.e1a-#{$name} {
		width: 32px * $size;
		height: 32px * $size;
		margin: -.2ex * $size .05em * $size 0 .1em * $size;
		background-size: 1em * $size 1em * $size;
	}
}

@import '_emojione-awesome.map';

@each $code, $name in $emoji-map {

	.e1a-#{$name} {
		background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/#{$code}.png");
	}

	.e1a-rel-#{$name} {
		background-image: url("emojione/assets/4.5/png/128/#{$code}.png");
	}
}