[class*=e1a-] {
  display: inline-block;
  width: 1em;
  height: 1em;
  margin: -0.2ex 0.05em 0 0.1em;
  line-height: normal;
  vertical-align: middle;
  background-repeat: no-repeat;
  background-position: center center;
  background-size: 1em 1em;
}

.e1a-sm {
  width: 32px;
  height: 32px;
  margin: -0.2ex 0.05em 0 0.1em;
  background-size: 1em 1em;
}

.e1a-med {
  width: 64px;
  height: 64px;
  margin: -0.4ex 0.1em 0 0.2em;
  background-size: 2em 2em;
}

.e1a-lg {
  width: 128px;
  height: 128px;
  margin: -0.8ex 0.2em 0 0.4em;
  background-size: 4em 4em;
}

.e1a-interrobang {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2049.png");
}

.e1a-rel-interrobang {
  background-image: url("emojione/assets/4.5/png/128/2049.png");
}

.e1a-tm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2122.png");
}

.e1a-rel-tm {
  background-image: url("emojione/assets/4.5/png/128/2122.png");
}

.e1a-information_source {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2139.png");
}

.e1a-rel-information_source {
  background-image: url("emojione/assets/4.5/png/128/2139.png");
}

.e1a-left_right_arrow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2194.png");
}

.e1a-rel-left_right_arrow {
  background-image: url("emojione/assets/4.5/png/128/2194.png");
}

.e1a-arrow_up_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2195.png");
}

.e1a-rel-arrow_up_down {
  background-image: url("emojione/assets/4.5/png/128/2195.png");
}

.e1a-arrow_upper_left {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2196.png");
}

.e1a-rel-arrow_upper_left {
  background-image: url("emojione/assets/4.5/png/128/2196.png");
}

.e1a-arrow_upper_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2197.png");
}

.e1a-rel-arrow_upper_right {
  background-image: url("emojione/assets/4.5/png/128/2197.png");
}

.e1a-arrow_lower_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2198.png");
}

.e1a-rel-arrow_lower_right {
  background-image: url("emojione/assets/4.5/png/128/2198.png");
}

.e1a-arrow_lower_left {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2199.png");
}

.e1a-rel-arrow_lower_left {
  background-image: url("emojione/assets/4.5/png/128/2199.png");
}

.e1a-keyboard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2328.png");
}

.e1a-rel-keyboard {
  background-image: url("emojione/assets/4.5/png/128/2328.png");
}

.e1a-sunny {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2600.png");
}

.e1a-rel-sunny {
  background-image: url("emojione/assets/4.5/png/128/2600.png");
}

.e1a-cloud {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2601.png");
}

.e1a-rel-cloud {
  background-image: url("emojione/assets/4.5/png/128/2601.png");
}

.e1a-umbrella2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2602.png");
}

.e1a-rel-umbrella2 {
  background-image: url("emojione/assets/4.5/png/128/2602.png");
}

.e1a-snowman2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2603.png");
}

.e1a-rel-snowman2 {
  background-image: url("emojione/assets/4.5/png/128/2603.png");
}

.e1a-comet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2604.png");
}

.e1a-rel-comet {
  background-image: url("emojione/assets/4.5/png/128/2604.png");
}

.e1a-ballot_box_with_check {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2611.png");
}

.e1a-rel-ballot_box_with_check {
  background-image: url("emojione/assets/4.5/png/128/2611.png");
}

.e1a-umbrella {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2614.png");
}

.e1a-rel-umbrella {
  background-image: url("emojione/assets/4.5/png/128/2614.png");
}

.e1a-coffee {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2615.png");
}

.e1a-rel-coffee {
  background-image: url("emojione/assets/4.5/png/128/2615.png");
}

.e1a-shamrock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2618.png");
}

.e1a-rel-shamrock {
  background-image: url("emojione/assets/4.5/png/128/2618.png");
}

.e1a-skull_crossbones {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2620.png");
}

.e1a-rel-skull_crossbones {
  background-image: url("emojione/assets/4.5/png/128/2620.png");
}

.e1a-radioactive {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2622.png");
}

.e1a-rel-radioactive {
  background-image: url("emojione/assets/4.5/png/128/2622.png");
}

.e1a-biohazard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2623.png");
}

.e1a-rel-biohazard {
  background-image: url("emojione/assets/4.5/png/128/2623.png");
}

.e1a-orthodox_cross {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2626.png");
}

.e1a-rel-orthodox_cross {
  background-image: url("emojione/assets/4.5/png/128/2626.png");
}

.e1a-wheel_of_dharma {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2638.png");
}

.e1a-rel-wheel_of_dharma {
  background-image: url("emojione/assets/4.5/png/128/2638.png");
}

.e1a-frowning2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2639.png");
}

.e1a-rel-frowning2 {
  background-image: url("emojione/assets/4.5/png/128/2639.png");
}

.e1a-female_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2640.png");
}

.e1a-rel-female_sign {
  background-image: url("emojione/assets/4.5/png/128/2640.png");
}

.e1a-male_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2642.png");
}

.e1a-rel-male_sign {
  background-image: url("emojione/assets/4.5/png/128/2642.png");
}

.e1a-aries {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2648.png");
}

.e1a-rel-aries {
  background-image: url("emojione/assets/4.5/png/128/2648.png");
}

.e1a-taurus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2649.png");
}

.e1a-rel-taurus {
  background-image: url("emojione/assets/4.5/png/128/2649.png");
}

.e1a-sagittarius {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2650.png");
}

.e1a-rel-sagittarius {
  background-image: url("emojione/assets/4.5/png/128/2650.png");
}

.e1a-capricorn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2651.png");
}

.e1a-rel-capricorn {
  background-image: url("emojione/assets/4.5/png/128/2651.png");
}

.e1a-aquarius {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2652.png");
}

.e1a-rel-aquarius {
  background-image: url("emojione/assets/4.5/png/128/2652.png");
}

.e1a-pisces {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2653.png");
}

.e1a-rel-pisces {
  background-image: url("emojione/assets/4.5/png/128/2653.png");
}

.e1a-spades {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2660.png");
}

.e1a-rel-spades {
  background-image: url("emojione/assets/4.5/png/128/2660.png");
}

.e1a-clubs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2663.png");
}

.e1a-rel-clubs {
  background-image: url("emojione/assets/4.5/png/128/2663.png");
}

.e1a-hearts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2665.png");
}

.e1a-rel-hearts {
  background-image: url("emojione/assets/4.5/png/128/2665.png");
}

.e1a-diamonds {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2666.png");
}

.e1a-rel-diamonds {
  background-image: url("emojione/assets/4.5/png/128/2666.png");
}

.e1a-hotsprings {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2668.png");
}

.e1a-rel-hotsprings {
  background-image: url("emojione/assets/4.5/png/128/2668.png");
}

.e1a-hammer_pick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2692.png");
}

.e1a-rel-hammer_pick {
  background-image: url("emojione/assets/4.5/png/128/2692.png");
}

.e1a-anchor {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2693.png");
}

.e1a-rel-anchor {
  background-image: url("emojione/assets/4.5/png/128/2693.png");
}

.e1a-crossed_swords {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2694.png");
}

.e1a-rel-crossed_swords {
  background-image: url("emojione/assets/4.5/png/128/2694.png");
}

.e1a-medical_symbol {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2695.png");
}

.e1a-rel-medical_symbol {
  background-image: url("emojione/assets/4.5/png/128/2695.png");
}

.e1a-scales {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2696.png");
}

.e1a-rel-scales {
  background-image: url("emojione/assets/4.5/png/128/2696.png");
}

.e1a-alembic {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2697.png");
}

.e1a-rel-alembic {
  background-image: url("emojione/assets/4.5/png/128/2697.png");
}

.e1a-gear {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2699.png");
}

.e1a-rel-gear {
  background-image: url("emojione/assets/4.5/png/128/2699.png");
}

.e1a-scissors {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2702.png");
}

.e1a-rel-scissors {
  background-image: url("emojione/assets/4.5/png/128/2702.png");
}

.e1a-white_check_mark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2705.png");
}

.e1a-rel-white_check_mark {
  background-image: url("emojione/assets/4.5/png/128/2705.png");
}

.e1a-airplane {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2708.png");
}

.e1a-rel-airplane {
  background-image: url("emojione/assets/4.5/png/128/2708.png");
}

.e1a-envelope {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2709.png");
}

.e1a-rel-envelope {
  background-image: url("emojione/assets/4.5/png/128/2709.png");
}

.e1a-black_nib {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2712.png");
}

.e1a-rel-black_nib {
  background-image: url("emojione/assets/4.5/png/128/2712.png");
}

.e1a-heavy_check_mark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2714.png");
}

.e1a-rel-heavy_check_mark {
  background-image: url("emojione/assets/4.5/png/128/2714.png");
}

.e1a-heavy_multiplication_x {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2716.png");
}

.e1a-rel-heavy_multiplication_x {
  background-image: url("emojione/assets/4.5/png/128/2716.png");
}

.e1a-star_of_david {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2721.png");
}

.e1a-rel-star_of_david {
  background-image: url("emojione/assets/4.5/png/128/2721.png");
}

.e1a-sparkles {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2728.png");
}

.e1a-rel-sparkles {
  background-image: url("emojione/assets/4.5/png/128/2728.png");
}

.e1a-eight_spoked_asterisk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2733.png");
}

.e1a-rel-eight_spoked_asterisk {
  background-image: url("emojione/assets/4.5/png/128/2733.png");
}

.e1a-eight_pointed_black_star {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2734.png");
}

.e1a-rel-eight_pointed_black_star {
  background-image: url("emojione/assets/4.5/png/128/2734.png");
}

.e1a-snowflake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2744.png");
}

.e1a-rel-snowflake {
  background-image: url("emojione/assets/4.5/png/128/2744.png");
}

.e1a-sparkle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2747.png");
}

.e1a-rel-sparkle {
  background-image: url("emojione/assets/4.5/png/128/2747.png");
}

.e1a-question {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2753.png");
}

.e1a-rel-question {
  background-image: url("emojione/assets/4.5/png/128/2753.png");
}

.e1a-grey_question {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2754.png");
}

.e1a-rel-grey_question {
  background-image: url("emojione/assets/4.5/png/128/2754.png");
}

.e1a-grey_exclamation {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2755.png");
}

.e1a-rel-grey_exclamation {
  background-image: url("emojione/assets/4.5/png/128/2755.png");
}

.e1a-exclamation {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2757.png");
}

.e1a-rel-exclamation {
  background-image: url("emojione/assets/4.5/png/128/2757.png");
}

.e1a-heart_exclamation {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2763.png");
}

.e1a-rel-heart_exclamation {
  background-image: url("emojione/assets/4.5/png/128/2763.png");
}

.e1a-heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2764.png");
}

.e1a-rel-heart {
  background-image: url("emojione/assets/4.5/png/128/2764.png");
}

.e1a-heavy_plus_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2795.png");
}

.e1a-rel-heavy_plus_sign {
  background-image: url("emojione/assets/4.5/png/128/2795.png");
}

.e1a-heavy_minus_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2796.png");
}

.e1a-rel-heavy_minus_sign {
  background-image: url("emojione/assets/4.5/png/128/2796.png");
}

.e1a-heavy_division_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2797.png");
}

.e1a-rel-heavy_division_sign {
  background-image: url("emojione/assets/4.5/png/128/2797.png");
}

.e1a-arrow_heading_up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2934.png");
}

.e1a-rel-arrow_heading_up {
  background-image: url("emojione/assets/4.5/png/128/2934.png");
}

.e1a-arrow_heading_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2935.png");
}

.e1a-rel-arrow_heading_down {
  background-image: url("emojione/assets/4.5/png/128/2935.png");
}

.e1a-wavy_dash {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/3030.png");
}

.e1a-rel-wavy_dash {
  background-image: url("emojione/assets/4.5/png/128/3030.png");
}

.e1a-congratulations {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/3297.png");
}

.e1a-rel-congratulations {
  background-image: url("emojione/assets/4.5/png/128/3297.png");
}

.e1a-secret {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/3299.png");
}

.e1a-rel-secret {
  background-image: url("emojione/assets/4.5/png/128/3299.png");
}

.e1a-orange_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e1.png");
}

.e1a-rel-orange_heart {
  background-image: url("emojione/assets/4.5/png/128/1f9e1.png");
}

.e1a-yellow_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49b.png");
}

.e1a-rel-yellow_heart {
  background-image: url("emojione/assets/4.5/png/128/1f49b.png");
}

.e1a-green_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49a.png");
}

.e1a-rel-green_heart {
  background-image: url("emojione/assets/4.5/png/128/1f49a.png");
}

.e1a-blue_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f499.png");
}

.e1a-rel-blue_heart {
  background-image: url("emojione/assets/4.5/png/128/1f499.png");
}

.e1a-purple_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49c.png");
}

.e1a-rel-purple_heart {
  background-image: url("emojione/assets/4.5/png/128/1f49c.png");
}

.e1a-black_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5a4.png");
}

.e1a-rel-black_heart {
  background-image: url("emojione/assets/4.5/png/128/1f5a4.png");
}

.e1a-broken_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f494.png");
}

.e1a-rel-broken_heart {
  background-image: url("emojione/assets/4.5/png/128/1f494.png");
}

.e1a-two_hearts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f495.png");
}

.e1a-rel-two_hearts {
  background-image: url("emojione/assets/4.5/png/128/1f495.png");
}

.e1a-revolving_hearts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49e.png");
}

.e1a-rel-revolving_hearts {
  background-image: url("emojione/assets/4.5/png/128/1f49e.png");
}

.e1a-heartbeat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f493.png");
}

.e1a-rel-heartbeat {
  background-image: url("emojione/assets/4.5/png/128/1f493.png");
}

.e1a-heartpulse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f497.png");
}

.e1a-rel-heartpulse {
  background-image: url("emojione/assets/4.5/png/128/1f497.png");
}

.e1a-sparkling_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f496.png");
}

.e1a-rel-sparkling_heart {
  background-image: url("emojione/assets/4.5/png/128/1f496.png");
}

.e1a-cupid {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f498.png");
}

.e1a-rel-cupid {
  background-image: url("emojione/assets/4.5/png/128/1f498.png");
}

.e1a-gift_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49d.png");
}

.e1a-rel-gift_heart {
  background-image: url("emojione/assets/4.5/png/128/1f49d.png");
}

.e1a-heart_decoration {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f49f.png");
}

.e1a-rel-heart_decoration {
  background-image: url("emojione/assets/4.5/png/128/1f49f.png");
}

.e1a-peace {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/262e.png");
}

.e1a-rel-peace {
  background-image: url("emojione/assets/4.5/png/128/262e.png");
}

.e1a-cross {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/271d.png");
}

.e1a-rel-cross {
  background-image: url("emojione/assets/4.5/png/128/271d.png");
}

.e1a-star_and_crescent {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/262a.png");
}

.e1a-rel-star_and_crescent {
  background-image: url("emojione/assets/4.5/png/128/262a.png");
}

.e1a-om_symbol {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f549.png");
}

.e1a-rel-om_symbol {
  background-image: url("emojione/assets/4.5/png/128/1f549.png");
}

.e1a-six_pointed_star {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52f.png");
}

.e1a-rel-six_pointed_star {
  background-image: url("emojione/assets/4.5/png/128/1f52f.png");
}

.e1a-menorah {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f54e.png");
}

.e1a-rel-menorah {
  background-image: url("emojione/assets/4.5/png/128/1f54e.png");
}

.e1a-yin_yang {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/262f.png");
}

.e1a-rel-yin_yang {
  background-image: url("emojione/assets/4.5/png/128/262f.png");
}

.e1a-place_of_worship {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6d0.png");
}

.e1a-rel-place_of_worship {
  background-image: url("emojione/assets/4.5/png/128/1f6d0.png");
}

.e1a-ophiuchus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26ce.png");
}

.e1a-rel-ophiuchus {
  background-image: url("emojione/assets/4.5/png/128/26ce.png");
}

.e1a-gemini {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264a.png");
}

.e1a-rel-gemini {
  background-image: url("emojione/assets/4.5/png/128/264a.png");
}

.e1a-cancer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264b.png");
}

.e1a-rel-cancer {
  background-image: url("emojione/assets/4.5/png/128/264b.png");
}

.e1a-leo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264c.png");
}

.e1a-rel-leo {
  background-image: url("emojione/assets/4.5/png/128/264c.png");
}

.e1a-virgo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264d.png");
}

.e1a-rel-virgo {
  background-image: url("emojione/assets/4.5/png/128/264d.png");
}

.e1a-libra {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264e.png");
}

.e1a-rel-libra {
  background-image: url("emojione/assets/4.5/png/128/264e.png");
}

.e1a-scorpius {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/264f.png");
}

.e1a-rel-scorpius {
  background-image: url("emojione/assets/4.5/png/128/264f.png");
}

.e1a-id {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f194.png");
}

.e1a-rel-id {
  background-image: url("emojione/assets/4.5/png/128/1f194.png");
}

.e1a-atom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/269b.png");
}

.e1a-rel-atom {
  background-image: url("emojione/assets/4.5/png/128/269b.png");
}

.e1a-infinity {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/267e.png");
}

.e1a-rel-infinity {
  background-image: url("emojione/assets/4.5/png/128/267e.png");
}

.e1a-accept {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f251.png");
}

.e1a-rel-accept {
  background-image: url("emojione/assets/4.5/png/128/1f251.png");
}

.e1a-mobile_phone_off {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f4.png");
}

.e1a-rel-mobile_phone_off {
  background-image: url("emojione/assets/4.5/png/128/1f4f4.png");
}

.e1a-vibration_mode {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f3.png");
}

.e1a-rel-vibration_mode {
  background-image: url("emojione/assets/4.5/png/128/1f4f3.png");
}

.e1a-u6709 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f236.png");
}

.e1a-rel-u6709 {
  background-image: url("emojione/assets/4.5/png/128/1f236.png");
}

.e1a-u7121 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f21a.png");
}

.e1a-rel-u7121 {
  background-image: url("emojione/assets/4.5/png/128/1f21a.png");
}

.e1a-u7533 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f238.png");
}

.e1a-rel-u7533 {
  background-image: url("emojione/assets/4.5/png/128/1f238.png");
}

.e1a-u55b6 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f23a.png");
}

.e1a-rel-u55b6 {
  background-image: url("emojione/assets/4.5/png/128/1f23a.png");
}

.e1a-u6708 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f237.png");
}

.e1a-rel-u6708 {
  background-image: url("emojione/assets/4.5/png/128/1f237.png");
}

.e1a-vs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f19a.png");
}

.e1a-rel-vs {
  background-image: url("emojione/assets/4.5/png/128/1f19a.png");
}

.e1a-white_flower {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ae.png");
}

.e1a-rel-white_flower {
  background-image: url("emojione/assets/4.5/png/128/1f4ae.png");
}

.e1a-ideograph_advantage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f250.png");
}

.e1a-rel-ideograph_advantage {
  background-image: url("emojione/assets/4.5/png/128/1f250.png");
}

.e1a-u5408 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f234.png");
}

.e1a-rel-u5408 {
  background-image: url("emojione/assets/4.5/png/128/1f234.png");
}

.e1a-u6e80 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f235.png");
}

.e1a-rel-u6e80 {
  background-image: url("emojione/assets/4.5/png/128/1f235.png");
}

.e1a-u5272 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f239.png");
}

.e1a-rel-u5272 {
  background-image: url("emojione/assets/4.5/png/128/1f239.png");
}

.e1a-u7981 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f232.png");
}

.e1a-rel-u7981 {
  background-image: url("emojione/assets/4.5/png/128/1f232.png");
}

.e1a-a {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f170.png");
}

.e1a-rel-a {
  background-image: url("emojione/assets/4.5/png/128/1f170.png");
}

.e1a-b {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f171.png");
}

.e1a-rel-b {
  background-image: url("emojione/assets/4.5/png/128/1f171.png");
}

.e1a-ab {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f18e.png");
}

.e1a-rel-ab {
  background-image: url("emojione/assets/4.5/png/128/1f18e.png");
}

.e1a-cl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f191.png");
}

.e1a-rel-cl {
  background-image: url("emojione/assets/4.5/png/128/1f191.png");
}

.e1a-o2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f17e.png");
}

.e1a-rel-o2 {
  background-image: url("emojione/assets/4.5/png/128/1f17e.png");
}

.e1a-sos {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f198.png");
}

.e1a-rel-sos {
  background-image: url("emojione/assets/4.5/png/128/1f198.png");
}

.e1a-x {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/274c.png");
}

.e1a-rel-x {
  background-image: url("emojione/assets/4.5/png/128/274c.png");
}

.e1a-o {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b55.png");
}

.e1a-rel-o {
  background-image: url("emojione/assets/4.5/png/128/2b55.png");
}

.e1a-octagonal_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6d1.png");
}

.e1a-rel-octagonal_sign {
  background-image: url("emojione/assets/4.5/png/128/1f6d1.png");
}

.e1a-no_entry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26d4.png");
}

.e1a-rel-no_entry {
  background-image: url("emojione/assets/4.5/png/128/26d4.png");
}

.e1a-name_badge {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4db.png");
}

.e1a-rel-name_badge {
  background-image: url("emojione/assets/4.5/png/128/1f4db.png");
}

.e1a-no_entry_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ab.png");
}

.e1a-rel-no_entry_sign {
  background-image: url("emojione/assets/4.5/png/128/1f6ab.png");
}

.e1a-100 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4af.png");
}

.e1a-rel-100 {
  background-image: url("emojione/assets/4.5/png/128/1f4af.png");
}

.e1a-anger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a2.png");
}

.e1a-rel-anger {
  background-image: url("emojione/assets/4.5/png/128/1f4a2.png");
}

.e1a-no_pedestrians {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b7.png");
}

.e1a-rel-no_pedestrians {
  background-image: url("emojione/assets/4.5/png/128/1f6b7.png");
}

.e1a-do_not_litter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6af.png");
}

.e1a-rel-do_not_litter {
  background-image: url("emojione/assets/4.5/png/128/1f6af.png");
}

.e1a-no_bicycles {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b3.png");
}

.e1a-rel-no_bicycles {
  background-image: url("emojione/assets/4.5/png/128/1f6b3.png");
}

.e1a-non-potable_water {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b1.png");
}

.e1a-rel-non-potable_water {
  background-image: url("emojione/assets/4.5/png/128/1f6b1.png");
}

.e1a-underage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51e.png");
}

.e1a-rel-underage {
  background-image: url("emojione/assets/4.5/png/128/1f51e.png");
}

.e1a-no_mobile_phones {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f5.png");
}

.e1a-rel-no_mobile_phones {
  background-image: url("emojione/assets/4.5/png/128/1f4f5.png");
}

.e1a-no_smoking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ad.png");
}

.e1a-rel-no_smoking {
  background-image: url("emojione/assets/4.5/png/128/1f6ad.png");
}

.e1a-bangbang {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/203c.png");
}

.e1a-rel-bangbang {
  background-image: url("emojione/assets/4.5/png/128/203c.png");
}

.e1a-low_brightness {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f505.png");
}

.e1a-rel-low_brightness {
  background-image: url("emojione/assets/4.5/png/128/1f505.png");
}

.e1a-high_brightness {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f506.png");
}

.e1a-rel-high_brightness {
  background-image: url("emojione/assets/4.5/png/128/1f506.png");
}

.e1a-part_alternation_mark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/303d.png");
}

.e1a-rel-part_alternation_mark {
  background-image: url("emojione/assets/4.5/png/128/303d.png");
}

.e1a-warning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26a0.png");
}

.e1a-rel-warning {
  background-image: url("emojione/assets/4.5/png/128/26a0.png");
}

.e1a-children_crossing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b8.png");
}

.e1a-rel-children_crossing {
  background-image: url("emojione/assets/4.5/png/128/1f6b8.png");
}

.e1a-trident {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f531.png");
}

.e1a-rel-trident {
  background-image: url("emojione/assets/4.5/png/128/1f531.png");
}

.e1a-fleur-de-lis {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/269c.png");
}

.e1a-rel-fleur-de-lis {
  background-image: url("emojione/assets/4.5/png/128/269c.png");
}

.e1a-beginner {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f530.png");
}

.e1a-rel-beginner {
  background-image: url("emojione/assets/4.5/png/128/1f530.png");
}

.e1a-recycle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/267b.png");
}

.e1a-rel-recycle {
  background-image: url("emojione/assets/4.5/png/128/267b.png");
}

.e1a-u6307 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f22f.png");
}

.e1a-rel-u6307 {
  background-image: url("emojione/assets/4.5/png/128/1f22f.png");
}

.e1a-chart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b9.png");
}

.e1a-rel-chart {
  background-image: url("emojione/assets/4.5/png/128/1f4b9.png");
}

.e1a-negative_squared_cross_mark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/274e.png");
}

.e1a-rel-negative_squared_cross_mark {
  background-image: url("emojione/assets/4.5/png/128/274e.png");
}

.e1a-globe_with_meridians {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f310.png");
}

.e1a-rel-globe_with_meridians {
  background-image: url("emojione/assets/4.5/png/128/1f310.png");
}

.e1a-diamond_shape_with_a_dot_inside {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a0.png");
}

.e1a-rel-diamond_shape_with_a_dot_inside {
  background-image: url("emojione/assets/4.5/png/128/1f4a0.png");
}

.e1a-m {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/24c2.png");
}

.e1a-rel-m {
  background-image: url("emojione/assets/4.5/png/128/24c2.png");
}

.e1a-cyclone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f300.png");
}

.e1a-rel-cyclone {
  background-image: url("emojione/assets/4.5/png/128/1f300.png");
}

.e1a-zzz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a4.png");
}

.e1a-rel-zzz {
  background-image: url("emojione/assets/4.5/png/128/1f4a4.png");
}

.e1a-atm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e7.png");
}

.e1a-rel-atm {
  background-image: url("emojione/assets/4.5/png/128/1f3e7.png");
}

.e1a-wc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6be.png");
}

.e1a-rel-wc {
  background-image: url("emojione/assets/4.5/png/128/1f6be.png");
}

.e1a-wheelchair {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/267f.png");
}

.e1a-rel-wheelchair {
  background-image: url("emojione/assets/4.5/png/128/267f.png");
}

.e1a-parking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f17f.png");
}

.e1a-rel-parking {
  background-image: url("emojione/assets/4.5/png/128/1f17f.png");
}

.e1a-u7a7a {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f233.png");
}

.e1a-rel-u7a7a {
  background-image: url("emojione/assets/4.5/png/128/1f233.png");
}

.e1a-sa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f202.png");
}

.e1a-rel-sa {
  background-image: url("emojione/assets/4.5/png/128/1f202.png");
}

.e1a-passport_control {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c2.png");
}

.e1a-rel-passport_control {
  background-image: url("emojione/assets/4.5/png/128/1f6c2.png");
}

.e1a-customs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c3.png");
}

.e1a-rel-customs {
  background-image: url("emojione/assets/4.5/png/128/1f6c3.png");
}

.e1a-baggage_claim {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c4.png");
}

.e1a-rel-baggage_claim {
  background-image: url("emojione/assets/4.5/png/128/1f6c4.png");
}

.e1a-left_luggage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c5.png");
}

.e1a-rel-left_luggage {
  background-image: url("emojione/assets/4.5/png/128/1f6c5.png");
}

.e1a-mens {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b9.png");
}

.e1a-rel-mens {
  background-image: url("emojione/assets/4.5/png/128/1f6b9.png");
}

.e1a-womens {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ba.png");
}

.e1a-rel-womens {
  background-image: url("emojione/assets/4.5/png/128/1f6ba.png");
}

.e1a-baby_symbol {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6bc.png");
}

.e1a-rel-baby_symbol {
  background-image: url("emojione/assets/4.5/png/128/1f6bc.png");
}

.e1a-restroom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6bb.png");
}

.e1a-rel-restroom {
  background-image: url("emojione/assets/4.5/png/128/1f6bb.png");
}

.e1a-put_litter_in_its_place {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ae.png");
}

.e1a-rel-put_litter_in_its_place {
  background-image: url("emojione/assets/4.5/png/128/1f6ae.png");
}

.e1a-cinema {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a6.png");
}

.e1a-rel-cinema {
  background-image: url("emojione/assets/4.5/png/128/1f3a6.png");
}

.e1a-signal_strength {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f6.png");
}

.e1a-rel-signal_strength {
  background-image: url("emojione/assets/4.5/png/128/1f4f6.png");
}

.e1a-koko {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f201.png");
}

.e1a-rel-koko {
  background-image: url("emojione/assets/4.5/png/128/1f201.png");
}

.e1a-symbols {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f523.png");
}

.e1a-rel-symbols {
  background-image: url("emojione/assets/4.5/png/128/1f523.png");
}

.e1a-abc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f524.png");
}

.e1a-rel-abc {
  background-image: url("emojione/assets/4.5/png/128/1f524.png");
}

.e1a-abcd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f521.png");
}

.e1a-rel-abcd {
  background-image: url("emojione/assets/4.5/png/128/1f521.png");
}

.e1a-capital_abcd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f520.png");
}

.e1a-rel-capital_abcd {
  background-image: url("emojione/assets/4.5/png/128/1f520.png");
}

.e1a-ng {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f196.png");
}

.e1a-rel-ng {
  background-image: url("emojione/assets/4.5/png/128/1f196.png");
}

.e1a-ok {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f197.png");
}

.e1a-rel-ok {
  background-image: url("emojione/assets/4.5/png/128/1f197.png");
}

.e1a-up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f199.png");
}

.e1a-rel-up {
  background-image: url("emojione/assets/4.5/png/128/1f199.png");
}

.e1a-cool {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f192.png");
}

.e1a-rel-cool {
  background-image: url("emojione/assets/4.5/png/128/1f192.png");
}

.e1a-new {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f195.png");
}

.e1a-rel-new {
  background-image: url("emojione/assets/4.5/png/128/1f195.png");
}

.e1a-free {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f193.png");
}

.e1a-rel-free {
  background-image: url("emojione/assets/4.5/png/128/1f193.png");
}

.e1a-zero {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0030-20e3.png");
}

.e1a-rel-zero {
  background-image: url("emojione/assets/4.5/png/128/0030-20e3.png");
}

.e1a-one {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0031-20e3.png");
}

.e1a-rel-one {
  background-image: url("emojione/assets/4.5/png/128/0031-20e3.png");
}

.e1a-two {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0032-20e3.png");
}

.e1a-rel-two {
  background-image: url("emojione/assets/4.5/png/128/0032-20e3.png");
}

.e1a-three {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0033-20e3.png");
}

.e1a-rel-three {
  background-image: url("emojione/assets/4.5/png/128/0033-20e3.png");
}

.e1a-four {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0034-20e3.png");
}

.e1a-rel-four {
  background-image: url("emojione/assets/4.5/png/128/0034-20e3.png");
}

.e1a-five {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0035-20e3.png");
}

.e1a-rel-five {
  background-image: url("emojione/assets/4.5/png/128/0035-20e3.png");
}

.e1a-six {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0036-20e3.png");
}

.e1a-rel-six {
  background-image: url("emojione/assets/4.5/png/128/0036-20e3.png");
}

.e1a-seven {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0037-20e3.png");
}

.e1a-rel-seven {
  background-image: url("emojione/assets/4.5/png/128/0037-20e3.png");
}

.e1a-eight {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0038-20e3.png");
}

.e1a-rel-eight {
  background-image: url("emojione/assets/4.5/png/128/0038-20e3.png");
}

.e1a-nine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0039-20e3.png");
}

.e1a-rel-nine {
  background-image: url("emojione/assets/4.5/png/128/0039-20e3.png");
}

.e1a-keycap_ten {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51f.png");
}

.e1a-rel-keycap_ten {
  background-image: url("emojione/assets/4.5/png/128/1f51f.png");
}

.e1a-1234 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f522.png");
}

.e1a-rel-1234 {
  background-image: url("emojione/assets/4.5/png/128/1f522.png");
}

.e1a-hash {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0023-20e3.png");
}

.e1a-rel-hash {
  background-image: url("emojione/assets/4.5/png/128/0023-20e3.png");
}

.e1a-asterisk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/002a-20e3.png");
}

.e1a-rel-asterisk {
  background-image: url("emojione/assets/4.5/png/128/002a-20e3.png");
}

.e1a-eject {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23cf.png");
}

.e1a-rel-eject {
  background-image: url("emojione/assets/4.5/png/128/23cf.png");
}

.e1a-arrow_forward {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25b6.png");
}

.e1a-rel-arrow_forward {
  background-image: url("emojione/assets/4.5/png/128/25b6.png");
}

.e1a-pause_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f8.png");
}

.e1a-rel-pause_button {
  background-image: url("emojione/assets/4.5/png/128/23f8.png");
}

.e1a-play_pause {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23ef.png");
}

.e1a-rel-play_pause {
  background-image: url("emojione/assets/4.5/png/128/23ef.png");
}

.e1a-stop_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f9.png");
}

.e1a-rel-stop_button {
  background-image: url("emojione/assets/4.5/png/128/23f9.png");
}

.e1a-record_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23fa.png");
}

.e1a-rel-record_button {
  background-image: url("emojione/assets/4.5/png/128/23fa.png");
}

.e1a-track_next {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23ed.png");
}

.e1a-rel-track_next {
  background-image: url("emojione/assets/4.5/png/128/23ed.png");
}

.e1a-track_previous {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23ee.png");
}

.e1a-rel-track_previous {
  background-image: url("emojione/assets/4.5/png/128/23ee.png");
}

.e1a-fast_forward {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23e9.png");
}

.e1a-rel-fast_forward {
  background-image: url("emojione/assets/4.5/png/128/23e9.png");
}

.e1a-rewind {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23ea.png");
}

.e1a-rel-rewind {
  background-image: url("emojione/assets/4.5/png/128/23ea.png");
}

.e1a-arrow_double_up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23eb.png");
}

.e1a-rel-arrow_double_up {
  background-image: url("emojione/assets/4.5/png/128/23eb.png");
}

.e1a-arrow_double_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23ec.png");
}

.e1a-rel-arrow_double_down {
  background-image: url("emojione/assets/4.5/png/128/23ec.png");
}

.e1a-arrow_backward {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25c0.png");
}

.e1a-rel-arrow_backward {
  background-image: url("emojione/assets/4.5/png/128/25c0.png");
}

.e1a-arrow_up_small {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f53c.png");
}

.e1a-rel-arrow_up_small {
  background-image: url("emojione/assets/4.5/png/128/1f53c.png");
}

.e1a-arrow_down_small {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f53d.png");
}

.e1a-rel-arrow_down_small {
  background-image: url("emojione/assets/4.5/png/128/1f53d.png");
}

.e1a-arrow_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/27a1.png");
}

.e1a-rel-arrow_right {
  background-image: url("emojione/assets/4.5/png/128/27a1.png");
}

.e1a-arrow_left {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b05.png");
}

.e1a-rel-arrow_left {
  background-image: url("emojione/assets/4.5/png/128/2b05.png");
}

.e1a-arrow_up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b06.png");
}

.e1a-rel-arrow_up {
  background-image: url("emojione/assets/4.5/png/128/2b06.png");
}

.e1a-arrow_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b07.png");
}

.e1a-rel-arrow_down {
  background-image: url("emojione/assets/4.5/png/128/2b07.png");
}

.e1a-arrow_right_hook {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/21aa.png");
}

.e1a-rel-arrow_right_hook {
  background-image: url("emojione/assets/4.5/png/128/21aa.png");
}

.e1a-leftwards_arrow_with_hook {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/21a9.png");
}

.e1a-rel-leftwards_arrow_with_hook {
  background-image: url("emojione/assets/4.5/png/128/21a9.png");
}

.e1a-twisted_rightwards_arrows {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f500.png");
}

.e1a-rel-twisted_rightwards_arrows {
  background-image: url("emojione/assets/4.5/png/128/1f500.png");
}

.e1a-repeat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f501.png");
}

.e1a-rel-repeat {
  background-image: url("emojione/assets/4.5/png/128/1f501.png");
}

.e1a-repeat_one {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f502.png");
}

.e1a-rel-repeat_one {
  background-image: url("emojione/assets/4.5/png/128/1f502.png");
}

.e1a-arrows_counterclockwise {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f504.png");
}

.e1a-rel-arrows_counterclockwise {
  background-image: url("emojione/assets/4.5/png/128/1f504.png");
}

.e1a-arrows_clockwise {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f503.png");
}

.e1a-rel-arrows_clockwise {
  background-image: url("emojione/assets/4.5/png/128/1f503.png");
}

.e1a-musical_note {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b5.png");
}

.e1a-rel-musical_note {
  background-image: url("emojione/assets/4.5/png/128/1f3b5.png");
}

.e1a-notes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b6.png");
}

.e1a-rel-notes {
  background-image: url("emojione/assets/4.5/png/128/1f3b6.png");
}

.e1a-heavy_dollar_sign {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b2.png");
}

.e1a-rel-heavy_dollar_sign {
  background-image: url("emojione/assets/4.5/png/128/1f4b2.png");
}

.e1a-currency_exchange {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b1.png");
}

.e1a-rel-currency_exchange {
  background-image: url("emojione/assets/4.5/png/128/1f4b1.png");
}

.e1a-copyright {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/00a9.png");
}

.e1a-rel-copyright {
  background-image: url("emojione/assets/4.5/png/128/00a9.png");
}

.e1a-registered {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/00ae.png");
}

.e1a-rel-registered {
  background-image: url("emojione/assets/4.5/png/128/00ae.png");
}

.e1a-curly_loop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/27b0.png");
}

.e1a-rel-curly_loop {
  background-image: url("emojione/assets/4.5/png/128/27b0.png");
}

.e1a-loop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/27bf.png");
}

.e1a-rel-loop {
  background-image: url("emojione/assets/4.5/png/128/27bf.png");
}

.e1a-end {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51a.png");
}

.e1a-rel-end {
  background-image: url("emojione/assets/4.5/png/128/1f51a.png");
}

.e1a-back {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f519.png");
}

.e1a-rel-back {
  background-image: url("emojione/assets/4.5/png/128/1f519.png");
}

.e1a-on {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51b.png");
}

.e1a-rel-on {
  background-image: url("emojione/assets/4.5/png/128/1f51b.png");
}

.e1a-top {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51d.png");
}

.e1a-rel-top {
  background-image: url("emojione/assets/4.5/png/128/1f51d.png");
}

.e1a-soon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f51c.png");
}

.e1a-rel-soon {
  background-image: url("emojione/assets/4.5/png/128/1f51c.png");
}

.e1a-radio_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f518.png");
}

.e1a-rel-radio_button {
  background-image: url("emojione/assets/4.5/png/128/1f518.png");
}

.e1a-white_circle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26aa.png");
}

.e1a-rel-white_circle {
  background-image: url("emojione/assets/4.5/png/128/26aa.png");
}

.e1a-black_circle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26ab.png");
}

.e1a-rel-black_circle {
  background-image: url("emojione/assets/4.5/png/128/26ab.png");
}

.e1a-red_circle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f534.png");
}

.e1a-rel-red_circle {
  background-image: url("emojione/assets/4.5/png/128/1f534.png");
}

.e1a-blue_circle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f535.png");
}

.e1a-rel-blue_circle {
  background-image: url("emojione/assets/4.5/png/128/1f535.png");
}

.e1a-small_red_triangle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f53a.png");
}

.e1a-rel-small_red_triangle {
  background-image: url("emojione/assets/4.5/png/128/1f53a.png");
}

.e1a-small_red_triangle_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f53b.png");
}

.e1a-rel-small_red_triangle_down {
  background-image: url("emojione/assets/4.5/png/128/1f53b.png");
}

.e1a-small_orange_diamond {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f538.png");
}

.e1a-rel-small_orange_diamond {
  background-image: url("emojione/assets/4.5/png/128/1f538.png");
}

.e1a-small_blue_diamond {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f539.png");
}

.e1a-rel-small_blue_diamond {
  background-image: url("emojione/assets/4.5/png/128/1f539.png");
}

.e1a-large_orange_diamond {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f536.png");
}

.e1a-rel-large_orange_diamond {
  background-image: url("emojione/assets/4.5/png/128/1f536.png");
}

.e1a-large_blue_diamond {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f537.png");
}

.e1a-rel-large_blue_diamond {
  background-image: url("emojione/assets/4.5/png/128/1f537.png");
}

.e1a-white_square_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f533.png");
}

.e1a-rel-white_square_button {
  background-image: url("emojione/assets/4.5/png/128/1f533.png");
}

.e1a-black_square_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f532.png");
}

.e1a-rel-black_square_button {
  background-image: url("emojione/assets/4.5/png/128/1f532.png");
}

.e1a-black_small_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25aa.png");
}

.e1a-rel-black_small_square {
  background-image: url("emojione/assets/4.5/png/128/25aa.png");
}

.e1a-white_small_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25ab.png");
}

.e1a-rel-white_small_square {
  background-image: url("emojione/assets/4.5/png/128/25ab.png");
}

.e1a-black_medium_small_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25fe.png");
}

.e1a-rel-black_medium_small_square {
  background-image: url("emojione/assets/4.5/png/128/25fe.png");
}

.e1a-white_medium_small_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25fd.png");
}

.e1a-rel-white_medium_small_square {
  background-image: url("emojione/assets/4.5/png/128/25fd.png");
}

.e1a-black_medium_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25fc.png");
}

.e1a-rel-black_medium_square {
  background-image: url("emojione/assets/4.5/png/128/25fc.png");
}

.e1a-white_medium_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/25fb.png");
}

.e1a-rel-white_medium_square {
  background-image: url("emojione/assets/4.5/png/128/25fb.png");
}

.e1a-black_large_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b1b.png");
}

.e1a-rel-black_large_square {
  background-image: url("emojione/assets/4.5/png/128/2b1b.png");
}

.e1a-white_large_square {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b1c.png");
}

.e1a-rel-white_large_square {
  background-image: url("emojione/assets/4.5/png/128/2b1c.png");
}

.e1a-speaker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f508.png");
}

.e1a-rel-speaker {
  background-image: url("emojione/assets/4.5/png/128/1f508.png");
}

.e1a-mute {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f507.png");
}

.e1a-rel-mute {
  background-image: url("emojione/assets/4.5/png/128/1f507.png");
}

.e1a-sound {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f509.png");
}

.e1a-rel-sound {
  background-image: url("emojione/assets/4.5/png/128/1f509.png");
}

.e1a-loud_sound {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50a.png");
}

.e1a-rel-loud_sound {
  background-image: url("emojione/assets/4.5/png/128/1f50a.png");
}

.e1a-bell {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f514.png");
}

.e1a-rel-bell {
  background-image: url("emojione/assets/4.5/png/128/1f514.png");
}

.e1a-no_bell {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f515.png");
}

.e1a-rel-no_bell {
  background-image: url("emojione/assets/4.5/png/128/1f515.png");
}

.e1a-mega {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e3.png");
}

.e1a-rel-mega {
  background-image: url("emojione/assets/4.5/png/128/1f4e3.png");
}

.e1a-loudspeaker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e2.png");
}

.e1a-rel-loudspeaker {
  background-image: url("emojione/assets/4.5/png/128/1f4e2.png");
}

.e1a-speech_left {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5e8.png");
}

.e1a-rel-speech_left {
  background-image: url("emojione/assets/4.5/png/128/1f5e8.png");
}

.e1a-eye_in_speech_bubble {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f441-1f5e8.png");
}

.e1a-rel-eye_in_speech_bubble {
  background-image: url("emojione/assets/4.5/png/128/1f441-1f5e8.png");
}

.e1a-speech_balloon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ac.png");
}

.e1a-rel-speech_balloon {
  background-image: url("emojione/assets/4.5/png/128/1f4ac.png");
}

.e1a-thought_balloon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ad.png");
}

.e1a-rel-thought_balloon {
  background-image: url("emojione/assets/4.5/png/128/1f4ad.png");
}

.e1a-anger_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5ef.png");
}

.e1a-rel-anger_right {
  background-image: url("emojione/assets/4.5/png/128/1f5ef.png");
}

.e1a-black_joker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f0cf.png");
}

.e1a-rel-black_joker {
  background-image: url("emojione/assets/4.5/png/128/1f0cf.png");
}

.e1a-flower_playing_cards {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b4.png");
}

.e1a-rel-flower_playing_cards {
  background-image: url("emojione/assets/4.5/png/128/1f3b4.png");
}

.e1a-mahjong {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f004.png");
}

.e1a-rel-mahjong {
  background-image: url("emojione/assets/4.5/png/128/1f004.png");
}

.e1a-clock1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f550.png");
}

.e1a-rel-clock1 {
  background-image: url("emojione/assets/4.5/png/128/1f550.png");
}

.e1a-clock2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f551.png");
}

.e1a-rel-clock2 {
  background-image: url("emojione/assets/4.5/png/128/1f551.png");
}

.e1a-clock3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f552.png");
}

.e1a-rel-clock3 {
  background-image: url("emojione/assets/4.5/png/128/1f552.png");
}

.e1a-clock4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f553.png");
}

.e1a-rel-clock4 {
  background-image: url("emojione/assets/4.5/png/128/1f553.png");
}

.e1a-clock5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f554.png");
}

.e1a-rel-clock5 {
  background-image: url("emojione/assets/4.5/png/128/1f554.png");
}

.e1a-clock6 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f555.png");
}

.e1a-rel-clock6 {
  background-image: url("emojione/assets/4.5/png/128/1f555.png");
}

.e1a-clock7 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f556.png");
}

.e1a-rel-clock7 {
  background-image: url("emojione/assets/4.5/png/128/1f556.png");
}

.e1a-clock8 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f557.png");
}

.e1a-rel-clock8 {
  background-image: url("emojione/assets/4.5/png/128/1f557.png");
}

.e1a-clock9 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f558.png");
}

.e1a-rel-clock9 {
  background-image: url("emojione/assets/4.5/png/128/1f558.png");
}

.e1a-clock10 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f559.png");
}

.e1a-rel-clock10 {
  background-image: url("emojione/assets/4.5/png/128/1f559.png");
}

.e1a-clock11 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55a.png");
}

.e1a-rel-clock11 {
  background-image: url("emojione/assets/4.5/png/128/1f55a.png");
}

.e1a-clock12 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55b.png");
}

.e1a-rel-clock12 {
  background-image: url("emojione/assets/4.5/png/128/1f55b.png");
}

.e1a-clock130 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55c.png");
}

.e1a-rel-clock130 {
  background-image: url("emojione/assets/4.5/png/128/1f55c.png");
}

.e1a-clock230 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55d.png");
}

.e1a-rel-clock230 {
  background-image: url("emojione/assets/4.5/png/128/1f55d.png");
}

.e1a-clock330 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55e.png");
}

.e1a-rel-clock330 {
  background-image: url("emojione/assets/4.5/png/128/1f55e.png");
}

.e1a-clock430 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f55f.png");
}

.e1a-rel-clock430 {
  background-image: url("emojione/assets/4.5/png/128/1f55f.png");
}

.e1a-clock530 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f560.png");
}

.e1a-rel-clock530 {
  background-image: url("emojione/assets/4.5/png/128/1f560.png");
}

.e1a-clock630 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f561.png");
}

.e1a-rel-clock630 {
  background-image: url("emojione/assets/4.5/png/128/1f561.png");
}

.e1a-clock730 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f562.png");
}

.e1a-rel-clock730 {
  background-image: url("emojione/assets/4.5/png/128/1f562.png");
}

.e1a-clock830 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f563.png");
}

.e1a-rel-clock830 {
  background-image: url("emojione/assets/4.5/png/128/1f563.png");
}

.e1a-clock930 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f564.png");
}

.e1a-rel-clock930 {
  background-image: url("emojione/assets/4.5/png/128/1f564.png");
}

.e1a-clock1030 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f565.png");
}

.e1a-rel-clock1030 {
  background-image: url("emojione/assets/4.5/png/128/1f565.png");
}

.e1a-clock1130 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f566.png");
}

.e1a-rel-clock1130 {
  background-image: url("emojione/assets/4.5/png/128/1f566.png");
}

.e1a-clock1230 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f567.png");
}

.e1a-rel-clock1230 {
  background-image: url("emojione/assets/4.5/png/128/1f567.png");
}

.e1a-digit_zero {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0030.png");
}

.e1a-rel-digit_zero {
  background-image: url("emojione/assets/4.5/png/128/0030.png");
}

.e1a-digit_one {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0031.png");
}

.e1a-rel-digit_one {
  background-image: url("emojione/assets/4.5/png/128/0031.png");
}

.e1a-digit_two {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0032.png");
}

.e1a-rel-digit_two {
  background-image: url("emojione/assets/4.5/png/128/0032.png");
}

.e1a-digit_three {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0033.png");
}

.e1a-rel-digit_three {
  background-image: url("emojione/assets/4.5/png/128/0033.png");
}

.e1a-digit_four {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0034.png");
}

.e1a-rel-digit_four {
  background-image: url("emojione/assets/4.5/png/128/0034.png");
}

.e1a-digit_five {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0035.png");
}

.e1a-rel-digit_five {
  background-image: url("emojione/assets/4.5/png/128/0035.png");
}

.e1a-digit_six {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0036.png");
}

.e1a-rel-digit_six {
  background-image: url("emojione/assets/4.5/png/128/0036.png");
}

.e1a-digit_seven {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0037.png");
}

.e1a-rel-digit_seven {
  background-image: url("emojione/assets/4.5/png/128/0037.png");
}

.e1a-digit_eight {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0038.png");
}

.e1a-rel-digit_eight {
  background-image: url("emojione/assets/4.5/png/128/0038.png");
}

.e1a-digit_nine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0039.png");
}

.e1a-rel-digit_nine {
  background-image: url("emojione/assets/4.5/png/128/0039.png");
}

.e1a-pound_symbol {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/0023.png");
}

.e1a-rel-pound_symbol {
  background-image: url("emojione/assets/4.5/png/128/0023.png");
}

.e1a-asterisk_symbol {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/002a.png");
}

.e1a-rel-asterisk_symbol {
  background-image: url("emojione/assets/4.5/png/128/002a.png");
}

.e1a-soccer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26bd.png");
}

.e1a-rel-soccer {
  background-image: url("emojione/assets/4.5/png/128/26bd.png");
}

.e1a-basketball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c0.png");
}

.e1a-rel-basketball {
  background-image: url("emojione/assets/4.5/png/128/1f3c0.png");
}

.e1a-football {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c8.png");
}

.e1a-rel-football {
  background-image: url("emojione/assets/4.5/png/128/1f3c8.png");
}

.e1a-baseball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26be.png");
}

.e1a-rel-baseball {
  background-image: url("emojione/assets/4.5/png/128/26be.png");
}

.e1a-softball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94e.png");
}

.e1a-rel-softball {
  background-image: url("emojione/assets/4.5/png/128/1f94e.png");
}

.e1a-tennis {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3be.png");
}

.e1a-rel-tennis {
  background-image: url("emojione/assets/4.5/png/128/1f3be.png");
}

.e1a-volleyball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d0.png");
}

.e1a-rel-volleyball {
  background-image: url("emojione/assets/4.5/png/128/1f3d0.png");
}

.e1a-rugby_football {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c9.png");
}

.e1a-rel-rugby_football {
  background-image: url("emojione/assets/4.5/png/128/1f3c9.png");
}

.e1a-8ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b1.png");
}

.e1a-rel-8ball {
  background-image: url("emojione/assets/4.5/png/128/1f3b1.png");
}

.e1a-ping_pong {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d3.png");
}

.e1a-rel-ping_pong {
  background-image: url("emojione/assets/4.5/png/128/1f3d3.png");
}

.e1a-badminton {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f8.png");
}

.e1a-rel-badminton {
  background-image: url("emojione/assets/4.5/png/128/1f3f8.png");
}

.e1a-goal {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f945.png");
}

.e1a-rel-goal {
  background-image: url("emojione/assets/4.5/png/128/1f945.png");
}

.e1a-hockey {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d2.png");
}

.e1a-rel-hockey {
  background-image: url("emojione/assets/4.5/png/128/1f3d2.png");
}

.e1a-field_hockey {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d1.png");
}

.e1a-rel-field_hockey {
  background-image: url("emojione/assets/4.5/png/128/1f3d1.png");
}

.e1a-cricket_game {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cf.png");
}

.e1a-rel-cricket_game {
  background-image: url("emojione/assets/4.5/png/128/1f3cf.png");
}

.e1a-lacrosse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94d.png");
}

.e1a-rel-lacrosse {
  background-image: url("emojione/assets/4.5/png/128/1f94d.png");
}

.e1a-golf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f3.png");
}

.e1a-rel-golf {
  background-image: url("emojione/assets/4.5/png/128/26f3.png");
}

.e1a-flying_disc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94f.png");
}

.e1a-rel-flying_disc {
  background-image: url("emojione/assets/4.5/png/128/1f94f.png");
}

.e1a-bow_and_arrow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f9.png");
}

.e1a-rel-bow_and_arrow {
  background-image: url("emojione/assets/4.5/png/128/1f3f9.png");
}

.e1a-fishing_pole_and_fish {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a3.png");
}

.e1a-rel-fishing_pole_and_fish {
  background-image: url("emojione/assets/4.5/png/128/1f3a3.png");
}

.e1a-boxing_glove {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94a.png");
}

.e1a-rel-boxing_glove {
  background-image: url("emojione/assets/4.5/png/128/1f94a.png");
}

.e1a-martial_arts_uniform {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94b.png");
}

.e1a-rel-martial_arts_uniform {
  background-image: url("emojione/assets/4.5/png/128/1f94b.png");
}

.e1a-running_shirt_with_sash {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3bd.png");
}

.e1a-rel-running_shirt_with_sash {
  background-image: url("emojione/assets/4.5/png/128/1f3bd.png");
}

.e1a-skateboard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f9.png");
}

.e1a-rel-skateboard {
  background-image: url("emojione/assets/4.5/png/128/1f6f9.png");
}

.e1a-ice_skate {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f8.png");
}

.e1a-rel-ice_skate {
  background-image: url("emojione/assets/4.5/png/128/26f8.png");
}

.e1a-curling_stone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f94c.png");
}

.e1a-rel-curling_stone {
  background-image: url("emojione/assets/4.5/png/128/1f94c.png");
}

.e1a-sled {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f7.png");
}

.e1a-rel-sled {
  background-image: url("emojione/assets/4.5/png/128/1f6f7.png");
}

.e1a-ski {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3bf.png");
}

.e1a-rel-ski {
  background-image: url("emojione/assets/4.5/png/128/1f3bf.png");
}

.e1a-skier {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f7.png");
}

.e1a-rel-skier {
  background-image: url("emojione/assets/4.5/png/128/26f7.png");
}

.e1a-snowboarder {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2.png");
}

.e1a-rel-snowboarder {
  background-image: url("emojione/assets/4.5/png/128/1f3c2.png");
}

.e1a-snowboarder_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2-1f3fb.png");
}

.e1a-rel-snowboarder_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c2-1f3fb.png");
}

.e1a-snowboarder_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2-1f3fc.png");
}

.e1a-rel-snowboarder_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c2-1f3fc.png");
}

.e1a-snowboarder_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2-1f3fd.png");
}

.e1a-rel-snowboarder_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c2-1f3fd.png");
}

.e1a-snowboarder_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2-1f3fe.png");
}

.e1a-rel-snowboarder_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c2-1f3fe.png");
}

.e1a-snowboarder_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c2-1f3ff.png");
}

.e1a-rel-snowboarder_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c2-1f3ff.png");
}

.e1a-person_lifting_weights {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb.png");
}

.e1a-rel-person_lifting_weights {
  background-image: url("emojione/assets/4.5/png/128/1f3cb.png");
}

.e1a-person_lifting_weights_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fb.png");
}

.e1a-rel-person_lifting_weights_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fb.png");
}

.e1a-person_lifting_weights_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fc.png");
}

.e1a-rel-person_lifting_weights_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fc.png");
}

.e1a-person_lifting_weights_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fd.png");
}

.e1a-rel-person_lifting_weights_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fd.png");
}

.e1a-person_lifting_weights_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fe.png");
}

.e1a-rel-person_lifting_weights_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fe.png");
}

.e1a-person_lifting_weights_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3ff.png");
}

.e1a-rel-person_lifting_weights_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3ff.png");
}

.e1a-woman_lifting_weights {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-2640.png");
}

.e1a-rel-woman_lifting_weights {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-2640.png");
}

.e1a-woman_lifting_weights_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fb-2640.png");
}

.e1a-rel-woman_lifting_weights_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fb-2640.png");
}

.e1a-woman_lifting_weights_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fc-2640.png");
}

.e1a-rel-woman_lifting_weights_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fc-2640.png");
}

.e1a-woman_lifting_weights_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fd-2640.png");
}

.e1a-rel-woman_lifting_weights_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fd-2640.png");
}

.e1a-woman_lifting_weights_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fe-2640.png");
}

.e1a-rel-woman_lifting_weights_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fe-2640.png");
}

.e1a-woman_lifting_weights_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3ff-2640.png");
}

.e1a-rel-woman_lifting_weights_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3ff-2640.png");
}

.e1a-man_lifting_weights {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-2642.png");
}

.e1a-rel-man_lifting_weights {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-2642.png");
}

.e1a-man_lifting_weights_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fb-2642.png");
}

.e1a-rel-man_lifting_weights_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fb-2642.png");
}

.e1a-man_lifting_weights_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fc-2642.png");
}

.e1a-rel-man_lifting_weights_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fc-2642.png");
}

.e1a-man_lifting_weights_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fd-2642.png");
}

.e1a-rel-man_lifting_weights_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fd-2642.png");
}

.e1a-man_lifting_weights_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3fe-2642.png");
}

.e1a-rel-man_lifting_weights_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3fe-2642.png");
}

.e1a-man_lifting_weights_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cb-1f3ff-2642.png");
}

.e1a-rel-man_lifting_weights_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cb-1f3ff-2642.png");
}

.e1a-people_wrestling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93c.png");
}

.e1a-rel-people_wrestling {
  background-image: url("emojione/assets/4.5/png/128/1f93c.png");
}

.e1a-women_wrestling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93c-2640.png");
}

.e1a-rel-women_wrestling {
  background-image: url("emojione/assets/4.5/png/128/1f93c-2640.png");
}

.e1a-men_wrestling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93c-2642.png");
}

.e1a-rel-men_wrestling {
  background-image: url("emojione/assets/4.5/png/128/1f93c-2642.png");
}

.e1a-person_doing_cartwheel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938.png");
}

.e1a-rel-person_doing_cartwheel {
  background-image: url("emojione/assets/4.5/png/128/1f938.png");
}

.e1a-person_doing_cartwheel_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fb.png");
}

.e1a-rel-person_doing_cartwheel_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fb.png");
}

.e1a-person_doing_cartwheel_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fc.png");
}

.e1a-rel-person_doing_cartwheel_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fc.png");
}

.e1a-person_doing_cartwheel_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fd.png");
}

.e1a-rel-person_doing_cartwheel_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fd.png");
}

.e1a-person_doing_cartwheel_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fe.png");
}

.e1a-rel-person_doing_cartwheel_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fe.png");
}

.e1a-person_doing_cartwheel_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3ff.png");
}

.e1a-rel-person_doing_cartwheel_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3ff.png");
}

.e1a-woman_cartwheeling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-2640.png");
}

.e1a-rel-woman_cartwheeling {
  background-image: url("emojione/assets/4.5/png/128/1f938-2640.png");
}

.e1a-woman_cartwheeling_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fb-2640.png");
}

.e1a-rel-woman_cartwheeling_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fb-2640.png");
}

.e1a-woman_cartwheeling_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fc-2640.png");
}

.e1a-rel-woman_cartwheeling_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fc-2640.png");
}

.e1a-woman_cartwheeling_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fd-2640.png");
}

.e1a-rel-woman_cartwheeling_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fd-2640.png");
}

.e1a-woman_cartwheeling_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fe-2640.png");
}

.e1a-rel-woman_cartwheeling_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fe-2640.png");
}

.e1a-woman_cartwheeling_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3ff-2640.png");
}

.e1a-rel-woman_cartwheeling_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3ff-2640.png");
}

.e1a-man_cartwheeling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-2642.png");
}

.e1a-rel-man_cartwheeling {
  background-image: url("emojione/assets/4.5/png/128/1f938-2642.png");
}

.e1a-man_cartwheeling_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fb-2642.png");
}

.e1a-rel-man_cartwheeling_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fb-2642.png");
}

.e1a-man_cartwheeling_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fc-2642.png");
}

.e1a-rel-man_cartwheeling_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fc-2642.png");
}

.e1a-man_cartwheeling_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fd-2642.png");
}

.e1a-rel-man_cartwheeling_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fd-2642.png");
}

.e1a-man_cartwheeling_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3fe-2642.png");
}

.e1a-rel-man_cartwheeling_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3fe-2642.png");
}

.e1a-man_cartwheeling_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f938-1f3ff-2642.png");
}

.e1a-rel-man_cartwheeling_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f938-1f3ff-2642.png");
}

.e1a-person_bouncing_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9.png");
}

.e1a-rel-person_bouncing_ball {
  background-image: url("emojione/assets/4.5/png/128/26f9.png");
}

.e1a-person_bouncing_ball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fb.png");
}

.e1a-rel-person_bouncing_ball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fb.png");
}

.e1a-person_bouncing_ball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fc.png");
}

.e1a-rel-person_bouncing_ball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fc.png");
}

.e1a-person_bouncing_ball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fd.png");
}

.e1a-rel-person_bouncing_ball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fd.png");
}

.e1a-person_bouncing_ball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fe.png");
}

.e1a-rel-person_bouncing_ball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fe.png");
}

.e1a-person_bouncing_ball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3ff.png");
}

.e1a-rel-person_bouncing_ball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3ff.png");
}

.e1a-woman_bouncing_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-2640.png");
}

.e1a-rel-woman_bouncing_ball {
  background-image: url("emojione/assets/4.5/png/128/26f9-2640.png");
}

.e1a-woman_bouncing_ball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fb-2640.png");
}

.e1a-rel-woman_bouncing_ball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fb-2640.png");
}

.e1a-woman_bouncing_ball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fc-2640.png");
}

.e1a-rel-woman_bouncing_ball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fc-2640.png");
}

.e1a-woman_bouncing_ball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fd-2640.png");
}

.e1a-rel-woman_bouncing_ball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fd-2640.png");
}

.e1a-woman_bouncing_ball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fe-2640.png");
}

.e1a-rel-woman_bouncing_ball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fe-2640.png");
}

.e1a-woman_bouncing_ball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3ff-2640.png");
}

.e1a-rel-woman_bouncing_ball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3ff-2640.png");
}

.e1a-man_bouncing_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-2642.png");
}

.e1a-rel-man_bouncing_ball {
  background-image: url("emojione/assets/4.5/png/128/26f9-2642.png");
}

.e1a-man_bouncing_ball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fb-2642.png");
}

.e1a-rel-man_bouncing_ball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fb-2642.png");
}

.e1a-man_bouncing_ball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fc-2642.png");
}

.e1a-rel-man_bouncing_ball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fc-2642.png");
}

.e1a-man_bouncing_ball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fd-2642.png");
}

.e1a-rel-man_bouncing_ball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fd-2642.png");
}

.e1a-man_bouncing_ball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3fe-2642.png");
}

.e1a-rel-man_bouncing_ball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3fe-2642.png");
}

.e1a-man_bouncing_ball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f9-1f3ff-2642.png");
}

.e1a-rel-man_bouncing_ball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/26f9-1f3ff-2642.png");
}

.e1a-person_fencing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93a.png");
}

.e1a-rel-person_fencing {
  background-image: url("emojione/assets/4.5/png/128/1f93a.png");
}

.e1a-person_playing_handball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e.png");
}

.e1a-rel-person_playing_handball {
  background-image: url("emojione/assets/4.5/png/128/1f93e.png");
}

.e1a-person_playing_handball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fb.png");
}

.e1a-rel-person_playing_handball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fb.png");
}

.e1a-person_playing_handball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fc.png");
}

.e1a-rel-person_playing_handball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fc.png");
}

.e1a-person_playing_handball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fd.png");
}

.e1a-rel-person_playing_handball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fd.png");
}

.e1a-person_playing_handball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fe.png");
}

.e1a-rel-person_playing_handball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fe.png");
}

.e1a-person_playing_handball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3ff.png");
}

.e1a-rel-person_playing_handball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3ff.png");
}

.e1a-woman_playing_handball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-2640.png");
}

.e1a-rel-woman_playing_handball {
  background-image: url("emojione/assets/4.5/png/128/1f93e-2640.png");
}

.e1a-woman_playing_handball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fb-2640.png");
}

.e1a-rel-woman_playing_handball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fb-2640.png");
}

.e1a-woman_playing_handball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fc-2640.png");
}

.e1a-rel-woman_playing_handball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fc-2640.png");
}

.e1a-woman_playing_handball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fd-2640.png");
}

.e1a-rel-woman_playing_handball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fd-2640.png");
}

.e1a-woman_playing_handball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fe-2640.png");
}

.e1a-rel-woman_playing_handball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fe-2640.png");
}

.e1a-woman_playing_handball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3ff-2640.png");
}

.e1a-rel-woman_playing_handball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3ff-2640.png");
}

.e1a-man_playing_handball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-2642.png");
}

.e1a-rel-man_playing_handball {
  background-image: url("emojione/assets/4.5/png/128/1f93e-2642.png");
}

.e1a-man_playing_handball_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fb-2642.png");
}

.e1a-rel-man_playing_handball_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fb-2642.png");
}

.e1a-man_playing_handball_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fc-2642.png");
}

.e1a-rel-man_playing_handball_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fc-2642.png");
}

.e1a-man_playing_handball_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fd-2642.png");
}

.e1a-rel-man_playing_handball_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fd-2642.png");
}

.e1a-man_playing_handball_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3fe-2642.png");
}

.e1a-rel-man_playing_handball_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3fe-2642.png");
}

.e1a-man_playing_handball_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93e-1f3ff-2642.png");
}

.e1a-rel-man_playing_handball_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93e-1f3ff-2642.png");
}

.e1a-person_golfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc.png");
}

.e1a-rel-person_golfing {
  background-image: url("emojione/assets/4.5/png/128/1f3cc.png");
}

.e1a-person_golfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fb.png");
}

.e1a-rel-person_golfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fb.png");
}

.e1a-person_golfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fc.png");
}

.e1a-rel-person_golfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fc.png");
}

.e1a-person_golfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fd.png");
}

.e1a-rel-person_golfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fd.png");
}

.e1a-person_golfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fe.png");
}

.e1a-rel-person_golfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fe.png");
}

.e1a-person_golfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3ff.png");
}

.e1a-rel-person_golfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3ff.png");
}

.e1a-woman_golfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-2640.png");
}

.e1a-rel-woman_golfing {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-2640.png");
}

.e1a-woman_golfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fb-2640.png");
}

.e1a-rel-woman_golfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fb-2640.png");
}

.e1a-woman_golfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fc-2640.png");
}

.e1a-rel-woman_golfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fc-2640.png");
}

.e1a-woman_golfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fd-2640.png");
}

.e1a-rel-woman_golfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fd-2640.png");
}

.e1a-woman_golfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fe-2640.png");
}

.e1a-rel-woman_golfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fe-2640.png");
}

.e1a-woman_golfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3ff-2640.png");
}

.e1a-rel-woman_golfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3ff-2640.png");
}

.e1a-man_golfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-2642.png");
}

.e1a-rel-man_golfing {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-2642.png");
}

.e1a-man_golfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fb-2642.png");
}

.e1a-rel-man_golfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fb-2642.png");
}

.e1a-man_golfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fc-2642.png");
}

.e1a-rel-man_golfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fc-2642.png");
}

.e1a-man_golfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fd-2642.png");
}

.e1a-rel-man_golfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fd-2642.png");
}

.e1a-man_golfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3fe-2642.png");
}

.e1a-rel-man_golfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3fe-2642.png");
}

.e1a-man_golfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cc-1f3ff-2642.png");
}

.e1a-rel-man_golfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3cc-1f3ff-2642.png");
}

.e1a-horse_racing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7.png");
}

.e1a-rel-horse_racing {
  background-image: url("emojione/assets/4.5/png/128/1f3c7.png");
}

.e1a-horse_racing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7-1f3fb.png");
}

.e1a-rel-horse_racing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c7-1f3fb.png");
}

.e1a-horse_racing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7-1f3fc.png");
}

.e1a-rel-horse_racing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c7-1f3fc.png");
}

.e1a-horse_racing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7-1f3fd.png");
}

.e1a-rel-horse_racing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c7-1f3fd.png");
}

.e1a-horse_racing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7-1f3fe.png");
}

.e1a-rel-horse_racing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c7-1f3fe.png");
}

.e1a-horse_racing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c7-1f3ff.png");
}

.e1a-rel-horse_racing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c7-1f3ff.png");
}

.e1a-person_in_lotus_position {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8.png");
}

.e1a-rel-person_in_lotus_position {
  background-image: url("emojione/assets/4.5/png/128/1f9d8.png");
}

.e1a-person_in_lotus_position_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fb.png");
}

.e1a-rel-person_in_lotus_position_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fb.png");
}

.e1a-person_in_lotus_position_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fc.png");
}

.e1a-rel-person_in_lotus_position_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fc.png");
}

.e1a-person_in_lotus_position_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fd.png");
}

.e1a-rel-person_in_lotus_position_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fd.png");
}

.e1a-person_in_lotus_position_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fe.png");
}

.e1a-rel-person_in_lotus_position_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fe.png");
}

.e1a-person_in_lotus_position_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3ff.png");
}

.e1a-rel-person_in_lotus_position_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3ff.png");
}

.e1a-woman_in_lotus_position {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-2640.png");
}

.e1a-rel-woman_in_lotus_position {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-2640.png");
}

.e1a-woman_in_lotus_position_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fb-2640.png");
}

.e1a-rel-woman_in_lotus_position_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fb-2640.png");
}

.e1a-woman_in_lotus_position_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fc-2640.png");
}

.e1a-rel-woman_in_lotus_position_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fc-2640.png");
}

.e1a-woman_in_lotus_position_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fd-2640.png");
}

.e1a-rel-woman_in_lotus_position_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fd-2640.png");
}

.e1a-woman_in_lotus_position_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fe-2640.png");
}

.e1a-rel-woman_in_lotus_position_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fe-2640.png");
}

.e1a-woman_in_lotus_position_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3ff-2640.png");
}

.e1a-rel-woman_in_lotus_position_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3ff-2640.png");
}

.e1a-man_in_lotus_position {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-2642.png");
}

.e1a-rel-man_in_lotus_position {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-2642.png");
}

.e1a-man_in_lotus_position_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fb-2642.png");
}

.e1a-rel-man_in_lotus_position_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fb-2642.png");
}

.e1a-man_in_lotus_position_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fc-2642.png");
}

.e1a-rel-man_in_lotus_position_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fc-2642.png");
}

.e1a-man_in_lotus_position_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fd-2642.png");
}

.e1a-rel-man_in_lotus_position_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fd-2642.png");
}

.e1a-man_in_lotus_position_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3fe-2642.png");
}

.e1a-rel-man_in_lotus_position_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3fe-2642.png");
}

.e1a-man_in_lotus_position_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d8-1f3ff-2642.png");
}

.e1a-rel-man_in_lotus_position_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d8-1f3ff-2642.png");
}

.e1a-person_surfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4.png");
}

.e1a-rel-person_surfing {
  background-image: url("emojione/assets/4.5/png/128/1f3c4.png");
}

.e1a-person_surfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fb.png");
}

.e1a-rel-person_surfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fb.png");
}

.e1a-person_surfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fc.png");
}

.e1a-rel-person_surfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fc.png");
}

.e1a-person_surfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fd.png");
}

.e1a-rel-person_surfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fd.png");
}

.e1a-person_surfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fe.png");
}

.e1a-rel-person_surfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fe.png");
}

.e1a-person_surfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3ff.png");
}

.e1a-rel-person_surfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3ff.png");
}

.e1a-woman_surfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-2640.png");
}

.e1a-rel-woman_surfing {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-2640.png");
}

.e1a-woman_surfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fb-2640.png");
}

.e1a-rel-woman_surfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fb-2640.png");
}

.e1a-woman_surfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fc-2640.png");
}

.e1a-rel-woman_surfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fc-2640.png");
}

.e1a-woman_surfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fd-2640.png");
}

.e1a-rel-woman_surfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fd-2640.png");
}

.e1a-woman_surfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fe-2640.png");
}

.e1a-rel-woman_surfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fe-2640.png");
}

.e1a-woman_surfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3ff-2640.png");
}

.e1a-rel-woman_surfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3ff-2640.png");
}

.e1a-man_surfing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-2642.png");
}

.e1a-rel-man_surfing {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-2642.png");
}

.e1a-man_surfing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fb-2642.png");
}

.e1a-rel-man_surfing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fb-2642.png");
}

.e1a-man_surfing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fc-2642.png");
}

.e1a-rel-man_surfing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fc-2642.png");
}

.e1a-man_surfing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fd-2642.png");
}

.e1a-rel-man_surfing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fd-2642.png");
}

.e1a-man_surfing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3fe-2642.png");
}

.e1a-rel-man_surfing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3fe-2642.png");
}

.e1a-man_surfing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c4-1f3ff-2642.png");
}

.e1a-rel-man_surfing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c4-1f3ff-2642.png");
}

.e1a-person_swimming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca.png");
}

.e1a-rel-person_swimming {
  background-image: url("emojione/assets/4.5/png/128/1f3ca.png");
}

.e1a-person_swimming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fb.png");
}

.e1a-rel-person_swimming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fb.png");
}

.e1a-person_swimming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fc.png");
}

.e1a-rel-person_swimming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fc.png");
}

.e1a-person_swimming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fd.png");
}

.e1a-rel-person_swimming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fd.png");
}

.e1a-person_swimming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fe.png");
}

.e1a-rel-person_swimming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fe.png");
}

.e1a-person_swimming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3ff.png");
}

.e1a-rel-person_swimming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3ff.png");
}

.e1a-woman_swimming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-2640.png");
}

.e1a-rel-woman_swimming {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-2640.png");
}

.e1a-woman_swimming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fb-2640.png");
}

.e1a-rel-woman_swimming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fb-2640.png");
}

.e1a-woman_swimming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fc-2640.png");
}

.e1a-rel-woman_swimming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fc-2640.png");
}

.e1a-woman_swimming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fd-2640.png");
}

.e1a-rel-woman_swimming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fd-2640.png");
}

.e1a-woman_swimming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fe-2640.png");
}

.e1a-rel-woman_swimming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fe-2640.png");
}

.e1a-woman_swimming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3ff-2640.png");
}

.e1a-rel-woman_swimming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3ff-2640.png");
}

.e1a-man_swimming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-2642.png");
}

.e1a-rel-man_swimming {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-2642.png");
}

.e1a-man_swimming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fb-2642.png");
}

.e1a-rel-man_swimming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fb-2642.png");
}

.e1a-man_swimming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fc-2642.png");
}

.e1a-rel-man_swimming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fc-2642.png");
}

.e1a-man_swimming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fd-2642.png");
}

.e1a-rel-man_swimming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fd-2642.png");
}

.e1a-man_swimming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3fe-2642.png");
}

.e1a-rel-man_swimming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3fe-2642.png");
}

.e1a-man_swimming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ca-1f3ff-2642.png");
}

.e1a-rel-man_swimming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3ca-1f3ff-2642.png");
}

.e1a-person_playing_water_polo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d.png");
}

.e1a-rel-person_playing_water_polo {
  background-image: url("emojione/assets/4.5/png/128/1f93d.png");
}

.e1a-person_playing_water_polo_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fb.png");
}

.e1a-rel-person_playing_water_polo_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fb.png");
}

.e1a-person_playing_water_polo_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fc.png");
}

.e1a-rel-person_playing_water_polo_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fc.png");
}

.e1a-person_playing_water_polo_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fd.png");
}

.e1a-rel-person_playing_water_polo_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fd.png");
}

.e1a-person_playing_water_polo_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fe.png");
}

.e1a-rel-person_playing_water_polo_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fe.png");
}

.e1a-person_playing_water_polo_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3ff.png");
}

.e1a-rel-person_playing_water_polo_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3ff.png");
}

.e1a-woman_playing_water_polo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-2640.png");
}

.e1a-rel-woman_playing_water_polo {
  background-image: url("emojione/assets/4.5/png/128/1f93d-2640.png");
}

.e1a-woman_playing_water_polo_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fb-2640.png");
}

.e1a-rel-woman_playing_water_polo_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fb-2640.png");
}

.e1a-woman_playing_water_polo_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fc-2640.png");
}

.e1a-rel-woman_playing_water_polo_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fc-2640.png");
}

.e1a-woman_playing_water_polo_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fd-2640.png");
}

.e1a-rel-woman_playing_water_polo_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fd-2640.png");
}

.e1a-woman_playing_water_polo_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fe-2640.png");
}

.e1a-rel-woman_playing_water_polo_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fe-2640.png");
}

.e1a-woman_playing_water_polo_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3ff-2640.png");
}

.e1a-rel-woman_playing_water_polo_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3ff-2640.png");
}

.e1a-man_playing_water_polo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-2642.png");
}

.e1a-rel-man_playing_water_polo {
  background-image: url("emojione/assets/4.5/png/128/1f93d-2642.png");
}

.e1a-man_playing_water_polo_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fb-2642.png");
}

.e1a-rel-man_playing_water_polo_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fb-2642.png");
}

.e1a-man_playing_water_polo_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fc-2642.png");
}

.e1a-rel-man_playing_water_polo_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fc-2642.png");
}

.e1a-man_playing_water_polo_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fd-2642.png");
}

.e1a-rel-man_playing_water_polo_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fd-2642.png");
}

.e1a-man_playing_water_polo_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3fe-2642.png");
}

.e1a-rel-man_playing_water_polo_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3fe-2642.png");
}

.e1a-man_playing_water_polo_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f93d-1f3ff-2642.png");
}

.e1a-rel-man_playing_water_polo_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f93d-1f3ff-2642.png");
}

.e1a-person_rowing_boat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3.png");
}

.e1a-rel-person_rowing_boat {
  background-image: url("emojione/assets/4.5/png/128/1f6a3.png");
}

.e1a-person_rowing_boat_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fb.png");
}

.e1a-rel-person_rowing_boat_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fb.png");
}

.e1a-person_rowing_boat_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fc.png");
}

.e1a-rel-person_rowing_boat_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fc.png");
}

.e1a-person_rowing_boat_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fd.png");
}

.e1a-rel-person_rowing_boat_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fd.png");
}

.e1a-person_rowing_boat_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fe.png");
}

.e1a-rel-person_rowing_boat_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fe.png");
}

.e1a-person_rowing_boat_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3ff.png");
}

.e1a-rel-person_rowing_boat_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3ff.png");
}

.e1a-woman_rowing_boat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-2640.png");
}

.e1a-rel-woman_rowing_boat {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-2640.png");
}

.e1a-woman_rowing_boat_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fb-2640.png");
}

.e1a-rel-woman_rowing_boat_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fb-2640.png");
}

.e1a-woman_rowing_boat_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fc-2640.png");
}

.e1a-rel-woman_rowing_boat_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fc-2640.png");
}

.e1a-woman_rowing_boat_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fd-2640.png");
}

.e1a-rel-woman_rowing_boat_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fd-2640.png");
}

.e1a-woman_rowing_boat_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fe-2640.png");
}

.e1a-rel-woman_rowing_boat_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fe-2640.png");
}

.e1a-woman_rowing_boat_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3ff-2640.png");
}

.e1a-rel-woman_rowing_boat_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3ff-2640.png");
}

.e1a-man_rowing_boat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-2642.png");
}

.e1a-rel-man_rowing_boat {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-2642.png");
}

.e1a-man_rowing_boat_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fb-2642.png");
}

.e1a-rel-man_rowing_boat_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fb-2642.png");
}

.e1a-man_rowing_boat_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fc-2642.png");
}

.e1a-rel-man_rowing_boat_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fc-2642.png");
}

.e1a-man_rowing_boat_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fd-2642.png");
}

.e1a-rel-man_rowing_boat_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fd-2642.png");
}

.e1a-man_rowing_boat_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3fe-2642.png");
}

.e1a-rel-man_rowing_boat_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3fe-2642.png");
}

.e1a-man_rowing_boat_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a3-1f3ff-2642.png");
}

.e1a-rel-man_rowing_boat_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6a3-1f3ff-2642.png");
}

.e1a-person_climbing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7.png");
}

.e1a-rel-person_climbing {
  background-image: url("emojione/assets/4.5/png/128/1f9d7.png");
}

.e1a-person_climbing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fb.png");
}

.e1a-rel-person_climbing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fb.png");
}

.e1a-person_climbing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fc.png");
}

.e1a-rel-person_climbing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fc.png");
}

.e1a-person_climbing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fd.png");
}

.e1a-rel-person_climbing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fd.png");
}

.e1a-person_climbing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fe.png");
}

.e1a-rel-person_climbing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fe.png");
}

.e1a-person_climbing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3ff.png");
}

.e1a-rel-person_climbing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3ff.png");
}

.e1a-woman_climbing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-2640.png");
}

.e1a-rel-woman_climbing {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-2640.png");
}

.e1a-woman_climbing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fb-2640.png");
}

.e1a-rel-woman_climbing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fb-2640.png");
}

.e1a-woman_climbing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fc-2640.png");
}

.e1a-rel-woman_climbing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fc-2640.png");
}

.e1a-woman_climbing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fd-2640.png");
}

.e1a-rel-woman_climbing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fd-2640.png");
}

.e1a-woman_climbing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fe-2640.png");
}

.e1a-rel-woman_climbing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fe-2640.png");
}

.e1a-woman_climbing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3ff-2640.png");
}

.e1a-rel-woman_climbing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3ff-2640.png");
}

.e1a-man_climbing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-2642.png");
}

.e1a-rel-man_climbing {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-2642.png");
}

.e1a-man_climbing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fb-2642.png");
}

.e1a-rel-man_climbing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fb-2642.png");
}

.e1a-man_climbing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fc-2642.png");
}

.e1a-rel-man_climbing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fc-2642.png");
}

.e1a-man_climbing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fd-2642.png");
}

.e1a-rel-man_climbing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fd-2642.png");
}

.e1a-man_climbing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3fe-2642.png");
}

.e1a-rel-man_climbing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3fe-2642.png");
}

.e1a-man_climbing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d7-1f3ff-2642.png");
}

.e1a-rel-man_climbing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d7-1f3ff-2642.png");
}

.e1a-person_mountain_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5.png");
}

.e1a-rel-person_mountain_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b5.png");
}

.e1a-person_mountain_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fb.png");
}

.e1a-rel-person_mountain_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fb.png");
}

.e1a-person_mountain_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fc.png");
}

.e1a-rel-person_mountain_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fc.png");
}

.e1a-person_mountain_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fd.png");
}

.e1a-rel-person_mountain_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fd.png");
}

.e1a-person_mountain_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fe.png");
}

.e1a-rel-person_mountain_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fe.png");
}

.e1a-person_mountain_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3ff.png");
}

.e1a-rel-person_mountain_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3ff.png");
}

.e1a-woman_mountain_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-2640.png");
}

.e1a-rel-woman_mountain_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-2640.png");
}

.e1a-woman_mountain_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fb-2640.png");
}

.e1a-rel-woman_mountain_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fb-2640.png");
}

.e1a-woman_mountain_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fc-2640.png");
}

.e1a-rel-woman_mountain_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fc-2640.png");
}

.e1a-woman_mountain_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fd-2640.png");
}

.e1a-rel-woman_mountain_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fd-2640.png");
}

.e1a-woman_mountain_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fe-2640.png");
}

.e1a-rel-woman_mountain_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fe-2640.png");
}

.e1a-woman_mountain_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3ff-2640.png");
}

.e1a-rel-woman_mountain_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3ff-2640.png");
}

.e1a-man_mountain_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-2642.png");
}

.e1a-rel-man_mountain_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-2642.png");
}

.e1a-man_mountain_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fb-2642.png");
}

.e1a-rel-man_mountain_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fb-2642.png");
}

.e1a-man_mountain_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fc-2642.png");
}

.e1a-rel-man_mountain_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fc-2642.png");
}

.e1a-man_mountain_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fd-2642.png");
}

.e1a-rel-man_mountain_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fd-2642.png");
}

.e1a-man_mountain_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3fe-2642.png");
}

.e1a-rel-man_mountain_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3fe-2642.png");
}

.e1a-man_mountain_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b5-1f3ff-2642.png");
}

.e1a-rel-man_mountain_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b5-1f3ff-2642.png");
}

.e1a-person_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4.png");
}

.e1a-rel-person_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b4.png");
}

.e1a-person_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fb.png");
}

.e1a-rel-person_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fb.png");
}

.e1a-person_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fc.png");
}

.e1a-rel-person_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fc.png");
}

.e1a-person_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fd.png");
}

.e1a-rel-person_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fd.png");
}

.e1a-person_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fe.png");
}

.e1a-rel-person_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fe.png");
}

.e1a-person_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3ff.png");
}

.e1a-rel-person_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3ff.png");
}

.e1a-woman_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-2640.png");
}

.e1a-rel-woman_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-2640.png");
}

.e1a-woman_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fb-2640.png");
}

.e1a-rel-woman_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fb-2640.png");
}

.e1a-woman_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fc-2640.png");
}

.e1a-rel-woman_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fc-2640.png");
}

.e1a-woman_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fd-2640.png");
}

.e1a-rel-woman_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fd-2640.png");
}

.e1a-woman_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fe-2640.png");
}

.e1a-rel-woman_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fe-2640.png");
}

.e1a-woman_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3ff-2640.png");
}

.e1a-rel-woman_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3ff-2640.png");
}

.e1a-man_biking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-2642.png");
}

.e1a-rel-man_biking {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-2642.png");
}

.e1a-man_biking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fb-2642.png");
}

.e1a-rel-man_biking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fb-2642.png");
}

.e1a-man_biking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fc-2642.png");
}

.e1a-rel-man_biking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fc-2642.png");
}

.e1a-man_biking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fd-2642.png");
}

.e1a-rel-man_biking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fd-2642.png");
}

.e1a-man_biking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3fe-2642.png");
}

.e1a-rel-man_biking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3fe-2642.png");
}

.e1a-man_biking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b4-1f3ff-2642.png");
}

.e1a-rel-man_biking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b4-1f3ff-2642.png");
}

.e1a-trophy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c6.png");
}

.e1a-rel-trophy {
  background-image: url("emojione/assets/4.5/png/128/1f3c6.png");
}

.e1a-first_place {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f947.png");
}

.e1a-rel-first_place {
  background-image: url("emojione/assets/4.5/png/128/1f947.png");
}

.e1a-second_place {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f948.png");
}

.e1a-rel-second_place {
  background-image: url("emojione/assets/4.5/png/128/1f948.png");
}

.e1a-third_place {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f949.png");
}

.e1a-rel-third_place {
  background-image: url("emojione/assets/4.5/png/128/1f949.png");
}

.e1a-medal {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c5.png");
}

.e1a-rel-medal {
  background-image: url("emojione/assets/4.5/png/128/1f3c5.png");
}

.e1a-military_medal {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f396.png");
}

.e1a-rel-military_medal {
  background-image: url("emojione/assets/4.5/png/128/1f396.png");
}

.e1a-rosette {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f5.png");
}

.e1a-rel-rosette {
  background-image: url("emojione/assets/4.5/png/128/1f3f5.png");
}

.e1a-reminder_ribbon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f397.png");
}

.e1a-rel-reminder_ribbon {
  background-image: url("emojione/assets/4.5/png/128/1f397.png");
}

.e1a-ticket {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ab.png");
}

.e1a-rel-ticket {
  background-image: url("emojione/assets/4.5/png/128/1f3ab.png");
}

.e1a-tickets {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f39f.png");
}

.e1a-rel-tickets {
  background-image: url("emojione/assets/4.5/png/128/1f39f.png");
}

.e1a-circus_tent {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3aa.png");
}

.e1a-rel-circus_tent {
  background-image: url("emojione/assets/4.5/png/128/1f3aa.png");
}

.e1a-person_juggling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939.png");
}

.e1a-rel-person_juggling {
  background-image: url("emojione/assets/4.5/png/128/1f939.png");
}

.e1a-person_juggling_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fb.png");
}

.e1a-rel-person_juggling_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fb.png");
}

.e1a-person_juggling_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fc.png");
}

.e1a-rel-person_juggling_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fc.png");
}

.e1a-person_juggling_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fd.png");
}

.e1a-rel-person_juggling_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fd.png");
}

.e1a-person_juggling_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fe.png");
}

.e1a-rel-person_juggling_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fe.png");
}

.e1a-person_juggling_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3ff.png");
}

.e1a-rel-person_juggling_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3ff.png");
}

.e1a-woman_juggling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-2640.png");
}

.e1a-rel-woman_juggling {
  background-image: url("emojione/assets/4.5/png/128/1f939-2640.png");
}

.e1a-woman_juggling_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fb-2640.png");
}

.e1a-rel-woman_juggling_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fb-2640.png");
}

.e1a-woman_juggling_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fc-2640.png");
}

.e1a-rel-woman_juggling_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fc-2640.png");
}

.e1a-woman_juggling_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fd-2640.png");
}

.e1a-rel-woman_juggling_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fd-2640.png");
}

.e1a-woman_juggling_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fe-2640.png");
}

.e1a-rel-woman_juggling_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fe-2640.png");
}

.e1a-woman_juggling_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3ff-2640.png");
}

.e1a-rel-woman_juggling_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3ff-2640.png");
}

.e1a-man_juggling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-2642.png");
}

.e1a-rel-man_juggling {
  background-image: url("emojione/assets/4.5/png/128/1f939-2642.png");
}

.e1a-man_juggling_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fb-2642.png");
}

.e1a-rel-man_juggling_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fb-2642.png");
}

.e1a-man_juggling_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fc-2642.png");
}

.e1a-rel-man_juggling_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fc-2642.png");
}

.e1a-man_juggling_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fd-2642.png");
}

.e1a-rel-man_juggling_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fd-2642.png");
}

.e1a-man_juggling_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3fe-2642.png");
}

.e1a-rel-man_juggling_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3fe-2642.png");
}

.e1a-man_juggling_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f939-1f3ff-2642.png");
}

.e1a-rel-man_juggling_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f939-1f3ff-2642.png");
}

.e1a-performing_arts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ad.png");
}

.e1a-rel-performing_arts {
  background-image: url("emojione/assets/4.5/png/128/1f3ad.png");
}

.e1a-art {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a8.png");
}

.e1a-rel-art {
  background-image: url("emojione/assets/4.5/png/128/1f3a8.png");
}

.e1a-clapper {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ac.png");
}

.e1a-rel-clapper {
  background-image: url("emojione/assets/4.5/png/128/1f3ac.png");
}

.e1a-microphone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a4.png");
}

.e1a-rel-microphone {
  background-image: url("emojione/assets/4.5/png/128/1f3a4.png");
}

.e1a-headphones {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a7.png");
}

.e1a-rel-headphones {
  background-image: url("emojione/assets/4.5/png/128/1f3a7.png");
}

.e1a-musical_score {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3bc.png");
}

.e1a-rel-musical_score {
  background-image: url("emojione/assets/4.5/png/128/1f3bc.png");
}

.e1a-musical_keyboard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b9.png");
}

.e1a-rel-musical_keyboard {
  background-image: url("emojione/assets/4.5/png/128/1f3b9.png");
}

.e1a-drum {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f941.png");
}

.e1a-rel-drum {
  background-image: url("emojione/assets/4.5/png/128/1f941.png");
}

.e1a-saxophone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b7.png");
}

.e1a-rel-saxophone {
  background-image: url("emojione/assets/4.5/png/128/1f3b7.png");
}

.e1a-trumpet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ba.png");
}

.e1a-rel-trumpet {
  background-image: url("emojione/assets/4.5/png/128/1f3ba.png");
}

.e1a-guitar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b8.png");
}

.e1a-rel-guitar {
  background-image: url("emojione/assets/4.5/png/128/1f3b8.png");
}

.e1a-violin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3bb.png");
}

.e1a-rel-violin {
  background-image: url("emojione/assets/4.5/png/128/1f3bb.png");
}

.e1a-game_die {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b2.png");
}

.e1a-rel-game_die {
  background-image: url("emojione/assets/4.5/png/128/1f3b2.png");
}

.e1a-dart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3af.png");
}

.e1a-rel-dart {
  background-image: url("emojione/assets/4.5/png/128/1f3af.png");
}

.e1a-bowling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b3.png");
}

.e1a-rel-bowling {
  background-image: url("emojione/assets/4.5/png/128/1f3b3.png");
}

.e1a-video_game {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ae.png");
}

.e1a-rel-video_game {
  background-image: url("emojione/assets/4.5/png/128/1f3ae.png");
}

.e1a-slot_machine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3b0.png");
}

.e1a-rel-slot_machine {
  background-image: url("emojione/assets/4.5/png/128/1f3b0.png");
}

.e1a-watch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/231a.png");
}

.e1a-rel-watch {
  background-image: url("emojione/assets/4.5/png/128/231a.png");
}

.e1a-iphone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f1.png");
}

.e1a-rel-iphone {
  background-image: url("emojione/assets/4.5/png/128/1f4f1.png");
}

.e1a-calling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f2.png");
}

.e1a-rel-calling {
  background-image: url("emojione/assets/4.5/png/128/1f4f2.png");
}

.e1a-computer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4bb.png");
}

.e1a-rel-computer {
  background-image: url("emojione/assets/4.5/png/128/1f4bb.png");
}

.e1a-desktop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5a5.png");
}

.e1a-rel-desktop {
  background-image: url("emojione/assets/4.5/png/128/1f5a5.png");
}

.e1a-printer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5a8.png");
}

.e1a-rel-printer {
  background-image: url("emojione/assets/4.5/png/128/1f5a8.png");
}

.e1a-mouse_three_button {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5b1.png");
}

.e1a-rel-mouse_three_button {
  background-image: url("emojione/assets/4.5/png/128/1f5b1.png");
}

.e1a-trackball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5b2.png");
}

.e1a-rel-trackball {
  background-image: url("emojione/assets/4.5/png/128/1f5b2.png");
}

.e1a-joystick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f579.png");
}

.e1a-rel-joystick {
  background-image: url("emojione/assets/4.5/png/128/1f579.png");
}

.e1a-chess_pawn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/265f.png");
}

.e1a-rel-chess_pawn {
  background-image: url("emojione/assets/4.5/png/128/265f.png");
}

.e1a-jigsaw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e9.png");
}

.e1a-rel-jigsaw {
  background-image: url("emojione/assets/4.5/png/128/1f9e9.png");
}

.e1a-compression {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5dc.png");
}

.e1a-rel-compression {
  background-image: url("emojione/assets/4.5/png/128/1f5dc.png");
}

.e1a-minidisc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4bd.png");
}

.e1a-rel-minidisc {
  background-image: url("emojione/assets/4.5/png/128/1f4bd.png");
}

.e1a-floppy_disk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4be.png");
}

.e1a-rel-floppy_disk {
  background-image: url("emojione/assets/4.5/png/128/1f4be.png");
}

.e1a-cd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4bf.png");
}

.e1a-rel-cd {
  background-image: url("emojione/assets/4.5/png/128/1f4bf.png");
}

.e1a-dvd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c0.png");
}

.e1a-rel-dvd {
  background-image: url("emojione/assets/4.5/png/128/1f4c0.png");
}

.e1a-vhs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4fc.png");
}

.e1a-rel-vhs {
  background-image: url("emojione/assets/4.5/png/128/1f4fc.png");
}

.e1a-camera {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f7.png");
}

.e1a-rel-camera {
  background-image: url("emojione/assets/4.5/png/128/1f4f7.png");
}

.e1a-camera_with_flash {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f8.png");
}

.e1a-rel-camera_with_flash {
  background-image: url("emojione/assets/4.5/png/128/1f4f8.png");
}

.e1a-video_camera {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f9.png");
}

.e1a-rel-video_camera {
  background-image: url("emojione/assets/4.5/png/128/1f4f9.png");
}

.e1a-movie_camera {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a5.png");
}

.e1a-rel-movie_camera {
  background-image: url("emojione/assets/4.5/png/128/1f3a5.png");
}

.e1a-projector {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4fd.png");
}

.e1a-rel-projector {
  background-image: url("emojione/assets/4.5/png/128/1f4fd.png");
}

.e1a-film_frames {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f39e.png");
}

.e1a-rel-film_frames {
  background-image: url("emojione/assets/4.5/png/128/1f39e.png");
}

.e1a-telephone_receiver {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4de.png");
}

.e1a-rel-telephone_receiver {
  background-image: url("emojione/assets/4.5/png/128/1f4de.png");
}

.e1a-telephone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/260e.png");
}

.e1a-rel-telephone {
  background-image: url("emojione/assets/4.5/png/128/260e.png");
}

.e1a-pager {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4df.png");
}

.e1a-rel-pager {
  background-image: url("emojione/assets/4.5/png/128/1f4df.png");
}

.e1a-fax {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e0.png");
}

.e1a-rel-fax {
  background-image: url("emojione/assets/4.5/png/128/1f4e0.png");
}

.e1a-tv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4fa.png");
}

.e1a-rel-tv {
  background-image: url("emojione/assets/4.5/png/128/1f4fa.png");
}

.e1a-radio {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4fb.png");
}

.e1a-rel-radio {
  background-image: url("emojione/assets/4.5/png/128/1f4fb.png");
}

.e1a-microphone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f399.png");
}

.e1a-rel-microphone2 {
  background-image: url("emojione/assets/4.5/png/128/1f399.png");
}

.e1a-level_slider {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f39a.png");
}

.e1a-rel-level_slider {
  background-image: url("emojione/assets/4.5/png/128/1f39a.png");
}

.e1a-control_knobs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f39b.png");
}

.e1a-rel-control_knobs {
  background-image: url("emojione/assets/4.5/png/128/1f39b.png");
}

.e1a-stopwatch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f1.png");
}

.e1a-rel-stopwatch {
  background-image: url("emojione/assets/4.5/png/128/23f1.png");
}

.e1a-timer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f2.png");
}

.e1a-rel-timer {
  background-image: url("emojione/assets/4.5/png/128/23f2.png");
}

.e1a-alarm_clock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f0.png");
}

.e1a-rel-alarm_clock {
  background-image: url("emojione/assets/4.5/png/128/23f0.png");
}

.e1a-clock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f570.png");
}

.e1a-rel-clock {
  background-image: url("emojione/assets/4.5/png/128/1f570.png");
}

.e1a-hourglass {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/231b.png");
}

.e1a-rel-hourglass {
  background-image: url("emojione/assets/4.5/png/128/231b.png");
}

.e1a-hourglass_flowing_sand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/23f3.png");
}

.e1a-rel-hourglass_flowing_sand {
  background-image: url("emojione/assets/4.5/png/128/23f3.png");
}

.e1a-satellite {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e1.png");
}

.e1a-rel-satellite {
  background-image: url("emojione/assets/4.5/png/128/1f4e1.png");
}

.e1a-compass {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ed.png");
}

.e1a-rel-compass {
  background-image: url("emojione/assets/4.5/png/128/1f9ed.png");
}

.e1a-battery {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50b.png");
}

.e1a-rel-battery {
  background-image: url("emojione/assets/4.5/png/128/1f50b.png");
}

.e1a-electric_plug {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50c.png");
}

.e1a-rel-electric_plug {
  background-image: url("emojione/assets/4.5/png/128/1f50c.png");
}

.e1a-magnet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f2.png");
}

.e1a-rel-magnet {
  background-image: url("emojione/assets/4.5/png/128/1f9f2.png");
}

.e1a-bulb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a1.png");
}

.e1a-rel-bulb {
  background-image: url("emojione/assets/4.5/png/128/1f4a1.png");
}

.e1a-flashlight {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f526.png");
}

.e1a-rel-flashlight {
  background-image: url("emojione/assets/4.5/png/128/1f526.png");
}

.e1a-candle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f56f.png");
}

.e1a-rel-candle {
  background-image: url("emojione/assets/4.5/png/128/1f56f.png");
}

.e1a-fire_extinguisher {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ef.png");
}

.e1a-rel-fire_extinguisher {
  background-image: url("emojione/assets/4.5/png/128/1f9ef.png");
}

.e1a-wastebasket {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5d1.png");
}

.e1a-rel-wastebasket {
  background-image: url("emojione/assets/4.5/png/128/1f5d1.png");
}

.e1a-oil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e2.png");
}

.e1a-rel-oil {
  background-image: url("emojione/assets/4.5/png/128/1f6e2.png");
}

.e1a-money_with_wings {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b8.png");
}

.e1a-rel-money_with_wings {
  background-image: url("emojione/assets/4.5/png/128/1f4b8.png");
}

.e1a-dollar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b5.png");
}

.e1a-rel-dollar {
  background-image: url("emojione/assets/4.5/png/128/1f4b5.png");
}

.e1a-yen {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b4.png");
}

.e1a-rel-yen {
  background-image: url("emojione/assets/4.5/png/128/1f4b4.png");
}

.e1a-euro {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b6.png");
}

.e1a-rel-euro {
  background-image: url("emojione/assets/4.5/png/128/1f4b6.png");
}

.e1a-pound {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b7.png");
}

.e1a-rel-pound {
  background-image: url("emojione/assets/4.5/png/128/1f4b7.png");
}

.e1a-moneybag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b0.png");
}

.e1a-rel-moneybag {
  background-image: url("emojione/assets/4.5/png/128/1f4b0.png");
}

.e1a-credit_card {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4b3.png");
}

.e1a-rel-credit_card {
  background-image: url("emojione/assets/4.5/png/128/1f4b3.png");
}

.e1a-gem {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48e.png");
}

.e1a-rel-gem {
  background-image: url("emojione/assets/4.5/png/128/1f48e.png");
}

.e1a-nazar_amulet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ff.png");
}

.e1a-rel-nazar_amulet {
  background-image: url("emojione/assets/4.5/png/128/1f9ff.png");
}

.e1a-bricks {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f1.png");
}

.e1a-rel-bricks {
  background-image: url("emojione/assets/4.5/png/128/1f9f1.png");
}

.e1a-toolbox {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f0.png");
}

.e1a-rel-toolbox {
  background-image: url("emojione/assets/4.5/png/128/1f9f0.png");
}

.e1a-wrench {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f527.png");
}

.e1a-rel-wrench {
  background-image: url("emojione/assets/4.5/png/128/1f527.png");
}

.e1a-hammer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f528.png");
}

.e1a-rel-hammer {
  background-image: url("emojione/assets/4.5/png/128/1f528.png");
}

.e1a-tools {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e0.png");
}

.e1a-rel-tools {
  background-image: url("emojione/assets/4.5/png/128/1f6e0.png");
}

.e1a-pick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26cf.png");
}

.e1a-rel-pick {
  background-image: url("emojione/assets/4.5/png/128/26cf.png");
}

.e1a-nut_and_bolt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f529.png");
}

.e1a-rel-nut_and_bolt {
  background-image: url("emojione/assets/4.5/png/128/1f529.png");
}

.e1a-chains {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26d3.png");
}

.e1a-rel-chains {
  background-image: url("emojione/assets/4.5/png/128/26d3.png");
}

.e1a-gun {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52b.png");
}

.e1a-rel-gun {
  background-image: url("emojione/assets/4.5/png/128/1f52b.png");
}

.e1a-bomb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a3.png");
}

.e1a-rel-bomb {
  background-image: url("emojione/assets/4.5/png/128/1f4a3.png");
}

.e1a-knife {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52a.png");
}

.e1a-rel-knife {
  background-image: url("emojione/assets/4.5/png/128/1f52a.png");
}

.e1a-dagger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5e1.png");
}

.e1a-rel-dagger {
  background-image: url("emojione/assets/4.5/png/128/1f5e1.png");
}

.e1a-shield {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e1.png");
}

.e1a-rel-shield {
  background-image: url("emojione/assets/4.5/png/128/1f6e1.png");
}

.e1a-smoking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ac.png");
}

.e1a-rel-smoking {
  background-image: url("emojione/assets/4.5/png/128/1f6ac.png");
}

.e1a-coffin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26b0.png");
}

.e1a-rel-coffin {
  background-image: url("emojione/assets/4.5/png/128/26b0.png");
}

.e1a-urn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26b1.png");
}

.e1a-rel-urn {
  background-image: url("emojione/assets/4.5/png/128/26b1.png");
}

.e1a-amphora {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3fa.png");
}

.e1a-rel-amphora {
  background-image: url("emojione/assets/4.5/png/128/1f3fa.png");
}

.e1a-crystal_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52e.png");
}

.e1a-rel-crystal_ball {
  background-image: url("emojione/assets/4.5/png/128/1f52e.png");
}

.e1a-prayer_beads {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ff.png");
}

.e1a-rel-prayer_beads {
  background-image: url("emojione/assets/4.5/png/128/1f4ff.png");
}

.e1a-barber {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f488.png");
}

.e1a-rel-barber {
  background-image: url("emojione/assets/4.5/png/128/1f488.png");
}

.e1a-test_tube {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ea.png");
}

.e1a-rel-test_tube {
  background-image: url("emojione/assets/4.5/png/128/1f9ea.png");
}

.e1a-petri_dish {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9eb.png");
}

.e1a-rel-petri_dish {
  background-image: url("emojione/assets/4.5/png/128/1f9eb.png");
}

.e1a-dna {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ec.png");
}

.e1a-rel-dna {
  background-image: url("emojione/assets/4.5/png/128/1f9ec.png");
}

.e1a-abacus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9ee.png");
}

.e1a-rel-abacus {
  background-image: url("emojione/assets/4.5/png/128/1f9ee.png");
}

.e1a-telescope {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52d.png");
}

.e1a-rel-telescope {
  background-image: url("emojione/assets/4.5/png/128/1f52d.png");
}

.e1a-microscope {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f52c.png");
}

.e1a-rel-microscope {
  background-image: url("emojione/assets/4.5/png/128/1f52c.png");
}

.e1a-hole {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f573.png");
}

.e1a-rel-hole {
  background-image: url("emojione/assets/4.5/png/128/1f573.png");
}

.e1a-pill {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48a.png");
}

.e1a-rel-pill {
  background-image: url("emojione/assets/4.5/png/128/1f48a.png");
}

.e1a-syringe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f489.png");
}

.e1a-rel-syringe {
  background-image: url("emojione/assets/4.5/png/128/1f489.png");
}

.e1a-thermometer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f321.png");
}

.e1a-rel-thermometer {
  background-image: url("emojione/assets/4.5/png/128/1f321.png");
}

.e1a-toilet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6bd.png");
}

.e1a-rel-toilet {
  background-image: url("emojione/assets/4.5/png/128/1f6bd.png");
}

.e1a-potable_water {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b0.png");
}

.e1a-rel-potable_water {
  background-image: url("emojione/assets/4.5/png/128/1f6b0.png");
}

.e1a-shower {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6bf.png");
}

.e1a-rel-shower {
  background-image: url("emojione/assets/4.5/png/128/1f6bf.png");
}

.e1a-bathtub {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c1.png");
}

.e1a-rel-bathtub {
  background-image: url("emojione/assets/4.5/png/128/1f6c1.png");
}

.e1a-bath {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0.png");
}

.e1a-rel-bath {
  background-image: url("emojione/assets/4.5/png/128/1f6c0.png");
}

.e1a-bath_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0-1f3fb.png");
}

.e1a-rel-bath_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6c0-1f3fb.png");
}

.e1a-bath_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0-1f3fc.png");
}

.e1a-rel-bath_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6c0-1f3fc.png");
}

.e1a-bath_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0-1f3fd.png");
}

.e1a-rel-bath_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6c0-1f3fd.png");
}

.e1a-bath_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0-1f3fe.png");
}

.e1a-rel-bath_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6c0-1f3fe.png");
}

.e1a-bath_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6c0-1f3ff.png");
}

.e1a-rel-bath_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6c0-1f3ff.png");
}

.e1a-broom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f9.png");
}

.e1a-rel-broom {
  background-image: url("emojione/assets/4.5/png/128/1f9f9.png");
}

.e1a-basket {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9fa.png");
}

.e1a-rel-basket {
  background-image: url("emojione/assets/4.5/png/128/1f9fa.png");
}

.e1a-roll_of_paper {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9fb.png");
}

.e1a-rel-roll_of_paper {
  background-image: url("emojione/assets/4.5/png/128/1f9fb.png");
}

.e1a-soap {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9fc.png");
}

.e1a-rel-soap {
  background-image: url("emojione/assets/4.5/png/128/1f9fc.png");
}

.e1a-sponge {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9fd.png");
}

.e1a-rel-sponge {
  background-image: url("emojione/assets/4.5/png/128/1f9fd.png");
}

.e1a-squeeze_bottle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f4.png");
}

.e1a-rel-squeeze_bottle {
  background-image: url("emojione/assets/4.5/png/128/1f9f4.png");
}

.e1a-thread {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f5.png");
}

.e1a-rel-thread {
  background-image: url("emojione/assets/4.5/png/128/1f9f5.png");
}

.e1a-yarn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f6.png");
}

.e1a-rel-yarn {
  background-image: url("emojione/assets/4.5/png/128/1f9f6.png");
}

.e1a-bellhop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ce.png");
}

.e1a-rel-bellhop {
  background-image: url("emojione/assets/4.5/png/128/1f6ce.png");
}

.e1a-key {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f511.png");
}

.e1a-rel-key {
  background-image: url("emojione/assets/4.5/png/128/1f511.png");
}

.e1a-key2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5dd.png");
}

.e1a-rel-key2 {
  background-image: url("emojione/assets/4.5/png/128/1f5dd.png");
}

.e1a-door {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6aa.png");
}

.e1a-rel-door {
  background-image: url("emojione/assets/4.5/png/128/1f6aa.png");
}

.e1a-couch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cb.png");
}

.e1a-rel-couch {
  background-image: url("emojione/assets/4.5/png/128/1f6cb.png");
}

.e1a-bed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cf.png");
}

.e1a-rel-bed {
  background-image: url("emojione/assets/4.5/png/128/1f6cf.png");
}

.e1a-sleeping_accommodation {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc.png");
}

.e1a-rel-sleeping_accommodation {
  background-image: url("emojione/assets/4.5/png/128/1f6cc.png");
}

.e1a-person_in_bed_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc-1f3fb.png");
}

.e1a-rel-person_in_bed_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6cc-1f3fb.png");
}

.e1a-person_in_bed_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc-1f3fc.png");
}

.e1a-rel-person_in_bed_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6cc-1f3fc.png");
}

.e1a-person_in_bed_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc-1f3fd.png");
}

.e1a-rel-person_in_bed_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6cc-1f3fd.png");
}

.e1a-person_in_bed_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc-1f3fe.png");
}

.e1a-rel-person_in_bed_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6cc-1f3fe.png");
}

.e1a-person_in_bed_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cc-1f3ff.png");
}

.e1a-rel-person_in_bed_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6cc-1f3ff.png");
}

.e1a-teddy_bear {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f8.png");
}

.e1a-rel-teddy_bear {
  background-image: url("emojione/assets/4.5/png/128/1f9f8.png");
}

.e1a-frame_photo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5bc.png");
}

.e1a-rel-frame_photo {
  background-image: url("emojione/assets/4.5/png/128/1f5bc.png");
}

.e1a-shopping_bags {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6cd.png");
}

.e1a-rel-shopping_bags {
  background-image: url("emojione/assets/4.5/png/128/1f6cd.png");
}

.e1a-shopping_cart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6d2.png");
}

.e1a-rel-shopping_cart {
  background-image: url("emojione/assets/4.5/png/128/1f6d2.png");
}

.e1a-gift {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f381.png");
}

.e1a-rel-gift {
  background-image: url("emojione/assets/4.5/png/128/1f381.png");
}

.e1a-balloon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f388.png");
}

.e1a-rel-balloon {
  background-image: url("emojione/assets/4.5/png/128/1f388.png");
}

.e1a-flags {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38f.png");
}

.e1a-rel-flags {
  background-image: url("emojione/assets/4.5/png/128/1f38f.png");
}

.e1a-ribbon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f380.png");
}

.e1a-rel-ribbon {
  background-image: url("emojione/assets/4.5/png/128/1f380.png");
}

.e1a-confetti_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38a.png");
}

.e1a-rel-confetti_ball {
  background-image: url("emojione/assets/4.5/png/128/1f38a.png");
}

.e1a-tada {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f389.png");
}

.e1a-rel-tada {
  background-image: url("emojione/assets/4.5/png/128/1f389.png");
}

.e1a-dolls {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38e.png");
}

.e1a-rel-dolls {
  background-image: url("emojione/assets/4.5/png/128/1f38e.png");
}

.e1a-izakaya_lantern {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ee.png");
}

.e1a-rel-izakaya_lantern {
  background-image: url("emojione/assets/4.5/png/128/1f3ee.png");
}

.e1a-wind_chime {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f390.png");
}

.e1a-rel-wind_chime {
  background-image: url("emojione/assets/4.5/png/128/1f390.png");
}

.e1a-red_envelope {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e7.png");
}

.e1a-rel-red_envelope {
  background-image: url("emojione/assets/4.5/png/128/1f9e7.png");
}

.e1a-envelope_with_arrow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e9.png");
}

.e1a-rel-envelope_with_arrow {
  background-image: url("emojione/assets/4.5/png/128/1f4e9.png");
}

.e1a-incoming_envelope {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e8.png");
}

.e1a-rel-incoming_envelope {
  background-image: url("emojione/assets/4.5/png/128/1f4e8.png");
}

.e1a-e-mail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e7.png");
}

.e1a-rel-e-mail {
  background-image: url("emojione/assets/4.5/png/128/1f4e7.png");
}

.e1a-love_letter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48c.png");
}

.e1a-rel-love_letter {
  background-image: url("emojione/assets/4.5/png/128/1f48c.png");
}

.e1a-inbox_tray {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e5.png");
}

.e1a-rel-inbox_tray {
  background-image: url("emojione/assets/4.5/png/128/1f4e5.png");
}

.e1a-outbox_tray {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e4.png");
}

.e1a-rel-outbox_tray {
  background-image: url("emojione/assets/4.5/png/128/1f4e4.png");
}

.e1a-package {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4e6.png");
}

.e1a-rel-package {
  background-image: url("emojione/assets/4.5/png/128/1f4e6.png");
}

.e1a-label {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f7.png");
}

.e1a-rel-label {
  background-image: url("emojione/assets/4.5/png/128/1f3f7.png");
}

.e1a-mailbox_closed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ea.png");
}

.e1a-rel-mailbox_closed {
  background-image: url("emojione/assets/4.5/png/128/1f4ea.png");
}

.e1a-mailbox {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4eb.png");
}

.e1a-rel-mailbox {
  background-image: url("emojione/assets/4.5/png/128/1f4eb.png");
}

.e1a-mailbox_with_mail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ec.png");
}

.e1a-rel-mailbox_with_mail {
  background-image: url("emojione/assets/4.5/png/128/1f4ec.png");
}

.e1a-mailbox_with_no_mail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ed.png");
}

.e1a-rel-mailbox_with_no_mail {
  background-image: url("emojione/assets/4.5/png/128/1f4ed.png");
}

.e1a-postbox {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ee.png");
}

.e1a-rel-postbox {
  background-image: url("emojione/assets/4.5/png/128/1f4ee.png");
}

.e1a-postal_horn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ef.png");
}

.e1a-rel-postal_horn {
  background-image: url("emojione/assets/4.5/png/128/1f4ef.png");
}

.e1a-scroll {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4dc.png");
}

.e1a-rel-scroll {
  background-image: url("emojione/assets/4.5/png/128/1f4dc.png");
}

.e1a-page_with_curl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c3.png");
}

.e1a-rel-page_with_curl {
  background-image: url("emojione/assets/4.5/png/128/1f4c3.png");
}

.e1a-page_facing_up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c4.png");
}

.e1a-rel-page_facing_up {
  background-image: url("emojione/assets/4.5/png/128/1f4c4.png");
}

.e1a-receipt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9fe.png");
}

.e1a-rel-receipt {
  background-image: url("emojione/assets/4.5/png/128/1f9fe.png");
}

.e1a-bookmark_tabs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d1.png");
}

.e1a-rel-bookmark_tabs {
  background-image: url("emojione/assets/4.5/png/128/1f4d1.png");
}

.e1a-bar_chart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ca.png");
}

.e1a-rel-bar_chart {
  background-image: url("emojione/assets/4.5/png/128/1f4ca.png");
}

.e1a-chart_with_upwards_trend {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c8.png");
}

.e1a-rel-chart_with_upwards_trend {
  background-image: url("emojione/assets/4.5/png/128/1f4c8.png");
}

.e1a-chart_with_downwards_trend {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c9.png");
}

.e1a-rel-chart_with_downwards_trend {
  background-image: url("emojione/assets/4.5/png/128/1f4c9.png");
}

.e1a-notepad_spiral {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5d2.png");
}

.e1a-rel-notepad_spiral {
  background-image: url("emojione/assets/4.5/png/128/1f5d2.png");
}

.e1a-calendar_spiral {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5d3.png");
}

.e1a-rel-calendar_spiral {
  background-image: url("emojione/assets/4.5/png/128/1f5d3.png");
}

.e1a-calendar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c6.png");
}

.e1a-rel-calendar {
  background-image: url("emojione/assets/4.5/png/128/1f4c6.png");
}

.e1a-date {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c5.png");
}

.e1a-rel-date {
  background-image: url("emojione/assets/4.5/png/128/1f4c5.png");
}

.e1a-card_index {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c7.png");
}

.e1a-rel-card_index {
  background-image: url("emojione/assets/4.5/png/128/1f4c7.png");
}

.e1a-card_box {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5c3.png");
}

.e1a-rel-card_box {
  background-image: url("emojione/assets/4.5/png/128/1f5c3.png");
}

.e1a-ballot_box {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5f3.png");
}

.e1a-rel-ballot_box {
  background-image: url("emojione/assets/4.5/png/128/1f5f3.png");
}

.e1a-file_cabinet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5c4.png");
}

.e1a-rel-file_cabinet {
  background-image: url("emojione/assets/4.5/png/128/1f5c4.png");
}

.e1a-clipboard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4cb.png");
}

.e1a-rel-clipboard {
  background-image: url("emojione/assets/4.5/png/128/1f4cb.png");
}

.e1a-file_folder {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c1.png");
}

.e1a-rel-file_folder {
  background-image: url("emojione/assets/4.5/png/128/1f4c1.png");
}

.e1a-open_file_folder {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4c2.png");
}

.e1a-rel-open_file_folder {
  background-image: url("emojione/assets/4.5/png/128/1f4c2.png");
}

.e1a-dividers {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5c2.png");
}

.e1a-rel-dividers {
  background-image: url("emojione/assets/4.5/png/128/1f5c2.png");
}

.e1a-newspaper2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5de.png");
}

.e1a-rel-newspaper2 {
  background-image: url("emojione/assets/4.5/png/128/1f5de.png");
}

.e1a-newspaper {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4f0.png");
}

.e1a-rel-newspaper {
  background-image: url("emojione/assets/4.5/png/128/1f4f0.png");
}

.e1a-notebook {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d3.png");
}

.e1a-rel-notebook {
  background-image: url("emojione/assets/4.5/png/128/1f4d3.png");
}

.e1a-notebook_with_decorative_cover {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d4.png");
}

.e1a-rel-notebook_with_decorative_cover {
  background-image: url("emojione/assets/4.5/png/128/1f4d4.png");
}

.e1a-ledger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d2.png");
}

.e1a-rel-ledger {
  background-image: url("emojione/assets/4.5/png/128/1f4d2.png");
}

.e1a-closed_book {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d5.png");
}

.e1a-rel-closed_book {
  background-image: url("emojione/assets/4.5/png/128/1f4d5.png");
}

.e1a-green_book {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d7.png");
}

.e1a-rel-green_book {
  background-image: url("emojione/assets/4.5/png/128/1f4d7.png");
}

.e1a-blue_book {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d8.png");
}

.e1a-rel-blue_book {
  background-image: url("emojione/assets/4.5/png/128/1f4d8.png");
}

.e1a-orange_book {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d9.png");
}

.e1a-rel-orange_book {
  background-image: url("emojione/assets/4.5/png/128/1f4d9.png");
}

.e1a-books {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4da.png");
}

.e1a-rel-books {
  background-image: url("emojione/assets/4.5/png/128/1f4da.png");
}

.e1a-book {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d6.png");
}

.e1a-rel-book {
  background-image: url("emojione/assets/4.5/png/128/1f4d6.png");
}

.e1a-bookmark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f516.png");
}

.e1a-rel-bookmark {
  background-image: url("emojione/assets/4.5/png/128/1f516.png");
}

.e1a-link {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f517.png");
}

.e1a-rel-link {
  background-image: url("emojione/assets/4.5/png/128/1f517.png");
}

.e1a-paperclip {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ce.png");
}

.e1a-rel-paperclip {
  background-image: url("emojione/assets/4.5/png/128/1f4ce.png");
}

.e1a-paperclips {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f587.png");
}

.e1a-rel-paperclips {
  background-image: url("emojione/assets/4.5/png/128/1f587.png");
}

.e1a-triangular_ruler {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4d0.png");
}

.e1a-rel-triangular_ruler {
  background-image: url("emojione/assets/4.5/png/128/1f4d0.png");
}

.e1a-straight_ruler {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4cf.png");
}

.e1a-rel-straight_ruler {
  background-image: url("emojione/assets/4.5/png/128/1f4cf.png");
}

.e1a-safety_pin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f7.png");
}

.e1a-rel-safety_pin {
  background-image: url("emojione/assets/4.5/png/128/1f9f7.png");
}

.e1a-pushpin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4cc.png");
}

.e1a-rel-pushpin {
  background-image: url("emojione/assets/4.5/png/128/1f4cc.png");
}

.e1a-round_pushpin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4cd.png");
}

.e1a-rel-round_pushpin {
  background-image: url("emojione/assets/4.5/png/128/1f4cd.png");
}

.e1a-pen_ballpoint {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f58a.png");
}

.e1a-rel-pen_ballpoint {
  background-image: url("emojione/assets/4.5/png/128/1f58a.png");
}

.e1a-pen_fountain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f58b.png");
}

.e1a-rel-pen_fountain {
  background-image: url("emojione/assets/4.5/png/128/1f58b.png");
}

.e1a-paintbrush {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f58c.png");
}

.e1a-rel-paintbrush {
  background-image: url("emojione/assets/4.5/png/128/1f58c.png");
}

.e1a-crayon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f58d.png");
}

.e1a-rel-crayon {
  background-image: url("emojione/assets/4.5/png/128/1f58d.png");
}

.e1a-pencil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4dd.png");
}

.e1a-rel-pencil {
  background-image: url("emojione/assets/4.5/png/128/1f4dd.png");
}

.e1a-pencil2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270f.png");
}

.e1a-rel-pencil2 {
  background-image: url("emojione/assets/4.5/png/128/270f.png");
}

.e1a-mag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50d.png");
}

.e1a-rel-mag {
  background-image: url("emojione/assets/4.5/png/128/1f50d.png");
}

.e1a-mag_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50e.png");
}

.e1a-rel-mag_right {
  background-image: url("emojione/assets/4.5/png/128/1f50e.png");
}

.e1a-lock_with_ink_pen {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f50f.png");
}

.e1a-rel-lock_with_ink_pen {
  background-image: url("emojione/assets/4.5/png/128/1f50f.png");
}

.e1a-closed_lock_with_key {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f510.png");
}

.e1a-rel-closed_lock_with_key {
  background-image: url("emojione/assets/4.5/png/128/1f510.png");
}

.e1a-dog {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f436.png");
}

.e1a-rel-dog {
  background-image: url("emojione/assets/4.5/png/128/1f436.png");
}

.e1a-cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f431.png");
}

.e1a-rel-cat {
  background-image: url("emojione/assets/4.5/png/128/1f431.png");
}

.e1a-mouse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42d.png");
}

.e1a-rel-mouse {
  background-image: url("emojione/assets/4.5/png/128/1f42d.png");
}

.e1a-hamster {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f439.png");
}

.e1a-rel-hamster {
  background-image: url("emojione/assets/4.5/png/128/1f439.png");
}

.e1a-rabbit {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f430.png");
}

.e1a-rel-rabbit {
  background-image: url("emojione/assets/4.5/png/128/1f430.png");
}

.e1a-fox {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98a.png");
}

.e1a-rel-fox {
  background-image: url("emojione/assets/4.5/png/128/1f98a.png");
}

.e1a-raccoon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99d.png");
}

.e1a-rel-raccoon {
  background-image: url("emojione/assets/4.5/png/128/1f99d.png");
}

.e1a-bear {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43b.png");
}

.e1a-rel-bear {
  background-image: url("emojione/assets/4.5/png/128/1f43b.png");
}

.e1a-panda_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43c.png");
}

.e1a-rel-panda_face {
  background-image: url("emojione/assets/4.5/png/128/1f43c.png");
}

.e1a-kangaroo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f998.png");
}

.e1a-rel-kangaroo {
  background-image: url("emojione/assets/4.5/png/128/1f998.png");
}

.e1a-badger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9a1.png");
}

.e1a-rel-badger {
  background-image: url("emojione/assets/4.5/png/128/1f9a1.png");
}

.e1a-koala {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f428.png");
}

.e1a-rel-koala {
  background-image: url("emojione/assets/4.5/png/128/1f428.png");
}

.e1a-tiger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42f.png");
}

.e1a-rel-tiger {
  background-image: url("emojione/assets/4.5/png/128/1f42f.png");
}

.e1a-lion_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f981.png");
}

.e1a-rel-lion_face {
  background-image: url("emojione/assets/4.5/png/128/1f981.png");
}

.e1a-cow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42e.png");
}

.e1a-rel-cow {
  background-image: url("emojione/assets/4.5/png/128/1f42e.png");
}

.e1a-pig {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f437.png");
}

.e1a-rel-pig {
  background-image: url("emojione/assets/4.5/png/128/1f437.png");
}

.e1a-pig_nose {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43d.png");
}

.e1a-rel-pig_nose {
  background-image: url("emojione/assets/4.5/png/128/1f43d.png");
}

.e1a-frog {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f438.png");
}

.e1a-rel-frog {
  background-image: url("emojione/assets/4.5/png/128/1f438.png");
}

.e1a-monkey_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f435.png");
}

.e1a-rel-monkey_face {
  background-image: url("emojione/assets/4.5/png/128/1f435.png");
}

.e1a-see_no_evil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f648.png");
}

.e1a-rel-see_no_evil {
  background-image: url("emojione/assets/4.5/png/128/1f648.png");
}

.e1a-hear_no_evil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f649.png");
}

.e1a-rel-hear_no_evil {
  background-image: url("emojione/assets/4.5/png/128/1f649.png");
}

.e1a-speak_no_evil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64a.png");
}

.e1a-rel-speak_no_evil {
  background-image: url("emojione/assets/4.5/png/128/1f64a.png");
}

.e1a-monkey {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f412.png");
}

.e1a-rel-monkey {
  background-image: url("emojione/assets/4.5/png/128/1f412.png");
}

.e1a-chicken {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f414.png");
}

.e1a-rel-chicken {
  background-image: url("emojione/assets/4.5/png/128/1f414.png");
}

.e1a-penguin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f427.png");
}

.e1a-rel-penguin {
  background-image: url("emojione/assets/4.5/png/128/1f427.png");
}

.e1a-bird {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f426.png");
}

.e1a-rel-bird {
  background-image: url("emojione/assets/4.5/png/128/1f426.png");
}

.e1a-baby_chick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f424.png");
}

.e1a-rel-baby_chick {
  background-image: url("emojione/assets/4.5/png/128/1f424.png");
}

.e1a-hatching_chick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f423.png");
}

.e1a-rel-hatching_chick {
  background-image: url("emojione/assets/4.5/png/128/1f423.png");
}

.e1a-hatched_chick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f425.png");
}

.e1a-rel-hatched_chick {
  background-image: url("emojione/assets/4.5/png/128/1f425.png");
}

.e1a-duck {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f986.png");
}

.e1a-rel-duck {
  background-image: url("emojione/assets/4.5/png/128/1f986.png");
}

.e1a-swan {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9a2.png");
}

.e1a-rel-swan {
  background-image: url("emojione/assets/4.5/png/128/1f9a2.png");
}

.e1a-eagle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f985.png");
}

.e1a-rel-eagle {
  background-image: url("emojione/assets/4.5/png/128/1f985.png");
}

.e1a-owl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f989.png");
}

.e1a-rel-owl {
  background-image: url("emojione/assets/4.5/png/128/1f989.png");
}

.e1a-parrot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99c.png");
}

.e1a-rel-parrot {
  background-image: url("emojione/assets/4.5/png/128/1f99c.png");
}

.e1a-peacock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99a.png");
}

.e1a-rel-peacock {
  background-image: url("emojione/assets/4.5/png/128/1f99a.png");
}

.e1a-bat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f987.png");
}

.e1a-rel-bat {
  background-image: url("emojione/assets/4.5/png/128/1f987.png");
}

.e1a-wolf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43a.png");
}

.e1a-rel-wolf {
  background-image: url("emojione/assets/4.5/png/128/1f43a.png");
}

.e1a-boar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f417.png");
}

.e1a-rel-boar {
  background-image: url("emojione/assets/4.5/png/128/1f417.png");
}

.e1a-horse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f434.png");
}

.e1a-rel-horse {
  background-image: url("emojione/assets/4.5/png/128/1f434.png");
}

.e1a-unicorn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f984.png");
}

.e1a-rel-unicorn {
  background-image: url("emojione/assets/4.5/png/128/1f984.png");
}

.e1a-bee {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41d.png");
}

.e1a-rel-bee {
  background-image: url("emojione/assets/4.5/png/128/1f41d.png");
}

.e1a-bug {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41b.png");
}

.e1a-rel-bug {
  background-image: url("emojione/assets/4.5/png/128/1f41b.png");
}

.e1a-butterfly {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98b.png");
}

.e1a-rel-butterfly {
  background-image: url("emojione/assets/4.5/png/128/1f98b.png");
}

.e1a-snail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40c.png");
}

.e1a-rel-snail {
  background-image: url("emojione/assets/4.5/png/128/1f40c.png");
}

.e1a-shell {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41a.png");
}

.e1a-rel-shell {
  background-image: url("emojione/assets/4.5/png/128/1f41a.png");
}

.e1a-beetle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41e.png");
}

.e1a-rel-beetle {
  background-image: url("emojione/assets/4.5/png/128/1f41e.png");
}

.e1a-ant {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41c.png");
}

.e1a-rel-ant {
  background-image: url("emojione/assets/4.5/png/128/1f41c.png");
}

.e1a-cricket {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f997.png");
}

.e1a-rel-cricket {
  background-image: url("emojione/assets/4.5/png/128/1f997.png");
}

.e1a-spider {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f577.png");
}

.e1a-rel-spider {
  background-image: url("emojione/assets/4.5/png/128/1f577.png");
}

.e1a-spider_web {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f578.png");
}

.e1a-rel-spider_web {
  background-image: url("emojione/assets/4.5/png/128/1f578.png");
}

.e1a-scorpion {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f982.png");
}

.e1a-rel-scorpion {
  background-image: url("emojione/assets/4.5/png/128/1f982.png");
}

.e1a-mosquito {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99f.png");
}

.e1a-rel-mosquito {
  background-image: url("emojione/assets/4.5/png/128/1f99f.png");
}

.e1a-microbe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9a0.png");
}

.e1a-rel-microbe {
  background-image: url("emojione/assets/4.5/png/128/1f9a0.png");
}

.e1a-turtle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f422.png");
}

.e1a-rel-turtle {
  background-image: url("emojione/assets/4.5/png/128/1f422.png");
}

.e1a-snake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40d.png");
}

.e1a-rel-snake {
  background-image: url("emojione/assets/4.5/png/128/1f40d.png");
}

.e1a-lizard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98e.png");
}

.e1a-rel-lizard {
  background-image: url("emojione/assets/4.5/png/128/1f98e.png");
}

.e1a-t_rex {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f996.png");
}

.e1a-rel-t_rex {
  background-image: url("emojione/assets/4.5/png/128/1f996.png");
}

.e1a-sauropod {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f995.png");
}

.e1a-rel-sauropod {
  background-image: url("emojione/assets/4.5/png/128/1f995.png");
}

.e1a-octopus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f419.png");
}

.e1a-rel-octopus {
  background-image: url("emojione/assets/4.5/png/128/1f419.png");
}

.e1a-squid {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f991.png");
}

.e1a-rel-squid {
  background-image: url("emojione/assets/4.5/png/128/1f991.png");
}

.e1a-shrimp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f990.png");
}

.e1a-rel-shrimp {
  background-image: url("emojione/assets/4.5/png/128/1f990.png");
}

.e1a-crab {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f980.png");
}

.e1a-rel-crab {
  background-image: url("emojione/assets/4.5/png/128/1f980.png");
}

.e1a-lobster {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99e.png");
}

.e1a-rel-lobster {
  background-image: url("emojione/assets/4.5/png/128/1f99e.png");
}

.e1a-blowfish {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f421.png");
}

.e1a-rel-blowfish {
  background-image: url("emojione/assets/4.5/png/128/1f421.png");
}

.e1a-tropical_fish {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f420.png");
}

.e1a-rel-tropical_fish {
  background-image: url("emojione/assets/4.5/png/128/1f420.png");
}

.e1a-fish {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f41f.png");
}

.e1a-rel-fish {
  background-image: url("emojione/assets/4.5/png/128/1f41f.png");
}

.e1a-dolphin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42c.png");
}

.e1a-rel-dolphin {
  background-image: url("emojione/assets/4.5/png/128/1f42c.png");
}

.e1a-whale {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f433.png");
}

.e1a-rel-whale {
  background-image: url("emojione/assets/4.5/png/128/1f433.png");
}

.e1a-whale2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40b.png");
}

.e1a-rel-whale2 {
  background-image: url("emojione/assets/4.5/png/128/1f40b.png");
}

.e1a-shark {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f988.png");
}

.e1a-rel-shark {
  background-image: url("emojione/assets/4.5/png/128/1f988.png");
}

.e1a-crocodile {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40a.png");
}

.e1a-rel-crocodile {
  background-image: url("emojione/assets/4.5/png/128/1f40a.png");
}

.e1a-tiger2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f405.png");
}

.e1a-rel-tiger2 {
  background-image: url("emojione/assets/4.5/png/128/1f405.png");
}

.e1a-leopard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f406.png");
}

.e1a-rel-leopard {
  background-image: url("emojione/assets/4.5/png/128/1f406.png");
}

.e1a-zebra {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f993.png");
}

.e1a-rel-zebra {
  background-image: url("emojione/assets/4.5/png/128/1f993.png");
}

.e1a-gorilla {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98d.png");
}

.e1a-rel-gorilla {
  background-image: url("emojione/assets/4.5/png/128/1f98d.png");
}

.e1a-elephant {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f418.png");
}

.e1a-rel-elephant {
  background-image: url("emojione/assets/4.5/png/128/1f418.png");
}

.e1a-rhino {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98f.png");
}

.e1a-rel-rhino {
  background-image: url("emojione/assets/4.5/png/128/1f98f.png");
}

.e1a-hippopotamus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f99b.png");
}

.e1a-rel-hippopotamus {
  background-image: url("emojione/assets/4.5/png/128/1f99b.png");
}

.e1a-dromedary_camel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42a.png");
}

.e1a-rel-dromedary_camel {
  background-image: url("emojione/assets/4.5/png/128/1f42a.png");
}

.e1a-camel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f42b.png");
}

.e1a-rel-camel {
  background-image: url("emojione/assets/4.5/png/128/1f42b.png");
}

.e1a-giraffe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f992.png");
}

.e1a-rel-giraffe {
  background-image: url("emojione/assets/4.5/png/128/1f992.png");
}

.e1a-llama {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f999.png");
}

.e1a-rel-llama {
  background-image: url("emojione/assets/4.5/png/128/1f999.png");
}

.e1a-water_buffalo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f403.png");
}

.e1a-rel-water_buffalo {
  background-image: url("emojione/assets/4.5/png/128/1f403.png");
}

.e1a-ox {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f402.png");
}

.e1a-rel-ox {
  background-image: url("emojione/assets/4.5/png/128/1f402.png");
}

.e1a-cow2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f404.png");
}

.e1a-rel-cow2 {
  background-image: url("emojione/assets/4.5/png/128/1f404.png");
}

.e1a-racehorse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40e.png");
}

.e1a-rel-racehorse {
  background-image: url("emojione/assets/4.5/png/128/1f40e.png");
}

.e1a-pig2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f416.png");
}

.e1a-rel-pig2 {
  background-image: url("emojione/assets/4.5/png/128/1f416.png");
}

.e1a-ram {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f40f.png");
}

.e1a-rel-ram {
  background-image: url("emojione/assets/4.5/png/128/1f40f.png");
}

.e1a-sheep {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f411.png");
}

.e1a-rel-sheep {
  background-image: url("emojione/assets/4.5/png/128/1f411.png");
}

.e1a-goat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f410.png");
}

.e1a-rel-goat {
  background-image: url("emojione/assets/4.5/png/128/1f410.png");
}

.e1a-deer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f98c.png");
}

.e1a-rel-deer {
  background-image: url("emojione/assets/4.5/png/128/1f98c.png");
}

.e1a-dog2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f415.png");
}

.e1a-rel-dog2 {
  background-image: url("emojione/assets/4.5/png/128/1f415.png");
}

.e1a-poodle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f429.png");
}

.e1a-rel-poodle {
  background-image: url("emojione/assets/4.5/png/128/1f429.png");
}

.e1a-cat2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f408.png");
}

.e1a-rel-cat2 {
  background-image: url("emojione/assets/4.5/png/128/1f408.png");
}

.e1a-rooster {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f413.png");
}

.e1a-rel-rooster {
  background-image: url("emojione/assets/4.5/png/128/1f413.png");
}

.e1a-turkey {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f983.png");
}

.e1a-rel-turkey {
  background-image: url("emojione/assets/4.5/png/128/1f983.png");
}

.e1a-dove {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f54a.png");
}

.e1a-rel-dove {
  background-image: url("emojione/assets/4.5/png/128/1f54a.png");
}

.e1a-rabbit2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f407.png");
}

.e1a-rel-rabbit2 {
  background-image: url("emojione/assets/4.5/png/128/1f407.png");
}

.e1a-mouse2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f401.png");
}

.e1a-rel-mouse2 {
  background-image: url("emojione/assets/4.5/png/128/1f401.png");
}

.e1a-rat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f400.png");
}

.e1a-rel-rat {
  background-image: url("emojione/assets/4.5/png/128/1f400.png");
}

.e1a-chipmunk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43f.png");
}

.e1a-rel-chipmunk {
  background-image: url("emojione/assets/4.5/png/128/1f43f.png");
}

.e1a-hedgehog {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f994.png");
}

.e1a-rel-hedgehog {
  background-image: url("emojione/assets/4.5/png/128/1f994.png");
}

.e1a-feet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f43e.png");
}

.e1a-rel-feet {
  background-image: url("emojione/assets/4.5/png/128/1f43e.png");
}

.e1a-dragon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f409.png");
}

.e1a-rel-dragon {
  background-image: url("emojione/assets/4.5/png/128/1f409.png");
}

.e1a-dragon_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f432.png");
}

.e1a-rel-dragon_face {
  background-image: url("emojione/assets/4.5/png/128/1f432.png");
}

.e1a-cactus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f335.png");
}

.e1a-rel-cactus {
  background-image: url("emojione/assets/4.5/png/128/1f335.png");
}

.e1a-christmas_tree {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f384.png");
}

.e1a-rel-christmas_tree {
  background-image: url("emojione/assets/4.5/png/128/1f384.png");
}

.e1a-evergreen_tree {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f332.png");
}

.e1a-rel-evergreen_tree {
  background-image: url("emojione/assets/4.5/png/128/1f332.png");
}

.e1a-deciduous_tree {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f333.png");
}

.e1a-rel-deciduous_tree {
  background-image: url("emojione/assets/4.5/png/128/1f333.png");
}

.e1a-palm_tree {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f334.png");
}

.e1a-rel-palm_tree {
  background-image: url("emojione/assets/4.5/png/128/1f334.png");
}

.e1a-seedling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f331.png");
}

.e1a-rel-seedling {
  background-image: url("emojione/assets/4.5/png/128/1f331.png");
}

.e1a-herb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33f.png");
}

.e1a-rel-herb {
  background-image: url("emojione/assets/4.5/png/128/1f33f.png");
}

.e1a-four_leaf_clover {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f340.png");
}

.e1a-rel-four_leaf_clover {
  background-image: url("emojione/assets/4.5/png/128/1f340.png");
}

.e1a-bamboo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38d.png");
}

.e1a-rel-bamboo {
  background-image: url("emojione/assets/4.5/png/128/1f38d.png");
}

.e1a-tanabata_tree {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38b.png");
}

.e1a-rel-tanabata_tree {
  background-image: url("emojione/assets/4.5/png/128/1f38b.png");
}

.e1a-leaves {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f343.png");
}

.e1a-rel-leaves {
  background-image: url("emojione/assets/4.5/png/128/1f343.png");
}

.e1a-fallen_leaf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f342.png");
}

.e1a-rel-fallen_leaf {
  background-image: url("emojione/assets/4.5/png/128/1f342.png");
}

.e1a-maple_leaf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f341.png");
}

.e1a-rel-maple_leaf {
  background-image: url("emojione/assets/4.5/png/128/1f341.png");
}

.e1a-mushroom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f344.png");
}

.e1a-rel-mushroom {
  background-image: url("emojione/assets/4.5/png/128/1f344.png");
}

.e1a-ear_of_rice {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33e.png");
}

.e1a-rel-ear_of_rice {
  background-image: url("emojione/assets/4.5/png/128/1f33e.png");
}

.e1a-bouquet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f490.png");
}

.e1a-rel-bouquet {
  background-image: url("emojione/assets/4.5/png/128/1f490.png");
}

.e1a-tulip {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f337.png");
}

.e1a-rel-tulip {
  background-image: url("emojione/assets/4.5/png/128/1f337.png");
}

.e1a-rose {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f339.png");
}

.e1a-rel-rose {
  background-image: url("emojione/assets/4.5/png/128/1f339.png");
}

.e1a-wilted_rose {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f940.png");
}

.e1a-rel-wilted_rose {
  background-image: url("emojione/assets/4.5/png/128/1f940.png");
}

.e1a-hibiscus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33a.png");
}

.e1a-rel-hibiscus {
  background-image: url("emojione/assets/4.5/png/128/1f33a.png");
}

.e1a-cherry_blossom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f338.png");
}

.e1a-rel-cherry_blossom {
  background-image: url("emojione/assets/4.5/png/128/1f338.png");
}

.e1a-blossom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33c.png");
}

.e1a-rel-blossom {
  background-image: url("emojione/assets/4.5/png/128/1f33c.png");
}

.e1a-sunflower {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33b.png");
}

.e1a-rel-sunflower {
  background-image: url("emojione/assets/4.5/png/128/1f33b.png");
}

.e1a-sun_with_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31e.png");
}

.e1a-rel-sun_with_face {
  background-image: url("emojione/assets/4.5/png/128/1f31e.png");
}

.e1a-full_moon_with_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31d.png");
}

.e1a-rel-full_moon_with_face {
  background-image: url("emojione/assets/4.5/png/128/1f31d.png");
}

.e1a-first_quarter_moon_with_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31b.png");
}

.e1a-rel-first_quarter_moon_with_face {
  background-image: url("emojione/assets/4.5/png/128/1f31b.png");
}

.e1a-last_quarter_moon_with_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31c.png");
}

.e1a-rel-last_quarter_moon_with_face {
  background-image: url("emojione/assets/4.5/png/128/1f31c.png");
}

.e1a-new_moon_with_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31a.png");
}

.e1a-rel-new_moon_with_face {
  background-image: url("emojione/assets/4.5/png/128/1f31a.png");
}

.e1a-full_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f315.png");
}

.e1a-rel-full_moon {
  background-image: url("emojione/assets/4.5/png/128/1f315.png");
}

.e1a-waning_gibbous_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f316.png");
}

.e1a-rel-waning_gibbous_moon {
  background-image: url("emojione/assets/4.5/png/128/1f316.png");
}

.e1a-last_quarter_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f317.png");
}

.e1a-rel-last_quarter_moon {
  background-image: url("emojione/assets/4.5/png/128/1f317.png");
}

.e1a-waning_crescent_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f318.png");
}

.e1a-rel-waning_crescent_moon {
  background-image: url("emojione/assets/4.5/png/128/1f318.png");
}

.e1a-new_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f311.png");
}

.e1a-rel-new_moon {
  background-image: url("emojione/assets/4.5/png/128/1f311.png");
}

.e1a-waxing_crescent_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f312.png");
}

.e1a-rel-waxing_crescent_moon {
  background-image: url("emojione/assets/4.5/png/128/1f312.png");
}

.e1a-first_quarter_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f313.png");
}

.e1a-rel-first_quarter_moon {
  background-image: url("emojione/assets/4.5/png/128/1f313.png");
}

.e1a-waxing_gibbous_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f314.png");
}

.e1a-rel-waxing_gibbous_moon {
  background-image: url("emojione/assets/4.5/png/128/1f314.png");
}

.e1a-crescent_moon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f319.png");
}

.e1a-rel-crescent_moon {
  background-image: url("emojione/assets/4.5/png/128/1f319.png");
}

.e1a-earth_americas {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30e.png");
}

.e1a-rel-earth_americas {
  background-image: url("emojione/assets/4.5/png/128/1f30e.png");
}

.e1a-earth_africa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30d.png");
}

.e1a-rel-earth_africa {
  background-image: url("emojione/assets/4.5/png/128/1f30d.png");
}

.e1a-earth_asia {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30f.png");
}

.e1a-rel-earth_asia {
  background-image: url("emojione/assets/4.5/png/128/1f30f.png");
}

.e1a-dizzy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ab.png");
}

.e1a-rel-dizzy {
  background-image: url("emojione/assets/4.5/png/128/1f4ab.png");
}

.e1a-star {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/2b50.png");
}

.e1a-rel-star {
  background-image: url("emojione/assets/4.5/png/128/2b50.png");
}

.e1a-star2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f31f.png");
}

.e1a-rel-star2 {
  background-image: url("emojione/assets/4.5/png/128/1f31f.png");
}

.e1a-zap {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26a1.png");
}

.e1a-rel-zap {
  background-image: url("emojione/assets/4.5/png/128/26a1.png");
}

.e1a-boom {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a5.png");
}

.e1a-rel-boom {
  background-image: url("emojione/assets/4.5/png/128/1f4a5.png");
}

.e1a-fire {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f525.png");
}

.e1a-rel-fire {
  background-image: url("emojione/assets/4.5/png/128/1f525.png");
}

.e1a-cloud_tornado {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32a.png");
}

.e1a-rel-cloud_tornado {
  background-image: url("emojione/assets/4.5/png/128/1f32a.png");
}

.e1a-rainbow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f308.png");
}

.e1a-rel-rainbow {
  background-image: url("emojione/assets/4.5/png/128/1f308.png");
}

.e1a-white_sun_small_cloud {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f324.png");
}

.e1a-rel-white_sun_small_cloud {
  background-image: url("emojione/assets/4.5/png/128/1f324.png");
}

.e1a-partly_sunny {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26c5.png");
}

.e1a-rel-partly_sunny {
  background-image: url("emojione/assets/4.5/png/128/26c5.png");
}

.e1a-white_sun_cloud {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f325.png");
}

.e1a-rel-white_sun_cloud {
  background-image: url("emojione/assets/4.5/png/128/1f325.png");
}

.e1a-white_sun_rain_cloud {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f326.png");
}

.e1a-rel-white_sun_rain_cloud {
  background-image: url("emojione/assets/4.5/png/128/1f326.png");
}

.e1a-cloud_rain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f327.png");
}

.e1a-rel-cloud_rain {
  background-image: url("emojione/assets/4.5/png/128/1f327.png");
}

.e1a-thunder_cloud_rain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26c8.png");
}

.e1a-rel-thunder_cloud_rain {
  background-image: url("emojione/assets/4.5/png/128/26c8.png");
}

.e1a-cloud_lightning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f329.png");
}

.e1a-rel-cloud_lightning {
  background-image: url("emojione/assets/4.5/png/128/1f329.png");
}

.e1a-cloud_snow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f328.png");
}

.e1a-rel-cloud_snow {
  background-image: url("emojione/assets/4.5/png/128/1f328.png");
}

.e1a-snowman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26c4.png");
}

.e1a-rel-snowman {
  background-image: url("emojione/assets/4.5/png/128/26c4.png");
}

.e1a-wind_blowing_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32c.png");
}

.e1a-rel-wind_blowing_face {
  background-image: url("emojione/assets/4.5/png/128/1f32c.png");
}

.e1a-dash {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a8.png");
}

.e1a-rel-dash {
  background-image: url("emojione/assets/4.5/png/128/1f4a8.png");
}

.e1a-droplet {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a7.png");
}

.e1a-rel-droplet {
  background-image: url("emojione/assets/4.5/png/128/1f4a7.png");
}

.e1a-sweat_drops {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a6.png");
}

.e1a-rel-sweat_drops {
  background-image: url("emojione/assets/4.5/png/128/1f4a6.png");
}

.e1a-ocean {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30a.png");
}

.e1a-rel-ocean {
  background-image: url("emojione/assets/4.5/png/128/1f30a.png");
}

.e1a-fog {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32b.png");
}

.e1a-rel-fog {
  background-image: url("emojione/assets/4.5/png/128/1f32b.png");
}

.e1a-green_apple {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34f.png");
}

.e1a-rel-green_apple {
  background-image: url("emojione/assets/4.5/png/128/1f34f.png");
}

.e1a-apple {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34e.png");
}

.e1a-rel-apple {
  background-image: url("emojione/assets/4.5/png/128/1f34e.png");
}

.e1a-pear {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f350.png");
}

.e1a-rel-pear {
  background-image: url("emojione/assets/4.5/png/128/1f350.png");
}

.e1a-tangerine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34a.png");
}

.e1a-rel-tangerine {
  background-image: url("emojione/assets/4.5/png/128/1f34a.png");
}

.e1a-lemon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34b.png");
}

.e1a-rel-lemon {
  background-image: url("emojione/assets/4.5/png/128/1f34b.png");
}

.e1a-banana {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34c.png");
}

.e1a-rel-banana {
  background-image: url("emojione/assets/4.5/png/128/1f34c.png");
}

.e1a-watermelon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f349.png");
}

.e1a-rel-watermelon {
  background-image: url("emojione/assets/4.5/png/128/1f349.png");
}

.e1a-grapes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f347.png");
}

.e1a-rel-grapes {
  background-image: url("emojione/assets/4.5/png/128/1f347.png");
}

.e1a-strawberry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f353.png");
}

.e1a-rel-strawberry {
  background-image: url("emojione/assets/4.5/png/128/1f353.png");
}

.e1a-melon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f348.png");
}

.e1a-rel-melon {
  background-image: url("emojione/assets/4.5/png/128/1f348.png");
}

.e1a-cherries {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f352.png");
}

.e1a-rel-cherries {
  background-image: url("emojione/assets/4.5/png/128/1f352.png");
}

.e1a-peach {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f351.png");
}

.e1a-rel-peach {
  background-image: url("emojione/assets/4.5/png/128/1f351.png");
}

.e1a-mango {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96d.png");
}

.e1a-rel-mango {
  background-image: url("emojione/assets/4.5/png/128/1f96d.png");
}

.e1a-pineapple {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f34d.png");
}

.e1a-rel-pineapple {
  background-image: url("emojione/assets/4.5/png/128/1f34d.png");
}

.e1a-coconut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f965.png");
}

.e1a-rel-coconut {
  background-image: url("emojione/assets/4.5/png/128/1f965.png");
}

.e1a-kiwi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95d.png");
}

.e1a-rel-kiwi {
  background-image: url("emojione/assets/4.5/png/128/1f95d.png");
}

.e1a-tomato {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f345.png");
}

.e1a-rel-tomato {
  background-image: url("emojione/assets/4.5/png/128/1f345.png");
}

.e1a-eggplant {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f346.png");
}

.e1a-rel-eggplant {
  background-image: url("emojione/assets/4.5/png/128/1f346.png");
}

.e1a-avocado {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f951.png");
}

.e1a-rel-avocado {
  background-image: url("emojione/assets/4.5/png/128/1f951.png");
}

.e1a-broccoli {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f966.png");
}

.e1a-rel-broccoli {
  background-image: url("emojione/assets/4.5/png/128/1f966.png");
}

.e1a-leafy_green {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96c.png");
}

.e1a-rel-leafy_green {
  background-image: url("emojione/assets/4.5/png/128/1f96c.png");
}

.e1a-cucumber {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f952.png");
}

.e1a-rel-cucumber {
  background-image: url("emojione/assets/4.5/png/128/1f952.png");
}

.e1a-hot_pepper {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f336.png");
}

.e1a-rel-hot_pepper {
  background-image: url("emojione/assets/4.5/png/128/1f336.png");
}

.e1a-corn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f33d.png");
}

.e1a-rel-corn {
  background-image: url("emojione/assets/4.5/png/128/1f33d.png");
}

.e1a-carrot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f955.png");
}

.e1a-rel-carrot {
  background-image: url("emojione/assets/4.5/png/128/1f955.png");
}

.e1a-potato {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f954.png");
}

.e1a-rel-potato {
  background-image: url("emojione/assets/4.5/png/128/1f954.png");
}

.e1a-sweet_potato {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f360.png");
}

.e1a-rel-sweet_potato {
  background-image: url("emojione/assets/4.5/png/128/1f360.png");
}

.e1a-croissant {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f950.png");
}

.e1a-rel-croissant {
  background-image: url("emojione/assets/4.5/png/128/1f950.png");
}

.e1a-bread {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35e.png");
}

.e1a-rel-bread {
  background-image: url("emojione/assets/4.5/png/128/1f35e.png");
}

.e1a-french_bread {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f956.png");
}

.e1a-rel-french_bread {
  background-image: url("emojione/assets/4.5/png/128/1f956.png");
}

.e1a-pretzel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f968.png");
}

.e1a-rel-pretzel {
  background-image: url("emojione/assets/4.5/png/128/1f968.png");
}

.e1a-bagel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96f.png");
}

.e1a-rel-bagel {
  background-image: url("emojione/assets/4.5/png/128/1f96f.png");
}

.e1a-cheese {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9c0.png");
}

.e1a-rel-cheese {
  background-image: url("emojione/assets/4.5/png/128/1f9c0.png");
}

.e1a-egg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95a.png");
}

.e1a-rel-egg {
  background-image: url("emojione/assets/4.5/png/128/1f95a.png");
}

.e1a-cooking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f373.png");
}

.e1a-rel-cooking {
  background-image: url("emojione/assets/4.5/png/128/1f373.png");
}

.e1a-pancakes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95e.png");
}

.e1a-rel-pancakes {
  background-image: url("emojione/assets/4.5/png/128/1f95e.png");
}

.e1a-bacon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f953.png");
}

.e1a-rel-bacon {
  background-image: url("emojione/assets/4.5/png/128/1f953.png");
}

.e1a-cut_of_meat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f969.png");
}

.e1a-rel-cut_of_meat {
  background-image: url("emojione/assets/4.5/png/128/1f969.png");
}

.e1a-poultry_leg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f357.png");
}

.e1a-rel-poultry_leg {
  background-image: url("emojione/assets/4.5/png/128/1f357.png");
}

.e1a-meat_on_bone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f356.png");
}

.e1a-rel-meat_on_bone {
  background-image: url("emojione/assets/4.5/png/128/1f356.png");
}

.e1a-hotdog {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32d.png");
}

.e1a-rel-hotdog {
  background-image: url("emojione/assets/4.5/png/128/1f32d.png");
}

.e1a-hamburger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f354.png");
}

.e1a-rel-hamburger {
  background-image: url("emojione/assets/4.5/png/128/1f354.png");
}

.e1a-fries {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35f.png");
}

.e1a-rel-fries {
  background-image: url("emojione/assets/4.5/png/128/1f35f.png");
}

.e1a-pizza {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f355.png");
}

.e1a-rel-pizza {
  background-image: url("emojione/assets/4.5/png/128/1f355.png");
}

.e1a-sandwich {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96a.png");
}

.e1a-rel-sandwich {
  background-image: url("emojione/assets/4.5/png/128/1f96a.png");
}

.e1a-stuffed_flatbread {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f959.png");
}

.e1a-rel-stuffed_flatbread {
  background-image: url("emojione/assets/4.5/png/128/1f959.png");
}

.e1a-taco {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32e.png");
}

.e1a-rel-taco {
  background-image: url("emojione/assets/4.5/png/128/1f32e.png");
}

.e1a-burrito {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f32f.png");
}

.e1a-rel-burrito {
  background-image: url("emojione/assets/4.5/png/128/1f32f.png");
}

.e1a-salad {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f957.png");
}

.e1a-rel-salad {
  background-image: url("emojione/assets/4.5/png/128/1f957.png");
}

.e1a-shallow_pan_of_food {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f958.png");
}

.e1a-rel-shallow_pan_of_food {
  background-image: url("emojione/assets/4.5/png/128/1f958.png");
}

.e1a-canned_food {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96b.png");
}

.e1a-rel-canned_food {
  background-image: url("emojione/assets/4.5/png/128/1f96b.png");
}

.e1a-spaghetti {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35d.png");
}

.e1a-rel-spaghetti {
  background-image: url("emojione/assets/4.5/png/128/1f35d.png");
}

.e1a-ramen {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35c.png");
}

.e1a-rel-ramen {
  background-image: url("emojione/assets/4.5/png/128/1f35c.png");
}

.e1a-stew {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f372.png");
}

.e1a-rel-stew {
  background-image: url("emojione/assets/4.5/png/128/1f372.png");
}

.e1a-curry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35b.png");
}

.e1a-rel-curry {
  background-image: url("emojione/assets/4.5/png/128/1f35b.png");
}

.e1a-sushi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f363.png");
}

.e1a-rel-sushi {
  background-image: url("emojione/assets/4.5/png/128/1f363.png");
}

.e1a-bento {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f371.png");
}

.e1a-rel-bento {
  background-image: url("emojione/assets/4.5/png/128/1f371.png");
}

.e1a-fried_shrimp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f364.png");
}

.e1a-rel-fried_shrimp {
  background-image: url("emojione/assets/4.5/png/128/1f364.png");
}

.e1a-rice_ball {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f359.png");
}

.e1a-rel-rice_ball {
  background-image: url("emojione/assets/4.5/png/128/1f359.png");
}

.e1a-rice {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f35a.png");
}

.e1a-rel-rice {
  background-image: url("emojione/assets/4.5/png/128/1f35a.png");
}

.e1a-rice_cracker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f358.png");
}

.e1a-rel-rice_cracker {
  background-image: url("emojione/assets/4.5/png/128/1f358.png");
}

.e1a-fish_cake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f365.png");
}

.e1a-rel-fish_cake {
  background-image: url("emojione/assets/4.5/png/128/1f365.png");
}

.e1a-fortune_cookie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f960.png");
}

.e1a-rel-fortune_cookie {
  background-image: url("emojione/assets/4.5/png/128/1f960.png");
}

.e1a-oden {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f362.png");
}

.e1a-rel-oden {
  background-image: url("emojione/assets/4.5/png/128/1f362.png");
}

.e1a-dango {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f361.png");
}

.e1a-rel-dango {
  background-image: url("emojione/assets/4.5/png/128/1f361.png");
}

.e1a-shaved_ice {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f367.png");
}

.e1a-rel-shaved_ice {
  background-image: url("emojione/assets/4.5/png/128/1f367.png");
}

.e1a-ice_cream {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f368.png");
}

.e1a-rel-ice_cream {
  background-image: url("emojione/assets/4.5/png/128/1f368.png");
}

.e1a-icecream {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f366.png");
}

.e1a-rel-icecream {
  background-image: url("emojione/assets/4.5/png/128/1f366.png");
}

.e1a-pie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f967.png");
}

.e1a-rel-pie {
  background-image: url("emojione/assets/4.5/png/128/1f967.png");
}

.e1a-cake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f370.png");
}

.e1a-rel-cake {
  background-image: url("emojione/assets/4.5/png/128/1f370.png");
}

.e1a-birthday {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f382.png");
}

.e1a-rel-birthday {
  background-image: url("emojione/assets/4.5/png/128/1f382.png");
}

.e1a-moon_cake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f96e.png");
}

.e1a-rel-moon_cake {
  background-image: url("emojione/assets/4.5/png/128/1f96e.png");
}

.e1a-cupcake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9c1.png");
}

.e1a-rel-cupcake {
  background-image: url("emojione/assets/4.5/png/128/1f9c1.png");
}

.e1a-custard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36e.png");
}

.e1a-rel-custard {
  background-image: url("emojione/assets/4.5/png/128/1f36e.png");
}

.e1a-lollipop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36d.png");
}

.e1a-rel-lollipop {
  background-image: url("emojione/assets/4.5/png/128/1f36d.png");
}

.e1a-candy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36c.png");
}

.e1a-rel-candy {
  background-image: url("emojione/assets/4.5/png/128/1f36c.png");
}

.e1a-chocolate_bar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36b.png");
}

.e1a-rel-chocolate_bar {
  background-image: url("emojione/assets/4.5/png/128/1f36b.png");
}

.e1a-popcorn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37f.png");
}

.e1a-rel-popcorn {
  background-image: url("emojione/assets/4.5/png/128/1f37f.png");
}

.e1a-salt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9c2.png");
}

.e1a-rel-salt {
  background-image: url("emojione/assets/4.5/png/128/1f9c2.png");
}

.e1a-doughnut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f369.png");
}

.e1a-rel-doughnut {
  background-image: url("emojione/assets/4.5/png/128/1f369.png");
}

.e1a-dumpling {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95f.png");
}

.e1a-rel-dumpling {
  background-image: url("emojione/assets/4.5/png/128/1f95f.png");
}

.e1a-cookie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36a.png");
}

.e1a-rel-cookie {
  background-image: url("emojione/assets/4.5/png/128/1f36a.png");
}

.e1a-chestnut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f330.png");
}

.e1a-rel-chestnut {
  background-image: url("emojione/assets/4.5/png/128/1f330.png");
}

.e1a-peanuts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95c.png");
}

.e1a-rel-peanuts {
  background-image: url("emojione/assets/4.5/png/128/1f95c.png");
}

.e1a-honey_pot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f36f.png");
}

.e1a-rel-honey_pot {
  background-image: url("emojione/assets/4.5/png/128/1f36f.png");
}

.e1a-milk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f95b.png");
}

.e1a-rel-milk {
  background-image: url("emojione/assets/4.5/png/128/1f95b.png");
}

.e1a-baby_bottle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37c.png");
}

.e1a-rel-baby_bottle {
  background-image: url("emojione/assets/4.5/png/128/1f37c.png");
}

.e1a-tea {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f375.png");
}

.e1a-rel-tea {
  background-image: url("emojione/assets/4.5/png/128/1f375.png");
}

.e1a-cup_with_straw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f964.png");
}

.e1a-rel-cup_with_straw {
  background-image: url("emojione/assets/4.5/png/128/1f964.png");
}

.e1a-sake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f376.png");
}

.e1a-rel-sake {
  background-image: url("emojione/assets/4.5/png/128/1f376.png");
}

.e1a-beer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37a.png");
}

.e1a-rel-beer {
  background-image: url("emojione/assets/4.5/png/128/1f37a.png");
}

.e1a-beers {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37b.png");
}

.e1a-rel-beers {
  background-image: url("emojione/assets/4.5/png/128/1f37b.png");
}

.e1a-champagne_glass {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f942.png");
}

.e1a-rel-champagne_glass {
  background-image: url("emojione/assets/4.5/png/128/1f942.png");
}

.e1a-wine_glass {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f377.png");
}

.e1a-rel-wine_glass {
  background-image: url("emojione/assets/4.5/png/128/1f377.png");
}

.e1a-tumbler_glass {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f943.png");
}

.e1a-rel-tumbler_glass {
  background-image: url("emojione/assets/4.5/png/128/1f943.png");
}

.e1a-cocktail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f378.png");
}

.e1a-rel-cocktail {
  background-image: url("emojione/assets/4.5/png/128/1f378.png");
}

.e1a-tropical_drink {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f379.png");
}

.e1a-rel-tropical_drink {
  background-image: url("emojione/assets/4.5/png/128/1f379.png");
}

.e1a-champagne {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37e.png");
}

.e1a-rel-champagne {
  background-image: url("emojione/assets/4.5/png/128/1f37e.png");
}

.e1a-spoon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f944.png");
}

.e1a-rel-spoon {
  background-image: url("emojione/assets/4.5/png/128/1f944.png");
}

.e1a-fork_and_knife {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f374.png");
}

.e1a-rel-fork_and_knife {
  background-image: url("emojione/assets/4.5/png/128/1f374.png");
}

.e1a-fork_knife_plate {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f37d.png");
}

.e1a-rel-fork_knife_plate {
  background-image: url("emojione/assets/4.5/png/128/1f37d.png");
}

.e1a-bowl_with_spoon {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f963.png");
}

.e1a-rel-bowl_with_spoon {
  background-image: url("emojione/assets/4.5/png/128/1f963.png");
}

.e1a-takeout_box {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f961.png");
}

.e1a-rel-takeout_box {
  background-image: url("emojione/assets/4.5/png/128/1f961.png");
}

.e1a-chopsticks {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f962.png");
}

.e1a-rel-chopsticks {
  background-image: url("emojione/assets/4.5/png/128/1f962.png");
}

.e1a-grinning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f600.png");
}

.e1a-rel-grinning {
  background-image: url("emojione/assets/4.5/png/128/1f600.png");
}

.e1a-smiley {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f603.png");
}

.e1a-rel-smiley {
  background-image: url("emojione/assets/4.5/png/128/1f603.png");
}

.e1a-smile {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f604.png");
}

.e1a-rel-smile {
  background-image: url("emojione/assets/4.5/png/128/1f604.png");
}

.e1a-grin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f601.png");
}

.e1a-rel-grin {
  background-image: url("emojione/assets/4.5/png/128/1f601.png");
}

.e1a-laughing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f606.png");
}

.e1a-rel-laughing {
  background-image: url("emojione/assets/4.5/png/128/1f606.png");
}

.e1a-sweat_smile {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f605.png");
}

.e1a-rel-sweat_smile {
  background-image: url("emojione/assets/4.5/png/128/1f605.png");
}

.e1a-joy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f602.png");
}

.e1a-rel-joy {
  background-image: url("emojione/assets/4.5/png/128/1f602.png");
}

.e1a-rofl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f923.png");
}

.e1a-rel-rofl {
  background-image: url("emojione/assets/4.5/png/128/1f923.png");
}

.e1a-relaxed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/263a.png");
}

.e1a-rel-relaxed {
  background-image: url("emojione/assets/4.5/png/128/263a.png");
}

.e1a-blush {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60a.png");
}

.e1a-rel-blush {
  background-image: url("emojione/assets/4.5/png/128/1f60a.png");
}

.e1a-innocent {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f607.png");
}

.e1a-rel-innocent {
  background-image: url("emojione/assets/4.5/png/128/1f607.png");
}

.e1a-slight_smile {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f642.png");
}

.e1a-rel-slight_smile {
  background-image: url("emojione/assets/4.5/png/128/1f642.png");
}

.e1a-upside_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f643.png");
}

.e1a-rel-upside_down {
  background-image: url("emojione/assets/4.5/png/128/1f643.png");
}

.e1a-wink {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f609.png");
}

.e1a-rel-wink {
  background-image: url("emojione/assets/4.5/png/128/1f609.png");
}

.e1a-relieved {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60c.png");
}

.e1a-rel-relieved {
  background-image: url("emojione/assets/4.5/png/128/1f60c.png");
}

.e1a-heart_eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60d.png");
}

.e1a-rel-heart_eyes {
  background-image: url("emojione/assets/4.5/png/128/1f60d.png");
}

.e1a-kissing_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f618.png");
}

.e1a-rel-kissing_heart {
  background-image: url("emojione/assets/4.5/png/128/1f618.png");
}

.e1a-smiling_face_with_3_hearts {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f970.png");
}

.e1a-rel-smiling_face_with_3_hearts {
  background-image: url("emojione/assets/4.5/png/128/1f970.png");
}

.e1a-kissing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f617.png");
}

.e1a-rel-kissing {
  background-image: url("emojione/assets/4.5/png/128/1f617.png");
}

.e1a-kissing_smiling_eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f619.png");
}

.e1a-rel-kissing_smiling_eyes {
  background-image: url("emojione/assets/4.5/png/128/1f619.png");
}

.e1a-kissing_closed_eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61a.png");
}

.e1a-rel-kissing_closed_eyes {
  background-image: url("emojione/assets/4.5/png/128/1f61a.png");
}

.e1a-yum {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60b.png");
}

.e1a-rel-yum {
  background-image: url("emojione/assets/4.5/png/128/1f60b.png");
}

.e1a-stuck_out_tongue {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61b.png");
}

.e1a-rel-stuck_out_tongue {
  background-image: url("emojione/assets/4.5/png/128/1f61b.png");
}

.e1a-stuck_out_tongue_closed_eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61d.png");
}

.e1a-rel-stuck_out_tongue_closed_eyes {
  background-image: url("emojione/assets/4.5/png/128/1f61d.png");
}

.e1a-stuck_out_tongue_winking_eye {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61c.png");
}

.e1a-rel-stuck_out_tongue_winking_eye {
  background-image: url("emojione/assets/4.5/png/128/1f61c.png");
}

.e1a-zany_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92a.png");
}

.e1a-rel-zany_face {
  background-image: url("emojione/assets/4.5/png/128/1f92a.png");
}

.e1a-face_with_raised_eyebrow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f928.png");
}

.e1a-rel-face_with_raised_eyebrow {
  background-image: url("emojione/assets/4.5/png/128/1f928.png");
}

.e1a-face_with_monocle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d0.png");
}

.e1a-rel-face_with_monocle {
  background-image: url("emojione/assets/4.5/png/128/1f9d0.png");
}

.e1a-nerd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f913.png");
}

.e1a-rel-nerd {
  background-image: url("emojione/assets/4.5/png/128/1f913.png");
}

.e1a-sunglasses {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60e.png");
}

.e1a-rel-sunglasses {
  background-image: url("emojione/assets/4.5/png/128/1f60e.png");
}

.e1a-star_struck {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f929.png");
}

.e1a-rel-star_struck {
  background-image: url("emojione/assets/4.5/png/128/1f929.png");
}

.e1a-partying_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f973.png");
}

.e1a-rel-partying_face {
  background-image: url("emojione/assets/4.5/png/128/1f973.png");
}

.e1a-smirk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f60f.png");
}

.e1a-rel-smirk {
  background-image: url("emojione/assets/4.5/png/128/1f60f.png");
}

.e1a-unamused {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f612.png");
}

.e1a-rel-unamused {
  background-image: url("emojione/assets/4.5/png/128/1f612.png");
}

.e1a-disappointed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61e.png");
}

.e1a-rel-disappointed {
  background-image: url("emojione/assets/4.5/png/128/1f61e.png");
}

.e1a-pensive {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f614.png");
}

.e1a-rel-pensive {
  background-image: url("emojione/assets/4.5/png/128/1f614.png");
}

.e1a-worried {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f61f.png");
}

.e1a-rel-worried {
  background-image: url("emojione/assets/4.5/png/128/1f61f.png");
}

.e1a-confused {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f615.png");
}

.e1a-rel-confused {
  background-image: url("emojione/assets/4.5/png/128/1f615.png");
}

.e1a-slight_frown {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f641.png");
}

.e1a-rel-slight_frown {
  background-image: url("emojione/assets/4.5/png/128/1f641.png");
}

.e1a-persevere {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f623.png");
}

.e1a-rel-persevere {
  background-image: url("emojione/assets/4.5/png/128/1f623.png");
}

.e1a-confounded {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f616.png");
}

.e1a-rel-confounded {
  background-image: url("emojione/assets/4.5/png/128/1f616.png");
}

.e1a-tired_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62b.png");
}

.e1a-rel-tired_face {
  background-image: url("emojione/assets/4.5/png/128/1f62b.png");
}

.e1a-weary {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f629.png");
}

.e1a-rel-weary {
  background-image: url("emojione/assets/4.5/png/128/1f629.png");
}

.e1a-cry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f622.png");
}

.e1a-rel-cry {
  background-image: url("emojione/assets/4.5/png/128/1f622.png");
}

.e1a-sob {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62d.png");
}

.e1a-rel-sob {
  background-image: url("emojione/assets/4.5/png/128/1f62d.png");
}

.e1a-triumph {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f624.png");
}

.e1a-rel-triumph {
  background-image: url("emojione/assets/4.5/png/128/1f624.png");
}

.e1a-angry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f620.png");
}

.e1a-rel-angry {
  background-image: url("emojione/assets/4.5/png/128/1f620.png");
}

.e1a-rage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f621.png");
}

.e1a-rel-rage {
  background-image: url("emojione/assets/4.5/png/128/1f621.png");
}

.e1a-face_with_symbols_over_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92c.png");
}

.e1a-rel-face_with_symbols_over_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f92c.png");
}

.e1a-exploding_head {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92f.png");
}

.e1a-rel-exploding_head {
  background-image: url("emojione/assets/4.5/png/128/1f92f.png");
}

.e1a-flushed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f633.png");
}

.e1a-rel-flushed {
  background-image: url("emojione/assets/4.5/png/128/1f633.png");
}

.e1a-scream {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f631.png");
}

.e1a-rel-scream {
  background-image: url("emojione/assets/4.5/png/128/1f631.png");
}

.e1a-fearful {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f628.png");
}

.e1a-rel-fearful {
  background-image: url("emojione/assets/4.5/png/128/1f628.png");
}

.e1a-cold_sweat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f630.png");
}

.e1a-rel-cold_sweat {
  background-image: url("emojione/assets/4.5/png/128/1f630.png");
}

.e1a-hot_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f975.png");
}

.e1a-rel-hot_face {
  background-image: url("emojione/assets/4.5/png/128/1f975.png");
}

.e1a-cold_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f976.png");
}

.e1a-rel-cold_face {
  background-image: url("emojione/assets/4.5/png/128/1f976.png");
}

.e1a-pleading_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f97a.png");
}

.e1a-rel-pleading_face {
  background-image: url("emojione/assets/4.5/png/128/1f97a.png");
}

.e1a-disappointed_relieved {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f625.png");
}

.e1a-rel-disappointed_relieved {
  background-image: url("emojione/assets/4.5/png/128/1f625.png");
}

.e1a-sweat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f613.png");
}

.e1a-rel-sweat {
  background-image: url("emojione/assets/4.5/png/128/1f613.png");
}

.e1a-hugging {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f917.png");
}

.e1a-rel-hugging {
  background-image: url("emojione/assets/4.5/png/128/1f917.png");
}

.e1a-thinking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f914.png");
}

.e1a-rel-thinking {
  background-image: url("emojione/assets/4.5/png/128/1f914.png");
}

.e1a-face_with_hand_over_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92d.png");
}

.e1a-rel-face_with_hand_over_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f92d.png");
}

.e1a-shushing_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92b.png");
}

.e1a-rel-shushing_face {
  background-image: url("emojione/assets/4.5/png/128/1f92b.png");
}

.e1a-lying_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f925.png");
}

.e1a-rel-lying_face {
  background-image: url("emojione/assets/4.5/png/128/1f925.png");
}

.e1a-no_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f636.png");
}

.e1a-rel-no_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f636.png");
}

.e1a-neutral_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f610.png");
}

.e1a-rel-neutral_face {
  background-image: url("emojione/assets/4.5/png/128/1f610.png");
}

.e1a-expressionless {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f611.png");
}

.e1a-rel-expressionless {
  background-image: url("emojione/assets/4.5/png/128/1f611.png");
}

.e1a-grimacing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62c.png");
}

.e1a-rel-grimacing {
  background-image: url("emojione/assets/4.5/png/128/1f62c.png");
}

.e1a-rolling_eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f644.png");
}

.e1a-rel-rolling_eyes {
  background-image: url("emojione/assets/4.5/png/128/1f644.png");
}

.e1a-hushed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62f.png");
}

.e1a-rel-hushed {
  background-image: url("emojione/assets/4.5/png/128/1f62f.png");
}

.e1a-frowning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f626.png");
}

.e1a-rel-frowning {
  background-image: url("emojione/assets/4.5/png/128/1f626.png");
}

.e1a-anguished {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f627.png");
}

.e1a-rel-anguished {
  background-image: url("emojione/assets/4.5/png/128/1f627.png");
}

.e1a-open_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62e.png");
}

.e1a-rel-open_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f62e.png");
}

.e1a-astonished {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f632.png");
}

.e1a-rel-astonished {
  background-image: url("emojione/assets/4.5/png/128/1f632.png");
}

.e1a-sleeping {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f634.png");
}

.e1a-rel-sleeping {
  background-image: url("emojione/assets/4.5/png/128/1f634.png");
}

.e1a-drooling_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f924.png");
}

.e1a-rel-drooling_face {
  background-image: url("emojione/assets/4.5/png/128/1f924.png");
}

.e1a-sleepy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f62a.png");
}

.e1a-rel-sleepy {
  background-image: url("emojione/assets/4.5/png/128/1f62a.png");
}

.e1a-dizzy_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f635.png");
}

.e1a-rel-dizzy_face {
  background-image: url("emojione/assets/4.5/png/128/1f635.png");
}

.e1a-zipper_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f910.png");
}

.e1a-rel-zipper_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f910.png");
}

.e1a-woozy_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f974.png");
}

.e1a-rel-woozy_face {
  background-image: url("emojione/assets/4.5/png/128/1f974.png");
}

.e1a-nauseated_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f922.png");
}

.e1a-rel-nauseated_face {
  background-image: url("emojione/assets/4.5/png/128/1f922.png");
}

.e1a-face_vomiting {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f92e.png");
}

.e1a-rel-face_vomiting {
  background-image: url("emojione/assets/4.5/png/128/1f92e.png");
}

.e1a-sneezing_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f927.png");
}

.e1a-rel-sneezing_face {
  background-image: url("emojione/assets/4.5/png/128/1f927.png");
}

.e1a-mask {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f637.png");
}

.e1a-rel-mask {
  background-image: url("emojione/assets/4.5/png/128/1f637.png");
}

.e1a-thermometer_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f912.png");
}

.e1a-rel-thermometer_face {
  background-image: url("emojione/assets/4.5/png/128/1f912.png");
}

.e1a-head_bandage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f915.png");
}

.e1a-rel-head_bandage {
  background-image: url("emojione/assets/4.5/png/128/1f915.png");
}

.e1a-money_mouth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f911.png");
}

.e1a-rel-money_mouth {
  background-image: url("emojione/assets/4.5/png/128/1f911.png");
}

.e1a-cowboy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f920.png");
}

.e1a-rel-cowboy {
  background-image: url("emojione/assets/4.5/png/128/1f920.png");
}

.e1a-smiling_imp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f608.png");
}

.e1a-rel-smiling_imp {
  background-image: url("emojione/assets/4.5/png/128/1f608.png");
}

.e1a-imp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47f.png");
}

.e1a-rel-imp {
  background-image: url("emojione/assets/4.5/png/128/1f47f.png");
}

.e1a-japanese_ogre {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f479.png");
}

.e1a-rel-japanese_ogre {
  background-image: url("emojione/assets/4.5/png/128/1f479.png");
}

.e1a-japanese_goblin {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47a.png");
}

.e1a-rel-japanese_goblin {
  background-image: url("emojione/assets/4.5/png/128/1f47a.png");
}

.e1a-clown {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f921.png");
}

.e1a-rel-clown {
  background-image: url("emojione/assets/4.5/png/128/1f921.png");
}

.e1a-poop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4a9.png");
}

.e1a-rel-poop {
  background-image: url("emojione/assets/4.5/png/128/1f4a9.png");
}

.e1a-ghost {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47b.png");
}

.e1a-rel-ghost {
  background-image: url("emojione/assets/4.5/png/128/1f47b.png");
}

.e1a-skull {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f480.png");
}

.e1a-rel-skull {
  background-image: url("emojione/assets/4.5/png/128/1f480.png");
}

.e1a-alien {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47d.png");
}

.e1a-rel-alien {
  background-image: url("emojione/assets/4.5/png/128/1f47d.png");
}

.e1a-space_invader {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47e.png");
}

.e1a-rel-space_invader {
  background-image: url("emojione/assets/4.5/png/128/1f47e.png");
}

.e1a-robot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f916.png");
}

.e1a-rel-robot {
  background-image: url("emojione/assets/4.5/png/128/1f916.png");
}

.e1a-jack_o_lantern {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f383.png");
}

.e1a-rel-jack_o_lantern {
  background-image: url("emojione/assets/4.5/png/128/1f383.png");
}

.e1a-smiley_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63a.png");
}

.e1a-rel-smiley_cat {
  background-image: url("emojione/assets/4.5/png/128/1f63a.png");
}

.e1a-smile_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f638.png");
}

.e1a-rel-smile_cat {
  background-image: url("emojione/assets/4.5/png/128/1f638.png");
}

.e1a-joy_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f639.png");
}

.e1a-rel-joy_cat {
  background-image: url("emojione/assets/4.5/png/128/1f639.png");
}

.e1a-heart_eyes_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63b.png");
}

.e1a-rel-heart_eyes_cat {
  background-image: url("emojione/assets/4.5/png/128/1f63b.png");
}

.e1a-smirk_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63c.png");
}

.e1a-rel-smirk_cat {
  background-image: url("emojione/assets/4.5/png/128/1f63c.png");
}

.e1a-kissing_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63d.png");
}

.e1a-rel-kissing_cat {
  background-image: url("emojione/assets/4.5/png/128/1f63d.png");
}

.e1a-scream_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f640.png");
}

.e1a-rel-scream_cat {
  background-image: url("emojione/assets/4.5/png/128/1f640.png");
}

.e1a-crying_cat_face {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63f.png");
}

.e1a-rel-crying_cat_face {
  background-image: url("emojione/assets/4.5/png/128/1f63f.png");
}

.e1a-pouting_cat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f63e.png");
}

.e1a-rel-pouting_cat {
  background-image: url("emojione/assets/4.5/png/128/1f63e.png");
}

.e1a-palms_up_together {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932.png");
}

.e1a-rel-palms_up_together {
  background-image: url("emojione/assets/4.5/png/128/1f932.png");
}

.e1a-palms_up_together_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932-1f3fb.png");
}

.e1a-rel-palms_up_together_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f932-1f3fb.png");
}

.e1a-palms_up_together_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932-1f3fc.png");
}

.e1a-rel-palms_up_together_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f932-1f3fc.png");
}

.e1a-palms_up_together_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932-1f3fd.png");
}

.e1a-rel-palms_up_together_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f932-1f3fd.png");
}

.e1a-palms_up_together_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932-1f3fe.png");
}

.e1a-rel-palms_up_together_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f932-1f3fe.png");
}

.e1a-palms_up_together_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f932-1f3ff.png");
}

.e1a-rel-palms_up_together_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f932-1f3ff.png");
}

.e1a-open_hands {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450.png");
}

.e1a-rel-open_hands {
  background-image: url("emojione/assets/4.5/png/128/1f450.png");
}

.e1a-open_hands_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450-1f3fb.png");
}

.e1a-rel-open_hands_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f450-1f3fb.png");
}

.e1a-open_hands_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450-1f3fc.png");
}

.e1a-rel-open_hands_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f450-1f3fc.png");
}

.e1a-open_hands_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450-1f3fd.png");
}

.e1a-rel-open_hands_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f450-1f3fd.png");
}

.e1a-open_hands_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450-1f3fe.png");
}

.e1a-rel-open_hands_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f450-1f3fe.png");
}

.e1a-open_hands_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f450-1f3ff.png");
}

.e1a-rel-open_hands_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f450-1f3ff.png");
}

.e1a-raised_hands {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c.png");
}

.e1a-rel-raised_hands {
  background-image: url("emojione/assets/4.5/png/128/1f64c.png");
}

.e1a-raised_hands_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c-1f3fb.png");
}

.e1a-rel-raised_hands_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64c-1f3fb.png");
}

.e1a-raised_hands_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c-1f3fc.png");
}

.e1a-rel-raised_hands_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64c-1f3fc.png");
}

.e1a-raised_hands_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c-1f3fd.png");
}

.e1a-rel-raised_hands_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64c-1f3fd.png");
}

.e1a-raised_hands_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c-1f3fe.png");
}

.e1a-rel-raised_hands_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64c-1f3fe.png");
}

.e1a-raised_hands_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64c-1f3ff.png");
}

.e1a-rel-raised_hands_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64c-1f3ff.png");
}

.e1a-clap {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f.png");
}

.e1a-rel-clap {
  background-image: url("emojione/assets/4.5/png/128/1f44f.png");
}

.e1a-clap_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f-1f3fb.png");
}

.e1a-rel-clap_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44f-1f3fb.png");
}

.e1a-clap_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f-1f3fc.png");
}

.e1a-rel-clap_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44f-1f3fc.png");
}

.e1a-clap_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f-1f3fd.png");
}

.e1a-rel-clap_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44f-1f3fd.png");
}

.e1a-clap_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f-1f3fe.png");
}

.e1a-rel-clap_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44f-1f3fe.png");
}

.e1a-clap_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44f-1f3ff.png");
}

.e1a-rel-clap_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44f-1f3ff.png");
}

.e1a-handshake {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91d.png");
}

.e1a-rel-handshake {
  background-image: url("emojione/assets/4.5/png/128/1f91d.png");
}

.e1a-thumbsup {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d.png");
}

.e1a-rel-thumbsup {
  background-image: url("emojione/assets/4.5/png/128/1f44d.png");
}

.e1a-thumbsup_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d-1f3fb.png");
}

.e1a-rel-thumbsup_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44d-1f3fb.png");
}

.e1a-thumbsup_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d-1f3fc.png");
}

.e1a-rel-thumbsup_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44d-1f3fc.png");
}

.e1a-thumbsup_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d-1f3fd.png");
}

.e1a-rel-thumbsup_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44d-1f3fd.png");
}

.e1a-thumbsup_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d-1f3fe.png");
}

.e1a-rel-thumbsup_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44d-1f3fe.png");
}

.e1a-thumbsup_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44d-1f3ff.png");
}

.e1a-rel-thumbsup_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44d-1f3ff.png");
}

.e1a-thumbsdown {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e.png");
}

.e1a-rel-thumbsdown {
  background-image: url("emojione/assets/4.5/png/128/1f44e.png");
}

.e1a-thumbsdown_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e-1f3fb.png");
}

.e1a-rel-thumbsdown_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44e-1f3fb.png");
}

.e1a-thumbsdown_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e-1f3fc.png");
}

.e1a-rel-thumbsdown_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44e-1f3fc.png");
}

.e1a-thumbsdown_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e-1f3fd.png");
}

.e1a-rel-thumbsdown_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44e-1f3fd.png");
}

.e1a-thumbsdown_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e-1f3fe.png");
}

.e1a-rel-thumbsdown_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44e-1f3fe.png");
}

.e1a-thumbsdown_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44e-1f3ff.png");
}

.e1a-rel-thumbsdown_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44e-1f3ff.png");
}

.e1a-punch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a.png");
}

.e1a-rel-punch {
  background-image: url("emojione/assets/4.5/png/128/1f44a.png");
}

.e1a-punch_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a-1f3fb.png");
}

.e1a-rel-punch_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44a-1f3fb.png");
}

.e1a-punch_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a-1f3fc.png");
}

.e1a-rel-punch_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44a-1f3fc.png");
}

.e1a-punch_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a-1f3fd.png");
}

.e1a-rel-punch_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44a-1f3fd.png");
}

.e1a-punch_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a-1f3fe.png");
}

.e1a-rel-punch_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44a-1f3fe.png");
}

.e1a-punch_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44a-1f3ff.png");
}

.e1a-rel-punch_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44a-1f3ff.png");
}

.e1a-fist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a.png");
}

.e1a-rel-fist {
  background-image: url("emojione/assets/4.5/png/128/270a.png");
}

.e1a-fist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a-1f3fb.png");
}

.e1a-rel-fist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/270a-1f3fb.png");
}

.e1a-fist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a-1f3fc.png");
}

.e1a-rel-fist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/270a-1f3fc.png");
}

.e1a-fist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a-1f3fd.png");
}

.e1a-rel-fist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/270a-1f3fd.png");
}

.e1a-fist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a-1f3fe.png");
}

.e1a-rel-fist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/270a-1f3fe.png");
}

.e1a-fist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270a-1f3ff.png");
}

.e1a-rel-fist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/270a-1f3ff.png");
}

.e1a-left_facing_fist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b.png");
}

.e1a-rel-left_facing_fist {
  background-image: url("emojione/assets/4.5/png/128/1f91b.png");
}

.e1a-left_facing_fist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b-1f3fb.png");
}

.e1a-rel-left_facing_fist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f91b-1f3fb.png");
}

.e1a-left_facing_fist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b-1f3fc.png");
}

.e1a-rel-left_facing_fist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f91b-1f3fc.png");
}

.e1a-left_facing_fist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b-1f3fd.png");
}

.e1a-rel-left_facing_fist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f91b-1f3fd.png");
}

.e1a-left_facing_fist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b-1f3fe.png");
}

.e1a-rel-left_facing_fist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f91b-1f3fe.png");
}

.e1a-left_facing_fist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91b-1f3ff.png");
}

.e1a-rel-left_facing_fist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f91b-1f3ff.png");
}

.e1a-right_facing_fist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c.png");
}

.e1a-rel-right_facing_fist {
  background-image: url("emojione/assets/4.5/png/128/1f91c.png");
}

.e1a-right_facing_fist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c-1f3fb.png");
}

.e1a-rel-right_facing_fist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f91c-1f3fb.png");
}

.e1a-right_facing_fist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c-1f3fc.png");
}

.e1a-rel-right_facing_fist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f91c-1f3fc.png");
}

.e1a-right_facing_fist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c-1f3fd.png");
}

.e1a-rel-right_facing_fist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f91c-1f3fd.png");
}

.e1a-right_facing_fist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c-1f3fe.png");
}

.e1a-rel-right_facing_fist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f91c-1f3fe.png");
}

.e1a-right_facing_fist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91c-1f3ff.png");
}

.e1a-rel-right_facing_fist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f91c-1f3ff.png");
}

.e1a-fingers_crossed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e.png");
}

.e1a-rel-fingers_crossed {
  background-image: url("emojione/assets/4.5/png/128/1f91e.png");
}

.e1a-fingers_crossed_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e-1f3fb.png");
}

.e1a-rel-fingers_crossed_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f91e-1f3fb.png");
}

.e1a-fingers_crossed_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e-1f3fc.png");
}

.e1a-rel-fingers_crossed_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f91e-1f3fc.png");
}

.e1a-fingers_crossed_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e-1f3fd.png");
}

.e1a-rel-fingers_crossed_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f91e-1f3fd.png");
}

.e1a-fingers_crossed_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e-1f3fe.png");
}

.e1a-rel-fingers_crossed_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f91e-1f3fe.png");
}

.e1a-fingers_crossed_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91e-1f3ff.png");
}

.e1a-rel-fingers_crossed_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f91e-1f3ff.png");
}

.e1a-v {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c.png");
}

.e1a-rel-v {
  background-image: url("emojione/assets/4.5/png/128/270c.png");
}

.e1a-v_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c-1f3fb.png");
}

.e1a-rel-v_tone1 {
  background-image: url("emojione/assets/4.5/png/128/270c-1f3fb.png");
}

.e1a-v_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c-1f3fc.png");
}

.e1a-rel-v_tone2 {
  background-image: url("emojione/assets/4.5/png/128/270c-1f3fc.png");
}

.e1a-v_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c-1f3fd.png");
}

.e1a-rel-v_tone3 {
  background-image: url("emojione/assets/4.5/png/128/270c-1f3fd.png");
}

.e1a-v_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c-1f3fe.png");
}

.e1a-rel-v_tone4 {
  background-image: url("emojione/assets/4.5/png/128/270c-1f3fe.png");
}

.e1a-v_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270c-1f3ff.png");
}

.e1a-rel-v_tone5 {
  background-image: url("emojione/assets/4.5/png/128/270c-1f3ff.png");
}

.e1a-love_you_gesture {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f.png");
}

.e1a-rel-love_you_gesture {
  background-image: url("emojione/assets/4.5/png/128/1f91f.png");
}

.e1a-love_you_gesture_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f-1f3fb.png");
}

.e1a-rel-love_you_gesture_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f91f-1f3fb.png");
}

.e1a-love_you_gesture_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f-1f3fc.png");
}

.e1a-rel-love_you_gesture_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f91f-1f3fc.png");
}

.e1a-love_you_gesture_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f-1f3fd.png");
}

.e1a-rel-love_you_gesture_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f91f-1f3fd.png");
}

.e1a-love_you_gesture_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f-1f3fe.png");
}

.e1a-rel-love_you_gesture_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f91f-1f3fe.png");
}

.e1a-love_you_gesture_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91f-1f3ff.png");
}

.e1a-rel-love_you_gesture_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f91f-1f3ff.png");
}

.e1a-metal {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918.png");
}

.e1a-rel-metal {
  background-image: url("emojione/assets/4.5/png/128/1f918.png");
}

.e1a-metal_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918-1f3fb.png");
}

.e1a-rel-metal_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f918-1f3fb.png");
}

.e1a-metal_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918-1f3fc.png");
}

.e1a-rel-metal_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f918-1f3fc.png");
}

.e1a-metal_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918-1f3fd.png");
}

.e1a-rel-metal_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f918-1f3fd.png");
}

.e1a-metal_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918-1f3fe.png");
}

.e1a-rel-metal_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f918-1f3fe.png");
}

.e1a-metal_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f918-1f3ff.png");
}

.e1a-rel-metal_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f918-1f3ff.png");
}

.e1a-ok_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c.png");
}

.e1a-rel-ok_hand {
  background-image: url("emojione/assets/4.5/png/128/1f44c.png");
}

.e1a-ok_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c-1f3fb.png");
}

.e1a-rel-ok_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44c-1f3fb.png");
}

.e1a-ok_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c-1f3fc.png");
}

.e1a-rel-ok_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44c-1f3fc.png");
}

.e1a-ok_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c-1f3fd.png");
}

.e1a-rel-ok_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44c-1f3fd.png");
}

.e1a-ok_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c-1f3fe.png");
}

.e1a-rel-ok_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44c-1f3fe.png");
}

.e1a-ok_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44c-1f3ff.png");
}

.e1a-rel-ok_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44c-1f3ff.png");
}

.e1a-point_left {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448.png");
}

.e1a-rel-point_left {
  background-image: url("emojione/assets/4.5/png/128/1f448.png");
}

.e1a-point_left_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448-1f3fb.png");
}

.e1a-rel-point_left_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f448-1f3fb.png");
}

.e1a-point_left_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448-1f3fc.png");
}

.e1a-rel-point_left_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f448-1f3fc.png");
}

.e1a-point_left_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448-1f3fd.png");
}

.e1a-rel-point_left_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f448-1f3fd.png");
}

.e1a-point_left_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448-1f3fe.png");
}

.e1a-rel-point_left_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f448-1f3fe.png");
}

.e1a-point_left_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f448-1f3ff.png");
}

.e1a-rel-point_left_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f448-1f3ff.png");
}

.e1a-point_right {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449.png");
}

.e1a-rel-point_right {
  background-image: url("emojione/assets/4.5/png/128/1f449.png");
}

.e1a-point_right_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449-1f3fb.png");
}

.e1a-rel-point_right_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f449-1f3fb.png");
}

.e1a-point_right_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449-1f3fc.png");
}

.e1a-rel-point_right_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f449-1f3fc.png");
}

.e1a-point_right_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449-1f3fd.png");
}

.e1a-rel-point_right_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f449-1f3fd.png");
}

.e1a-point_right_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449-1f3fe.png");
}

.e1a-rel-point_right_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f449-1f3fe.png");
}

.e1a-point_right_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f449-1f3ff.png");
}

.e1a-rel-point_right_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f449-1f3ff.png");
}

.e1a-point_up_2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446.png");
}

.e1a-rel-point_up_2 {
  background-image: url("emojione/assets/4.5/png/128/1f446.png");
}

.e1a-point_up_2_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446-1f3fb.png");
}

.e1a-rel-point_up_2_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f446-1f3fb.png");
}

.e1a-point_up_2_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446-1f3fc.png");
}

.e1a-rel-point_up_2_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f446-1f3fc.png");
}

.e1a-point_up_2_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446-1f3fd.png");
}

.e1a-rel-point_up_2_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f446-1f3fd.png");
}

.e1a-point_up_2_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446-1f3fe.png");
}

.e1a-rel-point_up_2_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f446-1f3fe.png");
}

.e1a-point_up_2_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f446-1f3ff.png");
}

.e1a-rel-point_up_2_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f446-1f3ff.png");
}

.e1a-point_down {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447.png");
}

.e1a-rel-point_down {
  background-image: url("emojione/assets/4.5/png/128/1f447.png");
}

.e1a-point_down_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447-1f3fb.png");
}

.e1a-rel-point_down_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f447-1f3fb.png");
}

.e1a-point_down_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447-1f3fc.png");
}

.e1a-rel-point_down_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f447-1f3fc.png");
}

.e1a-point_down_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447-1f3fd.png");
}

.e1a-rel-point_down_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f447-1f3fd.png");
}

.e1a-point_down_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447-1f3fe.png");
}

.e1a-rel-point_down_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f447-1f3fe.png");
}

.e1a-point_down_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f447-1f3ff.png");
}

.e1a-rel-point_down_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f447-1f3ff.png");
}

.e1a-point_up {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d.png");
}

.e1a-rel-point_up {
  background-image: url("emojione/assets/4.5/png/128/261d.png");
}

.e1a-point_up_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d-1f3fb.png");
}

.e1a-rel-point_up_tone1 {
  background-image: url("emojione/assets/4.5/png/128/261d-1f3fb.png");
}

.e1a-point_up_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d-1f3fc.png");
}

.e1a-rel-point_up_tone2 {
  background-image: url("emojione/assets/4.5/png/128/261d-1f3fc.png");
}

.e1a-point_up_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d-1f3fd.png");
}

.e1a-rel-point_up_tone3 {
  background-image: url("emojione/assets/4.5/png/128/261d-1f3fd.png");
}

.e1a-point_up_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d-1f3fe.png");
}

.e1a-rel-point_up_tone4 {
  background-image: url("emojione/assets/4.5/png/128/261d-1f3fe.png");
}

.e1a-point_up_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/261d-1f3ff.png");
}

.e1a-rel-point_up_tone5 {
  background-image: url("emojione/assets/4.5/png/128/261d-1f3ff.png");
}

.e1a-raised_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b.png");
}

.e1a-rel-raised_hand {
  background-image: url("emojione/assets/4.5/png/128/270b.png");
}

.e1a-raised_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b-1f3fb.png");
}

.e1a-rel-raised_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/270b-1f3fb.png");
}

.e1a-raised_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b-1f3fc.png");
}

.e1a-rel-raised_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/270b-1f3fc.png");
}

.e1a-raised_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b-1f3fd.png");
}

.e1a-rel-raised_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/270b-1f3fd.png");
}

.e1a-raised_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b-1f3fe.png");
}

.e1a-rel-raised_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/270b-1f3fe.png");
}

.e1a-raised_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270b-1f3ff.png");
}

.e1a-rel-raised_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/270b-1f3ff.png");
}

.e1a-raised_back_of_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a.png");
}

.e1a-rel-raised_back_of_hand {
  background-image: url("emojione/assets/4.5/png/128/1f91a.png");
}

.e1a-raised_back_of_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a-1f3fb.png");
}

.e1a-rel-raised_back_of_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f91a-1f3fb.png");
}

.e1a-raised_back_of_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a-1f3fc.png");
}

.e1a-rel-raised_back_of_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f91a-1f3fc.png");
}

.e1a-raised_back_of_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a-1f3fd.png");
}

.e1a-rel-raised_back_of_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f91a-1f3fd.png");
}

.e1a-raised_back_of_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a-1f3fe.png");
}

.e1a-rel-raised_back_of_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f91a-1f3fe.png");
}

.e1a-raised_back_of_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f91a-1f3ff.png");
}

.e1a-rel-raised_back_of_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f91a-1f3ff.png");
}

.e1a-hand_splayed {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590.png");
}

.e1a-rel-hand_splayed {
  background-image: url("emojione/assets/4.5/png/128/1f590.png");
}

.e1a-hand_splayed_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590-1f3fb.png");
}

.e1a-rel-hand_splayed_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f590-1f3fb.png");
}

.e1a-hand_splayed_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590-1f3fc.png");
}

.e1a-rel-hand_splayed_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f590-1f3fc.png");
}

.e1a-hand_splayed_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590-1f3fd.png");
}

.e1a-rel-hand_splayed_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f590-1f3fd.png");
}

.e1a-hand_splayed_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590-1f3fe.png");
}

.e1a-rel-hand_splayed_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f590-1f3fe.png");
}

.e1a-hand_splayed_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f590-1f3ff.png");
}

.e1a-rel-hand_splayed_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f590-1f3ff.png");
}

.e1a-vulcan {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596.png");
}

.e1a-rel-vulcan {
  background-image: url("emojione/assets/4.5/png/128/1f596.png");
}

.e1a-vulcan_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596-1f3fb.png");
}

.e1a-rel-vulcan_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f596-1f3fb.png");
}

.e1a-vulcan_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596-1f3fc.png");
}

.e1a-rel-vulcan_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f596-1f3fc.png");
}

.e1a-vulcan_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596-1f3fd.png");
}

.e1a-rel-vulcan_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f596-1f3fd.png");
}

.e1a-vulcan_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596-1f3fe.png");
}

.e1a-rel-vulcan_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f596-1f3fe.png");
}

.e1a-vulcan_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f596-1f3ff.png");
}

.e1a-rel-vulcan_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f596-1f3ff.png");
}

.e1a-wave {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b.png");
}

.e1a-rel-wave {
  background-image: url("emojione/assets/4.5/png/128/1f44b.png");
}

.e1a-wave_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b-1f3fb.png");
}

.e1a-rel-wave_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f44b-1f3fb.png");
}

.e1a-wave_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b-1f3fc.png");
}

.e1a-rel-wave_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f44b-1f3fc.png");
}

.e1a-wave_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b-1f3fd.png");
}

.e1a-rel-wave_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f44b-1f3fd.png");
}

.e1a-wave_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b-1f3fe.png");
}

.e1a-rel-wave_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f44b-1f3fe.png");
}

.e1a-wave_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f44b-1f3ff.png");
}

.e1a-rel-wave_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f44b-1f3ff.png");
}

.e1a-call_me {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919.png");
}

.e1a-rel-call_me {
  background-image: url("emojione/assets/4.5/png/128/1f919.png");
}

.e1a-call_me_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919-1f3fb.png");
}

.e1a-rel-call_me_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f919-1f3fb.png");
}

.e1a-call_me_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919-1f3fc.png");
}

.e1a-rel-call_me_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f919-1f3fc.png");
}

.e1a-call_me_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919-1f3fd.png");
}

.e1a-rel-call_me_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f919-1f3fd.png");
}

.e1a-call_me_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919-1f3fe.png");
}

.e1a-rel-call_me_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f919-1f3fe.png");
}

.e1a-call_me_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f919-1f3ff.png");
}

.e1a-rel-call_me_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f919-1f3ff.png");
}

.e1a-muscle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa.png");
}

.e1a-rel-muscle {
  background-image: url("emojione/assets/4.5/png/128/1f4aa.png");
}

.e1a-muscle_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa-1f3fb.png");
}

.e1a-rel-muscle_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f4aa-1f3fb.png");
}

.e1a-muscle_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa-1f3fc.png");
}

.e1a-rel-muscle_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f4aa-1f3fc.png");
}

.e1a-muscle_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa-1f3fd.png");
}

.e1a-rel-muscle_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f4aa-1f3fd.png");
}

.e1a-muscle_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa-1f3fe.png");
}

.e1a-rel-muscle_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f4aa-1f3fe.png");
}

.e1a-muscle_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4aa-1f3ff.png");
}

.e1a-rel-muscle_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f4aa-1f3ff.png");
}

.e1a-leg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5.png");
}

.e1a-rel-leg {
  background-image: url("emojione/assets/4.5/png/128/1f9b5.png");
}

.e1a-leg_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5-1f3fb.png");
}

.e1a-rel-leg_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b5-1f3fb.png");
}

.e1a-leg_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5-1f3fc.png");
}

.e1a-rel-leg_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b5-1f3fc.png");
}

.e1a-leg_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5-1f3fd.png");
}

.e1a-rel-leg_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b5-1f3fd.png");
}

.e1a-leg_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5-1f3fe.png");
}

.e1a-rel-leg_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b5-1f3fe.png");
}

.e1a-leg_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b5-1f3ff.png");
}

.e1a-rel-leg_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b5-1f3ff.png");
}

.e1a-foot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6.png");
}

.e1a-rel-foot {
  background-image: url("emojione/assets/4.5/png/128/1f9b6.png");
}

.e1a-foot_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6-1f3fb.png");
}

.e1a-rel-foot_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b6-1f3fb.png");
}

.e1a-foot_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6-1f3fc.png");
}

.e1a-rel-foot_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b6-1f3fc.png");
}

.e1a-foot_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6-1f3fd.png");
}

.e1a-rel-foot_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b6-1f3fd.png");
}

.e1a-foot_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6-1f3fe.png");
}

.e1a-rel-foot_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b6-1f3fe.png");
}

.e1a-foot_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b6-1f3ff.png");
}

.e1a-rel-foot_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b6-1f3ff.png");
}

.e1a-middle_finger {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595.png");
}

.e1a-rel-middle_finger {
  background-image: url("emojione/assets/4.5/png/128/1f595.png");
}

.e1a-middle_finger_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595-1f3fb.png");
}

.e1a-rel-middle_finger_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f595-1f3fb.png");
}

.e1a-middle_finger_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595-1f3fc.png");
}

.e1a-rel-middle_finger_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f595-1f3fc.png");
}

.e1a-middle_finger_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595-1f3fd.png");
}

.e1a-rel-middle_finger_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f595-1f3fd.png");
}

.e1a-middle_finger_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595-1f3fe.png");
}

.e1a-rel-middle_finger_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f595-1f3fe.png");
}

.e1a-middle_finger_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f595-1f3ff.png");
}

.e1a-rel-middle_finger_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f595-1f3ff.png");
}

.e1a-writing_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d.png");
}

.e1a-rel-writing_hand {
  background-image: url("emojione/assets/4.5/png/128/270d.png");
}

.e1a-writing_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d-1f3fb.png");
}

.e1a-rel-writing_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/270d-1f3fb.png");
}

.e1a-writing_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d-1f3fc.png");
}

.e1a-rel-writing_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/270d-1f3fc.png");
}

.e1a-writing_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d-1f3fd.png");
}

.e1a-rel-writing_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/270d-1f3fd.png");
}

.e1a-writing_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d-1f3fe.png");
}

.e1a-rel-writing_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/270d-1f3fe.png");
}

.e1a-writing_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/270d-1f3ff.png");
}

.e1a-rel-writing_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/270d-1f3ff.png");
}

.e1a-pray {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f.png");
}

.e1a-rel-pray {
  background-image: url("emojione/assets/4.5/png/128/1f64f.png");
}

.e1a-pray_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f-1f3fb.png");
}

.e1a-rel-pray_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64f-1f3fb.png");
}

.e1a-pray_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f-1f3fc.png");
}

.e1a-rel-pray_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64f-1f3fc.png");
}

.e1a-pray_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f-1f3fd.png");
}

.e1a-rel-pray_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64f-1f3fd.png");
}

.e1a-pray_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f-1f3fe.png");
}

.e1a-rel-pray_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64f-1f3fe.png");
}

.e1a-pray_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64f-1f3ff.png");
}

.e1a-rel-pray_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64f-1f3ff.png");
}

.e1a-ring {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48d.png");
}

.e1a-rel-ring {
  background-image: url("emojione/assets/4.5/png/128/1f48d.png");
}

.e1a-lipstick {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f484.png");
}

.e1a-rel-lipstick {
  background-image: url("emojione/assets/4.5/png/128/1f484.png");
}

.e1a-kiss {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48b.png");
}

.e1a-rel-kiss {
  background-image: url("emojione/assets/4.5/png/128/1f48b.png");
}

.e1a-lips {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f444.png");
}

.e1a-rel-lips {
  background-image: url("emojione/assets/4.5/png/128/1f444.png");
}

.e1a-tongue {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f445.png");
}

.e1a-rel-tongue {
  background-image: url("emojione/assets/4.5/png/128/1f445.png");
}

.e1a-ear {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442.png");
}

.e1a-rel-ear {
  background-image: url("emojione/assets/4.5/png/128/1f442.png");
}

.e1a-ear_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442-1f3fb.png");
}

.e1a-rel-ear_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f442-1f3fb.png");
}

.e1a-ear_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442-1f3fc.png");
}

.e1a-rel-ear_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f442-1f3fc.png");
}

.e1a-ear_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442-1f3fd.png");
}

.e1a-rel-ear_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f442-1f3fd.png");
}

.e1a-ear_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442-1f3fe.png");
}

.e1a-rel-ear_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f442-1f3fe.png");
}

.e1a-ear_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f442-1f3ff.png");
}

.e1a-rel-ear_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f442-1f3ff.png");
}

.e1a-nose {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443.png");
}

.e1a-rel-nose {
  background-image: url("emojione/assets/4.5/png/128/1f443.png");
}

.e1a-nose_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443-1f3fb.png");
}

.e1a-rel-nose_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f443-1f3fb.png");
}

.e1a-nose_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443-1f3fc.png");
}

.e1a-rel-nose_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f443-1f3fc.png");
}

.e1a-nose_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443-1f3fd.png");
}

.e1a-rel-nose_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f443-1f3fd.png");
}

.e1a-nose_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443-1f3fe.png");
}

.e1a-rel-nose_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f443-1f3fe.png");
}

.e1a-nose_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f443-1f3ff.png");
}

.e1a-rel-nose_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f443-1f3ff.png");
}

.e1a-footprints {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f463.png");
}

.e1a-rel-footprints {
  background-image: url("emojione/assets/4.5/png/128/1f463.png");
}

.e1a-eye {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f441.png");
}

.e1a-rel-eye {
  background-image: url("emojione/assets/4.5/png/128/1f441.png");
}

.e1a-eyes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f440.png");
}

.e1a-rel-eyes {
  background-image: url("emojione/assets/4.5/png/128/1f440.png");
}

.e1a-brain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e0.png");
}

.e1a-rel-brain {
  background-image: url("emojione/assets/4.5/png/128/1f9e0.png");
}

.e1a-bone {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b4.png");
}

.e1a-rel-bone {
  background-image: url("emojione/assets/4.5/png/128/1f9b4.png");
}

.e1a-tooth {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b7.png");
}

.e1a-rel-tooth {
  background-image: url("emojione/assets/4.5/png/128/1f9b7.png");
}

.e1a-speaking_head {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5e3.png");
}

.e1a-rel-speaking_head {
  background-image: url("emojione/assets/4.5/png/128/1f5e3.png");
}

.e1a-bust_in_silhouette {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f464.png");
}

.e1a-rel-bust_in_silhouette {
  background-image: url("emojione/assets/4.5/png/128/1f464.png");
}

.e1a-busts_in_silhouette {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f465.png");
}

.e1a-rel-busts_in_silhouette {
  background-image: url("emojione/assets/4.5/png/128/1f465.png");
}

.e1a-baby {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476.png");
}

.e1a-rel-baby {
  background-image: url("emojione/assets/4.5/png/128/1f476.png");
}

.e1a-baby_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476-1f3fb.png");
}

.e1a-rel-baby_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f476-1f3fb.png");
}

.e1a-baby_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476-1f3fc.png");
}

.e1a-rel-baby_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f476-1f3fc.png");
}

.e1a-baby_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476-1f3fd.png");
}

.e1a-rel-baby_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f476-1f3fd.png");
}

.e1a-baby_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476-1f3fe.png");
}

.e1a-rel-baby_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f476-1f3fe.png");
}

.e1a-baby_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f476-1f3ff.png");
}

.e1a-rel-baby_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f476-1f3ff.png");
}

.e1a-girl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467.png");
}

.e1a-rel-girl {
  background-image: url("emojione/assets/4.5/png/128/1f467.png");
}

.e1a-girl_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467-1f3fb.png");
}

.e1a-rel-girl_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f467-1f3fb.png");
}

.e1a-girl_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467-1f3fc.png");
}

.e1a-rel-girl_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f467-1f3fc.png");
}

.e1a-girl_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467-1f3fd.png");
}

.e1a-rel-girl_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f467-1f3fd.png");
}

.e1a-girl_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467-1f3fe.png");
}

.e1a-rel-girl_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f467-1f3fe.png");
}

.e1a-girl_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f467-1f3ff.png");
}

.e1a-rel-girl_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f467-1f3ff.png");
}

.e1a-child {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2.png");
}

.e1a-rel-child {
  background-image: url("emojione/assets/4.5/png/128/1f9d2.png");
}

.e1a-child_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2-1f3fb.png");
}

.e1a-rel-child_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d2-1f3fb.png");
}

.e1a-child_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2-1f3fc.png");
}

.e1a-rel-child_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d2-1f3fc.png");
}

.e1a-child_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2-1f3fd.png");
}

.e1a-rel-child_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d2-1f3fd.png");
}

.e1a-child_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2-1f3fe.png");
}

.e1a-rel-child_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d2-1f3fe.png");
}

.e1a-child_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d2-1f3ff.png");
}

.e1a-rel-child_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d2-1f3ff.png");
}

.e1a-boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466.png");
}

.e1a-rel-boy {
  background-image: url("emojione/assets/4.5/png/128/1f466.png");
}

.e1a-boy_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466-1f3fb.png");
}

.e1a-rel-boy_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f466-1f3fb.png");
}

.e1a-boy_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466-1f3fc.png");
}

.e1a-rel-boy_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f466-1f3fc.png");
}

.e1a-boy_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466-1f3fd.png");
}

.e1a-rel-boy_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f466-1f3fd.png");
}

.e1a-boy_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466-1f3fe.png");
}

.e1a-rel-boy_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f466-1f3fe.png");
}

.e1a-boy_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f466-1f3ff.png");
}

.e1a-rel-boy_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f466-1f3ff.png");
}

.e1a-woman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469.png");
}

.e1a-rel-woman {
  background-image: url("emojione/assets/4.5/png/128/1f469.png");
}

.e1a-woman_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb.png");
}

.e1a-rel-woman_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb.png");
}

.e1a-woman_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc.png");
}

.e1a-rel-woman_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc.png");
}

.e1a-woman_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd.png");
}

.e1a-rel-woman_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd.png");
}

.e1a-woman_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe.png");
}

.e1a-rel-woman_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe.png");
}

.e1a-woman_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff.png");
}

.e1a-rel-woman_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff.png");
}

.e1a-adult {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1.png");
}

.e1a-rel-adult {
  background-image: url("emojione/assets/4.5/png/128/1f9d1.png");
}

.e1a-adult_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1-1f3fb.png");
}

.e1a-rel-adult_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d1-1f3fb.png");
}

.e1a-adult_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1-1f3fc.png");
}

.e1a-rel-adult_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d1-1f3fc.png");
}

.e1a-adult_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1-1f3fd.png");
}

.e1a-rel-adult_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d1-1f3fd.png");
}

.e1a-adult_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1-1f3fe.png");
}

.e1a-rel-adult_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d1-1f3fe.png");
}

.e1a-adult_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d1-1f3ff.png");
}

.e1a-rel-adult_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d1-1f3ff.png");
}

.e1a-man {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468.png");
}

.e1a-rel-man {
  background-image: url("emojione/assets/4.5/png/128/1f468.png");
}

.e1a-man_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb.png");
}

.e1a-rel-man_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb.png");
}

.e1a-man_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc.png");
}

.e1a-rel-man_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc.png");
}

.e1a-man_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd.png");
}

.e1a-rel-man_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd.png");
}

.e1a-man_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe.png");
}

.e1a-rel-man_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe.png");
}

.e1a-man_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff.png");
}

.e1a-rel-man_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff.png");
}

.e1a-blond_haired_person {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471.png");
}

.e1a-rel-blond_haired_person {
  background-image: url("emojione/assets/4.5/png/128/1f471.png");
}

.e1a-blond_haired_person_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fb.png");
}

.e1a-rel-blond_haired_person_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fb.png");
}

.e1a-blond_haired_person_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fc.png");
}

.e1a-rel-blond_haired_person_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fc.png");
}

.e1a-blond_haired_person_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fd.png");
}

.e1a-rel-blond_haired_person_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fd.png");
}

.e1a-blond_haired_person_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fe.png");
}

.e1a-rel-blond_haired_person_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fe.png");
}

.e1a-blond_haired_person_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3ff.png");
}

.e1a-rel-blond_haired_person_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3ff.png");
}

.e1a-blond-haired_woman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-2640.png");
}

.e1a-rel-blond-haired_woman {
  background-image: url("emojione/assets/4.5/png/128/1f471-2640.png");
}

.e1a-blond-haired_woman_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fb-2640.png");
}

.e1a-rel-blond-haired_woman_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fb-2640.png");
}

.e1a-blond-haired_woman_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fc-2640.png");
}

.e1a-rel-blond-haired_woman_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fc-2640.png");
}

.e1a-blond-haired_woman_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fd-2640.png");
}

.e1a-rel-blond-haired_woman_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fd-2640.png");
}

.e1a-blond-haired_woman_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fe-2640.png");
}

.e1a-rel-blond-haired_woman_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fe-2640.png");
}

.e1a-blond-haired_woman_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3ff-2640.png");
}

.e1a-rel-blond-haired_woman_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3ff-2640.png");
}

.e1a-blond-haired_man {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-2642.png");
}

.e1a-rel-blond-haired_man {
  background-image: url("emojione/assets/4.5/png/128/1f471-2642.png");
}

.e1a-blond-haired_man_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fb-2642.png");
}

.e1a-rel-blond-haired_man_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fb-2642.png");
}

.e1a-blond-haired_man_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fc-2642.png");
}

.e1a-rel-blond-haired_man_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fc-2642.png");
}

.e1a-blond-haired_man_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fd-2642.png");
}

.e1a-rel-blond-haired_man_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fd-2642.png");
}

.e1a-blond-haired_man_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3fe-2642.png");
}

.e1a-rel-blond-haired_man_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3fe-2642.png");
}

.e1a-blond-haired_man_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f471-1f3ff-2642.png");
}

.e1a-rel-blond-haired_man_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f471-1f3ff-2642.png");
}

.e1a-woman_red_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f9b0.png");
}

.e1a-rel-woman_red_haired {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f9b0.png");
}

.e1a-woman_red_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f9b0.png");
}

.e1a-rel-woman_red_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f9b0.png");
}

.e1a-woman_red_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f9b0.png");
}

.e1a-rel-woman_red_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f9b0.png");
}

.e1a-woman_red_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f9b0.png");
}

.e1a-rel-woman_red_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f9b0.png");
}

.e1a-woman_red_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f9b0.png");
}

.e1a-rel-woman_red_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f9b0.png");
}

.e1a-woman_red_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f9b0.png");
}

.e1a-rel-woman_red_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f9b0.png");
}

.e1a-man_red_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f9b0.png");
}

.e1a-rel-man_red_haired {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f9b0.png");
}

.e1a-man_red_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f9b0.png");
}

.e1a-rel-man_red_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f9b0.png");
}

.e1a-man_red_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f9b0.png");
}

.e1a-rel-man_red_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f9b0.png");
}

.e1a-man_red_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f9b0.png");
}

.e1a-rel-man_red_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f9b0.png");
}

.e1a-man_red_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f9b0.png");
}

.e1a-rel-man_red_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f9b0.png");
}

.e1a-man_red_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f9b0.png");
}

.e1a-rel-man_red_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f9b0.png");
}

.e1a-woman_curly_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f9b1.png");
}

.e1a-rel-woman_curly_haired {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f9b1.png");
}

.e1a-woman_curly_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f9b1.png");
}

.e1a-rel-woman_curly_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f9b1.png");
}

.e1a-woman_curly_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f9b1.png");
}

.e1a-rel-woman_curly_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f9b1.png");
}

.e1a-woman_curly_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f9b1.png");
}

.e1a-rel-woman_curly_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f9b1.png");
}

.e1a-woman_curly_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f9b1.png");
}

.e1a-rel-woman_curly_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f9b1.png");
}

.e1a-woman_curly_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f9b1.png");
}

.e1a-rel-woman_curly_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f9b1.png");
}

.e1a-man_curly_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f9b1.png");
}

.e1a-rel-man_curly_haired {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f9b1.png");
}

.e1a-man_curly_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f9b1.png");
}

.e1a-rel-man_curly_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f9b1.png");
}

.e1a-man_curly_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f9b1.png");
}

.e1a-rel-man_curly_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f9b1.png");
}

.e1a-man_curly_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f9b1.png");
}

.e1a-rel-man_curly_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f9b1.png");
}

.e1a-man_curly_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f9b1.png");
}

.e1a-rel-man_curly_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f9b1.png");
}

.e1a-man_curly_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f9b1.png");
}

.e1a-rel-man_curly_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f9b1.png");
}

.e1a-woman_white_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f9b3.png");
}

.e1a-rel-woman_white_haired {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f9b3.png");
}

.e1a-woman_white_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f9b3.png");
}

.e1a-rel-woman_white_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f9b3.png");
}

.e1a-woman_white_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f9b3.png");
}

.e1a-rel-woman_white_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f9b3.png");
}

.e1a-woman_white_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f9b3.png");
}

.e1a-rel-woman_white_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f9b3.png");
}

.e1a-woman_white_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f9b3.png");
}

.e1a-rel-woman_white_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f9b3.png");
}

.e1a-woman_white_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f9b3.png");
}

.e1a-rel-woman_white_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f9b3.png");
}

.e1a-man_white_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f9b3.png");
}

.e1a-rel-man_white_haired {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f9b3.png");
}

.e1a-man_white_haired_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f9b3.png");
}

.e1a-rel-man_white_haired_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f9b3.png");
}

.e1a-man_white_haired_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f9b3.png");
}

.e1a-rel-man_white_haired_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f9b3.png");
}

.e1a-man_white_haired_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f9b3.png");
}

.e1a-rel-man_white_haired_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f9b3.png");
}

.e1a-man_white_haired_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f9b3.png");
}

.e1a-rel-man_white_haired_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f9b3.png");
}

.e1a-man_white_haired_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f9b3.png");
}

.e1a-rel-man_white_haired_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f9b3.png");
}

.e1a-woman_bald {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f9b2.png");
}

.e1a-rel-woman_bald {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f9b2.png");
}

.e1a-woman_bald_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f9b2.png");
}

.e1a-rel-woman_bald_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f9b2.png");
}

.e1a-woman_bald_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f9b2.png");
}

.e1a-rel-woman_bald_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f9b2.png");
}

.e1a-woman_bald_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f9b2.png");
}

.e1a-rel-woman_bald_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f9b2.png");
}

.e1a-woman_bald_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f9b2.png");
}

.e1a-rel-woman_bald_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f9b2.png");
}

.e1a-woman_bald_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f9b2.png");
}

.e1a-rel-woman_bald_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f9b2.png");
}

.e1a-man_bald {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f9b2.png");
}

.e1a-rel-man_bald {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f9b2.png");
}

.e1a-man_bald_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f9b2.png");
}

.e1a-rel-man_bald_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f9b2.png");
}

.e1a-man_bald_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f9b2.png");
}

.e1a-rel-man_bald_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f9b2.png");
}

.e1a-man_bald_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f9b2.png");
}

.e1a-rel-man_bald_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f9b2.png");
}

.e1a-man_bald_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f9b2.png");
}

.e1a-rel-man_bald_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f9b2.png");
}

.e1a-man_bald_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f9b2.png");
}

.e1a-rel-man_bald_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f9b2.png");
}

.e1a-bearded_person {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4.png");
}

.e1a-rel-bearded_person {
  background-image: url("emojione/assets/4.5/png/128/1f9d4.png");
}

.e1a-bearded_person_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4-1f3fb.png");
}

.e1a-rel-bearded_person_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d4-1f3fb.png");
}

.e1a-bearded_person_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4-1f3fc.png");
}

.e1a-rel-bearded_person_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d4-1f3fc.png");
}

.e1a-bearded_person_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4-1f3fd.png");
}

.e1a-rel-bearded_person_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d4-1f3fd.png");
}

.e1a-bearded_person_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4-1f3fe.png");
}

.e1a-rel-bearded_person_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d4-1f3fe.png");
}

.e1a-bearded_person_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d4-1f3ff.png");
}

.e1a-rel-bearded_person_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d4-1f3ff.png");
}

.e1a-older_woman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475.png");
}

.e1a-rel-older_woman {
  background-image: url("emojione/assets/4.5/png/128/1f475.png");
}

.e1a-older_woman_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475-1f3fb.png");
}

.e1a-rel-older_woman_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f475-1f3fb.png");
}

.e1a-older_woman_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475-1f3fc.png");
}

.e1a-rel-older_woman_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f475-1f3fc.png");
}

.e1a-older_woman_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475-1f3fd.png");
}

.e1a-rel-older_woman_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f475-1f3fd.png");
}

.e1a-older_woman_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475-1f3fe.png");
}

.e1a-rel-older_woman_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f475-1f3fe.png");
}

.e1a-older_woman_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f475-1f3ff.png");
}

.e1a-rel-older_woman_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f475-1f3ff.png");
}

.e1a-older_adult {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3.png");
}

.e1a-rel-older_adult {
  background-image: url("emojione/assets/4.5/png/128/1f9d3.png");
}

.e1a-older_adult_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3-1f3fb.png");
}

.e1a-rel-older_adult_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d3-1f3fb.png");
}

.e1a-older_adult_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3-1f3fc.png");
}

.e1a-rel-older_adult_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d3-1f3fc.png");
}

.e1a-older_adult_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3-1f3fd.png");
}

.e1a-rel-older_adult_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d3-1f3fd.png");
}

.e1a-older_adult_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3-1f3fe.png");
}

.e1a-rel-older_adult_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d3-1f3fe.png");
}

.e1a-older_adult_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d3-1f3ff.png");
}

.e1a-rel-older_adult_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d3-1f3ff.png");
}

.e1a-older_man {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474.png");
}

.e1a-rel-older_man {
  background-image: url("emojione/assets/4.5/png/128/1f474.png");
}

.e1a-older_man_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474-1f3fb.png");
}

.e1a-rel-older_man_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f474-1f3fb.png");
}

.e1a-older_man_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474-1f3fc.png");
}

.e1a-rel-older_man_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f474-1f3fc.png");
}

.e1a-older_man_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474-1f3fd.png");
}

.e1a-rel-older_man_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f474-1f3fd.png");
}

.e1a-older_man_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474-1f3fe.png");
}

.e1a-rel-older_man_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f474-1f3fe.png");
}

.e1a-older_man_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f474-1f3ff.png");
}

.e1a-rel-older_man_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f474-1f3ff.png");
}

.e1a-man_with_chinese_cap {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472.png");
}

.e1a-rel-man_with_chinese_cap {
  background-image: url("emojione/assets/4.5/png/128/1f472.png");
}

.e1a-man_with_chinese_cap_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472-1f3fb.png");
}

.e1a-rel-man_with_chinese_cap_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f472-1f3fb.png");
}

.e1a-man_with_chinese_cap_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472-1f3fc.png");
}

.e1a-rel-man_with_chinese_cap_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f472-1f3fc.png");
}

.e1a-man_with_chinese_cap_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472-1f3fd.png");
}

.e1a-rel-man_with_chinese_cap_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f472-1f3fd.png");
}

.e1a-man_with_chinese_cap_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472-1f3fe.png");
}

.e1a-rel-man_with_chinese_cap_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f472-1f3fe.png");
}

.e1a-man_with_chinese_cap_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f472-1f3ff.png");
}

.e1a-rel-man_with_chinese_cap_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f472-1f3ff.png");
}

.e1a-person_wearing_turban {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473.png");
}

.e1a-rel-person_wearing_turban {
  background-image: url("emojione/assets/4.5/png/128/1f473.png");
}

.e1a-person_wearing_turban_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fb.png");
}

.e1a-rel-person_wearing_turban_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fb.png");
}

.e1a-person_wearing_turban_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fc.png");
}

.e1a-rel-person_wearing_turban_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fc.png");
}

.e1a-person_wearing_turban_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fd.png");
}

.e1a-rel-person_wearing_turban_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fd.png");
}

.e1a-person_wearing_turban_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fe.png");
}

.e1a-rel-person_wearing_turban_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fe.png");
}

.e1a-person_wearing_turban_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3ff.png");
}

.e1a-rel-person_wearing_turban_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3ff.png");
}

.e1a-woman_wearing_turban {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-2640.png");
}

.e1a-rel-woman_wearing_turban {
  background-image: url("emojione/assets/4.5/png/128/1f473-2640.png");
}

.e1a-woman_wearing_turban_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fb-2640.png");
}

.e1a-rel-woman_wearing_turban_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fb-2640.png");
}

.e1a-woman_wearing_turban_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fc-2640.png");
}

.e1a-rel-woman_wearing_turban_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fc-2640.png");
}

.e1a-woman_wearing_turban_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fd-2640.png");
}

.e1a-rel-woman_wearing_turban_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fd-2640.png");
}

.e1a-woman_wearing_turban_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fe-2640.png");
}

.e1a-rel-woman_wearing_turban_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fe-2640.png");
}

.e1a-woman_wearing_turban_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3ff-2640.png");
}

.e1a-rel-woman_wearing_turban_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3ff-2640.png");
}

.e1a-man_wearing_turban {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-2642.png");
}

.e1a-rel-man_wearing_turban {
  background-image: url("emojione/assets/4.5/png/128/1f473-2642.png");
}

.e1a-man_wearing_turban_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fb-2642.png");
}

.e1a-rel-man_wearing_turban_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fb-2642.png");
}

.e1a-man_wearing_turban_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fc-2642.png");
}

.e1a-rel-man_wearing_turban_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fc-2642.png");
}

.e1a-man_wearing_turban_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fd-2642.png");
}

.e1a-rel-man_wearing_turban_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fd-2642.png");
}

.e1a-man_wearing_turban_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3fe-2642.png");
}

.e1a-rel-man_wearing_turban_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3fe-2642.png");
}

.e1a-man_wearing_turban_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f473-1f3ff-2642.png");
}

.e1a-rel-man_wearing_turban_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f473-1f3ff-2642.png");
}

.e1a-woman_with_headscarf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5.png");
}

.e1a-rel-woman_with_headscarf {
  background-image: url("emojione/assets/4.5/png/128/1f9d5.png");
}

.e1a-woman_with_headscarf_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5-1f3fb.png");
}

.e1a-rel-woman_with_headscarf_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d5-1f3fb.png");
}

.e1a-woman_with_headscarf_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5-1f3fc.png");
}

.e1a-rel-woman_with_headscarf_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d5-1f3fc.png");
}

.e1a-woman_with_headscarf_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5-1f3fd.png");
}

.e1a-rel-woman_with_headscarf_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d5-1f3fd.png");
}

.e1a-woman_with_headscarf_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5-1f3fe.png");
}

.e1a-rel-woman_with_headscarf_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d5-1f3fe.png");
}

.e1a-woman_with_headscarf_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d5-1f3ff.png");
}

.e1a-rel-woman_with_headscarf_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d5-1f3ff.png");
}

.e1a-police_officer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e.png");
}

.e1a-rel-police_officer {
  background-image: url("emojione/assets/4.5/png/128/1f46e.png");
}

.e1a-police_officer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fb.png");
}

.e1a-rel-police_officer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fb.png");
}

.e1a-police_officer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fc.png");
}

.e1a-rel-police_officer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fc.png");
}

.e1a-police_officer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fd.png");
}

.e1a-rel-police_officer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fd.png");
}

.e1a-police_officer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fe.png");
}

.e1a-rel-police_officer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fe.png");
}

.e1a-police_officer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3ff.png");
}

.e1a-rel-police_officer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3ff.png");
}

.e1a-woman_police_officer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-2640.png");
}

.e1a-rel-woman_police_officer {
  background-image: url("emojione/assets/4.5/png/128/1f46e-2640.png");
}

.e1a-woman_police_officer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fb-2640.png");
}

.e1a-rel-woman_police_officer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fb-2640.png");
}

.e1a-woman_police_officer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fc-2640.png");
}

.e1a-rel-woman_police_officer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fc-2640.png");
}

.e1a-woman_police_officer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fd-2640.png");
}

.e1a-rel-woman_police_officer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fd-2640.png");
}

.e1a-woman_police_officer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fe-2640.png");
}

.e1a-rel-woman_police_officer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fe-2640.png");
}

.e1a-woman_police_officer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3ff-2640.png");
}

.e1a-rel-woman_police_officer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3ff-2640.png");
}

.e1a-man_police_officer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-2642.png");
}

.e1a-rel-man_police_officer {
  background-image: url("emojione/assets/4.5/png/128/1f46e-2642.png");
}

.e1a-man_police_officer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fb-2642.png");
}

.e1a-rel-man_police_officer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fb-2642.png");
}

.e1a-man_police_officer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fc-2642.png");
}

.e1a-rel-man_police_officer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fc-2642.png");
}

.e1a-man_police_officer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fd-2642.png");
}

.e1a-rel-man_police_officer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fd-2642.png");
}

.e1a-man_police_officer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3fe-2642.png");
}

.e1a-rel-man_police_officer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3fe-2642.png");
}

.e1a-man_police_officer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46e-1f3ff-2642.png");
}

.e1a-rel-man_police_officer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f46e-1f3ff-2642.png");
}

.e1a-construction_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477.png");
}

.e1a-rel-construction_worker {
  background-image: url("emojione/assets/4.5/png/128/1f477.png");
}

.e1a-construction_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fb.png");
}

.e1a-rel-construction_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fb.png");
}

.e1a-construction_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fc.png");
}

.e1a-rel-construction_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fc.png");
}

.e1a-construction_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fd.png");
}

.e1a-rel-construction_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fd.png");
}

.e1a-construction_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fe.png");
}

.e1a-rel-construction_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fe.png");
}

.e1a-construction_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3ff.png");
}

.e1a-rel-construction_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3ff.png");
}

.e1a-woman_construction_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-2640.png");
}

.e1a-rel-woman_construction_worker {
  background-image: url("emojione/assets/4.5/png/128/1f477-2640.png");
}

.e1a-woman_construction_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fb-2640.png");
}

.e1a-rel-woman_construction_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fb-2640.png");
}

.e1a-woman_construction_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fc-2640.png");
}

.e1a-rel-woman_construction_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fc-2640.png");
}

.e1a-woman_construction_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fd-2640.png");
}

.e1a-rel-woman_construction_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fd-2640.png");
}

.e1a-woman_construction_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fe-2640.png");
}

.e1a-rel-woman_construction_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fe-2640.png");
}

.e1a-woman_construction_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3ff-2640.png");
}

.e1a-rel-woman_construction_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3ff-2640.png");
}

.e1a-man_construction_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-2642.png");
}

.e1a-rel-man_construction_worker {
  background-image: url("emojione/assets/4.5/png/128/1f477-2642.png");
}

.e1a-man_construction_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fb-2642.png");
}

.e1a-rel-man_construction_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fb-2642.png");
}

.e1a-man_construction_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fc-2642.png");
}

.e1a-rel-man_construction_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fc-2642.png");
}

.e1a-man_construction_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fd-2642.png");
}

.e1a-rel-man_construction_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fd-2642.png");
}

.e1a-man_construction_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3fe-2642.png");
}

.e1a-rel-man_construction_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3fe-2642.png");
}

.e1a-man_construction_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f477-1f3ff-2642.png");
}

.e1a-rel-man_construction_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f477-1f3ff-2642.png");
}

.e1a-guard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482.png");
}

.e1a-rel-guard {
  background-image: url("emojione/assets/4.5/png/128/1f482.png");
}

.e1a-guard_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fb.png");
}

.e1a-rel-guard_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fb.png");
}

.e1a-guard_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fc.png");
}

.e1a-rel-guard_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fc.png");
}

.e1a-guard_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fd.png");
}

.e1a-rel-guard_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fd.png");
}

.e1a-guard_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fe.png");
}

.e1a-rel-guard_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fe.png");
}

.e1a-guard_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3ff.png");
}

.e1a-rel-guard_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3ff.png");
}

.e1a-woman_guard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-2640.png");
}

.e1a-rel-woman_guard {
  background-image: url("emojione/assets/4.5/png/128/1f482-2640.png");
}

.e1a-woman_guard_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fb-2640.png");
}

.e1a-rel-woman_guard_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fb-2640.png");
}

.e1a-woman_guard_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fc-2640.png");
}

.e1a-rel-woman_guard_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fc-2640.png");
}

.e1a-woman_guard_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fd-2640.png");
}

.e1a-rel-woman_guard_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fd-2640.png");
}

.e1a-woman_guard_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fe-2640.png");
}

.e1a-rel-woman_guard_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fe-2640.png");
}

.e1a-woman_guard_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3ff-2640.png");
}

.e1a-rel-woman_guard_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3ff-2640.png");
}

.e1a-man_guard {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-2642.png");
}

.e1a-rel-man_guard {
  background-image: url("emojione/assets/4.5/png/128/1f482-2642.png");
}

.e1a-man_guard_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fb-2642.png");
}

.e1a-rel-man_guard_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fb-2642.png");
}

.e1a-man_guard_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fc-2642.png");
}

.e1a-rel-man_guard_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fc-2642.png");
}

.e1a-man_guard_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fd-2642.png");
}

.e1a-rel-man_guard_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fd-2642.png");
}

.e1a-man_guard_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3fe-2642.png");
}

.e1a-rel-man_guard_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3fe-2642.png");
}

.e1a-man_guard_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f482-1f3ff-2642.png");
}

.e1a-rel-man_guard_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f482-1f3ff-2642.png");
}

.e1a-detective {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575.png");
}

.e1a-rel-detective {
  background-image: url("emojione/assets/4.5/png/128/1f575.png");
}

.e1a-detective_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fb.png");
}

.e1a-rel-detective_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fb.png");
}

.e1a-detective_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fc.png");
}

.e1a-rel-detective_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fc.png");
}

.e1a-detective_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fd.png");
}

.e1a-rel-detective_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fd.png");
}

.e1a-detective_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fe.png");
}

.e1a-rel-detective_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fe.png");
}

.e1a-detective_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3ff.png");
}

.e1a-rel-detective_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3ff.png");
}

.e1a-woman_detective {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-2640.png");
}

.e1a-rel-woman_detective {
  background-image: url("emojione/assets/4.5/png/128/1f575-2640.png");
}

.e1a-woman_detective_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fb-2640.png");
}

.e1a-rel-woman_detective_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fb-2640.png");
}

.e1a-woman_detective_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fc-2640.png");
}

.e1a-rel-woman_detective_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fc-2640.png");
}

.e1a-woman_detective_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fd-2640.png");
}

.e1a-rel-woman_detective_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fd-2640.png");
}

.e1a-woman_detective_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fe-2640.png");
}

.e1a-rel-woman_detective_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fe-2640.png");
}

.e1a-woman_detective_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3ff-2640.png");
}

.e1a-rel-woman_detective_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3ff-2640.png");
}

.e1a-man_detective {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-2642.png");
}

.e1a-rel-man_detective {
  background-image: url("emojione/assets/4.5/png/128/1f575-2642.png");
}

.e1a-man_detective_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fb-2642.png");
}

.e1a-rel-man_detective_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fb-2642.png");
}

.e1a-man_detective_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fc-2642.png");
}

.e1a-rel-man_detective_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fc-2642.png");
}

.e1a-man_detective_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fd-2642.png");
}

.e1a-rel-man_detective_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fd-2642.png");
}

.e1a-man_detective_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3fe-2642.png");
}

.e1a-rel-man_detective_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3fe-2642.png");
}

.e1a-man_detective_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f575-1f3ff-2642.png");
}

.e1a-rel-man_detective_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f575-1f3ff-2642.png");
}

.e1a-woman_health_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2695.png");
}

.e1a-rel-woman_health_worker {
  background-image: url("emojione/assets/4.5/png/128/1f469-2695.png");
}

.e1a-woman_health_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-2695.png");
}

.e1a-rel-woman_health_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-2695.png");
}

.e1a-woman_health_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-2695.png");
}

.e1a-rel-woman_health_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-2695.png");
}

.e1a-woman_health_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-2695.png");
}

.e1a-rel-woman_health_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-2695.png");
}

.e1a-woman_health_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-2695.png");
}

.e1a-rel-woman_health_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-2695.png");
}

.e1a-woman_health_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-2695.png");
}

.e1a-rel-woman_health_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-2695.png");
}

.e1a-man_health_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-2695.png");
}

.e1a-rel-man_health_worker {
  background-image: url("emojione/assets/4.5/png/128/1f468-2695.png");
}

.e1a-man_health_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-2695.png");
}

.e1a-rel-man_health_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-2695.png");
}

.e1a-man_health_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-2695.png");
}

.e1a-rel-man_health_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-2695.png");
}

.e1a-man_health_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-2695.png");
}

.e1a-rel-man_health_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-2695.png");
}

.e1a-man_health_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-2695.png");
}

.e1a-rel-man_health_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-2695.png");
}

.e1a-man_health_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-2695.png");
}

.e1a-rel-man_health_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-2695.png");
}

.e1a-woman_farmer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f33e.png");
}

.e1a-rel-woman_farmer {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f33e.png");
}

.e1a-woman_farmer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f33e.png");
}

.e1a-rel-woman_farmer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f33e.png");
}

.e1a-woman_farmer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f33e.png");
}

.e1a-rel-woman_farmer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f33e.png");
}

.e1a-woman_farmer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f33e.png");
}

.e1a-rel-woman_farmer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f33e.png");
}

.e1a-woman_farmer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f33e.png");
}

.e1a-rel-woman_farmer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f33e.png");
}

.e1a-woman_farmer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f33e.png");
}

.e1a-rel-woman_farmer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f33e.png");
}

.e1a-man_farmer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f33e.png");
}

.e1a-rel-man_farmer {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f33e.png");
}

.e1a-man_farmer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f33e.png");
}

.e1a-rel-man_farmer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f33e.png");
}

.e1a-man_farmer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f33e.png");
}

.e1a-rel-man_farmer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f33e.png");
}

.e1a-man_farmer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f33e.png");
}

.e1a-rel-man_farmer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f33e.png");
}

.e1a-man_farmer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f33e.png");
}

.e1a-rel-man_farmer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f33e.png");
}

.e1a-man_farmer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f33e.png");
}

.e1a-rel-man_farmer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f33e.png");
}

.e1a-woman_cook {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f373.png");
}

.e1a-rel-woman_cook {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f373.png");
}

.e1a-woman_cook_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f373.png");
}

.e1a-rel-woman_cook_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f373.png");
}

.e1a-woman_cook_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f373.png");
}

.e1a-rel-woman_cook_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f373.png");
}

.e1a-woman_cook_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f373.png");
}

.e1a-rel-woman_cook_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f373.png");
}

.e1a-woman_cook_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f373.png");
}

.e1a-rel-woman_cook_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f373.png");
}

.e1a-woman_cook_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f373.png");
}

.e1a-rel-woman_cook_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f373.png");
}

.e1a-man_cook {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f373.png");
}

.e1a-rel-man_cook {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f373.png");
}

.e1a-man_cook_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f373.png");
}

.e1a-rel-man_cook_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f373.png");
}

.e1a-man_cook_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f373.png");
}

.e1a-rel-man_cook_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f373.png");
}

.e1a-man_cook_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f373.png");
}

.e1a-rel-man_cook_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f373.png");
}

.e1a-man_cook_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f373.png");
}

.e1a-rel-man_cook_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f373.png");
}

.e1a-man_cook_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f373.png");
}

.e1a-rel-man_cook_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f373.png");
}

.e1a-woman_student {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f393.png");
}

.e1a-rel-woman_student {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f393.png");
}

.e1a-woman_student_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f393.png");
}

.e1a-rel-woman_student_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f393.png");
}

.e1a-woman_student_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f393.png");
}

.e1a-rel-woman_student_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f393.png");
}

.e1a-woman_student_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f393.png");
}

.e1a-rel-woman_student_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f393.png");
}

.e1a-woman_student_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f393.png");
}

.e1a-rel-woman_student_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f393.png");
}

.e1a-woman_student_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f393.png");
}

.e1a-rel-woman_student_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f393.png");
}

.e1a-man_student {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f393.png");
}

.e1a-rel-man_student {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f393.png");
}

.e1a-man_student_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f393.png");
}

.e1a-rel-man_student_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f393.png");
}

.e1a-man_student_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f393.png");
}

.e1a-rel-man_student_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f393.png");
}

.e1a-man_student_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f393.png");
}

.e1a-rel-man_student_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f393.png");
}

.e1a-man_student_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f393.png");
}

.e1a-rel-man_student_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f393.png");
}

.e1a-man_student_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f393.png");
}

.e1a-rel-man_student_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f393.png");
}

.e1a-woman_singer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3a4.png");
}

.e1a-rel-woman_singer {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3a4.png");
}

.e1a-woman_singer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f3a4.png");
}

.e1a-rel-woman_singer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f3a4.png");
}

.e1a-woman_singer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f3a4.png");
}

.e1a-rel-woman_singer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f3a4.png");
}

.e1a-woman_singer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f3a4.png");
}

.e1a-rel-woman_singer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f3a4.png");
}

.e1a-woman_singer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f3a4.png");
}

.e1a-rel-woman_singer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f3a4.png");
}

.e1a-woman_singer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f3a4.png");
}

.e1a-rel-woman_singer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f3a4.png");
}

.e1a-man_singer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3a4.png");
}

.e1a-rel-man_singer {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3a4.png");
}

.e1a-man_singer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f3a4.png");
}

.e1a-rel-man_singer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f3a4.png");
}

.e1a-man_singer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f3a4.png");
}

.e1a-rel-man_singer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f3a4.png");
}

.e1a-man_singer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f3a4.png");
}

.e1a-rel-man_singer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f3a4.png");
}

.e1a-man_singer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f3a4.png");
}

.e1a-rel-man_singer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f3a4.png");
}

.e1a-man_singer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f3a4.png");
}

.e1a-rel-man_singer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f3a4.png");
}

.e1a-woman_teacher {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3eb.png");
}

.e1a-rel-woman_teacher {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3eb.png");
}

.e1a-woman_teacher_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f3eb.png");
}

.e1a-rel-woman_teacher_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f3eb.png");
}

.e1a-woman_teacher_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f3eb.png");
}

.e1a-rel-woman_teacher_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f3eb.png");
}

.e1a-woman_teacher_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f3eb.png");
}

.e1a-rel-woman_teacher_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f3eb.png");
}

.e1a-woman_teacher_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f3eb.png");
}

.e1a-rel-woman_teacher_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f3eb.png");
}

.e1a-woman_teacher_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f3eb.png");
}

.e1a-rel-woman_teacher_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f3eb.png");
}

.e1a-man_teacher {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3eb.png");
}

.e1a-rel-man_teacher {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3eb.png");
}

.e1a-man_teacher_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f3eb.png");
}

.e1a-rel-man_teacher_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f3eb.png");
}

.e1a-man_teacher_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f3eb.png");
}

.e1a-rel-man_teacher_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f3eb.png");
}

.e1a-man_teacher_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f3eb.png");
}

.e1a-rel-man_teacher_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f3eb.png");
}

.e1a-man_teacher_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f3eb.png");
}

.e1a-rel-man_teacher_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f3eb.png");
}

.e1a-man_teacher_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f3eb.png");
}

.e1a-rel-man_teacher_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f3eb.png");
}

.e1a-woman_factory_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ed.png");
}

.e1a-rel-woman_factory_worker {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ed.png");
}

.e1a-woman_factory_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f3ed.png");
}

.e1a-rel-woman_factory_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f3ed.png");
}

.e1a-woman_factory_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f3ed.png");
}

.e1a-rel-woman_factory_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f3ed.png");
}

.e1a-woman_factory_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f3ed.png");
}

.e1a-rel-woman_factory_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f3ed.png");
}

.e1a-woman_factory_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f3ed.png");
}

.e1a-rel-woman_factory_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f3ed.png");
}

.e1a-woman_factory_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f3ed.png");
}

.e1a-rel-woman_factory_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f3ed.png");
}

.e1a-man_factory_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ed.png");
}

.e1a-rel-man_factory_worker {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ed.png");
}

.e1a-man_factory_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f3ed.png");
}

.e1a-rel-man_factory_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f3ed.png");
}

.e1a-man_factory_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f3ed.png");
}

.e1a-rel-man_factory_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f3ed.png");
}

.e1a-man_factory_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f3ed.png");
}

.e1a-rel-man_factory_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f3ed.png");
}

.e1a-man_factory_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f3ed.png");
}

.e1a-rel-man_factory_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f3ed.png");
}

.e1a-man_factory_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f3ed.png");
}

.e1a-rel-man_factory_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f3ed.png");
}

.e1a-woman_technologist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f4bb.png");
}

.e1a-rel-woman_technologist {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f4bb.png");
}

.e1a-woman_technologist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f4bb.png");
}

.e1a-rel-woman_technologist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f4bb.png");
}

.e1a-woman_technologist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f4bb.png");
}

.e1a-rel-woman_technologist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f4bb.png");
}

.e1a-woman_technologist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f4bb.png");
}

.e1a-rel-woman_technologist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f4bb.png");
}

.e1a-woman_technologist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f4bb.png");
}

.e1a-rel-woman_technologist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f4bb.png");
}

.e1a-woman_technologist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f4bb.png");
}

.e1a-rel-woman_technologist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f4bb.png");
}

.e1a-man_technologist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f4bb.png");
}

.e1a-rel-man_technologist {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f4bb.png");
}

.e1a-man_technologist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f4bb.png");
}

.e1a-rel-man_technologist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f4bb.png");
}

.e1a-man_technologist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f4bb.png");
}

.e1a-rel-man_technologist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f4bb.png");
}

.e1a-man_technologist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f4bb.png");
}

.e1a-rel-man_technologist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f4bb.png");
}

.e1a-man_technologist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f4bb.png");
}

.e1a-rel-man_technologist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f4bb.png");
}

.e1a-man_technologist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f4bb.png");
}

.e1a-rel-man_technologist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f4bb.png");
}

.e1a-woman_office_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f4bc.png");
}

.e1a-rel-woman_office_worker {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f4bc.png");
}

.e1a-woman_office_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f4bc.png");
}

.e1a-rel-woman_office_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f4bc.png");
}

.e1a-woman_office_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f4bc.png");
}

.e1a-rel-woman_office_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f4bc.png");
}

.e1a-woman_office_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f4bc.png");
}

.e1a-rel-woman_office_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f4bc.png");
}

.e1a-woman_office_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f4bc.png");
}

.e1a-rel-woman_office_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f4bc.png");
}

.e1a-woman_office_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f4bc.png");
}

.e1a-rel-woman_office_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f4bc.png");
}

.e1a-man_office_worker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f4bc.png");
}

.e1a-rel-man_office_worker {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f4bc.png");
}

.e1a-man_office_worker_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f4bc.png");
}

.e1a-rel-man_office_worker_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f4bc.png");
}

.e1a-man_office_worker_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f4bc.png");
}

.e1a-rel-man_office_worker_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f4bc.png");
}

.e1a-man_office_worker_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f4bc.png");
}

.e1a-rel-man_office_worker_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f4bc.png");
}

.e1a-man_office_worker_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f4bc.png");
}

.e1a-rel-man_office_worker_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f4bc.png");
}

.e1a-man_office_worker_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f4bc.png");
}

.e1a-rel-man_office_worker_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f4bc.png");
}

.e1a-woman_mechanic {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f527.png");
}

.e1a-rel-woman_mechanic {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f527.png");
}

.e1a-woman_mechanic_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f527.png");
}

.e1a-rel-woman_mechanic_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f527.png");
}

.e1a-woman_mechanic_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f527.png");
}

.e1a-rel-woman_mechanic_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f527.png");
}

.e1a-woman_mechanic_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f527.png");
}

.e1a-rel-woman_mechanic_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f527.png");
}

.e1a-woman_mechanic_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f527.png");
}

.e1a-rel-woman_mechanic_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f527.png");
}

.e1a-woman_mechanic_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f527.png");
}

.e1a-rel-woman_mechanic_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f527.png");
}

.e1a-man_mechanic {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f527.png");
}

.e1a-rel-man_mechanic {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f527.png");
}

.e1a-man_mechanic_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f527.png");
}

.e1a-rel-man_mechanic_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f527.png");
}

.e1a-man_mechanic_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f527.png");
}

.e1a-rel-man_mechanic_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f527.png");
}

.e1a-man_mechanic_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f527.png");
}

.e1a-rel-man_mechanic_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f527.png");
}

.e1a-man_mechanic_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f527.png");
}

.e1a-rel-man_mechanic_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f527.png");
}

.e1a-man_mechanic_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f527.png");
}

.e1a-rel-man_mechanic_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f527.png");
}

.e1a-woman_scientist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f52c.png");
}

.e1a-rel-woman_scientist {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f52c.png");
}

.e1a-woman_scientist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f52c.png");
}

.e1a-rel-woman_scientist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f52c.png");
}

.e1a-woman_scientist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f52c.png");
}

.e1a-rel-woman_scientist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f52c.png");
}

.e1a-woman_scientist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f52c.png");
}

.e1a-rel-woman_scientist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f52c.png");
}

.e1a-woman_scientist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f52c.png");
}

.e1a-rel-woman_scientist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f52c.png");
}

.e1a-woman_scientist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f52c.png");
}

.e1a-rel-woman_scientist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f52c.png");
}

.e1a-man_scientist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f52c.png");
}

.e1a-rel-man_scientist {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f52c.png");
}

.e1a-man_scientist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f52c.png");
}

.e1a-rel-man_scientist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f52c.png");
}

.e1a-man_scientist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f52c.png");
}

.e1a-rel-man_scientist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f52c.png");
}

.e1a-man_scientist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f52c.png");
}

.e1a-rel-man_scientist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f52c.png");
}

.e1a-man_scientist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f52c.png");
}

.e1a-rel-man_scientist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f52c.png");
}

.e1a-man_scientist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f52c.png");
}

.e1a-rel-man_scientist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f52c.png");
}

.e1a-woman_artist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3a8.png");
}

.e1a-rel-woman_artist {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3a8.png");
}

.e1a-woman_artist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f3a8.png");
}

.e1a-rel-woman_artist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f3a8.png");
}

.e1a-woman_artist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f3a8.png");
}

.e1a-rel-woman_artist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f3a8.png");
}

.e1a-woman_artist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f3a8.png");
}

.e1a-rel-woman_artist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f3a8.png");
}

.e1a-woman_artist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f3a8.png");
}

.e1a-rel-woman_artist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f3a8.png");
}

.e1a-woman_artist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f3a8.png");
}

.e1a-rel-woman_artist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f3a8.png");
}

.e1a-man_artist {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3a8.png");
}

.e1a-rel-man_artist {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3a8.png");
}

.e1a-man_artist_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f3a8.png");
}

.e1a-rel-man_artist_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f3a8.png");
}

.e1a-man_artist_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f3a8.png");
}

.e1a-rel-man_artist_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f3a8.png");
}

.e1a-man_artist_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f3a8.png");
}

.e1a-rel-man_artist_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f3a8.png");
}

.e1a-man_artist_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f3a8.png");
}

.e1a-rel-man_artist_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f3a8.png");
}

.e1a-man_artist_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f3a8.png");
}

.e1a-rel-man_artist_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f3a8.png");
}

.e1a-woman_firefighter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f692.png");
}

.e1a-rel-woman_firefighter {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f692.png");
}

.e1a-woman_firefighter_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f692.png");
}

.e1a-rel-woman_firefighter_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f692.png");
}

.e1a-woman_firefighter_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f692.png");
}

.e1a-rel-woman_firefighter_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f692.png");
}

.e1a-woman_firefighter_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f692.png");
}

.e1a-rel-woman_firefighter_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f692.png");
}

.e1a-woman_firefighter_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f692.png");
}

.e1a-rel-woman_firefighter_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f692.png");
}

.e1a-woman_firefighter_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f692.png");
}

.e1a-rel-woman_firefighter_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f692.png");
}

.e1a-man_firefighter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f692.png");
}

.e1a-rel-man_firefighter {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f692.png");
}

.e1a-man_firefighter_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f692.png");
}

.e1a-rel-man_firefighter_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f692.png");
}

.e1a-man_firefighter_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f692.png");
}

.e1a-rel-man_firefighter_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f692.png");
}

.e1a-man_firefighter_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f692.png");
}

.e1a-rel-man_firefighter_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f692.png");
}

.e1a-man_firefighter_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f692.png");
}

.e1a-rel-man_firefighter_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f692.png");
}

.e1a-man_firefighter_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f692.png");
}

.e1a-rel-man_firefighter_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f692.png");
}

.e1a-woman_pilot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2708.png");
}

.e1a-rel-woman_pilot {
  background-image: url("emojione/assets/4.5/png/128/1f469-2708.png");
}

.e1a-woman_pilot_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-2708.png");
}

.e1a-rel-woman_pilot_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-2708.png");
}

.e1a-woman_pilot_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-2708.png");
}

.e1a-rel-woman_pilot_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-2708.png");
}

.e1a-woman_pilot_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-2708.png");
}

.e1a-rel-woman_pilot_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-2708.png");
}

.e1a-woman_pilot_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-2708.png");
}

.e1a-rel-woman_pilot_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-2708.png");
}

.e1a-woman_pilot_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-2708.png");
}

.e1a-rel-woman_pilot_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-2708.png");
}

.e1a-man_pilot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-2708.png");
}

.e1a-rel-man_pilot {
  background-image: url("emojione/assets/4.5/png/128/1f468-2708.png");
}

.e1a-man_pilot_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-2708.png");
}

.e1a-rel-man_pilot_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-2708.png");
}

.e1a-man_pilot_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-2708.png");
}

.e1a-rel-man_pilot_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-2708.png");
}

.e1a-man_pilot_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-2708.png");
}

.e1a-rel-man_pilot_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-2708.png");
}

.e1a-man_pilot_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-2708.png");
}

.e1a-rel-man_pilot_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-2708.png");
}

.e1a-man_pilot_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-2708.png");
}

.e1a-rel-man_pilot_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-2708.png");
}

.e1a-woman_astronaut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f680.png");
}

.e1a-rel-woman_astronaut {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f680.png");
}

.e1a-woman_astronaut_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-1f680.png");
}

.e1a-rel-woman_astronaut_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-1f680.png");
}

.e1a-woman_astronaut_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-1f680.png");
}

.e1a-rel-woman_astronaut_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-1f680.png");
}

.e1a-woman_astronaut_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-1f680.png");
}

.e1a-rel-woman_astronaut_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-1f680.png");
}

.e1a-woman_astronaut_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-1f680.png");
}

.e1a-rel-woman_astronaut_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-1f680.png");
}

.e1a-woman_astronaut_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-1f680.png");
}

.e1a-rel-woman_astronaut_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-1f680.png");
}

.e1a-man_astronaut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f680.png");
}

.e1a-rel-man_astronaut {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f680.png");
}

.e1a-man_astronaut_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-1f680.png");
}

.e1a-rel-man_astronaut_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-1f680.png");
}

.e1a-man_astronaut_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-1f680.png");
}

.e1a-rel-man_astronaut_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-1f680.png");
}

.e1a-man_astronaut_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-1f680.png");
}

.e1a-rel-man_astronaut_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-1f680.png");
}

.e1a-man_astronaut_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-1f680.png");
}

.e1a-rel-man_astronaut_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-1f680.png");
}

.e1a-man_astronaut_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-1f680.png");
}

.e1a-rel-man_astronaut_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-1f680.png");
}

.e1a-woman_judge {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2696.png");
}

.e1a-rel-woman_judge {
  background-image: url("emojione/assets/4.5/png/128/1f469-2696.png");
}

.e1a-woman_judge_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fb-2696.png");
}

.e1a-rel-woman_judge_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fb-2696.png");
}

.e1a-woman_judge_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fc-2696.png");
}

.e1a-rel-woman_judge_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fc-2696.png");
}

.e1a-woman_judge_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fd-2696.png");
}

.e1a-rel-woman_judge_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fd-2696.png");
}

.e1a-woman_judge_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3fe-2696.png");
}

.e1a-rel-woman_judge_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3fe-2696.png");
}

.e1a-woman_judge_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f3ff-2696.png");
}

.e1a-rel-woman_judge_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f3ff-2696.png");
}

.e1a-man_judge {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-2696.png");
}

.e1a-rel-man_judge {
  background-image: url("emojione/assets/4.5/png/128/1f468-2696.png");
}

.e1a-man_judge_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fb-2696.png");
}

.e1a-rel-man_judge_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fb-2696.png");
}

.e1a-man_judge_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fc-2696.png");
}

.e1a-rel-man_judge_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fc-2696.png");
}

.e1a-man_judge_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fd-2696.png");
}

.e1a-rel-man_judge_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fd-2696.png");
}

.e1a-man_judge_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3fe-2696.png");
}

.e1a-rel-man_judge_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3fe-2696.png");
}

.e1a-man_judge_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f3ff-2696.png");
}

.e1a-rel-man_judge_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f3ff-2696.png");
}

.e1a-bride_with_veil {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470.png");
}

.e1a-rel-bride_with_veil {
  background-image: url("emojione/assets/4.5/png/128/1f470.png");
}

.e1a-bride_with_veil_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470-1f3fb.png");
}

.e1a-rel-bride_with_veil_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f470-1f3fb.png");
}

.e1a-bride_with_veil_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470-1f3fc.png");
}

.e1a-rel-bride_with_veil_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f470-1f3fc.png");
}

.e1a-bride_with_veil_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470-1f3fd.png");
}

.e1a-rel-bride_with_veil_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f470-1f3fd.png");
}

.e1a-bride_with_veil_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470-1f3fe.png");
}

.e1a-rel-bride_with_veil_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f470-1f3fe.png");
}

.e1a-bride_with_veil_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f470-1f3ff.png");
}

.e1a-rel-bride_with_veil_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f470-1f3ff.png");
}

.e1a-man_in_tuxedo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935.png");
}

.e1a-rel-man_in_tuxedo {
  background-image: url("emojione/assets/4.5/png/128/1f935.png");
}

.e1a-man_in_tuxedo_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935-1f3fb.png");
}

.e1a-rel-man_in_tuxedo_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f935-1f3fb.png");
}

.e1a-man_in_tuxedo_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935-1f3fc.png");
}

.e1a-rel-man_in_tuxedo_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f935-1f3fc.png");
}

.e1a-man_in_tuxedo_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935-1f3fd.png");
}

.e1a-rel-man_in_tuxedo_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f935-1f3fd.png");
}

.e1a-man_in_tuxedo_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935-1f3fe.png");
}

.e1a-rel-man_in_tuxedo_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f935-1f3fe.png");
}

.e1a-man_in_tuxedo_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f935-1f3ff.png");
}

.e1a-rel-man_in_tuxedo_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f935-1f3ff.png");
}

.e1a-princess {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478.png");
}

.e1a-rel-princess {
  background-image: url("emojione/assets/4.5/png/128/1f478.png");
}

.e1a-princess_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478-1f3fb.png");
}

.e1a-rel-princess_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f478-1f3fb.png");
}

.e1a-princess_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478-1f3fc.png");
}

.e1a-rel-princess_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f478-1f3fc.png");
}

.e1a-princess_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478-1f3fd.png");
}

.e1a-rel-princess_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f478-1f3fd.png");
}

.e1a-princess_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478-1f3fe.png");
}

.e1a-rel-princess_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f478-1f3fe.png");
}

.e1a-princess_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f478-1f3ff.png");
}

.e1a-rel-princess_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f478-1f3ff.png");
}

.e1a-prince {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934.png");
}

.e1a-rel-prince {
  background-image: url("emojione/assets/4.5/png/128/1f934.png");
}

.e1a-prince_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934-1f3fb.png");
}

.e1a-rel-prince_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f934-1f3fb.png");
}

.e1a-prince_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934-1f3fc.png");
}

.e1a-rel-prince_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f934-1f3fc.png");
}

.e1a-prince_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934-1f3fd.png");
}

.e1a-rel-prince_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f934-1f3fd.png");
}

.e1a-prince_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934-1f3fe.png");
}

.e1a-rel-prince_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f934-1f3fe.png");
}

.e1a-prince_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f934-1f3ff.png");
}

.e1a-rel-prince_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f934-1f3ff.png");
}

.e1a-mrs_claus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936.png");
}

.e1a-rel-mrs_claus {
  background-image: url("emojione/assets/4.5/png/128/1f936.png");
}

.e1a-mrs_claus_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936-1f3fb.png");
}

.e1a-rel-mrs_claus_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f936-1f3fb.png");
}

.e1a-mrs_claus_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936-1f3fd.png");
}

.e1a-rel-mrs_claus_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f936-1f3fd.png");
}

.e1a-mrs_claus_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936-1f3fc.png");
}

.e1a-rel-mrs_claus_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f936-1f3fc.png");
}

.e1a-mrs_claus_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936-1f3fe.png");
}

.e1a-rel-mrs_claus_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f936-1f3fe.png");
}

.e1a-mrs_claus_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f936-1f3ff.png");
}

.e1a-rel-mrs_claus_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f936-1f3ff.png");
}

.e1a-santa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385.png");
}

.e1a-rel-santa {
  background-image: url("emojione/assets/4.5/png/128/1f385.png");
}

.e1a-santa_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385-1f3fb.png");
}

.e1a-rel-santa_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f385-1f3fb.png");
}

.e1a-santa_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385-1f3fc.png");
}

.e1a-rel-santa_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f385-1f3fc.png");
}

.e1a-santa_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385-1f3fd.png");
}

.e1a-rel-santa_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f385-1f3fd.png");
}

.e1a-santa_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385-1f3fe.png");
}

.e1a-rel-santa_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f385-1f3fe.png");
}

.e1a-santa_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f385-1f3ff.png");
}

.e1a-rel-santa_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f385-1f3ff.png");
}

.e1a-superhero {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8.png");
}

.e1a-rel-superhero {
  background-image: url("emojione/assets/4.5/png/128/1f9b8.png");
}

.e1a-superhero_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fb.png");
}

.e1a-rel-superhero_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fb.png");
}

.e1a-superhero_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fc.png");
}

.e1a-rel-superhero_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fc.png");
}

.e1a-superhero_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fd.png");
}

.e1a-rel-superhero_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fd.png");
}

.e1a-superhero_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fe.png");
}

.e1a-rel-superhero_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fe.png");
}

.e1a-superhero_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3ff.png");
}

.e1a-rel-superhero_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3ff.png");
}

.e1a-woman_superhero {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-2640.png");
}

.e1a-rel-woman_superhero {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-2640.png");
}

.e1a-woman_superhero_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fb-2640.png");
}

.e1a-rel-woman_superhero_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fb-2640.png");
}

.e1a-woman_superhero_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fc-2640.png");
}

.e1a-rel-woman_superhero_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fc-2640.png");
}

.e1a-woman_superhero_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fd-2640.png");
}

.e1a-rel-woman_superhero_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fd-2640.png");
}

.e1a-woman_superhero_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fe-2640.png");
}

.e1a-rel-woman_superhero_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fe-2640.png");
}

.e1a-woman_superhero_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3ff-2640.png");
}

.e1a-rel-woman_superhero_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3ff-2640.png");
}

.e1a-man_superhero {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-2642.png");
}

.e1a-rel-man_superhero {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-2642.png");
}

.e1a-man_superhero_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fb-2642.png");
}

.e1a-rel-man_superhero_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fb-2642.png");
}

.e1a-man_superhero_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fc-2642.png");
}

.e1a-rel-man_superhero_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fc-2642.png");
}

.e1a-man_superhero_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fd-2642.png");
}

.e1a-rel-man_superhero_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fd-2642.png");
}

.e1a-man_superhero_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3fe-2642.png");
}

.e1a-rel-man_superhero_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3fe-2642.png");
}

.e1a-man_superhero_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b8-1f3ff-2642.png");
}

.e1a-rel-man_superhero_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b8-1f3ff-2642.png");
}

.e1a-supervillain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9.png");
}

.e1a-rel-supervillain {
  background-image: url("emojione/assets/4.5/png/128/1f9b9.png");
}

.e1a-supervillain_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fb.png");
}

.e1a-rel-supervillain_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fb.png");
}

.e1a-supervillain_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fc.png");
}

.e1a-rel-supervillain_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fc.png");
}

.e1a-supervillain_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fd.png");
}

.e1a-rel-supervillain_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fd.png");
}

.e1a-supervillain_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fe.png");
}

.e1a-rel-supervillain_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fe.png");
}

.e1a-supervillain_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3ff.png");
}

.e1a-rel-supervillain_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3ff.png");
}

.e1a-woman_supervillain_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fb-2640.png");
}

.e1a-rel-woman_supervillain_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fb-2640.png");
}

.e1a-woman_supervillain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-2640.png");
}

.e1a-rel-woman_supervillain {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-2640.png");
}

.e1a-woman_supervillain_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fc-2640.png");
}

.e1a-rel-woman_supervillain_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fc-2640.png");
}

.e1a-woman_supervillain_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fd-2640.png");
}

.e1a-rel-woman_supervillain_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fd-2640.png");
}

.e1a-woman_supervillain_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fe-2640.png");
}

.e1a-rel-woman_supervillain_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fe-2640.png");
}

.e1a-woman_supervillain_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3ff-2640.png");
}

.e1a-rel-woman_supervillain_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3ff-2640.png");
}

.e1a-man_supervillain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-2642.png");
}

.e1a-rel-man_supervillain {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-2642.png");
}

.e1a-man_supervillain_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fb-2642.png");
}

.e1a-rel-man_supervillain_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fb-2642.png");
}

.e1a-man_supervillain_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fc-2642.png");
}

.e1a-rel-man_supervillain_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fc-2642.png");
}

.e1a-man_supervillain_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fd-2642.png");
}

.e1a-rel-man_supervillain_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fd-2642.png");
}

.e1a-man_supervillain_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3fe-2642.png");
}

.e1a-rel-man_supervillain_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3fe-2642.png");
}

.e1a-man_supervillain_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b9-1f3ff-2642.png");
}

.e1a-rel-man_supervillain_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9b9-1f3ff-2642.png");
}

.e1a-mage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9.png");
}

.e1a-rel-mage {
  background-image: url("emojione/assets/4.5/png/128/1f9d9.png");
}

.e1a-mage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fb.png");
}

.e1a-rel-mage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fb.png");
}

.e1a-mage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fc.png");
}

.e1a-rel-mage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fc.png");
}

.e1a-mage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fd.png");
}

.e1a-rel-mage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fd.png");
}

.e1a-mage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fe.png");
}

.e1a-rel-mage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fe.png");
}

.e1a-mage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3ff.png");
}

.e1a-rel-mage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3ff.png");
}

.e1a-woman_mage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-2640.png");
}

.e1a-rel-woman_mage {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-2640.png");
}

.e1a-woman_mage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fb-2640.png");
}

.e1a-rel-woman_mage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fb-2640.png");
}

.e1a-woman_mage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fc-2640.png");
}

.e1a-rel-woman_mage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fc-2640.png");
}

.e1a-woman_mage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fd-2640.png");
}

.e1a-rel-woman_mage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fd-2640.png");
}

.e1a-woman_mage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fe-2640.png");
}

.e1a-rel-woman_mage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fe-2640.png");
}

.e1a-woman_mage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3ff-2640.png");
}

.e1a-rel-woman_mage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3ff-2640.png");
}

.e1a-man_mage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-2642.png");
}

.e1a-rel-man_mage {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-2642.png");
}

.e1a-man_mage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fb-2642.png");
}

.e1a-rel-man_mage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fb-2642.png");
}

.e1a-man_mage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fc-2642.png");
}

.e1a-rel-man_mage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fc-2642.png");
}

.e1a-man_mage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fd-2642.png");
}

.e1a-rel-man_mage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fd-2642.png");
}

.e1a-man_mage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3fe-2642.png");
}

.e1a-rel-man_mage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3fe-2642.png");
}

.e1a-man_mage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d9-1f3ff-2642.png");
}

.e1a-rel-man_mage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d9-1f3ff-2642.png");
}

.e1a-elf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd.png");
}

.e1a-rel-elf {
  background-image: url("emojione/assets/4.5/png/128/1f9dd.png");
}

.e1a-elf_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fb.png");
}

.e1a-rel-elf_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fb.png");
}

.e1a-elf_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fc.png");
}

.e1a-rel-elf_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fc.png");
}

.e1a-elf_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fd.png");
}

.e1a-rel-elf_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fd.png");
}

.e1a-elf_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fe.png");
}

.e1a-rel-elf_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fe.png");
}

.e1a-elf_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3ff.png");
}

.e1a-rel-elf_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3ff.png");
}

.e1a-woman_elf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-2640.png");
}

.e1a-rel-woman_elf {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-2640.png");
}

.e1a-woman_elf_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fb-2640.png");
}

.e1a-rel-woman_elf_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fb-2640.png");
}

.e1a-woman_elf_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fc-2640.png");
}

.e1a-rel-woman_elf_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fc-2640.png");
}

.e1a-woman_elf_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fd-2640.png");
}

.e1a-rel-woman_elf_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fd-2640.png");
}

.e1a-woman_elf_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fe-2640.png");
}

.e1a-rel-woman_elf_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fe-2640.png");
}

.e1a-woman_elf_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3ff-2640.png");
}

.e1a-rel-woman_elf_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3ff-2640.png");
}

.e1a-man_elf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-2642.png");
}

.e1a-rel-man_elf {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-2642.png");
}

.e1a-man_elf_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fb-2642.png");
}

.e1a-rel-man_elf_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fb-2642.png");
}

.e1a-man_elf_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fc-2642.png");
}

.e1a-rel-man_elf_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fc-2642.png");
}

.e1a-man_elf_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fd-2642.png");
}

.e1a-rel-man_elf_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fd-2642.png");
}

.e1a-man_elf_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3fe-2642.png");
}

.e1a-rel-man_elf_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3fe-2642.png");
}

.e1a-man_elf_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dd-1f3ff-2642.png");
}

.e1a-rel-man_elf_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dd-1f3ff-2642.png");
}

.e1a-vampire {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db.png");
}

.e1a-rel-vampire {
  background-image: url("emojione/assets/4.5/png/128/1f9db.png");
}

.e1a-vampire_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fb.png");
}

.e1a-rel-vampire_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fb.png");
}

.e1a-vampire_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fc.png");
}

.e1a-rel-vampire_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fc.png");
}

.e1a-vampire_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fd.png");
}

.e1a-rel-vampire_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fd.png");
}

.e1a-vampire_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fe.png");
}

.e1a-rel-vampire_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fe.png");
}

.e1a-vampire_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3ff.png");
}

.e1a-rel-vampire_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3ff.png");
}

.e1a-woman_vampire {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-2640.png");
}

.e1a-rel-woman_vampire {
  background-image: url("emojione/assets/4.5/png/128/1f9db-2640.png");
}

.e1a-woman_vampire_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fb-2640.png");
}

.e1a-rel-woman_vampire_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fb-2640.png");
}

.e1a-woman_vampire_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fc-2640.png");
}

.e1a-rel-woman_vampire_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fc-2640.png");
}

.e1a-woman_vampire_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fd-2640.png");
}

.e1a-rel-woman_vampire_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fd-2640.png");
}

.e1a-woman_vampire_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fe-2640.png");
}

.e1a-rel-woman_vampire_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fe-2640.png");
}

.e1a-woman_vampire_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3ff-2640.png");
}

.e1a-rel-woman_vampire_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3ff-2640.png");
}

.e1a-man_vampire {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-2642.png");
}

.e1a-rel-man_vampire {
  background-image: url("emojione/assets/4.5/png/128/1f9db-2642.png");
}

.e1a-man_vampire_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fb-2642.png");
}

.e1a-rel-man_vampire_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fb-2642.png");
}

.e1a-man_vampire_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fc-2642.png");
}

.e1a-rel-man_vampire_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fc-2642.png");
}

.e1a-man_vampire_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fd-2642.png");
}

.e1a-rel-man_vampire_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fd-2642.png");
}

.e1a-man_vampire_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3fe-2642.png");
}

.e1a-rel-man_vampire_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3fe-2642.png");
}

.e1a-man_vampire_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9db-1f3ff-2642.png");
}

.e1a-rel-man_vampire_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9db-1f3ff-2642.png");
}

.e1a-zombie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9df.png");
}

.e1a-rel-zombie {
  background-image: url("emojione/assets/4.5/png/128/1f9df.png");
}

.e1a-woman_zombie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9df-2640.png");
}

.e1a-rel-woman_zombie {
  background-image: url("emojione/assets/4.5/png/128/1f9df-2640.png");
}

.e1a-man_zombie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9df-2642.png");
}

.e1a-rel-man_zombie {
  background-image: url("emojione/assets/4.5/png/128/1f9df-2642.png");
}

.e1a-genie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9de.png");
}

.e1a-rel-genie {
  background-image: url("emojione/assets/4.5/png/128/1f9de.png");
}

.e1a-woman_genie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9de-2640.png");
}

.e1a-rel-woman_genie {
  background-image: url("emojione/assets/4.5/png/128/1f9de-2640.png");
}

.e1a-man_genie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9de-2642.png");
}

.e1a-rel-man_genie {
  background-image: url("emojione/assets/4.5/png/128/1f9de-2642.png");
}

.e1a-merperson {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc.png");
}

.e1a-rel-merperson {
  background-image: url("emojione/assets/4.5/png/128/1f9dc.png");
}

.e1a-merperson_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fb.png");
}

.e1a-rel-merperson_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fb.png");
}

.e1a-merperson_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fc.png");
}

.e1a-rel-merperson_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fc.png");
}

.e1a-merperson_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fd.png");
}

.e1a-rel-merperson_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fd.png");
}

.e1a-merperson_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fe.png");
}

.e1a-rel-merperson_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fe.png");
}

.e1a-merperson_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3ff.png");
}

.e1a-rel-merperson_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3ff.png");
}

.e1a-mermaid {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-2640.png");
}

.e1a-rel-mermaid {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-2640.png");
}

.e1a-mermaid_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fb-2640.png");
}

.e1a-rel-mermaid_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fb-2640.png");
}

.e1a-mermaid_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fc-2640.png");
}

.e1a-rel-mermaid_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fc-2640.png");
}

.e1a-mermaid_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fd-2640.png");
}

.e1a-rel-mermaid_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fd-2640.png");
}

.e1a-mermaid_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fe-2640.png");
}

.e1a-rel-mermaid_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fe-2640.png");
}

.e1a-mermaid_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3ff-2640.png");
}

.e1a-rel-mermaid_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3ff-2640.png");
}

.e1a-merman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-2642.png");
}

.e1a-rel-merman {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-2642.png");
}

.e1a-merman_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fb-2642.png");
}

.e1a-rel-merman_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fb-2642.png");
}

.e1a-merman_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fc-2642.png");
}

.e1a-rel-merman_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fc-2642.png");
}

.e1a-merman_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fd-2642.png");
}

.e1a-rel-merman_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fd-2642.png");
}

.e1a-merman_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3fe-2642.png");
}

.e1a-rel-merman_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3fe-2642.png");
}

.e1a-merman_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9dc-1f3ff-2642.png");
}

.e1a-rel-merman_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9dc-1f3ff-2642.png");
}

.e1a-fairy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da.png");
}

.e1a-rel-fairy {
  background-image: url("emojione/assets/4.5/png/128/1f9da.png");
}

.e1a-fairy_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fb.png");
}

.e1a-rel-fairy_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fb.png");
}

.e1a-fairy_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fc.png");
}

.e1a-rel-fairy_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fc.png");
}

.e1a-fairy_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fd.png");
}

.e1a-rel-fairy_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fd.png");
}

.e1a-fairy_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fe.png");
}

.e1a-rel-fairy_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fe.png");
}

.e1a-fairy_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3ff.png");
}

.e1a-rel-fairy_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3ff.png");
}

.e1a-woman_fairy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-2640.png");
}

.e1a-rel-woman_fairy {
  background-image: url("emojione/assets/4.5/png/128/1f9da-2640.png");
}

.e1a-woman_fairy_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fb-2640.png");
}

.e1a-rel-woman_fairy_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fb-2640.png");
}

.e1a-woman_fairy_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fc-2640.png");
}

.e1a-rel-woman_fairy_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fc-2640.png");
}

.e1a-woman_fairy_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fd-2640.png");
}

.e1a-rel-woman_fairy_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fd-2640.png");
}

.e1a-woman_fairy_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fe-2640.png");
}

.e1a-rel-woman_fairy_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fe-2640.png");
}

.e1a-woman_fairy_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3ff-2640.png");
}

.e1a-rel-woman_fairy_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3ff-2640.png");
}

.e1a-man_fairy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-2642.png");
}

.e1a-rel-man_fairy {
  background-image: url("emojione/assets/4.5/png/128/1f9da-2642.png");
}

.e1a-man_fairy_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fb-2642.png");
}

.e1a-rel-man_fairy_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fb-2642.png");
}

.e1a-man_fairy_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fc-2642.png");
}

.e1a-rel-man_fairy_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fc-2642.png");
}

.e1a-man_fairy_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fd-2642.png");
}

.e1a-rel-man_fairy_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fd-2642.png");
}

.e1a-man_fairy_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3fe-2642.png");
}

.e1a-rel-man_fairy_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3fe-2642.png");
}

.e1a-man_fairy_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9da-1f3ff-2642.png");
}

.e1a-rel-man_fairy_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9da-1f3ff-2642.png");
}

.e1a-angel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c.png");
}

.e1a-rel-angel {
  background-image: url("emojione/assets/4.5/png/128/1f47c.png");
}

.e1a-angel_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c-1f3fb.png");
}

.e1a-rel-angel_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f47c-1f3fb.png");
}

.e1a-angel_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c-1f3fc.png");
}

.e1a-rel-angel_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f47c-1f3fc.png");
}

.e1a-angel_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c-1f3fd.png");
}

.e1a-rel-angel_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f47c-1f3fd.png");
}

.e1a-angel_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c-1f3fe.png");
}

.e1a-rel-angel_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f47c-1f3fe.png");
}

.e1a-angel_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f47c-1f3ff.png");
}

.e1a-rel-angel_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f47c-1f3ff.png");
}

.e1a-pregnant_woman {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930.png");
}

.e1a-rel-pregnant_woman {
  background-image: url("emojione/assets/4.5/png/128/1f930.png");
}

.e1a-pregnant_woman_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930-1f3fb.png");
}

.e1a-rel-pregnant_woman_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f930-1f3fb.png");
}

.e1a-pregnant_woman_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930-1f3fc.png");
}

.e1a-rel-pregnant_woman_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f930-1f3fc.png");
}

.e1a-pregnant_woman_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930-1f3fd.png");
}

.e1a-rel-pregnant_woman_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f930-1f3fd.png");
}

.e1a-pregnant_woman_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930-1f3fe.png");
}

.e1a-rel-pregnant_woman_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f930-1f3fe.png");
}

.e1a-pregnant_woman_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f930-1f3ff.png");
}

.e1a-rel-pregnant_woman_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f930-1f3ff.png");
}

.e1a-breast_feeding {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931.png");
}

.e1a-rel-breast_feeding {
  background-image: url("emojione/assets/4.5/png/128/1f931.png");
}

.e1a-breast_feeding_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931-1f3fb.png");
}

.e1a-rel-breast_feeding_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f931-1f3fb.png");
}

.e1a-breast_feeding_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931-1f3fc.png");
}

.e1a-rel-breast_feeding_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f931-1f3fc.png");
}

.e1a-breast_feeding_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931-1f3fd.png");
}

.e1a-rel-breast_feeding_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f931-1f3fd.png");
}

.e1a-breast_feeding_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931-1f3fe.png");
}

.e1a-rel-breast_feeding_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f931-1f3fe.png");
}

.e1a-breast_feeding_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f931-1f3ff.png");
}

.e1a-rel-breast_feeding_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f931-1f3ff.png");
}

.e1a-person_bowing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647.png");
}

.e1a-rel-person_bowing {
  background-image: url("emojione/assets/4.5/png/128/1f647.png");
}

.e1a-person_bowing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fb.png");
}

.e1a-rel-person_bowing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fb.png");
}

.e1a-person_bowing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fc.png");
}

.e1a-rel-person_bowing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fc.png");
}

.e1a-person_bowing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fd.png");
}

.e1a-rel-person_bowing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fd.png");
}

.e1a-person_bowing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fe.png");
}

.e1a-rel-person_bowing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fe.png");
}

.e1a-person_bowing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3ff.png");
}

.e1a-rel-person_bowing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3ff.png");
}

.e1a-woman_bowing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-2640.png");
}

.e1a-rel-woman_bowing {
  background-image: url("emojione/assets/4.5/png/128/1f647-2640.png");
}

.e1a-woman_bowing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fb-2640.png");
}

.e1a-rel-woman_bowing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fb-2640.png");
}

.e1a-woman_bowing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fc-2640.png");
}

.e1a-rel-woman_bowing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fc-2640.png");
}

.e1a-woman_bowing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fd-2640.png");
}

.e1a-rel-woman_bowing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fd-2640.png");
}

.e1a-woman_bowing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fe-2640.png");
}

.e1a-rel-woman_bowing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fe-2640.png");
}

.e1a-woman_bowing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3ff-2640.png");
}

.e1a-rel-woman_bowing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3ff-2640.png");
}

.e1a-man_bowing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-2642.png");
}

.e1a-rel-man_bowing {
  background-image: url("emojione/assets/4.5/png/128/1f647-2642.png");
}

.e1a-man_bowing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fb-2642.png");
}

.e1a-rel-man_bowing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fb-2642.png");
}

.e1a-man_bowing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fc-2642.png");
}

.e1a-rel-man_bowing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fc-2642.png");
}

.e1a-man_bowing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fd-2642.png");
}

.e1a-rel-man_bowing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fd-2642.png");
}

.e1a-man_bowing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3fe-2642.png");
}

.e1a-rel-man_bowing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3fe-2642.png");
}

.e1a-man_bowing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f647-1f3ff-2642.png");
}

.e1a-rel-man_bowing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f647-1f3ff-2642.png");
}

.e1a-person_tipping_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481.png");
}

.e1a-rel-person_tipping_hand {
  background-image: url("emojione/assets/4.5/png/128/1f481.png");
}

.e1a-person_tipping_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fb.png");
}

.e1a-rel-person_tipping_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fb.png");
}

.e1a-person_tipping_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fc.png");
}

.e1a-rel-person_tipping_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fc.png");
}

.e1a-person_tipping_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fd.png");
}

.e1a-rel-person_tipping_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fd.png");
}

.e1a-person_tipping_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fe.png");
}

.e1a-rel-person_tipping_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fe.png");
}

.e1a-person_tipping_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3ff.png");
}

.e1a-rel-person_tipping_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3ff.png");
}

.e1a-woman_tipping_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-2640.png");
}

.e1a-rel-woman_tipping_hand {
  background-image: url("emojione/assets/4.5/png/128/1f481-2640.png");
}

.e1a-woman_tipping_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fb-2640.png");
}

.e1a-rel-woman_tipping_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fb-2640.png");
}

.e1a-woman_tipping_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fc-2640.png");
}

.e1a-rel-woman_tipping_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fc-2640.png");
}

.e1a-woman_tipping_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fd-2640.png");
}

.e1a-rel-woman_tipping_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fd-2640.png");
}

.e1a-woman_tipping_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fe-2640.png");
}

.e1a-rel-woman_tipping_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fe-2640.png");
}

.e1a-woman_tipping_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3ff-2640.png");
}

.e1a-rel-woman_tipping_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3ff-2640.png");
}

.e1a-man_tipping_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-2642.png");
}

.e1a-rel-man_tipping_hand {
  background-image: url("emojione/assets/4.5/png/128/1f481-2642.png");
}

.e1a-man_tipping_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fb-2642.png");
}

.e1a-rel-man_tipping_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fb-2642.png");
}

.e1a-man_tipping_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fc-2642.png");
}

.e1a-rel-man_tipping_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fc-2642.png");
}

.e1a-man_tipping_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fd-2642.png");
}

.e1a-rel-man_tipping_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fd-2642.png");
}

.e1a-man_tipping_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3fe-2642.png");
}

.e1a-rel-man_tipping_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3fe-2642.png");
}

.e1a-man_tipping_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f481-1f3ff-2642.png");
}

.e1a-rel-man_tipping_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f481-1f3ff-2642.png");
}

.e1a-person_gesturing_no {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645.png");
}

.e1a-rel-person_gesturing_no {
  background-image: url("emojione/assets/4.5/png/128/1f645.png");
}

.e1a-person_gesturing_no_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fb.png");
}

.e1a-rel-person_gesturing_no_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fb.png");
}

.e1a-person_gesturing_no_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fc.png");
}

.e1a-rel-person_gesturing_no_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fc.png");
}

.e1a-person_gesturing_no_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fd.png");
}

.e1a-rel-person_gesturing_no_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fd.png");
}

.e1a-person_gesturing_no_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fe.png");
}

.e1a-rel-person_gesturing_no_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fe.png");
}

.e1a-person_gesturing_no_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3ff.png");
}

.e1a-rel-person_gesturing_no_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3ff.png");
}

.e1a-woman_gesturing_no {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-2640.png");
}

.e1a-rel-woman_gesturing_no {
  background-image: url("emojione/assets/4.5/png/128/1f645-2640.png");
}

.e1a-woman_gesturing_no_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fb-2640.png");
}

.e1a-rel-woman_gesturing_no_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fb-2640.png");
}

.e1a-woman_gesturing_no_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fc-2640.png");
}

.e1a-rel-woman_gesturing_no_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fc-2640.png");
}

.e1a-woman_gesturing_no_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fd-2640.png");
}

.e1a-rel-woman_gesturing_no_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fd-2640.png");
}

.e1a-woman_gesturing_no_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fe-2640.png");
}

.e1a-rel-woman_gesturing_no_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fe-2640.png");
}

.e1a-woman_gesturing_no_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3ff-2640.png");
}

.e1a-rel-woman_gesturing_no_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3ff-2640.png");
}

.e1a-man_gesturing_no {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-2642.png");
}

.e1a-rel-man_gesturing_no {
  background-image: url("emojione/assets/4.5/png/128/1f645-2642.png");
}

.e1a-man_gesturing_no_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fb-2642.png");
}

.e1a-rel-man_gesturing_no_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fb-2642.png");
}

.e1a-man_gesturing_no_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fc-2642.png");
}

.e1a-rel-man_gesturing_no_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fc-2642.png");
}

.e1a-man_gesturing_no_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fd-2642.png");
}

.e1a-rel-man_gesturing_no_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fd-2642.png");
}

.e1a-man_gesturing_no_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3fe-2642.png");
}

.e1a-rel-man_gesturing_no_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3fe-2642.png");
}

.e1a-man_gesturing_no_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f645-1f3ff-2642.png");
}

.e1a-rel-man_gesturing_no_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f645-1f3ff-2642.png");
}

.e1a-person_gesturing_ok {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646.png");
}

.e1a-rel-person_gesturing_ok {
  background-image: url("emojione/assets/4.5/png/128/1f646.png");
}

.e1a-person_gesturing_ok_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fb.png");
}

.e1a-rel-person_gesturing_ok_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fb.png");
}

.e1a-person_gesturing_ok_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fc.png");
}

.e1a-rel-person_gesturing_ok_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fc.png");
}

.e1a-person_gesturing_ok_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fd.png");
}

.e1a-rel-person_gesturing_ok_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fd.png");
}

.e1a-person_gesturing_ok_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fe.png");
}

.e1a-rel-person_gesturing_ok_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fe.png");
}

.e1a-person_gesturing_ok_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3ff.png");
}

.e1a-rel-person_gesturing_ok_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3ff.png");
}

.e1a-woman_gesturing_ok {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-2640.png");
}

.e1a-rel-woman_gesturing_ok {
  background-image: url("emojione/assets/4.5/png/128/1f646-2640.png");
}

.e1a-woman_gesturing_ok_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fb-2640.png");
}

.e1a-rel-woman_gesturing_ok_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fb-2640.png");
}

.e1a-woman_gesturing_ok_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fc-2640.png");
}

.e1a-rel-woman_gesturing_ok_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fc-2640.png");
}

.e1a-woman_gesturing_ok_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fd-2640.png");
}

.e1a-rel-woman_gesturing_ok_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fd-2640.png");
}

.e1a-woman_gesturing_ok_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fe-2640.png");
}

.e1a-rel-woman_gesturing_ok_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fe-2640.png");
}

.e1a-woman_gesturing_ok_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3ff-2640.png");
}

.e1a-rel-woman_gesturing_ok_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3ff-2640.png");
}

.e1a-man_gesturing_ok {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-2642.png");
}

.e1a-rel-man_gesturing_ok {
  background-image: url("emojione/assets/4.5/png/128/1f646-2642.png");
}

.e1a-man_gesturing_ok_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fb-2642.png");
}

.e1a-rel-man_gesturing_ok_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fb-2642.png");
}

.e1a-man_gesturing_ok_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fc-2642.png");
}

.e1a-rel-man_gesturing_ok_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fc-2642.png");
}

.e1a-man_gesturing_ok_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fd-2642.png");
}

.e1a-rel-man_gesturing_ok_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fd-2642.png");
}

.e1a-man_gesturing_ok_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3fe-2642.png");
}

.e1a-rel-man_gesturing_ok_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3fe-2642.png");
}

.e1a-man_gesturing_ok_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f646-1f3ff-2642.png");
}

.e1a-rel-man_gesturing_ok_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f646-1f3ff-2642.png");
}

.e1a-person_raising_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b.png");
}

.e1a-rel-person_raising_hand {
  background-image: url("emojione/assets/4.5/png/128/1f64b.png");
}

.e1a-person_raising_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fb.png");
}

.e1a-rel-person_raising_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fb.png");
}

.e1a-person_raising_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fc.png");
}

.e1a-rel-person_raising_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fc.png");
}

.e1a-person_raising_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fd.png");
}

.e1a-rel-person_raising_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fd.png");
}

.e1a-person_raising_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fe.png");
}

.e1a-rel-person_raising_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fe.png");
}

.e1a-person_raising_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3ff.png");
}

.e1a-rel-person_raising_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3ff.png");
}

.e1a-woman_raising_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-2640.png");
}

.e1a-rel-woman_raising_hand {
  background-image: url("emojione/assets/4.5/png/128/1f64b-2640.png");
}

.e1a-woman_raising_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fb-2640.png");
}

.e1a-rel-woman_raising_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fb-2640.png");
}

.e1a-woman_raising_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fc-2640.png");
}

.e1a-rel-woman_raising_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fc-2640.png");
}

.e1a-woman_raising_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fd-2640.png");
}

.e1a-rel-woman_raising_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fd-2640.png");
}

.e1a-woman_raising_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fe-2640.png");
}

.e1a-rel-woman_raising_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fe-2640.png");
}

.e1a-woman_raising_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3ff-2640.png");
}

.e1a-rel-woman_raising_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3ff-2640.png");
}

.e1a-man_raising_hand {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-2642.png");
}

.e1a-rel-man_raising_hand {
  background-image: url("emojione/assets/4.5/png/128/1f64b-2642.png");
}

.e1a-man_raising_hand_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fb-2642.png");
}

.e1a-rel-man_raising_hand_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fb-2642.png");
}

.e1a-man_raising_hand_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fc-2642.png");
}

.e1a-rel-man_raising_hand_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fc-2642.png");
}

.e1a-man_raising_hand_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fd-2642.png");
}

.e1a-rel-man_raising_hand_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fd-2642.png");
}

.e1a-man_raising_hand_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3fe-2642.png");
}

.e1a-rel-man_raising_hand_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3fe-2642.png");
}

.e1a-man_raising_hand_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64b-1f3ff-2642.png");
}

.e1a-rel-man_raising_hand_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64b-1f3ff-2642.png");
}

.e1a-person_facepalming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926.png");
}

.e1a-rel-person_facepalming {
  background-image: url("emojione/assets/4.5/png/128/1f926.png");
}

.e1a-person_facepalming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fb.png");
}

.e1a-rel-person_facepalming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fb.png");
}

.e1a-person_facepalming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fc.png");
}

.e1a-rel-person_facepalming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fc.png");
}

.e1a-person_facepalming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fd.png");
}

.e1a-rel-person_facepalming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fd.png");
}

.e1a-person_facepalming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fe.png");
}

.e1a-rel-person_facepalming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fe.png");
}

.e1a-person_facepalming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3ff.png");
}

.e1a-rel-person_facepalming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3ff.png");
}

.e1a-woman_facepalming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-2640.png");
}

.e1a-rel-woman_facepalming {
  background-image: url("emojione/assets/4.5/png/128/1f926-2640.png");
}

.e1a-woman_facepalming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fb-2640.png");
}

.e1a-rel-woman_facepalming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fb-2640.png");
}

.e1a-woman_facepalming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fc-2640.png");
}

.e1a-rel-woman_facepalming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fc-2640.png");
}

.e1a-woman_facepalming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fd-2640.png");
}

.e1a-rel-woman_facepalming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fd-2640.png");
}

.e1a-woman_facepalming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fe-2640.png");
}

.e1a-rel-woman_facepalming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fe-2640.png");
}

.e1a-woman_facepalming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3ff-2640.png");
}

.e1a-rel-woman_facepalming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3ff-2640.png");
}

.e1a-man_facepalming {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-2642.png");
}

.e1a-rel-man_facepalming {
  background-image: url("emojione/assets/4.5/png/128/1f926-2642.png");
}

.e1a-man_facepalming_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fb-2642.png");
}

.e1a-rel-man_facepalming_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fb-2642.png");
}

.e1a-man_facepalming_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fc-2642.png");
}

.e1a-rel-man_facepalming_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fc-2642.png");
}

.e1a-man_facepalming_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fd-2642.png");
}

.e1a-rel-man_facepalming_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fd-2642.png");
}

.e1a-man_facepalming_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3fe-2642.png");
}

.e1a-rel-man_facepalming_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3fe-2642.png");
}

.e1a-man_facepalming_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f926-1f3ff-2642.png");
}

.e1a-rel-man_facepalming_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f926-1f3ff-2642.png");
}

.e1a-person_shrugging {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937.png");
}

.e1a-rel-person_shrugging {
  background-image: url("emojione/assets/4.5/png/128/1f937.png");
}

.e1a-person_shrugging_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fb.png");
}

.e1a-rel-person_shrugging_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fb.png");
}

.e1a-person_shrugging_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fc.png");
}

.e1a-rel-person_shrugging_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fc.png");
}

.e1a-person_shrugging_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fd.png");
}

.e1a-rel-person_shrugging_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fd.png");
}

.e1a-person_shrugging_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fe.png");
}

.e1a-rel-person_shrugging_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fe.png");
}

.e1a-person_shrugging_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3ff.png");
}

.e1a-rel-person_shrugging_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3ff.png");
}

.e1a-woman_shrugging {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-2640.png");
}

.e1a-rel-woman_shrugging {
  background-image: url("emojione/assets/4.5/png/128/1f937-2640.png");
}

.e1a-woman_shrugging_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fb-2640.png");
}

.e1a-rel-woman_shrugging_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fb-2640.png");
}

.e1a-woman_shrugging_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fc-2640.png");
}

.e1a-rel-woman_shrugging_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fc-2640.png");
}

.e1a-woman_shrugging_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fd-2640.png");
}

.e1a-rel-woman_shrugging_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fd-2640.png");
}

.e1a-woman_shrugging_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fe-2640.png");
}

.e1a-rel-woman_shrugging_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fe-2640.png");
}

.e1a-woman_shrugging_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3ff-2640.png");
}

.e1a-rel-woman_shrugging_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3ff-2640.png");
}

.e1a-man_shrugging {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-2642.png");
}

.e1a-rel-man_shrugging {
  background-image: url("emojione/assets/4.5/png/128/1f937-2642.png");
}

.e1a-man_shrugging_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fb-2642.png");
}

.e1a-rel-man_shrugging_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fb-2642.png");
}

.e1a-man_shrugging_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fc-2642.png");
}

.e1a-rel-man_shrugging_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fc-2642.png");
}

.e1a-man_shrugging_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fd-2642.png");
}

.e1a-rel-man_shrugging_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fd-2642.png");
}

.e1a-man_shrugging_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3fe-2642.png");
}

.e1a-rel-man_shrugging_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3fe-2642.png");
}

.e1a-man_shrugging_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f937-1f3ff-2642.png");
}

.e1a-rel-man_shrugging_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f937-1f3ff-2642.png");
}

.e1a-person_pouting {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e.png");
}

.e1a-rel-person_pouting {
  background-image: url("emojione/assets/4.5/png/128/1f64e.png");
}

.e1a-person_pouting_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fb.png");
}

.e1a-rel-person_pouting_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fb.png");
}

.e1a-person_pouting_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fc.png");
}

.e1a-rel-person_pouting_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fc.png");
}

.e1a-person_pouting_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fd.png");
}

.e1a-rel-person_pouting_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fd.png");
}

.e1a-person_pouting_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fe.png");
}

.e1a-rel-person_pouting_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fe.png");
}

.e1a-person_pouting_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3ff.png");
}

.e1a-rel-person_pouting_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3ff.png");
}

.e1a-woman_pouting {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-2640.png");
}

.e1a-rel-woman_pouting {
  background-image: url("emojione/assets/4.5/png/128/1f64e-2640.png");
}

.e1a-woman_pouting_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fb-2640.png");
}

.e1a-rel-woman_pouting_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fb-2640.png");
}

.e1a-woman_pouting_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fc-2640.png");
}

.e1a-rel-woman_pouting_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fc-2640.png");
}

.e1a-woman_pouting_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fd-2640.png");
}

.e1a-rel-woman_pouting_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fd-2640.png");
}

.e1a-woman_pouting_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fe-2640.png");
}

.e1a-rel-woman_pouting_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fe-2640.png");
}

.e1a-woman_pouting_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3ff-2640.png");
}

.e1a-rel-woman_pouting_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3ff-2640.png");
}

.e1a-man_pouting {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-2642.png");
}

.e1a-rel-man_pouting {
  background-image: url("emojione/assets/4.5/png/128/1f64e-2642.png");
}

.e1a-man_pouting_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fb-2642.png");
}

.e1a-rel-man_pouting_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fb-2642.png");
}

.e1a-man_pouting_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fc-2642.png");
}

.e1a-rel-man_pouting_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fc-2642.png");
}

.e1a-man_pouting_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fd-2642.png");
}

.e1a-rel-man_pouting_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fd-2642.png");
}

.e1a-man_pouting_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3fe-2642.png");
}

.e1a-rel-man_pouting_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3fe-2642.png");
}

.e1a-man_pouting_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64e-1f3ff-2642.png");
}

.e1a-rel-man_pouting_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64e-1f3ff-2642.png");
}

.e1a-person_frowning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d.png");
}

.e1a-rel-person_frowning {
  background-image: url("emojione/assets/4.5/png/128/1f64d.png");
}

.e1a-person_frowning_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fb.png");
}

.e1a-rel-person_frowning_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fb.png");
}

.e1a-person_frowning_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fc.png");
}

.e1a-rel-person_frowning_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fc.png");
}

.e1a-person_frowning_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fd.png");
}

.e1a-rel-person_frowning_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fd.png");
}

.e1a-person_frowning_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fe.png");
}

.e1a-rel-person_frowning_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fe.png");
}

.e1a-person_frowning_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3ff.png");
}

.e1a-rel-person_frowning_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3ff.png");
}

.e1a-woman_frowning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-2640.png");
}

.e1a-rel-woman_frowning {
  background-image: url("emojione/assets/4.5/png/128/1f64d-2640.png");
}

.e1a-woman_frowning_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fb-2640.png");
}

.e1a-rel-woman_frowning_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fb-2640.png");
}

.e1a-woman_frowning_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fc-2640.png");
}

.e1a-rel-woman_frowning_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fc-2640.png");
}

.e1a-woman_frowning_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fd-2640.png");
}

.e1a-rel-woman_frowning_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fd-2640.png");
}

.e1a-woman_frowning_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fe-2640.png");
}

.e1a-rel-woman_frowning_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fe-2640.png");
}

.e1a-woman_frowning_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3ff-2640.png");
}

.e1a-rel-woman_frowning_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3ff-2640.png");
}

.e1a-man_frowning {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-2642.png");
}

.e1a-rel-man_frowning {
  background-image: url("emojione/assets/4.5/png/128/1f64d-2642.png");
}

.e1a-man_frowning_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fb-2642.png");
}

.e1a-rel-man_frowning_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fb-2642.png");
}

.e1a-man_frowning_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fc-2642.png");
}

.e1a-rel-man_frowning_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fc-2642.png");
}

.e1a-man_frowning_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fd-2642.png");
}

.e1a-rel-man_frowning_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fd-2642.png");
}

.e1a-man_frowning_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3fe-2642.png");
}

.e1a-rel-man_frowning_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3fe-2642.png");
}

.e1a-man_frowning_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f64d-1f3ff-2642.png");
}

.e1a-rel-man_frowning_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f64d-1f3ff-2642.png");
}

.e1a-person_getting_haircut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487.png");
}

.e1a-rel-person_getting_haircut {
  background-image: url("emojione/assets/4.5/png/128/1f487.png");
}

.e1a-person_getting_haircut_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fb.png");
}

.e1a-rel-person_getting_haircut_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fb.png");
}

.e1a-person_getting_haircut_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fc.png");
}

.e1a-rel-person_getting_haircut_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fc.png");
}

.e1a-person_getting_haircut_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fd.png");
}

.e1a-rel-person_getting_haircut_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fd.png");
}

.e1a-person_getting_haircut_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fe.png");
}

.e1a-rel-person_getting_haircut_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fe.png");
}

.e1a-person_getting_haircut_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3ff.png");
}

.e1a-rel-person_getting_haircut_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3ff.png");
}

.e1a-woman_getting_haircut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-2640.png");
}

.e1a-rel-woman_getting_haircut {
  background-image: url("emojione/assets/4.5/png/128/1f487-2640.png");
}

.e1a-woman_getting_haircut_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fb-2640.png");
}

.e1a-rel-woman_getting_haircut_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fb-2640.png");
}

.e1a-woman_getting_haircut_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fc-2640.png");
}

.e1a-rel-woman_getting_haircut_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fc-2640.png");
}

.e1a-woman_getting_haircut_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fd-2640.png");
}

.e1a-rel-woman_getting_haircut_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fd-2640.png");
}

.e1a-woman_getting_haircut_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fe-2640.png");
}

.e1a-rel-woman_getting_haircut_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fe-2640.png");
}

.e1a-woman_getting_haircut_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3ff-2640.png");
}

.e1a-rel-woman_getting_haircut_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3ff-2640.png");
}

.e1a-man_getting_haircut {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-2642.png");
}

.e1a-rel-man_getting_haircut {
  background-image: url("emojione/assets/4.5/png/128/1f487-2642.png");
}

.e1a-man_getting_haircut_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fb-2642.png");
}

.e1a-rel-man_getting_haircut_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fb-2642.png");
}

.e1a-man_getting_haircut_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fc-2642.png");
}

.e1a-rel-man_getting_haircut_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fc-2642.png");
}

.e1a-man_getting_haircut_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fd-2642.png");
}

.e1a-rel-man_getting_haircut_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fd-2642.png");
}

.e1a-man_getting_haircut_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3fe-2642.png");
}

.e1a-rel-man_getting_haircut_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3fe-2642.png");
}

.e1a-man_getting_haircut_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f487-1f3ff-2642.png");
}

.e1a-rel-man_getting_haircut_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f487-1f3ff-2642.png");
}

.e1a-person_getting_massage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486.png");
}

.e1a-rel-person_getting_massage {
  background-image: url("emojione/assets/4.5/png/128/1f486.png");
}

.e1a-person_getting_massage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fb.png");
}

.e1a-rel-person_getting_massage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fb.png");
}

.e1a-person_getting_massage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fc.png");
}

.e1a-rel-person_getting_massage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fc.png");
}

.e1a-person_getting_massage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fd.png");
}

.e1a-rel-person_getting_massage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fd.png");
}

.e1a-person_getting_massage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fe.png");
}

.e1a-rel-person_getting_massage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fe.png");
}

.e1a-person_getting_massage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3ff.png");
}

.e1a-rel-person_getting_massage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3ff.png");
}

.e1a-woman_getting_face_massage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-2640.png");
}

.e1a-rel-woman_getting_face_massage {
  background-image: url("emojione/assets/4.5/png/128/1f486-2640.png");
}

.e1a-woman_getting_face_massage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fb-2640.png");
}

.e1a-rel-woman_getting_face_massage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fb-2640.png");
}

.e1a-woman_getting_face_massage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fc-2640.png");
}

.e1a-rel-woman_getting_face_massage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fc-2640.png");
}

.e1a-woman_getting_face_massage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fd-2640.png");
}

.e1a-rel-woman_getting_face_massage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fd-2640.png");
}

.e1a-woman_getting_face_massage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fe-2640.png");
}

.e1a-rel-woman_getting_face_massage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fe-2640.png");
}

.e1a-woman_getting_face_massage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3ff-2640.png");
}

.e1a-rel-woman_getting_face_massage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3ff-2640.png");
}

.e1a-man_getting_face_massage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-2642.png");
}

.e1a-rel-man_getting_face_massage {
  background-image: url("emojione/assets/4.5/png/128/1f486-2642.png");
}

.e1a-man_getting_face_massage_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fb-2642.png");
}

.e1a-rel-man_getting_face_massage_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fb-2642.png");
}

.e1a-man_getting_face_massage_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fc-2642.png");
}

.e1a-rel-man_getting_face_massage_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fc-2642.png");
}

.e1a-man_getting_face_massage_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fd-2642.png");
}

.e1a-rel-man_getting_face_massage_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fd-2642.png");
}

.e1a-man_getting_face_massage_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3fe-2642.png");
}

.e1a-rel-man_getting_face_massage_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3fe-2642.png");
}

.e1a-man_getting_face_massage_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f486-1f3ff-2642.png");
}

.e1a-rel-man_getting_face_massage_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f486-1f3ff-2642.png");
}

.e1a-person_in_steamy_room {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6.png");
}

.e1a-rel-person_in_steamy_room {
  background-image: url("emojione/assets/4.5/png/128/1f9d6.png");
}

.e1a-person_in_steamy_room_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fb.png");
}

.e1a-rel-person_in_steamy_room_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fb.png");
}

.e1a-person_in_steamy_room_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fc.png");
}

.e1a-rel-person_in_steamy_room_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fc.png");
}

.e1a-person_in_steamy_room_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fd.png");
}

.e1a-rel-person_in_steamy_room_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fd.png");
}

.e1a-person_in_steamy_room_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fe.png");
}

.e1a-rel-person_in_steamy_room_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fe.png");
}

.e1a-person_in_steamy_room_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3ff.png");
}

.e1a-rel-person_in_steamy_room_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3ff.png");
}

.e1a-woman_in_steamy_room {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-2640.png");
}

.e1a-rel-woman_in_steamy_room {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-2640.png");
}

.e1a-woman_in_steamy_room_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fb-2640.png");
}

.e1a-rel-woman_in_steamy_room_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fb-2640.png");
}

.e1a-woman_in_steamy_room_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fc-2640.png");
}

.e1a-rel-woman_in_steamy_room_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fc-2640.png");
}

.e1a-woman_in_steamy_room_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fd-2640.png");
}

.e1a-rel-woman_in_steamy_room_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fd-2640.png");
}

.e1a-woman_in_steamy_room_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fe-2640.png");
}

.e1a-rel-woman_in_steamy_room_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fe-2640.png");
}

.e1a-woman_in_steamy_room_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3ff-2640.png");
}

.e1a-rel-woman_in_steamy_room_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3ff-2640.png");
}

.e1a-man_in_steamy_room {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-2642.png");
}

.e1a-rel-man_in_steamy_room {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-2642.png");
}

.e1a-man_in_steamy_room_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fb-2642.png");
}

.e1a-rel-man_in_steamy_room_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fb-2642.png");
}

.e1a-man_in_steamy_room_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fc-2642.png");
}

.e1a-rel-man_in_steamy_room_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fc-2642.png");
}

.e1a-man_in_steamy_room_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fd-2642.png");
}

.e1a-rel-man_in_steamy_room_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fd-2642.png");
}

.e1a-man_in_steamy_room_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3fe-2642.png");
}

.e1a-rel-man_in_steamy_room_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3fe-2642.png");
}

.e1a-man_in_steamy_room_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9d6-1f3ff-2642.png");
}

.e1a-rel-man_in_steamy_room_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f9d6-1f3ff-2642.png");
}

.e1a-nail_care {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485.png");
}

.e1a-rel-nail_care {
  background-image: url("emojione/assets/4.5/png/128/1f485.png");
}

.e1a-nail_care_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485-1f3fb.png");
}

.e1a-rel-nail_care_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f485-1f3fb.png");
}

.e1a-nail_care_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485-1f3fc.png");
}

.e1a-rel-nail_care_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f485-1f3fc.png");
}

.e1a-nail_care_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485-1f3fd.png");
}

.e1a-rel-nail_care_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f485-1f3fd.png");
}

.e1a-nail_care_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485-1f3fe.png");
}

.e1a-rel-nail_care_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f485-1f3fe.png");
}

.e1a-nail_care_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f485-1f3ff.png");
}

.e1a-rel-nail_care_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f485-1f3ff.png");
}

.e1a-selfie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933.png");
}

.e1a-rel-selfie {
  background-image: url("emojione/assets/4.5/png/128/1f933.png");
}

.e1a-selfie_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933-1f3fb.png");
}

.e1a-rel-selfie_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f933-1f3fb.png");
}

.e1a-selfie_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933-1f3fc.png");
}

.e1a-rel-selfie_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f933-1f3fc.png");
}

.e1a-selfie_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933-1f3fd.png");
}

.e1a-rel-selfie_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f933-1f3fd.png");
}

.e1a-selfie_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933-1f3fe.png");
}

.e1a-rel-selfie_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f933-1f3fe.png");
}

.e1a-selfie_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f933-1f3ff.png");
}

.e1a-rel-selfie_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f933-1f3ff.png");
}

.e1a-dancer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483.png");
}

.e1a-rel-dancer {
  background-image: url("emojione/assets/4.5/png/128/1f483.png");
}

.e1a-dancer_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483-1f3fb.png");
}

.e1a-rel-dancer_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f483-1f3fb.png");
}

.e1a-dancer_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483-1f3fc.png");
}

.e1a-rel-dancer_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f483-1f3fc.png");
}

.e1a-dancer_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483-1f3fd.png");
}

.e1a-rel-dancer_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f483-1f3fd.png");
}

.e1a-dancer_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483-1f3fe.png");
}

.e1a-rel-dancer_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f483-1f3fe.png");
}

.e1a-dancer_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f483-1f3ff.png");
}

.e1a-rel-dancer_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f483-1f3ff.png");
}

.e1a-man_dancing {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a.png");
}

.e1a-rel-man_dancing {
  background-image: url("emojione/assets/4.5/png/128/1f57a.png");
}

.e1a-man_dancing_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a-1f3fb.png");
}

.e1a-rel-man_dancing_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f57a-1f3fb.png");
}

.e1a-man_dancing_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a-1f3fc.png");
}

.e1a-rel-man_dancing_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f57a-1f3fc.png");
}

.e1a-man_dancing_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a-1f3fd.png");
}

.e1a-rel-man_dancing_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f57a-1f3fd.png");
}

.e1a-man_dancing_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a-1f3ff.png");
}

.e1a-rel-man_dancing_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f57a-1f3ff.png");
}

.e1a-man_dancing_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f57a-1f3fe.png");
}

.e1a-rel-man_dancing_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f57a-1f3fe.png");
}

.e1a-people_with_bunny_ears_partying {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46f.png");
}

.e1a-rel-people_with_bunny_ears_partying {
  background-image: url("emojione/assets/4.5/png/128/1f46f.png");
}

.e1a-women_with_bunny_ears_partying {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46f-2640.png");
}

.e1a-rel-women_with_bunny_ears_partying {
  background-image: url("emojione/assets/4.5/png/128/1f46f-2640.png");
}

.e1a-men_with_bunny_ears_partying {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46f-2642.png");
}

.e1a-rel-men_with_bunny_ears_partying {
  background-image: url("emojione/assets/4.5/png/128/1f46f-2642.png");
}

.e1a-levitate {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574.png");
}

.e1a-rel-levitate {
  background-image: url("emojione/assets/4.5/png/128/1f574.png");
}

.e1a-levitate_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574-1f3fb.png");
}

.e1a-rel-levitate_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f574-1f3fb.png");
}

.e1a-levitate_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574-1f3fc.png");
}

.e1a-rel-levitate_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f574-1f3fc.png");
}

.e1a-levitate_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574-1f3fd.png");
}

.e1a-rel-levitate_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f574-1f3fd.png");
}

.e1a-levitate_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574-1f3fe.png");
}

.e1a-rel-levitate_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f574-1f3fe.png");
}

.e1a-levitate_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f574-1f3ff.png");
}

.e1a-rel-levitate_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f574-1f3ff.png");
}

.e1a-person_walking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6.png");
}

.e1a-rel-person_walking {
  background-image: url("emojione/assets/4.5/png/128/1f6b6.png");
}

.e1a-person_walking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fb.png");
}

.e1a-rel-person_walking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fb.png");
}

.e1a-person_walking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fc.png");
}

.e1a-rel-person_walking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fc.png");
}

.e1a-person_walking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fd.png");
}

.e1a-rel-person_walking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fd.png");
}

.e1a-person_walking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fe.png");
}

.e1a-rel-person_walking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fe.png");
}

.e1a-person_walking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3ff.png");
}

.e1a-rel-person_walking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3ff.png");
}

.e1a-woman_walking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-2640.png");
}

.e1a-rel-woman_walking {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-2640.png");
}

.e1a-woman_walking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fb-2640.png");
}

.e1a-rel-woman_walking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fb-2640.png");
}

.e1a-woman_walking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fc-2640.png");
}

.e1a-rel-woman_walking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fc-2640.png");
}

.e1a-woman_walking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fd-2640.png");
}

.e1a-rel-woman_walking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fd-2640.png");
}

.e1a-woman_walking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fe-2640.png");
}

.e1a-rel-woman_walking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fe-2640.png");
}

.e1a-woman_walking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3ff-2640.png");
}

.e1a-rel-woman_walking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3ff-2640.png");
}

.e1a-man_walking {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-2642.png");
}

.e1a-rel-man_walking {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-2642.png");
}

.e1a-man_walking_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fb-2642.png");
}

.e1a-rel-man_walking_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fb-2642.png");
}

.e1a-man_walking_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fc-2642.png");
}

.e1a-rel-man_walking_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fc-2642.png");
}

.e1a-man_walking_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fd-2642.png");
}

.e1a-rel-man_walking_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fd-2642.png");
}

.e1a-man_walking_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3fe-2642.png");
}

.e1a-rel-man_walking_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3fe-2642.png");
}

.e1a-man_walking_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b6-1f3ff-2642.png");
}

.e1a-rel-man_walking_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f6b6-1f3ff-2642.png");
}

.e1a-person_running {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3.png");
}

.e1a-rel-person_running {
  background-image: url("emojione/assets/4.5/png/128/1f3c3.png");
}

.e1a-person_running_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fb.png");
}

.e1a-rel-person_running_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fb.png");
}

.e1a-person_running_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fc.png");
}

.e1a-rel-person_running_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fc.png");
}

.e1a-person_running_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fd.png");
}

.e1a-rel-person_running_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fd.png");
}

.e1a-person_running_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fe.png");
}

.e1a-rel-person_running_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fe.png");
}

.e1a-person_running_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3ff.png");
}

.e1a-rel-person_running_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3ff.png");
}

.e1a-woman_running {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-2640.png");
}

.e1a-rel-woman_running {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-2640.png");
}

.e1a-woman_running_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fb-2640.png");
}

.e1a-rel-woman_running_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fb-2640.png");
}

.e1a-woman_running_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fc-2640.png");
}

.e1a-rel-woman_running_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fc-2640.png");
}

.e1a-woman_running_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fd-2640.png");
}

.e1a-rel-woman_running_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fd-2640.png");
}

.e1a-woman_running_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fe-2640.png");
}

.e1a-rel-woman_running_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fe-2640.png");
}

.e1a-woman_running_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3ff-2640.png");
}

.e1a-rel-woman_running_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3ff-2640.png");
}

.e1a-man_running {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-2642.png");
}

.e1a-rel-man_running {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-2642.png");
}

.e1a-man_running_tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fb-2642.png");
}

.e1a-rel-man_running_tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fb-2642.png");
}

.e1a-man_running_tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fc-2642.png");
}

.e1a-rel-man_running_tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fc-2642.png");
}

.e1a-man_running_tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fd-2642.png");
}

.e1a-rel-man_running_tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fd-2642.png");
}

.e1a-man_running_tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3fe-2642.png");
}

.e1a-rel-man_running_tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3fe-2642.png");
}

.e1a-man_running_tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c3-1f3ff-2642.png");
}

.e1a-rel-man_running_tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3c3-1f3ff-2642.png");
}

.e1a-couple {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46b.png");
}

.e1a-rel-couple {
  background-image: url("emojione/assets/4.5/png/128/1f46b.png");
}

.e1a-two_women_holding_hands {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46d.png");
}

.e1a-rel-two_women_holding_hands {
  background-image: url("emojione/assets/4.5/png/128/1f46d.png");
}

.e1a-two_men_holding_hands {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46c.png");
}

.e1a-rel-two_men_holding_hands {
  background-image: url("emojione/assets/4.5/png/128/1f46c.png");
}

.e1a-couple_with_heart {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f491.png");
}

.e1a-rel-couple_with_heart {
  background-image: url("emojione/assets/4.5/png/128/1f491.png");
}

.e1a-couple_with_heart_woman_man {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2764-1f468.png");
}

.e1a-rel-couple_with_heart_woman_man {
  background-image: url("emojione/assets/4.5/png/128/1f469-2764-1f468.png");
}

.e1a-couple_ww {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2764-1f469.png");
}

.e1a-rel-couple_ww {
  background-image: url("emojione/assets/4.5/png/128/1f469-2764-1f469.png");
}

.e1a-couple_mm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-2764-1f468.png");
}

.e1a-rel-couple_mm {
  background-image: url("emojione/assets/4.5/png/128/1f468-2764-1f468.png");
}

.e1a-couplekiss {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f48f.png");
}

.e1a-rel-couplekiss {
  background-image: url("emojione/assets/4.5/png/128/1f48f.png");
}

.e1a-kiss_woman_man {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2764-1f48b-1f468.png");
}

.e1a-rel-kiss_woman_man {
  background-image: url("emojione/assets/4.5/png/128/1f469-2764-1f48b-1f468.png");
}

.e1a-kiss_ww {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-2764-1f48b-1f469.png");
}

.e1a-rel-kiss_ww {
  background-image: url("emojione/assets/4.5/png/128/1f469-2764-1f48b-1f469.png");
}

.e1a-kiss_mm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-2764-1f48b-1f468.png");
}

.e1a-rel-kiss_mm {
  background-image: url("emojione/assets/4.5/png/128/1f468-2764-1f48b-1f468.png");
}

.e1a-family {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f46a.png");
}

.e1a-rel-family {
  background-image: url("emojione/assets/4.5/png/128/1f46a.png");
}

.e1a-family_man_woman_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f469-1f466.png");
}

.e1a-rel-family_man_woman_boy {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f469-1f466.png");
}

.e1a-family_mwg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f469-1f467.png");
}

.e1a-rel-family_mwg {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f469-1f467.png");
}

.e1a-family_mwgb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f469-1f467-1f466.png");
}

.e1a-rel-family_mwgb {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f469-1f467-1f466.png");
}

.e1a-family_mwbb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f469-1f466-1f466.png");
}

.e1a-rel-family_mwbb {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f469-1f466-1f466.png");
}

.e1a-family_mwgg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f469-1f467-1f467.png");
}

.e1a-rel-family_mwgg {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f469-1f467-1f467.png");
}

.e1a-family_wwb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f469-1f466.png");
}

.e1a-rel-family_wwb {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f469-1f466.png");
}

.e1a-family_wwg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f469-1f467.png");
}

.e1a-rel-family_wwg {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f469-1f467.png");
}

.e1a-family_wwgb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f469-1f467-1f466.png");
}

.e1a-rel-family_wwgb {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f469-1f467-1f466.png");
}

.e1a-family_wwbb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f469-1f466-1f466.png");
}

.e1a-rel-family_wwbb {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f469-1f466-1f466.png");
}

.e1a-family_wwgg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f469-1f467-1f467.png");
}

.e1a-rel-family_wwgg {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f469-1f467-1f467.png");
}

.e1a-family_mmb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f468-1f466.png");
}

.e1a-rel-family_mmb {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f468-1f466.png");
}

.e1a-family_mmg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f468-1f467.png");
}

.e1a-rel-family_mmg {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f468-1f467.png");
}

.e1a-family_mmgb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f468-1f467-1f466.png");
}

.e1a-rel-family_mmgb {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f468-1f467-1f466.png");
}

.e1a-family_mmbb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f468-1f466-1f466.png");
}

.e1a-rel-family_mmbb {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f468-1f466-1f466.png");
}

.e1a-family_mmgg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f468-1f467-1f467.png");
}

.e1a-rel-family_mmgg {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f468-1f467-1f467.png");
}

.e1a-family_woman_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f466.png");
}

.e1a-rel-family_woman_boy {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f466.png");
}

.e1a-family_woman_girl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f467.png");
}

.e1a-rel-family_woman_girl {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f467.png");
}

.e1a-family_woman_girl_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f467-1f466.png");
}

.e1a-rel-family_woman_girl_boy {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f467-1f466.png");
}

.e1a-family_woman_boy_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f466-1f466.png");
}

.e1a-rel-family_woman_boy_boy {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f466-1f466.png");
}

.e1a-family_woman_girl_girl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f469-1f467-1f467.png");
}

.e1a-rel-family_woman_girl_girl {
  background-image: url("emojione/assets/4.5/png/128/1f469-1f467-1f467.png");
}

.e1a-family_man_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f466.png");
}

.e1a-rel-family_man_boy {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f466.png");
}

.e1a-family_man_girl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f467.png");
}

.e1a-rel-family_man_girl {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f467.png");
}

.e1a-family_man_girl_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f467-1f466.png");
}

.e1a-rel-family_man_girl_boy {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f467-1f466.png");
}

.e1a-family_man_boy_boy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f466-1f466.png");
}

.e1a-rel-family_man_boy_boy {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f466-1f466.png");
}

.e1a-family_man_girl_girl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f468-1f467-1f467.png");
}

.e1a-rel-family_man_girl_girl {
  background-image: url("emojione/assets/4.5/png/128/1f468-1f467-1f467.png");
}

.e1a-coat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e5.png");
}

.e1a-rel-coat {
  background-image: url("emojione/assets/4.5/png/128/1f9e5.png");
}

.e1a-womans_clothes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45a.png");
}

.e1a-rel-womans_clothes {
  background-image: url("emojione/assets/4.5/png/128/1f45a.png");
}

.e1a-shirt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f455.png");
}

.e1a-rel-shirt {
  background-image: url("emojione/assets/4.5/png/128/1f455.png");
}

.e1a-jeans {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f456.png");
}

.e1a-rel-jeans {
  background-image: url("emojione/assets/4.5/png/128/1f456.png");
}

.e1a-necktie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f454.png");
}

.e1a-rel-necktie {
  background-image: url("emojione/assets/4.5/png/128/1f454.png");
}

.e1a-dress {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f457.png");
}

.e1a-rel-dress {
  background-image: url("emojione/assets/4.5/png/128/1f457.png");
}

.e1a-bikini {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f459.png");
}

.e1a-rel-bikini {
  background-image: url("emojione/assets/4.5/png/128/1f459.png");
}

.e1a-kimono {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f458.png");
}

.e1a-rel-kimono {
  background-image: url("emojione/assets/4.5/png/128/1f458.png");
}

.e1a-lab_coat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f97c.png");
}

.e1a-rel-lab_coat {
  background-image: url("emojione/assets/4.5/png/128/1f97c.png");
}

.e1a-high_heel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f460.png");
}

.e1a-rel-high_heel {
  background-image: url("emojione/assets/4.5/png/128/1f460.png");
}

.e1a-sandal {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f461.png");
}

.e1a-rel-sandal {
  background-image: url("emojione/assets/4.5/png/128/1f461.png");
}

.e1a-boot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f462.png");
}

.e1a-rel-boot {
  background-image: url("emojione/assets/4.5/png/128/1f462.png");
}

.e1a-mans_shoe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45e.png");
}

.e1a-rel-mans_shoe {
  background-image: url("emojione/assets/4.5/png/128/1f45e.png");
}

.e1a-athletic_shoe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45f.png");
}

.e1a-rel-athletic_shoe {
  background-image: url("emojione/assets/4.5/png/128/1f45f.png");
}

.e1a-hiking_boot {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f97e.png");
}

.e1a-rel-hiking_boot {
  background-image: url("emojione/assets/4.5/png/128/1f97e.png");
}

.e1a-womans_flat_shoe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f97f.png");
}

.e1a-rel-womans_flat_shoe {
  background-image: url("emojione/assets/4.5/png/128/1f97f.png");
}

.e1a-socks {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e6.png");
}

.e1a-rel-socks {
  background-image: url("emojione/assets/4.5/png/128/1f9e6.png");
}

.e1a-gloves {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e4.png");
}

.e1a-rel-gloves {
  background-image: url("emojione/assets/4.5/png/128/1f9e4.png");
}

.e1a-scarf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e3.png");
}

.e1a-rel-scarf {
  background-image: url("emojione/assets/4.5/png/128/1f9e3.png");
}

.e1a-tophat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a9.png");
}

.e1a-rel-tophat {
  background-image: url("emojione/assets/4.5/png/128/1f3a9.png");
}

.e1a-billed_cap {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e2.png");
}

.e1a-rel-billed_cap {
  background-image: url("emojione/assets/4.5/png/128/1f9e2.png");
}

.e1a-womans_hat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f452.png");
}

.e1a-rel-womans_hat {
  background-image: url("emojione/assets/4.5/png/128/1f452.png");
}

.e1a-mortar_board {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f393.png");
}

.e1a-rel-mortar_board {
  background-image: url("emojione/assets/4.5/png/128/1f393.png");
}

.e1a-helmet_with_cross {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26d1.png");
}

.e1a-rel-helmet_with_cross {
  background-image: url("emojione/assets/4.5/png/128/26d1.png");
}

.e1a-crown {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f451.png");
}

.e1a-rel-crown {
  background-image: url("emojione/assets/4.5/png/128/1f451.png");
}

.e1a-pouch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45d.png");
}

.e1a-rel-pouch {
  background-image: url("emojione/assets/4.5/png/128/1f45d.png");
}

.e1a-purse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45b.png");
}

.e1a-rel-purse {
  background-image: url("emojione/assets/4.5/png/128/1f45b.png");
}

.e1a-handbag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f45c.png");
}

.e1a-rel-handbag {
  background-image: url("emojione/assets/4.5/png/128/1f45c.png");
}

.e1a-briefcase {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4bc.png");
}

.e1a-rel-briefcase {
  background-image: url("emojione/assets/4.5/png/128/1f4bc.png");
}

.e1a-school_satchel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f392.png");
}

.e1a-rel-school_satchel {
  background-image: url("emojione/assets/4.5/png/128/1f392.png");
}

.e1a-eyeglasses {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f453.png");
}

.e1a-rel-eyeglasses {
  background-image: url("emojione/assets/4.5/png/128/1f453.png");
}

.e1a-dark_sunglasses {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f576.png");
}

.e1a-rel-dark_sunglasses {
  background-image: url("emojione/assets/4.5/png/128/1f576.png");
}

.e1a-goggles {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f97d.png");
}

.e1a-rel-goggles {
  background-image: url("emojione/assets/4.5/png/128/1f97d.png");
}

.e1a-closed_umbrella {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f302.png");
}

.e1a-rel-closed_umbrella {
  background-image: url("emojione/assets/4.5/png/128/1f302.png");
}

.e1a-red_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b0.png");
}

.e1a-rel-red_haired {
  background-image: url("emojione/assets/4.5/png/128/1f9b0.png");
}

.e1a-curly_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b1.png");
}

.e1a-rel-curly_haired {
  background-image: url("emojione/assets/4.5/png/128/1f9b1.png");
}

.e1a-white_haired {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b3.png");
}

.e1a-rel-white_haired {
  background-image: url("emojione/assets/4.5/png/128/1f9b3.png");
}

.e1a-bald {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9b2.png");
}

.e1a-rel-bald {
  background-image: url("emojione/assets/4.5/png/128/1f9b2.png");
}

.e1a-regional_indicator_z {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ff.png");
}

.e1a-rel-regional_indicator_z {
  background-image: url("emojione/assets/4.5/png/128/1f1ff.png");
}

.e1a-regional_indicator_y {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fe.png");
}

.e1a-rel-regional_indicator_y {
  background-image: url("emojione/assets/4.5/png/128/1f1fe.png");
}

.e1a-regional_indicator_x {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fd.png");
}

.e1a-rel-regional_indicator_x {
  background-image: url("emojione/assets/4.5/png/128/1f1fd.png");
}

.e1a-regional_indicator_w {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fc.png");
}

.e1a-rel-regional_indicator_w {
  background-image: url("emojione/assets/4.5/png/128/1f1fc.png");
}

.e1a-regional_indicator_v {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb.png");
}

.e1a-rel-regional_indicator_v {
  background-image: url("emojione/assets/4.5/png/128/1f1fb.png");
}

.e1a-regional_indicator_u {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa.png");
}

.e1a-rel-regional_indicator_u {
  background-image: url("emojione/assets/4.5/png/128/1f1fa.png");
}

.e1a-regional_indicator_t {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9.png");
}

.e1a-rel-regional_indicator_t {
  background-image: url("emojione/assets/4.5/png/128/1f1f9.png");
}

.e1a-regional_indicator_s {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8.png");
}

.e1a-rel-regional_indicator_s {
  background-image: url("emojione/assets/4.5/png/128/1f1f8.png");
}

.e1a-regional_indicator_r {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7.png");
}

.e1a-rel-regional_indicator_r {
  background-image: url("emojione/assets/4.5/png/128/1f1f7.png");
}

.e1a-regional_indicator_q {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f6.png");
}

.e1a-rel-regional_indicator_q {
  background-image: url("emojione/assets/4.5/png/128/1f1f6.png");
}

.e1a-regional_indicator_p {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5.png");
}

.e1a-rel-regional_indicator_p {
  background-image: url("emojione/assets/4.5/png/128/1f1f5.png");
}

.e1a-regional_indicator_o {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f4.png");
}

.e1a-rel-regional_indicator_o {
  background-image: url("emojione/assets/4.5/png/128/1f1f4.png");
}

.e1a-regional_indicator_n {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3.png");
}

.e1a-rel-regional_indicator_n {
  background-image: url("emojione/assets/4.5/png/128/1f1f3.png");
}

.e1a-regional_indicator_m {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2.png");
}

.e1a-rel-regional_indicator_m {
  background-image: url("emojione/assets/4.5/png/128/1f1f2.png");
}

.e1a-regional_indicator_l {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1.png");
}

.e1a-rel-regional_indicator_l {
  background-image: url("emojione/assets/4.5/png/128/1f1f1.png");
}

.e1a-regional_indicator_k {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0.png");
}

.e1a-rel-regional_indicator_k {
  background-image: url("emojione/assets/4.5/png/128/1f1f0.png");
}

.e1a-regional_indicator_j {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ef.png");
}

.e1a-rel-regional_indicator_j {
  background-image: url("emojione/assets/4.5/png/128/1f1ef.png");
}

.e1a-regional_indicator_i {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee.png");
}

.e1a-rel-regional_indicator_i {
  background-image: url("emojione/assets/4.5/png/128/1f1ee.png");
}

.e1a-regional_indicator_h {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed.png");
}

.e1a-rel-regional_indicator_h {
  background-image: url("emojione/assets/4.5/png/128/1f1ed.png");
}

.e1a-regional_indicator_g {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec.png");
}

.e1a-rel-regional_indicator_g {
  background-image: url("emojione/assets/4.5/png/128/1f1ec.png");
}

.e1a-regional_indicator_f {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb.png");
}

.e1a-rel-regional_indicator_f {
  background-image: url("emojione/assets/4.5/png/128/1f1eb.png");
}

.e1a-regional_indicator_e {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea.png");
}

.e1a-rel-regional_indicator_e {
  background-image: url("emojione/assets/4.5/png/128/1f1ea.png");
}

.e1a-regional_indicator_d {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9.png");
}

.e1a-rel-regional_indicator_d {
  background-image: url("emojione/assets/4.5/png/128/1f1e9.png");
}

.e1a-regional_indicator_c {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8.png");
}

.e1a-rel-regional_indicator_c {
  background-image: url("emojione/assets/4.5/png/128/1f1e8.png");
}

.e1a-regional_indicator_b {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7.png");
}

.e1a-rel-regional_indicator_b {
  background-image: url("emojione/assets/4.5/png/128/1f1e7.png");
}

.e1a-regional_indicator_a {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6.png");
}

.e1a-rel-regional_indicator_a {
  background-image: url("emojione/assets/4.5/png/128/1f1e6.png");
}

.e1a-red_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f697.png");
}

.e1a-rel-red_car {
  background-image: url("emojione/assets/4.5/png/128/1f697.png");
}

.e1a-taxi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f695.png");
}

.e1a-rel-taxi {
  background-image: url("emojione/assets/4.5/png/128/1f695.png");
}

.e1a-blue_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f699.png");
}

.e1a-rel-blue_car {
  background-image: url("emojione/assets/4.5/png/128/1f699.png");
}

.e1a-bus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68c.png");
}

.e1a-rel-bus {
  background-image: url("emojione/assets/4.5/png/128/1f68c.png");
}

.e1a-trolleybus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68e.png");
}

.e1a-rel-trolleybus {
  background-image: url("emojione/assets/4.5/png/128/1f68e.png");
}

.e1a-race_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ce.png");
}

.e1a-rel-race_car {
  background-image: url("emojione/assets/4.5/png/128/1f3ce.png");
}

.e1a-police_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f693.png");
}

.e1a-rel-police_car {
  background-image: url("emojione/assets/4.5/png/128/1f693.png");
}

.e1a-ambulance {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f691.png");
}

.e1a-rel-ambulance {
  background-image: url("emojione/assets/4.5/png/128/1f691.png");
}

.e1a-fire_engine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f692.png");
}

.e1a-rel-fire_engine {
  background-image: url("emojione/assets/4.5/png/128/1f692.png");
}

.e1a-minibus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f690.png");
}

.e1a-rel-minibus {
  background-image: url("emojione/assets/4.5/png/128/1f690.png");
}

.e1a-truck {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69a.png");
}

.e1a-rel-truck {
  background-image: url("emojione/assets/4.5/png/128/1f69a.png");
}

.e1a-articulated_lorry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69b.png");
}

.e1a-rel-articulated_lorry {
  background-image: url("emojione/assets/4.5/png/128/1f69b.png");
}

.e1a-tractor {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69c.png");
}

.e1a-rel-tractor {
  background-image: url("emojione/assets/4.5/png/128/1f69c.png");
}

.e1a-scooter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f4.png");
}

.e1a-rel-scooter {
  background-image: url("emojione/assets/4.5/png/128/1f6f4.png");
}

.e1a-bike {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6b2.png");
}

.e1a-rel-bike {
  background-image: url("emojione/assets/4.5/png/128/1f6b2.png");
}

.e1a-motor_scooter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f5.png");
}

.e1a-rel-motor_scooter {
  background-image: url("emojione/assets/4.5/png/128/1f6f5.png");
}

.e1a-motorcycle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3cd.png");
}

.e1a-rel-motorcycle {
  background-image: url("emojione/assets/4.5/png/128/1f3cd.png");
}

.e1a-rotating_light {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a8.png");
}

.e1a-rel-rotating_light {
  background-image: url("emojione/assets/4.5/png/128/1f6a8.png");
}

.e1a-oncoming_police_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f694.png");
}

.e1a-rel-oncoming_police_car {
  background-image: url("emojione/assets/4.5/png/128/1f694.png");
}

.e1a-oncoming_bus {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68d.png");
}

.e1a-rel-oncoming_bus {
  background-image: url("emojione/assets/4.5/png/128/1f68d.png");
}

.e1a-oncoming_automobile {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f698.png");
}

.e1a-rel-oncoming_automobile {
  background-image: url("emojione/assets/4.5/png/128/1f698.png");
}

.e1a-oncoming_taxi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f696.png");
}

.e1a-rel-oncoming_taxi {
  background-image: url("emojione/assets/4.5/png/128/1f696.png");
}

.e1a-aerial_tramway {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a1.png");
}

.e1a-rel-aerial_tramway {
  background-image: url("emojione/assets/4.5/png/128/1f6a1.png");
}

.e1a-mountain_cableway {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a0.png");
}

.e1a-rel-mountain_cableway {
  background-image: url("emojione/assets/4.5/png/128/1f6a0.png");
}

.e1a-suspension_railway {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69f.png");
}

.e1a-rel-suspension_railway {
  background-image: url("emojione/assets/4.5/png/128/1f69f.png");
}

.e1a-railway_car {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f683.png");
}

.e1a-rel-railway_car {
  background-image: url("emojione/assets/4.5/png/128/1f683.png");
}

.e1a-train {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68b.png");
}

.e1a-rel-train {
  background-image: url("emojione/assets/4.5/png/128/1f68b.png");
}

.e1a-mountain_railway {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69e.png");
}

.e1a-rel-mountain_railway {
  background-image: url("emojione/assets/4.5/png/128/1f69e.png");
}

.e1a-monorail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f69d.png");
}

.e1a-rel-monorail {
  background-image: url("emojione/assets/4.5/png/128/1f69d.png");
}

.e1a-bullettrain_side {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f684.png");
}

.e1a-rel-bullettrain_side {
  background-image: url("emojione/assets/4.5/png/128/1f684.png");
}

.e1a-bullettrain_front {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f685.png");
}

.e1a-rel-bullettrain_front {
  background-image: url("emojione/assets/4.5/png/128/1f685.png");
}

.e1a-light_rail {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f688.png");
}

.e1a-rel-light_rail {
  background-image: url("emojione/assets/4.5/png/128/1f688.png");
}

.e1a-steam_locomotive {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f682.png");
}

.e1a-rel-steam_locomotive {
  background-image: url("emojione/assets/4.5/png/128/1f682.png");
}

.e1a-train2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f686.png");
}

.e1a-rel-train2 {
  background-image: url("emojione/assets/4.5/png/128/1f686.png");
}

.e1a-metro {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f687.png");
}

.e1a-rel-metro {
  background-image: url("emojione/assets/4.5/png/128/1f687.png");
}

.e1a-tram {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68a.png");
}

.e1a-rel-tram {
  background-image: url("emojione/assets/4.5/png/128/1f68a.png");
}

.e1a-station {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f689.png");
}

.e1a-rel-station {
  background-image: url("emojione/assets/4.5/png/128/1f689.png");
}

.e1a-airplane_departure {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6eb.png");
}

.e1a-rel-airplane_departure {
  background-image: url("emojione/assets/4.5/png/128/1f6eb.png");
}

.e1a-airplane_arriving {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6ec.png");
}

.e1a-rel-airplane_arriving {
  background-image: url("emojione/assets/4.5/png/128/1f6ec.png");
}

.e1a-airplane_small {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e9.png");
}

.e1a-rel-airplane_small {
  background-image: url("emojione/assets/4.5/png/128/1f6e9.png");
}

.e1a-seat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f4ba.png");
}

.e1a-rel-seat {
  background-image: url("emojione/assets/4.5/png/128/1f4ba.png");
}

.e1a-luggage {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9f3.png");
}

.e1a-rel-luggage {
  background-image: url("emojione/assets/4.5/png/128/1f9f3.png");
}

.e1a-satellite_orbital {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f0.png");
}

.e1a-rel-satellite_orbital {
  background-image: url("emojione/assets/4.5/png/128/1f6f0.png");
}

.e1a-rocket {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f680.png");
}

.e1a-rel-rocket {
  background-image: url("emojione/assets/4.5/png/128/1f680.png");
}

.e1a-flying_saucer {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f8.png");
}

.e1a-rel-flying_saucer {
  background-image: url("emojione/assets/4.5/png/128/1f6f8.png");
}

.e1a-helicopter {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f681.png");
}

.e1a-rel-helicopter {
  background-image: url("emojione/assets/4.5/png/128/1f681.png");
}

.e1a-canoe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f6.png");
}

.e1a-rel-canoe {
  background-image: url("emojione/assets/4.5/png/128/1f6f6.png");
}

.e1a-sailboat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f5.png");
}

.e1a-rel-sailboat {
  background-image: url("emojione/assets/4.5/png/128/26f5.png");
}

.e1a-speedboat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a4.png");
}

.e1a-rel-speedboat {
  background-image: url("emojione/assets/4.5/png/128/1f6a4.png");
}

.e1a-motorboat {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e5.png");
}

.e1a-rel-motorboat {
  background-image: url("emojione/assets/4.5/png/128/1f6e5.png");
}

.e1a-cruise_ship {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6f3.png");
}

.e1a-rel-cruise_ship {
  background-image: url("emojione/assets/4.5/png/128/1f6f3.png");
}

.e1a-ferry {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f4.png");
}

.e1a-rel-ferry {
  background-image: url("emojione/assets/4.5/png/128/26f4.png");
}

.e1a-ship {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a2.png");
}

.e1a-rel-ship {
  background-image: url("emojione/assets/4.5/png/128/1f6a2.png");
}

.e1a-fuelpump {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26fd.png");
}

.e1a-rel-fuelpump {
  background-image: url("emojione/assets/4.5/png/128/26fd.png");
}

.e1a-construction {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a7.png");
}

.e1a-rel-construction {
  background-image: url("emojione/assets/4.5/png/128/1f6a7.png");
}

.e1a-vertical_traffic_light {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a6.png");
}

.e1a-rel-vertical_traffic_light {
  background-image: url("emojione/assets/4.5/png/128/1f6a6.png");
}

.e1a-traffic_light {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a5.png");
}

.e1a-rel-traffic_light {
  background-image: url("emojione/assets/4.5/png/128/1f6a5.png");
}

.e1a-busstop {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f68f.png");
}

.e1a-rel-busstop {
  background-image: url("emojione/assets/4.5/png/128/1f68f.png");
}

.e1a-map {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5fa.png");
}

.e1a-rel-map {
  background-image: url("emojione/assets/4.5/png/128/1f5fa.png");
}

.e1a-moyai {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5ff.png");
}

.e1a-rel-moyai {
  background-image: url("emojione/assets/4.5/png/128/1f5ff.png");
}

.e1a-statue_of_liberty {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5fd.png");
}

.e1a-rel-statue_of_liberty {
  background-image: url("emojione/assets/4.5/png/128/1f5fd.png");
}

.e1a-tokyo_tower {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5fc.png");
}

.e1a-rel-tokyo_tower {
  background-image: url("emojione/assets/4.5/png/128/1f5fc.png");
}

.e1a-european_castle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f0.png");
}

.e1a-rel-european_castle {
  background-image: url("emojione/assets/4.5/png/128/1f3f0.png");
}

.e1a-japanese_castle {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ef.png");
}

.e1a-rel-japanese_castle {
  background-image: url("emojione/assets/4.5/png/128/1f3ef.png");
}

.e1a-stadium {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3df.png");
}

.e1a-rel-stadium {
  background-image: url("emojione/assets/4.5/png/128/1f3df.png");
}

.e1a-ferris_wheel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a1.png");
}

.e1a-rel-ferris_wheel {
  background-image: url("emojione/assets/4.5/png/128/1f3a1.png");
}

.e1a-roller_coaster {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a2.png");
}

.e1a-rel-roller_coaster {
  background-image: url("emojione/assets/4.5/png/128/1f3a2.png");
}

.e1a-carousel_horse {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3a0.png");
}

.e1a-rel-carousel_horse {
  background-image: url("emojione/assets/4.5/png/128/1f3a0.png");
}

.e1a-fountain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f2.png");
}

.e1a-rel-fountain {
  background-image: url("emojione/assets/4.5/png/128/26f2.png");
}

.e1a-beach_umbrella {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f1.png");
}

.e1a-rel-beach_umbrella {
  background-image: url("emojione/assets/4.5/png/128/26f1.png");
}

.e1a-beach {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d6.png");
}

.e1a-rel-beach {
  background-image: url("emojione/assets/4.5/png/128/1f3d6.png");
}

.e1a-island {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3dd.png");
}

.e1a-rel-island {
  background-image: url("emojione/assets/4.5/png/128/1f3dd.png");
}

.e1a-desert {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3dc.png");
}

.e1a-rel-desert {
  background-image: url("emojione/assets/4.5/png/128/1f3dc.png");
}

.e1a-volcano {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30b.png");
}

.e1a-rel-volcano {
  background-image: url("emojione/assets/4.5/png/128/1f30b.png");
}

.e1a-mountain {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26f0.png");
}

.e1a-rel-mountain {
  background-image: url("emojione/assets/4.5/png/128/26f0.png");
}

.e1a-mountain_snow {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d4.png");
}

.e1a-rel-mountain_snow {
  background-image: url("emojione/assets/4.5/png/128/1f3d4.png");
}

.e1a-mount_fuji {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5fb.png");
}

.e1a-rel-mount_fuji {
  background-image: url("emojione/assets/4.5/png/128/1f5fb.png");
}

.e1a-camping {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d5.png");
}

.e1a-rel-camping {
  background-image: url("emojione/assets/4.5/png/128/1f3d5.png");
}

.e1a-tent {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26fa.png");
}

.e1a-rel-tent {
  background-image: url("emojione/assets/4.5/png/128/26fa.png");
}

.e1a-house {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e0.png");
}

.e1a-rel-house {
  background-image: url("emojione/assets/4.5/png/128/1f3e0.png");
}

.e1a-house_with_garden {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e1.png");
}

.e1a-rel-house_with_garden {
  background-image: url("emojione/assets/4.5/png/128/1f3e1.png");
}

.e1a-homes {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d8.png");
}

.e1a-rel-homes {
  background-image: url("emojione/assets/4.5/png/128/1f3d8.png");
}

.e1a-house_abandoned {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3da.png");
}

.e1a-rel-house_abandoned {
  background-image: url("emojione/assets/4.5/png/128/1f3da.png");
}

.e1a-construction_site {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d7.png");
}

.e1a-rel-construction_site {
  background-image: url("emojione/assets/4.5/png/128/1f3d7.png");
}

.e1a-factory {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ed.png");
}

.e1a-rel-factory {
  background-image: url("emojione/assets/4.5/png/128/1f3ed.png");
}

.e1a-office {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e2.png");
}

.e1a-rel-office {
  background-image: url("emojione/assets/4.5/png/128/1f3e2.png");
}

.e1a-department_store {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ec.png");
}

.e1a-rel-department_store {
  background-image: url("emojione/assets/4.5/png/128/1f3ec.png");
}

.e1a-post_office {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e3.png");
}

.e1a-rel-post_office {
  background-image: url("emojione/assets/4.5/png/128/1f3e3.png");
}

.e1a-european_post_office {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e4.png");
}

.e1a-rel-european_post_office {
  background-image: url("emojione/assets/4.5/png/128/1f3e4.png");
}

.e1a-hospital {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e5.png");
}

.e1a-rel-hospital {
  background-image: url("emojione/assets/4.5/png/128/1f3e5.png");
}

.e1a-bank {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e6.png");
}

.e1a-rel-bank {
  background-image: url("emojione/assets/4.5/png/128/1f3e6.png");
}

.e1a-hotel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e8.png");
}

.e1a-rel-hotel {
  background-image: url("emojione/assets/4.5/png/128/1f3e8.png");
}

.e1a-convenience_store {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ea.png");
}

.e1a-rel-convenience_store {
  background-image: url("emojione/assets/4.5/png/128/1f3ea.png");
}

.e1a-school {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3eb.png");
}

.e1a-rel-school {
  background-image: url("emojione/assets/4.5/png/128/1f3eb.png");
}

.e1a-love_hotel {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3e9.png");
}

.e1a-rel-love_hotel {
  background-image: url("emojione/assets/4.5/png/128/1f3e9.png");
}

.e1a-wedding {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f492.png");
}

.e1a-rel-wedding {
  background-image: url("emojione/assets/4.5/png/128/1f492.png");
}

.e1a-classical_building {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3db.png");
}

.e1a-rel-classical_building {
  background-image: url("emojione/assets/4.5/png/128/1f3db.png");
}

.e1a-church {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26ea.png");
}

.e1a-rel-church {
  background-image: url("emojione/assets/4.5/png/128/26ea.png");
}

.e1a-mosque {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f54c.png");
}

.e1a-rel-mosque {
  background-image: url("emojione/assets/4.5/png/128/1f54c.png");
}

.e1a-synagogue {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f54d.png");
}

.e1a-rel-synagogue {
  background-image: url("emojione/assets/4.5/png/128/1f54d.png");
}

.e1a-kaaba {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f54b.png");
}

.e1a-rel-kaaba {
  background-image: url("emojione/assets/4.5/png/128/1f54b.png");
}

.e1a-shinto_shrine {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/26e9.png");
}

.e1a-rel-shinto_shrine {
  background-image: url("emojione/assets/4.5/png/128/26e9.png");
}

.e1a-railway_track {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e4.png");
}

.e1a-rel-railway_track {
  background-image: url("emojione/assets/4.5/png/128/1f6e4.png");
}

.e1a-motorway {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6e3.png");
}

.e1a-rel-motorway {
  background-image: url("emojione/assets/4.5/png/128/1f6e3.png");
}

.e1a-japan {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f5fe.png");
}

.e1a-rel-japan {
  background-image: url("emojione/assets/4.5/png/128/1f5fe.png");
}

.e1a-rice_scene {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f391.png");
}

.e1a-rel-rice_scene {
  background-image: url("emojione/assets/4.5/png/128/1f391.png");
}

.e1a-park {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3de.png");
}

.e1a-rel-park {
  background-image: url("emojione/assets/4.5/png/128/1f3de.png");
}

.e1a-sunrise {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f305.png");
}

.e1a-rel-sunrise {
  background-image: url("emojione/assets/4.5/png/128/1f305.png");
}

.e1a-sunrise_over_mountains {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f304.png");
}

.e1a-rel-sunrise_over_mountains {
  background-image: url("emojione/assets/4.5/png/128/1f304.png");
}

.e1a-stars {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f320.png");
}

.e1a-rel-stars {
  background-image: url("emojione/assets/4.5/png/128/1f320.png");
}

.e1a-sparkler {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f387.png");
}

.e1a-rel-sparkler {
  background-image: url("emojione/assets/4.5/png/128/1f387.png");
}

.e1a-fireworks {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f386.png");
}

.e1a-rel-fireworks {
  background-image: url("emojione/assets/4.5/png/128/1f386.png");
}

.e1a-firecracker {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f9e8.png");
}

.e1a-rel-firecracker {
  background-image: url("emojione/assets/4.5/png/128/1f9e8.png");
}

.e1a-city_sunset {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f307.png");
}

.e1a-rel-city_sunset {
  background-image: url("emojione/assets/4.5/png/128/1f307.png");
}

.e1a-city_dusk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f306.png");
}

.e1a-rel-city_dusk {
  background-image: url("emojione/assets/4.5/png/128/1f306.png");
}

.e1a-cityscape {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3d9.png");
}

.e1a-rel-cityscape {
  background-image: url("emojione/assets/4.5/png/128/1f3d9.png");
}

.e1a-night_with_stars {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f303.png");
}

.e1a-rel-night_with_stars {
  background-image: url("emojione/assets/4.5/png/128/1f303.png");
}

.e1a-milky_way {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f30c.png");
}

.e1a-rel-milky_way {
  background-image: url("emojione/assets/4.5/png/128/1f30c.png");
}

.e1a-bridge_at_night {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f309.png");
}

.e1a-rel-bridge_at_night {
  background-image: url("emojione/assets/4.5/png/128/1f309.png");
}

.e1a-lock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f512.png");
}

.e1a-rel-lock {
  background-image: url("emojione/assets/4.5/png/128/1f512.png");
}

.e1a-unlock {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f513.png");
}

.e1a-rel-unlock {
  background-image: url("emojione/assets/4.5/png/128/1f513.png");
}

.e1a-foggy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f301.png");
}

.e1a-rel-foggy {
  background-image: url("emojione/assets/4.5/png/128/1f301.png");
}

.e1a-flag_white {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f3.png");
}

.e1a-rel-flag_white {
  background-image: url("emojione/assets/4.5/png/128/1f3f3.png");
}

.e1a-flag_black {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f4.png");
}

.e1a-rel-flag_black {
  background-image: url("emojione/assets/4.5/png/128/1f3f4.png");
}

.e1a-checkered_flag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3c1.png");
}

.e1a-rel-checkered_flag {
  background-image: url("emojione/assets/4.5/png/128/1f3c1.png");
}

.e1a-triangular_flag_on_post {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f6a9.png");
}

.e1a-rel-triangular_flag_on_post {
  background-image: url("emojione/assets/4.5/png/128/1f6a9.png");
}

.e1a-rainbow_flag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f3-1f308.png");
}

.e1a-rel-rainbow_flag {
  background-image: url("emojione/assets/4.5/png/128/1f3f3-1f308.png");
}

.e1a-pirate_flag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f4-2620.png");
}

.e1a-rel-pirate_flag {
  background-image: url("emojione/assets/4.5/png/128/1f3f4-2620.png");
}

.e1a-flag_af {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1eb.png");
}

.e1a-rel-flag_af {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1eb.png");
}

.e1a-flag_ax {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1fd.png");
}

.e1a-rel-flag_ax {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1fd.png");
}

.e1a-flag_al {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f1.png");
}

.e1a-rel-flag_al {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f1.png");
}

.e1a-flag_dz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1ff.png");
}

.e1a-rel-flag_dz {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1ff.png");
}

.e1a-flag_as {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f8.png");
}

.e1a-rel-flag_as {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f8.png");
}

.e1a-flag_ad {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1e9.png");
}

.e1a-rel-flag_ad {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1e9.png");
}

.e1a-flag_ao {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f4.png");
}

.e1a-rel-flag_ao {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f4.png");
}

.e1a-flag_ai {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1ee.png");
}

.e1a-rel-flag_ai {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1ee.png");
}

.e1a-flag_aq {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f6.png");
}

.e1a-rel-flag_aq {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f6.png");
}

.e1a-flag_ag {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1ec.png");
}

.e1a-rel-flag_ag {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1ec.png");
}

.e1a-flag_ar {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f7.png");
}

.e1a-rel-flag_ar {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f7.png");
}

.e1a-flag_am {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f2.png");
}

.e1a-rel-flag_am {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f2.png");
}

.e1a-flag_aw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1fc.png");
}

.e1a-rel-flag_aw {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1fc.png");
}

.e1a-flag_au {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1fa.png");
}

.e1a-rel-flag_au {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1fa.png");
}

.e1a-flag_at {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1f9.png");
}

.e1a-rel-flag_at {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1f9.png");
}

.e1a-flag_az {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1ff.png");
}

.e1a-rel-flag_az {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1ff.png");
}

.e1a-flag_bs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f8.png");
}

.e1a-rel-flag_bs {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f8.png");
}

.e1a-flag_bh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ed.png");
}

.e1a-rel-flag_bh {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ed.png");
}

.e1a-flag_bd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1e9.png");
}

.e1a-rel-flag_bd {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1e9.png");
}

.e1a-flag_bb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1e7.png");
}

.e1a-rel-flag_bb {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1e7.png");
}

.e1a-flag_by {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1fe.png");
}

.e1a-rel-flag_by {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1fe.png");
}

.e1a-flag_be {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ea.png");
}

.e1a-rel-flag_be {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ea.png");
}

.e1a-flag_bz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ff.png");
}

.e1a-rel-flag_bz {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ff.png");
}

.e1a-flag_bj {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ef.png");
}

.e1a-rel-flag_bj {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ef.png");
}

.e1a-flag_bm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f2.png");
}

.e1a-rel-flag_bm {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f2.png");
}

.e1a-flag_bt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f9.png");
}

.e1a-rel-flag_bt {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f9.png");
}

.e1a-flag_bo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f4.png");
}

.e1a-rel-flag_bo {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f4.png");
}

.e1a-flag_ba {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1e6.png");
}

.e1a-rel-flag_ba {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1e6.png");
}

.e1a-flag_bw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1fc.png");
}

.e1a-rel-flag_bw {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1fc.png");
}

.e1a-flag_br {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f7.png");
}

.e1a-rel-flag_br {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f7.png");
}

.e1a-flag_io {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f4.png");
}

.e1a-rel-flag_io {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f4.png");
}

.e1a-flag_vg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1ec.png");
}

.e1a-rel-flag_vg {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1ec.png");
}

.e1a-flag_bn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f3.png");
}

.e1a-rel-flag_bn {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f3.png");
}

.e1a-flag_bg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ec.png");
}

.e1a-rel-flag_bg {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ec.png");
}

.e1a-flag_bf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1eb.png");
}

.e1a-rel-flag_bf {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1eb.png");
}

.e1a-flag_bi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1ee.png");
}

.e1a-rel-flag_bi {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1ee.png");
}

.e1a-flag_kh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1ed.png");
}

.e1a-rel-flag_kh {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1ed.png");
}

.e1a-flag_cm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f2.png");
}

.e1a-rel-flag_cm {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f2.png");
}

.e1a-flag_ca {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1e6.png");
}

.e1a-rel-flag_ca {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1e6.png");
}

.e1a-flag_ic {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1e8.png");
}

.e1a-rel-flag_ic {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1e8.png");
}

.e1a-flag_cv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1fb.png");
}

.e1a-rel-flag_cv {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1fb.png");
}

.e1a-flag_bq {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f6.png");
}

.e1a-rel-flag_bq {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f6.png");
}

.e1a-flag_ky {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1fe.png");
}

.e1a-rel-flag_ky {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1fe.png");
}

.e1a-flag_cf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1eb.png");
}

.e1a-rel-flag_cf {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1eb.png");
}

.e1a-flag_td {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1e9.png");
}

.e1a-rel-flag_td {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1e9.png");
}

.e1a-flag_cl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f1.png");
}

.e1a-rel-flag_cl {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f1.png");
}

.e1a-flag_cn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f3.png");
}

.e1a-rel-flag_cn {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f3.png");
}

.e1a-flag_cx {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1fd.png");
}

.e1a-rel-flag_cx {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1fd.png");
}

.e1a-flag_cc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1e8.png");
}

.e1a-rel-flag_cc {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1e8.png");
}

.e1a-flag_co {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f4.png");
}

.e1a-rel-flag_co {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f4.png");
}

.e1a-flag_km {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1f2.png");
}

.e1a-rel-flag_km {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1f2.png");
}

.e1a-flag_cg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1ec.png");
}

.e1a-rel-flag_cg {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1ec.png");
}

.e1a-flag_cd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1e9.png");
}

.e1a-rel-flag_cd {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1e9.png");
}

.e1a-flag_ck {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f0.png");
}

.e1a-rel-flag_ck {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f0.png");
}

.e1a-flag_cr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f7.png");
}

.e1a-rel-flag_cr {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f7.png");
}

.e1a-flag_ci {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1ee.png");
}

.e1a-rel-flag_ci {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1ee.png");
}

.e1a-flag_hr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1f7.png");
}

.e1a-rel-flag_hr {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1f7.png");
}

.e1a-flag_cu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1fa.png");
}

.e1a-rel-flag_cu {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1fa.png");
}

.e1a-flag_cw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1fc.png");
}

.e1a-rel-flag_cw {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1fc.png");
}

.e1a-flag_cy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1fe.png");
}

.e1a-rel-flag_cy {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1fe.png");
}

.e1a-flag_cz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1ff.png");
}

.e1a-rel-flag_cz {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1ff.png");
}

.e1a-flag_dk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1f0.png");
}

.e1a-rel-flag_dk {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1f0.png");
}

.e1a-flag_dj {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1ef.png");
}

.e1a-rel-flag_dj {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1ef.png");
}

.e1a-flag_dm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1f2.png");
}

.e1a-rel-flag_dm {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1f2.png");
}

.e1a-flag_do {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1f4.png");
}

.e1a-rel-flag_do {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1f4.png");
}

.e1a-flag_ec {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1e8.png");
}

.e1a-rel-flag_ec {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1e8.png");
}

.e1a-flag_eg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1ec.png");
}

.e1a-rel-flag_eg {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1ec.png");
}

.e1a-flag_sv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1fb.png");
}

.e1a-rel-flag_sv {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1fb.png");
}

.e1a-flag_gq {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f6.png");
}

.e1a-rel-flag_gq {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f6.png");
}

.e1a-flag_er {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1f7.png");
}

.e1a-rel-flag_er {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1f7.png");
}

.e1a-flag_ee {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1ea.png");
}

.e1a-rel-flag_ee {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1ea.png");
}

.e1a-flag_et {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1f9.png");
}

.e1a-rel-flag_et {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1f9.png");
}

.e1a-flag_eu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1fa.png");
}

.e1a-rel-flag_eu {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1fa.png");
}

.e1a-flag_fk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1f0.png");
}

.e1a-rel-flag_fk {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1f0.png");
}

.e1a-flag_fo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1f4.png");
}

.e1a-rel-flag_fo {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1f4.png");
}

.e1a-flag_fj {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1ef.png");
}

.e1a-rel-flag_fj {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1ef.png");
}

.e1a-flag_fi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1ee.png");
}

.e1a-rel-flag_fi {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1ee.png");
}

.e1a-flag_fr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1f7.png");
}

.e1a-rel-flag_fr {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1f7.png");
}

.e1a-flag_gf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1eb.png");
}

.e1a-rel-flag_gf {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1eb.png");
}

.e1a-flag_pf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1eb.png");
}

.e1a-rel-flag_pf {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1eb.png");
}

.e1a-flag_tf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1eb.png");
}

.e1a-rel-flag_tf {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1eb.png");
}

.e1a-flag_ga {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1e6.png");
}

.e1a-rel-flag_ga {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1e6.png");
}

.e1a-flag_gm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f2.png");
}

.e1a-rel-flag_gm {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f2.png");
}

.e1a-flag_ge {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1ea.png");
}

.e1a-rel-flag_ge {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1ea.png");
}

.e1a-flag_de {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1ea.png");
}

.e1a-rel-flag_de {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1ea.png");
}

.e1a-flag_gh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1ed.png");
}

.e1a-rel-flag_gh {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1ed.png");
}

.e1a-flag_gi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1ee.png");
}

.e1a-rel-flag_gi {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1ee.png");
}

.e1a-flag_gr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f7.png");
}

.e1a-rel-flag_gr {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f7.png");
}

.e1a-flag_gl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f1.png");
}

.e1a-rel-flag_gl {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f1.png");
}

.e1a-flag_gd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1e9.png");
}

.e1a-rel-flag_gd {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1e9.png");
}

.e1a-flag_gp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f5.png");
}

.e1a-rel-flag_gp {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f5.png");
}

.e1a-flag_gu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1fa.png");
}

.e1a-rel-flag_gu {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1fa.png");
}

.e1a-flag_gt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f9.png");
}

.e1a-rel-flag_gt {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f9.png");
}

.e1a-flag_gg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1ec.png");
}

.e1a-rel-flag_gg {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1ec.png");
}

.e1a-flag_gn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f3.png");
}

.e1a-rel-flag_gn {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f3.png");
}

.e1a-flag_gw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1fc.png");
}

.e1a-rel-flag_gw {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1fc.png");
}

.e1a-flag_gy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1fe.png");
}

.e1a-rel-flag_gy {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1fe.png");
}

.e1a-flag_ht {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1f9.png");
}

.e1a-rel-flag_ht {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1f9.png");
}

.e1a-flag_hn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1f3.png");
}

.e1a-rel-flag_hn {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1f3.png");
}

.e1a-flag_hk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1f0.png");
}

.e1a-rel-flag_hk {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1f0.png");
}

.e1a-flag_hu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1fa.png");
}

.e1a-rel-flag_hu {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1fa.png");
}

.e1a-flag_is {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f8.png");
}

.e1a-rel-flag_is {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f8.png");
}

.e1a-flag_in {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f3.png");
}

.e1a-rel-flag_in {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f3.png");
}

.e1a-flag_id {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1e9.png");
}

.e1a-rel-flag_id {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1e9.png");
}

.e1a-flag_ir {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f7.png");
}

.e1a-rel-flag_ir {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f7.png");
}

.e1a-flag_iq {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f6.png");
}

.e1a-rel-flag_iq {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f6.png");
}

.e1a-flag_ie {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1ea.png");
}

.e1a-rel-flag_ie {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1ea.png");
}

.e1a-flag_im {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f2.png");
}

.e1a-rel-flag_im {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f2.png");
}

.e1a-flag_il {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f1.png");
}

.e1a-rel-flag_il {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f1.png");
}

.e1a-flag_it {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ee-1f1f9.png");
}

.e1a-rel-flag_it {
  background-image: url("emojione/assets/4.5/png/128/1f1ee-1f1f9.png");
}

.e1a-flag_jm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ef-1f1f2.png");
}

.e1a-rel-flag_jm {
  background-image: url("emojione/assets/4.5/png/128/1f1ef-1f1f2.png");
}

.e1a-flag_jp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ef-1f1f5.png");
}

.e1a-rel-flag_jp {
  background-image: url("emojione/assets/4.5/png/128/1f1ef-1f1f5.png");
}

.e1a-crossed_flags {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f38c.png");
}

.e1a-rel-crossed_flags {
  background-image: url("emojione/assets/4.5/png/128/1f38c.png");
}

.e1a-flag_je {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ef-1f1ea.png");
}

.e1a-rel-flag_je {
  background-image: url("emojione/assets/4.5/png/128/1f1ef-1f1ea.png");
}

.e1a-flag_jo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ef-1f1f4.png");
}

.e1a-rel-flag_jo {
  background-image: url("emojione/assets/4.5/png/128/1f1ef-1f1f4.png");
}

.e1a-flag_kz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1ff.png");
}

.e1a-rel-flag_kz {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1ff.png");
}

.e1a-flag_ke {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1ea.png");
}

.e1a-rel-flag_ke {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1ea.png");
}

.e1a-flag_ki {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1ee.png");
}

.e1a-rel-flag_ki {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1ee.png");
}

.e1a-flag_xk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fd-1f1f0.png");
}

.e1a-rel-flag_xk {
  background-image: url("emojione/assets/4.5/png/128/1f1fd-1f1f0.png");
}

.e1a-flag_kw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1fc.png");
}

.e1a-rel-flag_kw {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1fc.png");
}

.e1a-flag_kg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1ec.png");
}

.e1a-rel-flag_kg {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1ec.png");
}

.e1a-flag_la {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1e6.png");
}

.e1a-rel-flag_la {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1e6.png");
}

.e1a-flag_lv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1fb.png");
}

.e1a-rel-flag_lv {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1fb.png");
}

.e1a-flag_lb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1e7.png");
}

.e1a-rel-flag_lb {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1e7.png");
}

.e1a-flag_ls {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1f8.png");
}

.e1a-rel-flag_ls {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1f8.png");
}

.e1a-flag_lr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1f7.png");
}

.e1a-rel-flag_lr {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1f7.png");
}

.e1a-flag_ly {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1fe.png");
}

.e1a-rel-flag_ly {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1fe.png");
}

.e1a-flag_li {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1ee.png");
}

.e1a-rel-flag_li {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1ee.png");
}

.e1a-flag_lt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1f9.png");
}

.e1a-rel-flag_lt {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1f9.png");
}

.e1a-flag_lu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1fa.png");
}

.e1a-rel-flag_lu {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1fa.png");
}

.e1a-flag_mo {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f4.png");
}

.e1a-rel-flag_mo {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f4.png");
}

.e1a-flag_mk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f0.png");
}

.e1a-rel-flag_mk {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f0.png");
}

.e1a-flag_mg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1ec.png");
}

.e1a-rel-flag_mg {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1ec.png");
}

.e1a-flag_mw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1fc.png");
}

.e1a-rel-flag_mw {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1fc.png");
}

.e1a-flag_my {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1fe.png");
}

.e1a-rel-flag_my {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1fe.png");
}

.e1a-flag_mv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1fb.png");
}

.e1a-rel-flag_mv {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1fb.png");
}

.e1a-flag_ml {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f1.png");
}

.e1a-rel-flag_ml {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f1.png");
}

.e1a-flag_mt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f9.png");
}

.e1a-rel-flag_mt {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f9.png");
}

.e1a-flag_mh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1ed.png");
}

.e1a-rel-flag_mh {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1ed.png");
}

.e1a-flag_mq {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f6.png");
}

.e1a-rel-flag_mq {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f6.png");
}

.e1a-flag_mr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f7.png");
}

.e1a-rel-flag_mr {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f7.png");
}

.e1a-flag_mu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1fa.png");
}

.e1a-rel-flag_mu {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1fa.png");
}

.e1a-flag_yt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fe-1f1f9.png");
}

.e1a-rel-flag_yt {
  background-image: url("emojione/assets/4.5/png/128/1f1fe-1f1f9.png");
}

.e1a-flag_mx {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1fd.png");
}

.e1a-rel-flag_mx {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1fd.png");
}

.e1a-flag_fm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1eb-1f1f2.png");
}

.e1a-rel-flag_fm {
  background-image: url("emojione/assets/4.5/png/128/1f1eb-1f1f2.png");
}

.e1a-flag_md {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1e9.png");
}

.e1a-rel-flag_md {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1e9.png");
}

.e1a-flag_mc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1e8.png");
}

.e1a-rel-flag_mc {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1e8.png");
}

.e1a-flag_mn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f3.png");
}

.e1a-rel-flag_mn {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f3.png");
}

.e1a-flag_me {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1ea.png");
}

.e1a-rel-flag_me {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1ea.png");
}

.e1a-flag_ms {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f8.png");
}

.e1a-rel-flag_ms {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f8.png");
}

.e1a-flag_ma {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1e6.png");
}

.e1a-rel-flag_ma {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1e6.png");
}

.e1a-flag_mz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1ff.png");
}

.e1a-rel-flag_mz {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1ff.png");
}

.e1a-flag_mm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f2.png");
}

.e1a-rel-flag_mm {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f2.png");
}

.e1a-flag_na {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1e6.png");
}

.e1a-rel-flag_na {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1e6.png");
}

.e1a-flag_nr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1f7.png");
}

.e1a-rel-flag_nr {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1f7.png");
}

.e1a-flag_np {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1f5.png");
}

.e1a-rel-flag_np {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1f5.png");
}

.e1a-flag_nl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1f1.png");
}

.e1a-rel-flag_nl {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1f1.png");
}

.e1a-flag_nc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1e8.png");
}

.e1a-rel-flag_nc {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1e8.png");
}

.e1a-flag_nz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1ff.png");
}

.e1a-rel-flag_nz {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1ff.png");
}

.e1a-flag_ni {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1ee.png");
}

.e1a-rel-flag_ni {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1ee.png");
}

.e1a-flag_ne {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1ea.png");
}

.e1a-rel-flag_ne {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1ea.png");
}

.e1a-flag_ng {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1ec.png");
}

.e1a-rel-flag_ng {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1ec.png");
}

.e1a-flag_nu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1fa.png");
}

.e1a-rel-flag_nu {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1fa.png");
}

.e1a-flag_nf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1eb.png");
}

.e1a-rel-flag_nf {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1eb.png");
}

.e1a-flag_kp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1f5.png");
}

.e1a-rel-flag_kp {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1f5.png");
}

.e1a-flag_mp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1f5.png");
}

.e1a-rel-flag_mp {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1f5.png");
}

.e1a-flag_no {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f3-1f1f4.png");
}

.e1a-rel-flag_no {
  background-image: url("emojione/assets/4.5/png/128/1f1f3-1f1f4.png");
}

.e1a-flag_om {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f4-1f1f2.png");
}

.e1a-rel-flag_om {
  background-image: url("emojione/assets/4.5/png/128/1f1f4-1f1f2.png");
}

.e1a-flag_pk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f0.png");
}

.e1a-rel-flag_pk {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f0.png");
}

.e1a-flag_pw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1fc.png");
}

.e1a-rel-flag_pw {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1fc.png");
}

.e1a-flag_ps {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f8.png");
}

.e1a-rel-flag_ps {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f8.png");
}

.e1a-flag_pa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1e6.png");
}

.e1a-rel-flag_pa {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1e6.png");
}

.e1a-flag_pg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1ec.png");
}

.e1a-rel-flag_pg {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1ec.png");
}

.e1a-flag_py {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1fe.png");
}

.e1a-rel-flag_py {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1fe.png");
}

.e1a-flag_pe {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1ea.png");
}

.e1a-rel-flag_pe {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1ea.png");
}

.e1a-flag_ph {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1ed.png");
}

.e1a-rel-flag_ph {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1ed.png");
}

.e1a-flag_pn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f3.png");
}

.e1a-rel-flag_pn {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f3.png");
}

.e1a-flag_pl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f1.png");
}

.e1a-rel-flag_pl {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f1.png");
}

.e1a-flag_pt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f9.png");
}

.e1a-rel-flag_pt {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f9.png");
}

.e1a-flag_pr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f7.png");
}

.e1a-rel-flag_pr {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f7.png");
}

.e1a-flag_qa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f6-1f1e6.png");
}

.e1a-rel-flag_qa {
  background-image: url("emojione/assets/4.5/png/128/1f1f6-1f1e6.png");
}

.e1a-flag_re {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7-1f1ea.png");
}

.e1a-rel-flag_re {
  background-image: url("emojione/assets/4.5/png/128/1f1f7-1f1ea.png");
}

.e1a-flag_ro {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7-1f1f4.png");
}

.e1a-rel-flag_ro {
  background-image: url("emojione/assets/4.5/png/128/1f1f7-1f1f4.png");
}

.e1a-flag_ru {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7-1f1fa.png");
}

.e1a-rel-flag_ru {
  background-image: url("emojione/assets/4.5/png/128/1f1f7-1f1fa.png");
}

.e1a-flag_rw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7-1f1fc.png");
}

.e1a-rel-flag_rw {
  background-image: url("emojione/assets/4.5/png/128/1f1f7-1f1fc.png");
}

.e1a-flag_ws {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fc-1f1f8.png");
}

.e1a-rel-flag_ws {
  background-image: url("emojione/assets/4.5/png/128/1f1fc-1f1f8.png");
}

.e1a-flag_sm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f2.png");
}

.e1a-rel-flag_sm {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f2.png");
}

.e1a-flag_st {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f9.png");
}

.e1a-rel-flag_st {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f9.png");
}

.e1a-flag_sa {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1e6.png");
}

.e1a-rel-flag_sa {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1e6.png");
}

.e1a-flag_sn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f3.png");
}

.e1a-rel-flag_sn {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f3.png");
}

.e1a-flag_rs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f7-1f1f8.png");
}

.e1a-rel-flag_rs {
  background-image: url("emojione/assets/4.5/png/128/1f1f7-1f1f8.png");
}

.e1a-flag_sc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1e8.png");
}

.e1a-rel-flag_sc {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1e8.png");
}

.e1a-flag_sl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f1.png");
}

.e1a-rel-flag_sl {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f1.png");
}

.e1a-flag_sg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ec.png");
}

.e1a-rel-flag_sg {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ec.png");
}

.e1a-flag_sx {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1fd.png");
}

.e1a-rel-flag_sx {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1fd.png");
}

.e1a-flag_sk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f0.png");
}

.e1a-rel-flag_sk {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f0.png");
}

.e1a-flag_si {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ee.png");
}

.e1a-rel-flag_si {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ee.png");
}

.e1a-flag_gs {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1f8.png");
}

.e1a-rel-flag_gs {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1f8.png");
}

.e1a-flag_sb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1e7.png");
}

.e1a-rel-flag_sb {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1e7.png");
}

.e1a-flag_so {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f4.png");
}

.e1a-rel-flag_so {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f4.png");
}

.e1a-flag_za {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ff-1f1e6.png");
}

.e1a-rel-flag_za {
  background-image: url("emojione/assets/4.5/png/128/1f1ff-1f1e6.png");
}

.e1a-flag_kr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1f7.png");
}

.e1a-rel-flag_kr {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1f7.png");
}

.e1a-flag_ss {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f8.png");
}

.e1a-rel-flag_ss {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f8.png");
}

.e1a-flag_es {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1f8.png");
}

.e1a-rel-flag_es {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1f8.png");
}

.e1a-flag_lk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1f0.png");
}

.e1a-rel-flag_lk {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1f0.png");
}

.e1a-flag_bl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1f1.png");
}

.e1a-rel-flag_bl {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1f1.png");
}

.e1a-flag_sh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ed.png");
}

.e1a-rel-flag_sh {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ed.png");
}

.e1a-flag_kn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f0-1f1f3.png");
}

.e1a-rel-flag_kn {
  background-image: url("emojione/assets/4.5/png/128/1f1f0-1f1f3.png");
}

.e1a-flag_lc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f1-1f1e8.png");
}

.e1a-rel-flag_lc {
  background-image: url("emojione/assets/4.5/png/128/1f1f1-1f1e8.png");
}

.e1a-flag_pm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f5-1f1f2.png");
}

.e1a-rel-flag_pm {
  background-image: url("emojione/assets/4.5/png/128/1f1f5-1f1f2.png");
}

.e1a-flag_vc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1e8.png");
}

.e1a-rel-flag_vc {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1e8.png");
}

.e1a-flag_sd {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1e9.png");
}

.e1a-rel-flag_sd {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1e9.png");
}

.e1a-flag_sr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1f7.png");
}

.e1a-rel-flag_sr {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1f7.png");
}

.e1a-flag_sz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ff.png");
}

.e1a-rel-flag_sz {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ff.png");
}

.e1a-flag_se {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ea.png");
}

.e1a-rel-flag_se {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ea.png");
}

.e1a-flag_ch {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1ed.png");
}

.e1a-rel-flag_ch {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1ed.png");
}

.e1a-flag_sy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1fe.png");
}

.e1a-rel-flag_sy {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1fe.png");
}

.e1a-flag_tw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1fc.png");
}

.e1a-rel-flag_tw {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1fc.png");
}

.e1a-flag_tj {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1ef.png");
}

.e1a-rel-flag_tj {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1ef.png");
}

.e1a-flag_tz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1ff.png");
}

.e1a-rel-flag_tz {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1ff.png");
}

.e1a-flag_th {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1ed.png");
}

.e1a-rel-flag_th {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1ed.png");
}

.e1a-flag_tl {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f1.png");
}

.e1a-rel-flag_tl {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f1.png");
}

.e1a-flag_tg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1ec.png");
}

.e1a-rel-flag_tg {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1ec.png");
}

.e1a-flag_tk {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f0.png");
}

.e1a-rel-flag_tk {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f0.png");
}

.e1a-flag_to {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f4.png");
}

.e1a-rel-flag_to {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f4.png");
}

.e1a-flag_tt {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f9.png");
}

.e1a-rel-flag_tt {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f9.png");
}

.e1a-flag_tn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f3.png");
}

.e1a-rel-flag_tn {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f3.png");
}

.e1a-flag_tr {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f7.png");
}

.e1a-rel-flag_tr {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f7.png");
}

.e1a-flag_tm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1f2.png");
}

.e1a-rel-flag_tm {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1f2.png");
}

.e1a-flag_tc {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1e8.png");
}

.e1a-rel-flag_tc {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1e8.png");
}

.e1a-flag_vi {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1ee.png");
}

.e1a-rel-flag_vi {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1ee.png");
}

.e1a-flag_tv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1fb.png");
}

.e1a-rel-flag_tv {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1fb.png");
}

.e1a-flag_ug {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1ec.png");
}

.e1a-rel-flag_ug {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1ec.png");
}

.e1a-flag_ua {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1e6.png");
}

.e1a-rel-flag_ua {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1e6.png");
}

.e1a-flag_ae {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1ea.png");
}

.e1a-rel-flag_ae {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1ea.png");
}

.e1a-flag_gb {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ec-1f1e7.png");
}

.e1a-rel-flag_gb {
  background-image: url("emojione/assets/4.5/png/128/1f1ec-1f1e7.png");
}

.e1a-england {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0065-e006e-e0067-e007f.png");
}

.e1a-rel-england {
  background-image: url("emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0065-e006e-e0067-e007f.png");
}

.e1a-scotland {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0073-e0063-e0074-e007f.png");
}

.e1a-rel-scotland {
  background-image: url("emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0073-e0063-e0074-e007f.png");
}

.e1a-wales {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0077-e006c-e0073-e007f.png");
}

.e1a-rel-wales {
  background-image: url("emojione/assets/4.5/png/128/1f3f4-e0067-e0062-e0077-e006c-e0073-e007f.png");
}

.e1a-flag_us {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1f8.png");
}

.e1a-rel-flag_us {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1f8.png");
}

.e1a-flag_uy {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1fe.png");
}

.e1a-rel-flag_uy {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1fe.png");
}

.e1a-flag_uz {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1ff.png");
}

.e1a-rel-flag_uz {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1ff.png");
}

.e1a-flag_vu {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1fa.png");
}

.e1a-rel-flag_vu {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1fa.png");
}

.e1a-flag_va {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1e6.png");
}

.e1a-rel-flag_va {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1e6.png");
}

.e1a-flag_ve {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1ea.png");
}

.e1a-rel-flag_ve {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1ea.png");
}

.e1a-flag_vn {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fb-1f1f3.png");
}

.e1a-rel-flag_vn {
  background-image: url("emojione/assets/4.5/png/128/1f1fb-1f1f3.png");
}

.e1a-flag_wf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fc-1f1eb.png");
}

.e1a-rel-flag_wf {
  background-image: url("emojione/assets/4.5/png/128/1f1fc-1f1eb.png");
}

.e1a-flag_eh {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1ed.png");
}

.e1a-rel-flag_eh {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1ed.png");
}

.e1a-flag_ye {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fe-1f1ea.png");
}

.e1a-rel-flag_ye {
  background-image: url("emojione/assets/4.5/png/128/1f1fe-1f1ea.png");
}

.e1a-flag_zm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ff-1f1f2.png");
}

.e1a-rel-flag_zm {
  background-image: url("emojione/assets/4.5/png/128/1f1ff-1f1f2.png");
}

.e1a-flag_zw {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ff-1f1fc.png");
}

.e1a-rel-flag_zw {
  background-image: url("emojione/assets/4.5/png/128/1f1ff-1f1fc.png");
}

.e1a-flag_ac {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e6-1f1e8.png");
}

.e1a-rel-flag_ac {
  background-image: url("emojione/assets/4.5/png/128/1f1e6-1f1e8.png");
}

.e1a-flag_bv {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e7-1f1fb.png");
}

.e1a-rel-flag_bv {
  background-image: url("emojione/assets/4.5/png/128/1f1e7-1f1fb.png");
}

.e1a-flag_cp {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e8-1f1f5.png");
}

.e1a-rel-flag_cp {
  background-image: url("emojione/assets/4.5/png/128/1f1e8-1f1f5.png");
}

.e1a-flag_ea {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ea-1f1e6.png");
}

.e1a-rel-flag_ea {
  background-image: url("emojione/assets/4.5/png/128/1f1ea-1f1e6.png");
}

.e1a-flag_dg {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1e9-1f1ec.png");
}

.e1a-rel-flag_dg {
  background-image: url("emojione/assets/4.5/png/128/1f1e9-1f1ec.png");
}

.e1a-flag_hm {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1ed-1f1f2.png");
}

.e1a-rel-flag_hm {
  background-image: url("emojione/assets/4.5/png/128/1f1ed-1f1f2.png");
}

.e1a-flag_mf {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f2-1f1eb.png");
}

.e1a-rel-flag_mf {
  background-image: url("emojione/assets/4.5/png/128/1f1f2-1f1eb.png");
}

.e1a-flag_sj {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f8-1f1ef.png");
}

.e1a-rel-flag_sj {
  background-image: url("emojione/assets/4.5/png/128/1f1f8-1f1ef.png");
}

.e1a-flag_ta {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1f9-1f1e6.png");
}

.e1a-rel-flag_ta {
  background-image: url("emojione/assets/4.5/png/128/1f1f9-1f1e6.png");
}

.e1a-flag_um {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1f2.png");
}

.e1a-rel-flag_um {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1f2.png");
}

.e1a-united_nations {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f1fa-1f1f3.png");
}

.e1a-rel-united_nations {
  background-image: url("emojione/assets/4.5/png/128/1f1fa-1f1f3.png");
}

.e1a-tone1 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3fb.png");
}

.e1a-rel-tone1 {
  background-image: url("emojione/assets/4.5/png/128/1f3fb.png");
}

.e1a-tone2 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3fc.png");
}

.e1a-rel-tone2 {
  background-image: url("emojione/assets/4.5/png/128/1f3fc.png");
}

.e1a-tone3 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3fd.png");
}

.e1a-rel-tone3 {
  background-image: url("emojione/assets/4.5/png/128/1f3fd.png");
}

.e1a-tone4 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3fe.png");
}

.e1a-rel-tone4 {
  background-image: url("emojione/assets/4.5/png/128/1f3fe.png");
}

.e1a-tone5 {
  background-image: url("https://cdn.jsdelivr.net/emojione/assets/4.5/png/128/1f3ff.png");
}

.e1a-rel-tone5 {
  background-image: url("emojione/assets/4.5/png/128/1f3ff.png");
}

/*# sourceMappingURL=emojione-awesome.css.map */
